@@ -77,6 +77,11 @@ class NFeGenerator(object):
     """
     def __init__(self, sale, conn):
         self._sale = sale
+
+        # Fetch the ids so we can override them in the tests
+        self.sale_id = sale.id
+        self.payment_ids = [p.id for p in self._sale.payments]
+
         self.conn = conn
         self.root = ElementTree.Element(
             'NFe', xmlns='http://www.portalfiscal.inf.br/nfe')
@@ -107,7 +112,7 @@ class NFeGenerator(object):
         # ignore the NFe prefix
         name = "%s-nfe.xml" % data_id[3:]
         filename = os.path.join(location, name)
-        fp = open(filename, 'w')
+        fp = open(filename, 'wb')
         fp.write(nfe_tostring(self.root))
         fp.close()
 
@@ -123,7 +128,7 @@ class NFeGenerator(object):
         # ignore the NFe prefix
         name = "%s-nfe.txt" % data_id[3:]
         filename = os.path.join(location, name)
-        fp = open(filename, 'w')
+        fp = open(filename, 'wb')
         # we need to remove the accentuation to avoid import errors from
         # external applications.
         fp.write(strip_accents(self._as_txt()))
@@ -320,13 +325,13 @@ class NFeGenerator(object):
         sale_total = self._sale.get_total_sale_amount()
         items_total = self._sale.get_sale_subtotal()
 
-        fat = NFeInvoice(self._sale.id, items_total,
+        fat = NFeInvoice(self.sale_id, items_total,
                          self._sale.discount_value, sale_total)
         self._nfe_data.append(fat)
 
         payments = self._sale.payments
-        for p in payments:
-            dup = NFeDuplicata(p.id, p.due_date, p.value)
+        for i, p in enumerate(payments):
+            dup = NFeDuplicata(self.payment_ids[i], p.due_date, p.value)
             self._nfe_data.append(dup)
 
     def _add_additional_information(self):
@@ -955,6 +960,15 @@ class BaseNFeICMS(BaseNFeXMLGroup):
         'vCredICMSSN': ('v_cred_icms_sn', 2),
         'vBCSTRet': ('v_bc_st_ret', 2),
         'vICMSSTRet': ('v_icms_st_ret', 2),
+
+        # This are not supported but still need to be here, so they are included
+        # in the exported txt.
+        'motDesICMS': ('mot_des_icms', None),
+        'UFST': ('ufst', None),
+        'pBCOp': ('p_bc_op', 2),
+        'vBCSTDest': ('v_bc_st_dest', 2),
+        'vICMSSTDest': ('v_icms_st_dest', 2),
+
     }
 
     def __init__(self, sale_icms_info):
