@@ -44,6 +44,10 @@ class StoqCommandHandler:
         if create:
             config.create()
 
+        # FIXME: This should be removed and we should just import
+        #        the global settings after fixing StoqConfig to
+        #        only update the global settings.
+        self._db_settings = config.get_settings()
         setup(config, options, register_station=register_station,
               check_schema=check_schema, load_plugins=load_plugins)
         return config
@@ -142,6 +146,18 @@ class StoqCommandHandler:
                                    load_plugins=False)
 
         from stoqlib.database.admin import initialize_system
+        from stoqlib.database.settings import db_settings
+        if options.dbname:
+            db_settings.dbname = options.dbname
+        if options.address:
+            db_settings.address = options.address
+        if options.port:
+            db_settings.port = options.port
+        if options.username:
+            db_settings.username = options.username
+        if options.password:
+            db_settings.password = options.password
+
         initialize_system(password=options.password or config.get_password(),
                           force=options.force)
 
@@ -344,13 +360,12 @@ class StoqCommandHandler:
 
     def cmd_dump(self, options, output):
         """Create a database dump"""
-        from stoqlib.database.database import dump_database
         self._read_config(options)
 
         if output == '-':
             output = None
-        dump_database(output, gzip=options.gzip,
-                      format=options.format)
+        self._db_settings.dump_database(output, gzip=options.gzip,
+                                        format=options.format)
 
     def opt_dump(self, parser, group):
         group.add_option('-z', '--gzip',
@@ -364,11 +379,9 @@ class StoqCommandHandler:
 
     def cmd_restore(self, options, schema):
         """Restore a database dump"""
-        from stoqlib.database.database import execute_sql
-
         self._read_config(options, register_station=False,
                           check_schema=False)
-        execute_sql(schema)
+        self._db_settings.execute_sql(schema)
 
     def cmd_enable_plugin(self, options, plugin_name):
         """Enable a plugin on Stoq"""
@@ -396,10 +409,9 @@ class StoqCommandHandler:
 
     def cmd_shell(self, options):
         """Drop to a shell for executing SQL queries"""
-        from stoqlib.database.database import start_shell
         self._read_config(options, register_station=False,
                           check_schema=False)
-        start_shell(options.command)
+        self._db_settings.start_shell(options.command)
 
     def opt_shell(self, parser, group):
         group.add_option('-c', '--command',
