@@ -35,14 +35,14 @@ from stoqlib.domain.invoice import InvoiceLayout
 from stoqlib.gui.dialogs.clientcategorydialog import ClientCategoryDialog
 from stoqlib.gui.dialogs.devices import DeviceSettingsDialog
 from stoqlib.gui.editors.formfieldeditor import FormFieldEditor
+from stoqlib.gui.dialogs.invoicedialog import (InvoiceLayoutDialog,
+                                               InvoicePrinterDialog)
 from stoqlib.gui.dialogs.paymentcategorydialog import PaymentCategoryDialog
 from stoqlib.gui.dialogs.paymentmethod import PaymentMethodsDialog
 from stoqlib.gui.dialogs.pluginsdialog import PluginManagerDialog
+from stoqlib.gui.dialogs.sellabledialog import SellableTaxConstantsDialog
 from stoqlib.gui.dialogs.sintegradialog import SintegraDialog
-from stoqlib.gui.editors.invoiceeditor import (InvoiceLayoutDialog,
-                                               InvoicePrinterDialog)
 from stoqlib.gui.editors.personeditor import UserEditor
-from stoqlib.gui.editors.sellableeditor import SellableTaxConstantsDialog
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.eventsearch import EventSearch
 from stoqlib.gui.search.fiscalsearch import CfopSearch, FiscalBookEntrySearch
@@ -63,7 +63,9 @@ from stoqlib.gui.stockicons import (
     STOQ_PAYABLE_APP, STOQ_PLUGIN, STOQ_SUPPLIERS, STOQ_SYSTEM, STOQ_TAXES,
     STOQ_USER_PROFILES, STOQ_USERS)
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
+from stoqlib.lib.decorators import public
 from stoqlib.lib.message import info
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.translation import locale_sorted
 
 from stoq.gui.application import AppWindow
@@ -117,6 +119,7 @@ class Tasks(object):
             items, key=operator.itemgetter(0)):
             self.add_item(label, name, pixbuf)
 
+    @public(since="1.5.0")
     def add_item(self, label, name, pixbuf=None, cb=None):
         """
         @param label: Label to show in the interface
@@ -125,10 +128,13 @@ class Tasks(object):
         @param cb: callback
         """
         if type(pixbuf) == str:
+            stock_id = pixbuf
             try:
                 pixbuf = self.theme.load_icon(pixbuf, 32, 0)
             except glib.GError:
                 pixbuf = self.app.get_toplevel().render_icon(pixbuf, gtk.ICON_SIZE_DIALOG)
+            if pixbuf is not None:
+                pixbuf.stock_id = stock_id
         self.model.append([label, name, pixbuf])
         if cb is not None:
             setattr(self, '_open_' + name, cb)
@@ -291,6 +297,12 @@ class AdminApp(AppWindow):
         'ConfigurePlugins': 'plugins',
     }
 
+    action_permissions = {
+        'ConfigureInvoices': ('InvoiceLayout', PermissionManager.PERM_SEARCH),
+        'ConfigureInvoicePrinters': ('InvoicePrinter', PermissionManager.PERM_SEARCH),
+        'SearchTaxTemplate': ('ProductTaxTemplate', PermissionManager.PERM_SEARCH),
+    }
+
     #
     # Application
     #
@@ -354,10 +366,12 @@ class AdminApp(AppWindow):
         self.iconview.connect('item-activated', self.tasks.on_item_activated)
         self.iconview.select_path(self.model[0].path)
 
-        # Connect releated actions and tasks
+        # Connect releated actions and tasks and hide task if action is hidden
         for action_name, task in self.ACTION_TASKS.items():
             action = getattr(self, action_name)
             action.connect('activate', self._on_action__activate, task)
+            if not action.get_visible():
+                self.tasks.hide_item(task)
 
     def activate(self, params):
         # Admin app doesn't have anything to print/export
