@@ -45,6 +45,7 @@ from stoqlib.lib.decorators import cached_function
 from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.message import yesno
 from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.webservice import WebService
 from stoqlib.gui.base.dialogs import (get_dialog, run_dialog,
                                       get_current_toplevel)
@@ -155,7 +156,7 @@ class App(object):
     """Class for application control. """
 
     def __init__(self, window_class, config, options, shell, embedded,
-                 launcher, name):
+                 launcher, name, conn=None):
         """
         Create a new object App.
 
@@ -173,7 +174,7 @@ class App(object):
 
         # The self should be passed to main_window to let it access
         # shutdown and do_sync methods.
-        self.main_window = window_class(self)
+        self.main_window = window_class(self, conn=conn)
 
     def show(self, params=None):
         if self.embedded:
@@ -207,13 +208,32 @@ class AppWindow(GladeDelegate):
     title = ''
     size = ()
 
-    def __init__(self, app, keyactions=None):
+    #: This dictionary holds information about required permissions to access
+    #: certain actions. Keys should be the name of the action (for instance
+    #: SearchEmployess), and the value should be a tuple with the permission key
+    #: (domain object or action identifier) and the required permission. In this
+    #: case: ('Employee', perm.PERM_SEARCH). See <stoqlib.lib.permissions>
+    action_permissions = {}
+
+    # FIXME: we should have a common structure for all information regarding
+    # Actions
+    common_action_permissions = {
+        'HelpChat': ('app.common.help_chat', PermissionManager.PERM_ACCESS),
+        'HelpTranslate': ('app.common.help_translate', PermissionManager.PERM_ACCESS),
+        'HelpContents': ('app.common.help_contents', PermissionManager.PERM_ACCESS),
+        'HelpSupport': ('app.common.help_support', PermissionManager.PERM_ACCESS),
+        'HelpHelp': ('app.common.help', PermissionManager.PERM_ACCESS),
+    }
+
+    def __init__(self, app, keyactions=None, conn=None):
+        if conn is None:
+            conn = api.get_connection()
         self._action_groups = {}
         self._osx_app = None
         self._sensitive_group = dict()
         self._tool_items = []
         self.app = app
-        self.conn = api.get_connection()
+        self.conn = conn
         self.current_app = None
         self.current_app_widget = None
         self.uimanager = None
@@ -314,14 +334,15 @@ class AppWindow(GladeDelegate):
         if not stoq.stable and not api.is_developer_mode():
             self._display_unstable_version_message()
 
-        # Initial fullscreen state for launcher must be handled
-        # separate since the window is not realized when the state loading
-        # is run in hide_app() the first time.
-        window = self.get_toplevel()
-        window.realize()
-        self.ToggleFullscreen.set_active(
-            self._app_settings.get('show-fullscreen', False))
-        self.ToggleFullscreen.notify('active')
+        if not self.app.in_ui_test:
+            # Initial fullscreen state for launcher must be handled
+            # separate since the window is not realized when the state loading
+            # is run in hide_app() the first time.
+            window = self.get_toplevel()
+            window.realize()
+            self.ToggleFullscreen.set_active(
+                self._app_settings.get('show-fullscreen', False))
+            self.ToggleFullscreen.notify('active')
 
     def _create_shared_actions(self):
         if self.app.name != 'launcher':
@@ -879,8 +900,22 @@ class AppWindow(GladeDelegate):
         if filename is not None:
             ui_string = environ.get_resource_string('stoq', 'uixml', filename)
         ui_id = self.uimanager.add_ui_from_string(ui_string)
+
+        self.action_permissions.update(self.common_action_permissions)
+        pm = PermissionManager.get_permission_manager()
         for action in ag.list_actions():
-            setattr(self, action.get_name(), action)
+            action_name = action.get_name()
+            setattr(self, action_name, action)
+
+            # Check permissions
+            key, required = self.action_permissions.get(action_name,
+                                                        (None, pm.PERM_ALL))
+            if not pm.get(key) & required:
+                action.set_visible(False)
+                # Disable keyboard shortcut
+                path = action.get_accel_path()
+                gtk.accel_map_change_entry(path, 0, 0, True)
+
         return ui_id
 
     def add_tool_menu_actions(self, actions):
@@ -1029,15 +1064,16 @@ class AppWindow(GladeDelegate):
 
         self.get_toplevel().set_title(app.get_title())
         self.application_box.show()
+        app.toplevel = self.get_toplevel()
         app.activate(params or {})
 
         self.uimanager.ensure_update()
         self.current_app = app
         self.current_widget = app_window
-        while gtk.events_pending():
-            gtk.main_iteration()
-        app_window.show()
-        app.toplevel = self.get_toplevel()
+        if not self.app.in_ui_test:
+            while gtk.events_pending():
+                gtk.main_iteration()
+            app_window.show()
         app.setup_focus()
 
     def hide_app(self):
@@ -1363,14 +1399,15 @@ class SearchableAppWindow(AppWindow):
     #: the report class for printing the object list embedded on app.
     report_table = None
 
-    def __init__(self, app):
+    def __init__(self, app, conn=None):
         if self.search_table is None:
             raise TypeError("%r must define a search_table attribute" % self)
 
         self._loading_filters = False
 
-        conn = api.get_connection()
-        self.executer = ORMObjectQueryExecuter()
+        if conn is None:
+            conn = api.get_connection()
+        self.executer = ORMObjectQueryExecuter(conn)
         # FIXME: Remove this limit, but we need to migrate all existing
         #        searches to use lazy lists first. That in turn require
         #        us to rewrite the queries in such a way that count(*)
@@ -1387,7 +1424,7 @@ class SearchableAppWindow(AppWindow):
         self.results = self.search.search.results
         self.set_text_field_label(self.search_label)
 
-        AppWindow.__init__(self, app)
+        AppWindow.__init__(self, app, conn=conn)
         self.attach_slave('search_holder', self.search)
 
         self.create_filters()
@@ -1424,7 +1461,15 @@ class SearchableAppWindow(AppWindow):
         else:
             result = self.results.get_selected()
             results = [result] if result else None
-        results = results or list(self.results)
+
+        # There are no itens selected. We should print the entire list
+        if not results:
+            # We are using the lazy updater.
+            # FIXME: Kiwi should have an api to do this
+            if self.search.search._lazy_updater:
+                results = list(self.search.search._lazy_updater._model._result)
+            else:
+                results = list(self.results)
 
         self.print_report(self.report_table, self.results, results,
                           do_footer=False)
