@@ -64,10 +64,9 @@ from stoqlib.api import api
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.database.admin import (USER_ADMIN_DEFAULT_NAME, ensure_admin_user,
                                     create_default_profile_settings)
-from stoqlib.database.database import test_local_database
 from stoqlib.database.interfaces import (ICurrentBranchStation,
                                          ICurrentBranch)
-from stoqlib.database.settings import DatabaseSettings
+from stoqlib.database.settings import DatabaseSettings, test_local_database
 from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
 from stoqlib.domain.system import SystemTable
@@ -80,8 +79,8 @@ from stoqlib.gui.processview import ProcessView
 from stoqlib.lib.configparser import StoqConfig
 from stoqlib.lib.formatters import raw_phone_number
 from stoqlib.lib.kiwilibrary import library
-from stoqlib.lib.message import warning, yesno
-from stoqlib.lib.osutils import read_registry_key
+from stoqlib.lib.message import error, warning, yesno
+from stoqlib.lib.osutils import get_product_key, read_registry_key
 from stoqlib.lib.validators import validate_email
 from stoqlib.lib.webservice import WebService
 from twisted.internet import reactor
@@ -497,6 +496,8 @@ class StoqAdminPasswordStep(PasswordStep):
     #
 
     def validate_step(self):
+        # FIXME: self.password_slave os not implementing any
+        #        validate_confirm, so, this check is useless.
         good_pass = self.password_slave.validate_confirm()
         if good_pass:
             self.wizard.options.login_username = 'admin'
@@ -785,6 +786,13 @@ class FinishInstallationStep(BaseWizardStep):
             self.online_services.hide()
             self.online_info.hide()
 
+        # If you have a ProductKey you are required to enable online
+        # services
+        if get_product_key():
+            self.online_services.hide()
+            self.online_info.hide()
+            self.online_services.set_active(True)
+
     def _cancel(self):
         # This is the last step, so we will finish the installation
         # before we quit
@@ -883,9 +891,15 @@ class FirstTimeConfigWizard(BaseWizard):
     # Public API
 
     def get_win32_postgres_port(self):
-        return read_registry_key(
-            'HKLM', r'Software\PostgreSQL\Services\postgresql-8.4',
-            'Port')
+        for v in ['9.2', '9.1', '9.0', '8.4']:
+            key = read_registry_key(
+                'HKLM', r'Software\PostgreSQL\Services\postgresql-%s' % (v, ),
+                'Port')
+            if key:
+                return key
+
+        # Default port
+        return 5432
 
     def try_connect(self, settings, warn=True):
         logger.info('try_connect (warn=%s)' % (warn))
@@ -962,11 +976,15 @@ class FirstTimeConfigWizard(BaseWizard):
         parser = get_option_parser()
         db_options, unused_args = parser.parse_args(dbargs)
         self.config.set_from_options(db_options)
-        setup(self.config,
-              options=self.options,
-              check_schema=True,
-              register_station=False,
-              load_plugins=False)
+        try:
+            setup(self.config,
+                  options=self.options,
+                  check_schema=True,
+                  register_station=False,
+                  load_plugins=False)
+        except DatabaseInconsistency as err:
+            error(_('The database version differs from your installed '
+                    'version.'), str(err))
 
     def connect_for_settings(self, step):
         # Try to connect, we don't care if we can connect,
@@ -1010,20 +1028,26 @@ class FirstTimeConfigWizard(BaseWizard):
         else:
             lines = []
 
-        line = '%s:%s:%s:%s:%s' % (self.settings.address,
-                                   self.settings.port,
-                                   self.settings.dbname,
-                                   self.settings.username,
-                                   self.settings.password)
-        if line in lines:
-            return
+        # _get_connection_internal connects to the 'postgres' database,
+        # we need to allow connections without asking the password,
+        # otherwise stoqdbadmin will be stuck in the wizard when creating
+        # a new database.
+        for dbname in ['postgres', self.settings.dbname]:
+            line = '%s:%s:%s:%s:%s' % (self.settings.address,
+                                       self.settings.port,
+                                       dbname,
+                                       self.settings.username,
+                                       self.settings.password)
+            if line in lines:
+                continue
+            lines.append(line)
 
-        lines.append(line)
         if not os.path.exists(directory):
             os.makedirs(directory)
         fd = open(pgpass, 'w')
         fd.write('\n'.join(lines))
         fd.write('\n')
+        fd.close()
         os.chmod(pgpass, 0600)
 
     #
