@@ -38,7 +38,7 @@ from kiwi.currency import currency
 from kiwi.db.query import DateQueryState, DateIntervalQueryState
 from kiwi.python import Settable
 from kiwi.ui.dialogs import open as open_dialog
-from kiwi.ui.objectlist import ColoredColumn, Column, ObjectList
+from kiwi.ui.objectlist import ColoredColumn, Column, SearchColumn, ObjectList
 from kiwi.ui.search import Any, DateSearchFilter, DateSearchOption, SearchContainer
 from stoqlib.api import api
 from stoqlib.database.orm import const, OR, AND
@@ -54,7 +54,7 @@ from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
-from stoqlib.lib.dateconstants import get_month_names
+from stoqlib.lib.dateutils import get_month_names
 from stoqlib.lib.message import yesno
 from stoqlib.reporting.payment import AccountTransactionReport
 
@@ -124,13 +124,14 @@ class TransactionPage(object):
     def _create_search(self):
         self.search = TransactionSearchContainer(
             self, columns=self._get_columns(self.model.kind))
-        self.query = ORMObjectQueryExecuter()
+        self.query = ORMObjectQueryExecuter(self.app.conn)
         self.search.set_query_executer(self.query)
         self.search.results.connect('row-activated', self._on_row__activated)
         self.results = self.search.results
         tree_view = self.search.results.get_treeview()
         tree_view.set_rules_hint(True)
         tree_view.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
+        self.search.enable_advanced_search()
 
     def _add_date_filter(self):
         self.date_filter = DateSearchFilter(_('Date:'))
@@ -153,22 +154,25 @@ class TransactionPage(object):
         date = self.date_filter.get_state()
         queries = []
         if isinstance(date, DateQueryState) and date.date is not None:
-            queries.append(field == date.date)
+            queries.append(const.DATE(field) == date.date)
         elif isinstance(date, DateIntervalQueryState):
             queries.append(const.DATE(field) >= date.start)
             queries.append(const.DATE(field) <= date.end)
         return queries
 
     def _payment_query(self, query, having, conn):
-        queries = []
-        queries.extend(self._append_date_query(self.query.table.q.due_date))
+        queries = self._append_date_query(self.query.table.q.due_date)
         if query:
             queries.append(query)
-        return self.query.table.select(AND(*queries), connection=conn)
+
+        query = AND(*queries)
+        if not queries:
+            query = None
+        return self.query.table.select(query, connection=conn)
 
     def _transaction_query(self, query, having, conn):
-        queries = [OR(self.model.id == AccountTransaction.q.accountID,
-                      self.model.id == AccountTransaction.q.source_accountID)]
+        queries = [OR(self.model.id == AccountTransaction.q.account_id,
+                      self.model.id == AccountTransaction.q.source_account_id)]
 
         queries.extend(self._append_date_query(AccountTransaction.q.date))
 
@@ -244,11 +248,11 @@ class TransactionPage(object):
                               data_func=color_func)]
 
     def _get_payment_columns(self):
-        return [Column('due_date', title=_("Due date"), data_type=datetime.date, sorted=True),
-                Column('id', title=_("Code"), data_type=unicode),
-                Column('description', title=_("Description"), data_type=unicode, expand=True),
-                Column('value', title=_("Value"),
-                       data_type=currency)]
+        return [SearchColumn('due_date', title=_("Due date"), data_type=datetime.date, sorted=True),
+                SearchColumn('identifier', title=_("Code"), data_type=int),
+                SearchColumn('description', title=_("Description"), data_type=unicode, expand=True),
+                SearchColumn('value', title=_("Value"),
+                             data_type=currency)]
 
     def append_transactions(self, transactions):
         for transaction in transactions:
@@ -339,10 +343,10 @@ class FinancialApp(AppWindow):
     gladefile = 'financial'
     embedded = True
 
-    def __init__(self, app):
+    def __init__(self, app, conn=None):
         self._pages = {}
         self.accounts = AccountTree()
-        AppWindow.__init__(self, app)
+        AppWindow.__init__(self, app, conn=conn)
         self._tills_account = api.sysparam(self.conn).TILLS_ACCOUNT
         self._imbalance_account = api.sysparam(self.conn).IMBALANCE_ACCOUNT
         self._banks_account = api.sysparam(self.conn).BANKS_ACCOUNT
@@ -528,7 +532,7 @@ class FinancialApp(AppWindow):
             return False
 
         if (page.model == self._tills_account or
-            page.model.parentID == self._tills_account.id):
+            page.model.parent_id == self._tills_account.id):
             return False
         return True
 
