@@ -137,10 +137,10 @@ class InventoryApp(SearchableAppWindow):
             _('Show inventories at:'), self._get_branches_for_filter())
         self.add_filter(self.branch_filter,
                         position=SearchFilterPosition.TOP,
-                        columns=["branchID"])
+                        columns=["branch_id"])
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('Code'), sorted=True,
+        return [SearchColumn('identifier', title=_('Code'), sorted=True,
                        order=gtk.SORT_DESCENDING,
                        data_type=int, format='%03d', width=80),
                 SearchColumn('status_str', title=_('Status'),
@@ -241,7 +241,7 @@ class InventoryApp(SearchableAppWindow):
     def _register_product_counting(self):
         trans = api.new_transaction()
         inventory = trans.get(self.results.get_selected())
-        model = self.run_dialog(ProductCountingDialog, inventory, trans)
+        model = self.run_dialog(ProductCountingDialog, trans, inventory)
         api.finish_transaction(trans, model)
         trans.close()
         self.refresh()
@@ -250,7 +250,7 @@ class InventoryApp(SearchableAppWindow):
     def _adjust_product_quantities(self):
         trans = api.new_transaction()
         inventory = trans.get(self.results.get_selected())
-        model = self.run_dialog(ProductsAdjustmentDialog, inventory, trans)
+        model = self.run_dialog(ProductsAdjustmentDialog, trans, inventory)
         api.finish_transaction(trans, model)
         trans.close()
         self.refresh()
