@@ -48,6 +48,7 @@ class LauncherApp(object):
         self.main_window = launcher
         self.options = options
         self.name = 'launcher'
+        self.in_ui_test = False
 
 
 class Launcher(AppWindow):
@@ -55,10 +56,10 @@ class Launcher(AppWindow):
     app_name = _('Stoq')
     gladefile = 'launcher'
 
-    def __init__(self, options, shell):
+    def __init__(self, options, shell, conn=None):
         self.shell = shell
         app = LauncherApp(self, options)
-        AppWindow.__init__(self, app)
+        AppWindow.__init__(self, app, conn=conn)
 
     #
     # AppWindow
@@ -84,8 +85,9 @@ class Launcher(AppWindow):
             self.model.append([text, pixbuf, app])
 
         # FIXME: last opened application
-        self.iconview.select_path(self.model[0].path)
-        self.iconview.grab_focus()
+        if len(self.model):
+            self.iconview.select_path(self.model[0].path)
+            self.iconview.grab_focus()
 
     #
     # Public API
