@@ -28,13 +28,13 @@ from decimal import Decimal
 
 import pango
 import gtk
-from kiwi.argcheck import argcheck
 from kiwi.currency import currency
 from kiwi.datatypes import converter, ValidationError
 from kiwi.log import Logger
 from kiwi.python import Settable
 from kiwi.ui.widgets.list import Column
 from kiwi.ui.widgets.contextmenu import ContextMenu, ContextMenuItem
+
 from stoqdrivers.enum import UnitType
 from stoqlib.api import api
 from stoqlib.domain.devices import DeviceSettings
@@ -43,7 +43,9 @@ from stoqlib.domain.sale import Sale, Delivery
 from stoqlib.domain.sellable import Sellable
 from stoqlib.drivers.scale import read_scale_info
 from stoqlib.exceptions import StoqlibError, TaxError
+from stoqlib.gui.events import POSConfirmSaleEvent
 from stoqlib.lib.barcode import parse_barcode, BarcodeInfo
+from stoqlib.lib.decorators import cached_property, public
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.message import warning, info, yesno, marker
 from stoqlib.lib.pluginmanager import get_plugin_manager
@@ -57,9 +59,11 @@ from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.search.deliverysearch import DeliverySearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
-from stoqlib.gui.search.salesearch import SaleSearch, SoldItemsByBranchSearch
+from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
+                                           SoldItemsByBranchSearch)
 from stoqlib.gui.search.sellablesearch import SellableSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
+from stoqlib.gui.wizards.salereturnwizard import SaleTradeWizard
 
 from stoq.gui.application import AppWindow
 
@@ -67,12 +71,13 @@ _ = gettext.gettext
 log = Logger('stoq.pos')
 
 
-class _SaleItem(object):
+@public(since="1.5.0")
+class TemporarySaleItem(object):
     def __init__(self, sellable, quantity, price=None, notes=None):
         # Use only 3 decimal places for the quantity
         self.quantity = Decimal('%.3f' % quantity)
         self.sellable = sellable
-        self.description = sellable.description
+        self.description = sellable.get_description()
         self.unit = sellable.get_unit_description()
         self.code = sellable.code
 
@@ -83,6 +88,12 @@ class _SaleItem(object):
         self.estimated_fix_date = None
         self.notes = notes
 
+    # FIXME: Single joins dont cache de value if its None, and we use that a lot
+    # here. Add a cache until we fix SingleJoins to cache de value properly.
+    @cached_property(ttl=0)
+    def service(self):
+        return self.sellable.service
+
     @property
     def total(self):
         # Sale items are suposed to have only 2 digits, but the value price
@@ -106,8 +117,12 @@ class PosApp(AppWindow):
     gladefile = "pos"
     embedded = True
 
-    def __init__(self, app):
-        AppWindow.__init__(self, app)
+    def __init__(self, app, conn=None):
+        self._trade = None
+        self._trade_infobar = None
+
+        AppWindow.__init__(self, app, conn=conn)
+
         self._delivery = None
         self.param = api.sysparam(self.conn)
         self._coupon = None
@@ -124,6 +139,8 @@ class PosApp(AppWindow):
         group = get_accels('app.pos')
         actions = [
             # File
+            ('NewTrade', None, _('Trade...'),
+             group.get('new_trade')),
             ("TillOpen", None, _("Open Till..."),
              group.get('till_open')),
             ("TillClose", None, _("Close Till..."),
@@ -248,6 +265,19 @@ class PosApp(AppWindow):
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
+    @public(since="1.5.0")
+    def add_sale_item(self, item):
+        """Add a TemporarySaleItem item to the sale.
+
+        :param item: a `temporary item <TemporarySaleItem>` to add to the sale.
+          If the caller wants to store extra information about the sold items,
+          it can create a subclass of TemporarySaleItem and pass that class
+          here. This information will propagate when <POSConfirmSaleEvent> is
+          emitted.
+        """
+        assert isinstance(item, TemporarySaleItem)
+        self._update_added_item(item)
+
     #
     # Private
     #
@@ -326,7 +356,7 @@ class PosApp(AppWindow):
         menu.show_all()
 
     def _update_totals(self):
-        subtotal = currency(sum([item.total for item in self.sale_items]))
+        subtotal = self._get_subtotal()
         text = _(u"Total: %s") % converter.as_string(currency, subtotal)
         self.order_total_label.set_text(text)
 
@@ -346,8 +376,8 @@ class PosApp(AppWindow):
         self._reset_quantity_proxy()
         self._update_totals()
 
-    @argcheck(Sellable, bool)
-    def _update_list(self, sellable, notify_on_entry=False):
+    def _update_list(self, sellable):
+        assert isinstance(sellable, Sellable)
         try:
             sellable.check_taxes_validity()
         except TaxError as strerr:
@@ -365,8 +395,8 @@ class PosApp(AppWindow):
             info(_("It's not possible to add more than one service "
                    "at a time to an order. So, only one was added."))
 
-        sale_item = _SaleItem(sellable=sellable,
-                              quantity=quantity)
+        sale_item = TemporarySaleItem(sellable=sellable,
+                                      quantity=quantity)
         if is_service:
             with api.trans() as trans:
                 rv = self.run_dialog(ServiceItemEditor, trans, sale_item)
@@ -374,6 +404,9 @@ class PosApp(AppWindow):
                 return
         self._update_added_item(sale_item)
 
+    def _get_subtotal(self):
+        return currency(sum([item.total for item in self.sale_items]))
+
     def _get_sellable(self):
         barcode = self.barcode.get_text()
         if not barcode:
@@ -394,8 +427,8 @@ class PosApp(AppWindow):
         # If the barcode didnt match, maybe the user typed the product code
         if not sellable:
             sellable = Sellable.selectOneBy(code=barcode,
-                                        status=Sellable.STATUS_AVAILABLE,
-                                        connection=self.conn)
+                                            status=Sellable.STATUS_AVAILABLE,
+                                            connection=self.conn)
 
         # If the barcode has the price information, we need to calculate the
         # corresponding weight.
@@ -453,7 +486,8 @@ class PosApp(AppWindow):
         self.till_status_label.set_markup(text)
 
         self.set_sensitive([self.TillOpen], closed)
-        self.set_sensitive([self.TillClose], not closed or blocked)
+        self.set_sensitive([self.TillClose, self.NewTrade],
+                           not closed or blocked)
 
         self._set_sale_sensitive(not closed and not blocked)
 
@@ -469,7 +503,7 @@ class PosApp(AppWindow):
         for sale_item in self.sale_items:
             if sale_item and sale_item.sellable.product:
                 has_products = True
-            if sale_item and sale_item.sellable.service:
+            if sale_item and sale_item.service:
                 has_services = True
             if has_products and has_services:
                 break
@@ -478,8 +512,8 @@ class PosApp(AppWindow):
         sale_item = self.sale_items.get_selected()
         can_edit = bool(
             sale_item is not None and
-            sale_item.sellable.service and
-            sale_item.sellable.service != self.param.DELIVERY_SERVICE)
+            sale_item.service and
+            sale_item.service != self.param.DELIVERY_SERVICE)
         self.set_sensitive([self.edit_item_button], can_edit)
 
         self.set_sensitive((self.checkout_button,
@@ -586,7 +620,7 @@ class PosApp(AppWindow):
                 self.barcode.grab_focus()
                 return
 
-        self._update_list(sellable, notify_on_entry=True)
+        self._update_list(sellable)
         self.barcode.grab_focus()
 
     def _check_available_stock(self, storable, sellable):
@@ -607,15 +641,30 @@ class PosApp(AppWindow):
         self.set_sensitive(widgets, True)
 
         self._delivery = None
-
+        self._clear_trade()
         self._reset_quantity_proxy()
         self.barcode.set_text('')
         self._update_widgets()
 
+    def _clear_trade(self):
+        if not self._trade:
+            return
+
+        trans = self._trade.get_connection()
+        try:
+            trans.rollback()
+            trans.close()
+        except Exception:
+            # trans may have been closed on checkout
+            pass
+
+        self._trade = None
+        self._update_trade_infobar()
+
     def _edit_sale_item(self, sale_item):
-        if sale_item.sellable.service:
+        if sale_item.service:
             delivery_service = self.param.DELIVERY_SERVICE
-            if sale_item.sellable.service == delivery_service:
+            if sale_item.service == delivery_service:
                 self._edit_delivery()
                 return
             with api.trans() as trans:
@@ -676,12 +725,10 @@ class PosApp(AppWindow):
                 new_item = False
                 break
         else:
-            self._delivery_item = _SaleItem(
-                sellable=delivery_sellable,
-                quantity=1,
-                notes=delivery.notes,
-                price=delivery.price,
-                )
+            self._delivery_item = TemporarySaleItem(sellable=delivery_sellable,
+                                                    quantity=1,
+                                                    notes=delivery.notes,
+                                                    price=delivery.price)
             self._delivery_item.estimated_fix_date = delivery.estimated_fix_date
             new_item = True
 
@@ -703,18 +750,18 @@ class PosApp(AppWindow):
                     operation_nature=api.sysparam(trans).DEFAULT_OPERATION_NATURE)
 
         if self._delivery:
-            sale.client = self._delivery.client
-            sale.transporter = self._delivery.transporter
+            sale.client = trans.get(self._delivery.client)
+            sale.transporter = trans.get(self._delivery.transporter)
             delivery = Delivery(
                 connection=trans,
-                address=self._delivery.address,
-                transporter=self._delivery.transporter,
+                address=trans.get(self._delivery.address),
+                transporter=trans.get(self._delivery.transporter),
                 )
         else:
             delivery = None
 
         for fake_sale_item in self.sale_items:
-            sale_item = sale.add_sellable(fake_sale_item.sellable,
+            sale_item = sale.add_sellable(trans.get(fake_sale_item.sellable),
                                           price=fake_sale_item.price,
                                           quantity=fake_sale_item.quantity)
             sale_item.notes = fake_sale_item.notes
@@ -727,11 +774,30 @@ class PosApp(AppWindow):
 
         return sale
 
-    def _checkout(self):
+    @public(since="1.5.0")
+    def checkout(self, cancel_clear=False):
+        """Initiates the sale wizard to confirm sale.
+
+        :param cancel_clear: If cancel_clear is true, the sale will be cancelled
+          if the checkout is cancelled.
+        """
         assert len(self.sale_items) >= 1
 
-        trans = api.new_transaction()
-        sale = self._create_sale(trans)
+        if self._trade:
+            if self._get_subtotal() < self._trade.returned_total:
+                info(_("Traded value is greater than the new sale's value. "
+                       "Please add more items or return it in Sales app, "
+                       "then make a new sale"))
+                return
+
+            trans = self._trade.get_connection()
+            sale = self._create_sale(trans)
+            self._trade.new_sale = sale
+            self._trade.trade()
+        else:
+            trans = api.new_transaction()
+            sale = self._create_sale(trans)
+
         if self.param.CONFIRM_SALES_ON_TILL:
             sale.order()
             trans.commit(close=True)
@@ -739,18 +805,22 @@ class PosApp(AppWindow):
             assert self._coupon
 
             ordered = self._coupon.confirm(sale, trans)
-            if not api.finish_transaction(trans, ordered):
+            # Dont call finish_transaction here, since confirm() above did it
+            # already
+            if not ordered:
                 # FIXME: Move to TEF plugin
                 manager = get_plugin_manager()
-                if manager.is_active('tef'):
+                if manager.is_active('tef') or cancel_clear:
                     self._cancel_order(show_confirmation=False)
                 trans.close()
+                self._clear_trade()
                 return
 
             log.info("Checking out")
             trans.close()
 
         self._coupon = None
+        POSConfirmSaleEvent.emit(sale, self.sale_items[:])
         self._clear_order()
 
     def _remove_selected_item(self):
@@ -766,10 +836,25 @@ class PosApp(AppWindow):
         search_str = self.barcode.get_text()
         if search_str == '':
             if len(self.sale_items) >= 1:
-                self._checkout()
+                self.checkout()
         else:
             self._add_sale_item(search_str)
 
+    def _update_trade_infobar(self):
+        if self._trade and self._trade_infobar:
+            self._trade_infobar.show()
+        elif not self._trade and self._trade_infobar:
+            self._trade_infobar.hide()
+        elif self._trade:
+            button = gtk.Button(_("Cancel trade"))
+            button.connect('clicked', self._on_remove_trade_button__clicked)
+            value = converter.as_string(currency, self._trade.returned_total)
+            msg = _("There is a trade with value %s in progress...\n"
+                    "When checking out, it will be used as part of "
+                    "the payment.") % (value, )
+            self._trade_infobar = self.add_info_bar(gtk.MESSAGE_INFO, msg,
+                                                    action_widget=button)
+
     #
     # Coupon related
     #
@@ -783,8 +868,7 @@ class PosApp(AppWindow):
                     _("It is not possible to start a new sale if the "
                       "fiscal coupon cannot be opened."),
                     gtk.RESPONSE_YES, _("Try again"), _("Cancel sale")):
-                    #self.app.shutdown()
-                    break
+                    return None
 
         return coupon
 
@@ -818,8 +902,8 @@ class PosApp(AppWindow):
     def _close_till(self):
         if self._sale_started:
             if not yesno(_('You must finish or cancel the current sale before '
-                       'you can close the till.'),
-                     gtk.RESPONSE_NO, _("Cancel sale"), _("Finish sale")):
+                           'you can close the till.'),
+                         gtk.RESPONSE_NO, _("Cancel sale"), _("Finish sale")):
                 return
             self._cancel_order(show_confirmation=False)
         self._printer.close_till()
@@ -836,7 +920,7 @@ class PosApp(AppWindow):
 
     def on_Sales__activate(self, action):
         with api.trans() as trans:
-            self.run_dialog(SaleSearch, trans)
+            self.run_dialog(SaleWithToolbarSearch, trans)
 
     def on_SoldItemsByBranchSearch__activate(self, action):
         self.run_dialog(SoldItemsByBranchSearch, self.conn)
@@ -853,7 +937,7 @@ class PosApp(AppWindow):
         self.run_dialog(DeliverySearch, self.conn)
 
     def on_ConfirmOrder__activate(self, action):
-        self._checkout()
+        self.checkout()
 
     def on_NewDelivery__activate(self, action):
         self._create_delivery()
@@ -864,6 +948,25 @@ class PosApp(AppWindow):
     def on_TillOpen__activate(self, action):
         self._printer.open_till()
 
+    def on_NewTrade__activate(self, action):
+        if self._trade:
+            if yesno(_("There is already a trade in progress... Do you "
+                       "want to cancel it and start a new one?"),
+                     gtk.RESPONSE_NO, _("Cancel trade"), _("Don't cancel")):
+                self._clear_trade()
+            else:
+                return
+
+        trans = api.new_transaction()
+        rv = self.run_dialog(SaleTradeWizard, trans)
+        if rv:
+            self._trade = rv
+        else:
+            trans.rollback()
+            trans.close()
+
+        self._update_trade_infobar()
+
     #
     # Other callbacks
     #
@@ -881,6 +984,11 @@ class PosApp(AppWindow):
 
         return True
 
+    def _on_remove_trade_button__clicked(self, button):
+        if yesno(_("Do you really want to cancel the trade in progress?"),
+                 gtk.RESPONSE_NO, _("Cancel trade"), _("Don't cancel")):
+            self._clear_trade()
+
     def on_till_status_label__activate_link(self, button, link):
         if link == 'open-till':
             self._printer.open_till()
@@ -917,7 +1025,7 @@ class PosApp(AppWindow):
         self._create_delivery()
 
     def on_checkout_button__clicked(self, button):
-        self._checkout()
+        self.checkout()
 
     def on_edit_item_button__clicked(self, button):
         item = self.sale_items.get_selected()
