@@ -32,7 +32,7 @@ import gtk
 from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
-from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.objectlist import SearchColumn
 from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from stoqlib.api import api
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
@@ -61,6 +61,7 @@ from stoqlib.gui.wizards.purchasequotewizard import (QuotePurchaseWizard,
 from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import warning, yesno
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.reporting.purchase import PurchaseReport
 
 from stoq.gui.application import SearchableAppWindow
@@ -79,6 +80,13 @@ class PurchaseApp(SearchableAppWindow):
     report_table = PurchaseReport
     embedded = True
 
+    action_permissions = {
+        'ProductUnits': ('ProductUnit', PermissionManager.PERM_SEARCH),
+        'NewProduct': ('Product', PermissionManager.PERM_CREATE),
+        'Products': ('Product', PermissionManager.PERM_SEARCH),
+        'Services': ('Service', PermissionManager.PERM_SEARCH),
+    }
+
     #
     # Application
     #
@@ -173,6 +181,9 @@ class PurchaseApp(SearchableAppWindow):
         self.popup = self.uimanager.get_widget('/PurchaseSelection')
 
     def create_ui(self):
+        if api.sysparam(self.conn).SMART_LIST_LOADING:
+            self.search.search.enable_lazy_search()
+
         self.app.launcher.add_new_items([
             self.NewOrder,
             self.NewQuote,
@@ -249,11 +260,14 @@ class PurchaseApp(SearchableAppWindow):
         self.add_filter(self.status_filter, SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('#'),
+        return [SearchColumn('identifier', title=_('#'),
+                             long_title=_('Order number'),
                              data_type=int, justify=gtk.JUSTIFY_RIGHT,
                              width=60),
-                Column('status_str', title=_(u'Status'), data_type=str,
-                       visible=False),
+                SearchColumn('status_str', title=_('Status'), width=100,
+                             data_type=str, search_attribute='status',
+                             valid_values=self._get_status_values(),
+                             visible=False),
                 SearchColumn('open_date', title=_('Opened'),
                               long_title=_('Date Opened'), width=90,
                               data_type=datetime.date, sorted=True,
@@ -328,7 +342,7 @@ class PurchaseApp(SearchableAppWindow):
 
         if trans.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id))
+            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
 
     def _edit_order(self):
         selected = self.results.get_selected_rows()
@@ -425,7 +439,7 @@ class PurchaseApp(SearchableAppWindow):
 
         if trans.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id))
+            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
 
     def _new_product(self):
         with api.trans() as trans:
@@ -437,7 +451,7 @@ class PurchaseApp(SearchableAppWindow):
 
         if trans.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id))
+            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
 
     #
     # Kiwi Callbacks
