@@ -45,9 +45,6 @@ from stoqlib.domain.till import Till
 from stoqlib.exceptions import TillError
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
-                                                     PaymentStatusChangeDialog)
-from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.editors.paymenteditor import InPaymentEditor
 from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
 from stoqlib.gui.keybindings import get_accels
@@ -73,6 +70,7 @@ class ReceivableApp(BaseAccountWindow):
     search_table = InPaymentView
     search_label = _('matching:')
     report_table = ReceivablePaymentReport
+    editor_class = InPaymentEditor
 
     payment_category_type = PaymentCategory.TYPE_RECEIVABLE
 
@@ -174,9 +172,8 @@ class ReceivableApp(BaseAccountWindow):
         self.create_main_filter()
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('#'), long_title=_("Payment ID"),
-                             width=60, data_type=int,
-                             format='%04d'),
+        return [SearchColumn('identifier', title=_('#'), long_title=_("Payment ID"),
+                             width=60, data_type=int, format='%04d'),
                 SearchColumn('description', title=_('Description'),
                              data_type=str, ellipsize=pango.ELLIPSIZE_END,
                              expand=True, pack_end=True),
@@ -204,18 +201,6 @@ class ReceivableApp(BaseAccountWindow):
                              long_title=_('Payment category'), width=110,
                              visible=False)]
 
-    #
-    # BaseAccountWindow
-    #
-
-    def add_payment(self, category=None):
-        trans = api.new_transaction()
-        retval = self.run_dialog(InPaymentEditor, trans, category=category)
-        if api.finish_transaction(trans, retval):
-            self._update_filter_items()
-            self.search.refresh()
-        trans.close()
-
     #
     # Public API
     #
@@ -257,22 +242,6 @@ class ReceivableApp(BaseAccountWindow):
         values.insert(0, (_("Any"), None))
         return values
 
-    def _show_details(self, receivable_view):
-        trans = api.new_transaction()
-        payment = trans.get(receivable_view.payment)
-        retval = run_dialog(InPaymentEditor, self, trans, payment)
-        if api.finish_transaction(trans, retval):
-            self.search.refresh()
-        trans.close()
-        return retval
-
-    def _show_comments(self, receivable_view):
-        trans = api.new_transaction()
-        retval = run_dialog(PaymentCommentsDialog, self, trans,
-                            receivable_view.payment)
-        api.finish_transaction(trans, retval)
-        trans.close()
-
     def _receive(self, receivable_views):
         """
         Receives a list of items from a receivable_views, note that
@@ -296,41 +265,6 @@ class ReceivableApp(BaseAccountWindow):
         trans.close()
         self._update_widgets()
 
-    def _change_due_date(self, receivable_view):
-        """ Receives a receivable_view and change the payment due date
-        related to the view.
-        @param receivable_view: a InPaymentView instance
-        """
-        assert receivable_view.can_change_due_date()
-        trans = api.new_transaction()
-        payment = trans.get(receivable_view.payment)
-        sale = trans.get(receivable_view.sale)
-        retval = run_dialog(PaymentDueDateChangeDialog, self,
-                            trans, payment, sale)
-
-        if api.finish_transaction(trans, retval):
-            receivable_view.sync()
-            self.results.update(receivable_view)
-
-        trans.close()
-
-    def _change_status(self, receivable_view, status):
-        """Show a dialog do enter a reason for status change
-        @param receivable_view: a InPaymentView instance
-        """
-        trans = api.new_transaction()
-        payment = trans.get(receivable_view.payment)
-        order = trans.get(receivable_view.sale)
-        retval = run_dialog(PaymentStatusChangeDialog, self, trans,
-                            payment, status, order)
-
-        if api.finish_transaction(trans, retval):
-            receivable_view.sync()
-            self.results.update(receivable_view)
-            self.results.unselect_all()
-
-        trans.close()
-
     def _is_paid(self, receivable_view):
         """
         Determines if the selected payment is paid.
@@ -385,9 +319,6 @@ class ReceivableApp(BaseAccountWindow):
 
         client = parent.client
 
-        if not client:
-            return False
-
         return all(view.get_parent() and
                    view.get_parent().client is client and
                    view.get_parent().can_set_renegotiated()
@@ -398,7 +329,15 @@ class ReceivableApp(BaseAccountWindow):
         """
         if not views:
             return False
+        # Installments of renegotiated payments can not be edited.
+        if views[0].group.renegotiation:
+            return False
+
         sale_id = views[0].sale_id
+        # Lonely payments are not created as sales, and it's installments
+        # are edited differently.
+        if not sale_id:
+            return False
         can_edit = all(rv.sale_id == sale_id for rv in views)
         return can_edit
 
@@ -477,7 +416,7 @@ class ReceivableApp(BaseAccountWindow):
     #
 
     def on_results__row_activated(self, klist, receivable_view):
-        self._show_details(receivable_view)
+        self.show_details(receivable_view)
 
     def on_results__selection_changed(self, receivables, selected):
         self._update_widgets()
@@ -487,14 +426,14 @@ class ReceivableApp(BaseAccountWindow):
 
     def on_Details__activate(self, button):
         selected = self.results.get_selected_rows()[0]
-        self._show_details(selected)
+        self.show_details(selected)
 
     def on_Receive__activate(self, button):
         self._receive(self.results.get_selected_rows())
 
     def on_Comments__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
-        self._show_comments(receivable_view)
+        self.show_comments(receivable_view)
 
     def on_PrintReceipt__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
@@ -508,15 +447,17 @@ class ReceivableApp(BaseAccountWindow):
 
     def on_CancelPayment__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
-        self._change_status(receivable_view, Payment.STATUS_CANCELLED)
+        order = receivable_view.sale
+        self.change_status(receivable_view, order, Payment.STATUS_CANCELLED)
 
     def on_SetNotPaid__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
-        self._change_status(receivable_view, Payment.STATUS_PENDING)
+        order = receivable_view.sale
+        self.change_status(receivable_view, order, Payment.STATUS_PENDING)
 
     def on_ChangeDueDate__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
-        self._change_due_date(receivable_view)
+        self.change_due_date(receivable_view, receivable_view.sale)
 
     def on_BillCheckSearch__activate(self, action):
         self._run_bill_check_search()
@@ -541,7 +482,10 @@ class ReceivableApp(BaseAccountWindow):
                             groups)
 
         if api.finish_transaction(trans, retval):
+            # FIXME: Storm is not expiring the groups correctly.
+            # Figure out why. See bug 5087
             self.search.refresh()
+            self._update_widgets()
         trans.close()
 
     def on_Edit__activate(self, action):
