@@ -39,7 +39,7 @@ from stoqlib.api import api
 from stoqlib.database.orm import func, AND, OR
 from stoqlib.domain.invoice import InvoicePrinter
 from stoqlib.domain.sale import Sale, SaleView
-from stoqlib.gui.editors.invoiceeditor import SaleInvoicePrinterDialog
+from stoqlib.gui.dialogs.invoicedialog import SaleInvoicePrinterDialog
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.callsearch import ClientCallsSearch
 from stoqlib.gui.search.commissionsearch import CommissionSearch
@@ -47,7 +47,10 @@ from stoqlib.gui.search.deliverysearch import DeliverySearch
 from stoqlib.gui.search.loansearch import LoanItemSearch, LoanSearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
-from stoqlib.gui.search.salesearch import SoldItemsByBranchSearch
+from stoqlib.gui.search.salesearch import (SoldItemsByBranchSearch,
+                                           SalesByPaymentMethodSearch)
+from stoqlib.gui.search.salespersonsearch import SalesPersonSalesSearch
+from stoqlib.gui.search.creditcheckhistorysearch import CreditCheckHistorySearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.slaves.saleslave import SaleListToolbar
 from stoqlib.gui.stockicons import (STOQ_PRODUCTS, STOQ_SERVICES,
@@ -57,6 +60,7 @@ from stoqlib.gui.wizards.salequotewizard import SaleQuoteWizard
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.invoice import SaleInvoice, print_sale_invoice
 from stoqlib.lib.message import info, yesno
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
@@ -69,7 +73,7 @@ class FilterItem(object):
     def __init__(self, name, value=None):
         self.name = name
         self.value = value
-        self.id = name
+        self.id = value
 
 
 SALES_FILTERS = {
@@ -106,10 +110,14 @@ class SalesApp(SearchableAppWindow):
                  Sale.STATUS_RETURNED: 'return_date',
                  Sale.STATUS_RENEGOTIATED: 'close_date'}
 
-    def __init__(self, app):
+    action_permissions = {
+        "SalesPrintInvoice": ('app.sales.print_invoice', PermissionManager.PERM_SEARCH),
+    }
+
+    def __init__(self, app, conn=None):
         self.summary_label = None
         self._visible_date_col = None
-        SearchableAppWindow.__init__(self, app)
+        SearchableAppWindow.__init__(self, app, conn=conn)
 
     #
     # Application
@@ -128,6 +136,13 @@ class SalesApp(SearchableAppWindow):
             ("SearchSoldItemsByBranch", None, _("Sold items by branch..."),
              group.get("search_sold_items_by_branch"),
              _("Search for sold items by branch")),
+            ("SearchSalesByPaymentMethod", None,
+             _("Sales by payment method..."),
+             group.get("search_sales_by_payment")),
+            ("SearchSalesPersonSales", None,
+             _("Total sales made by salesperson..."),
+             group.get("search_salesperson_sales"),
+             _("Search for sales by payment method")),
             ("SearchProduct", STOQ_PRODUCTS, _("Products..."),
              group.get("search_products"),
              _("Search for products")),
@@ -143,6 +158,10 @@ class SalesApp(SearchableAppWindow):
             ("SearchClientCalls", None, _("Client Calls..."),
              group.get("search_client_calls"),
              _("Search for client calls")),
+            ("SearchCreditCheckHistory", None,
+             _("Client credit check history..."),
+             group.get("search_credit_check_history"),
+             _("Search for client check history")),
             ("SearchCommission", None, _("Commissions..."),
              group.get("search_commissions"),
              _("Search for salespersons commissions")),
@@ -181,6 +200,9 @@ class SalesApp(SearchableAppWindow):
         self.set_help_section(_("Sales help"), 'app-sales')
 
     def create_ui(self):
+        if api.sysparam(self.conn).SMART_LIST_LOADING:
+            self.search.search.enable_lazy_search()
+
         self.popup = self.uimanager.get_widget('/SaleSelection')
 
         self._columns = self.get_columns()
@@ -219,6 +241,7 @@ class SalesApp(SearchableAppWindow):
     #
 
     def create_filters(self):
+        self.executer.set_query(self._query)
         self.set_text_field_columns(['client_name', 'salesperson_name'])
 
         status_filter = ComboSearchFilter(_('Show sales'),
@@ -236,7 +259,8 @@ class SalesApp(SearchableAppWindow):
                                         search_attribute='status',
                                         valid_values=self._get_status_values())
 
-        cols = [SearchColumn('id', title=_('#'), width=80,
+        cols = [SearchColumn('identifier', title=_('#'), width=80,
+                             long_title=_('Order number'),
                              format='%05d', data_type=int, sorted=True),
                 SearchColumn('open_date', title=_('Open date'), width=120,
                              data_type=date, justify=gtk.JUSTIFY_RIGHT,
@@ -289,7 +313,8 @@ class SalesApp(SearchableAppWindow):
 
     def _setup_slaves(self):
         # This is only here to reuse the logic in it.
-        self.sale_toolbar = SaleListToolbar(self.conn, self.results)
+        self.sale_toolbar = SaleListToolbar(self.conn, self.results,
+                                            parent=self)
 
     def _can_cancel(self, view):
         # Here we want to cancel only quoting sales. This is why we don't use
@@ -399,6 +424,11 @@ class SalesApp(SearchableAppWindow):
 
         raise AssertionError(state.value.name, state.value.value)
 
+    def _query(self, query, having, conn):
+        branch = api.get_current_branch(self.conn)
+        return self.search_table.select_by_branch(query, branch, having=having,
+                                                  connection=conn)
+
     def _new_sale_quote(self):
         trans = api.new_transaction()
         model = self.run_dialog(SaleQuoteWizard, trans)
@@ -487,15 +517,24 @@ class SalesApp(SearchableAppWindow):
     def on_SearchClientCalls__activate(self, action):
         self.run_dialog(ClientCallsSearch, self.conn)
 
+    def on_SearchCreditCheckHistory__activate(self, action):
+        self.run_dialog(CreditCheckHistorySearch, self.conn)
+
     def on_SearchService__activate(self, button):
         self.run_dialog(ServiceSearch, self.conn, hide_toolbar=True)
 
     def on_SearchSoldItemsByBranch__activate(self, button):
         self.run_dialog(SoldItemsByBranchSearch, self.conn)
 
+    def on_SearchSalesByPaymentMethod__activate(self, button):
+        self.run_dialog(SalesByPaymentMethodSearch, self.conn)
+
     def on_SearchDelivery__activate(self, action):
         self.run_dialog(DeliverySearch, self.conn)
 
+    def on_SearchSalesPersonSales__activate(self, action):
+        self.run_dialog(SalesPersonSalesSearch, self.conn)
+
     # Toolbar
 
     def on_Edit__activate(self, action):
