@@ -117,7 +117,7 @@ class Shell(object):
             self._locale_error = (msg, err)
             log.warning(msg)
         else:
-            os.environ['LANG'] = lang
+            os.environ['LC_ALL'] = lang
             os.environ['LANGUAGE'] = lang
 
     def _prepare_logfiles(self):
@@ -164,17 +164,7 @@ class Shell(object):
 
         if 'STOQ_USE_GI' in os.environ:
             from stoq.lib import gicompat
-            if os.environ['STOQ_USE_GI'] == '3.0':
-                gtk_version = '3.0'
-                webkit_version = '3.0'
-            else:
-                gtk_version = '2.0'
-                webkit_version = '1.0'
             gicompat.enable()
-            gicompat.enable_gtk(version=gtk_version)
-            gicompat.enable_poppler()
-            gicompat.enable_webkit(version=webkit_version)
-            gicompat.enable_gudev()
 
     def _setup_gtk(self):
         import gtk
@@ -417,6 +407,10 @@ class Shell(object):
         from stoqlib.exceptions import LoginError
         from stoqlib.gui.login import LoginHelper
         from stoqlib.lib.message import error
+
+        # Check if we have the main branch before logging in.
+        # If there are no branches registered yet, the user will not be able to login.
+        self._check_param_main_branch()
         self._login = LoginHelper(username=self._options.login_username)
         try:
             if not self.login():
@@ -424,7 +418,6 @@ class Shell(object):
         except LoginError, e:
             error(str(e))
             return False
-        self._check_param_main_branch()
         self._check_param_online_services()
         self._maybe_show_welcome_dialog()
         return True
@@ -454,6 +447,7 @@ class Shell(object):
             sysparam(trans).MAIN_COMPANY = branch.id
             get_current_station(trans).branch = branch
             trans.commit()
+            trans.close()
 
     def _check_param_online_services(self):
         from stoqlib.database.runtime import new_transaction
@@ -483,6 +477,7 @@ class Shell(object):
             dialog.destroy()
             sparam.ONLINE_SERVICES = int(bool(response == gtk.RESPONSE_YES))
         trans.commit()
+        trans.close()
 
     def _maybe_show_welcome_dialog(self):
         from stoqlib.api import api
@@ -591,7 +586,6 @@ class Shell(object):
         raise SystemExit
 
     def _debug_hook(self, exctype, value, tb):
-        import traceback
         self._write_exception_hook(exctype, value, tb)
         traceback.print_exception(exctype, value, tb)
         print
