@@ -55,8 +55,8 @@ from stoqlib.gui.search.transfersearch import TransferOrderSearch
 from stoqlib.gui.search.stockdecreasesearch import StockDecreaseSearch
 from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
 from stoqlib.gui.wizards.receivingwizard import ReceivingOrderWizard
-from stoqlib.gui.wizards.stocktransferwizard import StockTransferWizard
 from stoqlib.gui.wizards.stockdecreasewizard import StockDecreaseWizard
+from stoqlib.gui.wizards.stocktransferwizard import StockTransferWizard
 from stoqlib.reporting.product import SimpleProductReport
 from stoqlib.gui.stockicons import STOQ_RECEIVING
 
@@ -86,7 +86,8 @@ class StockApp(SearchableAppWindow):
              group.get('new_receiving')),
             ('NewTransfer', gtk.STOCK_CONVERT, _('Transfer...'),
              group.get('transfer_product')),
-            ('NewStockDecrease', None, _('Stock decrease...')),
+            ('NewStockDecrease', None, _('Stock decrease...'),
+             group.get('stock_decrease')),
             ('StockInitial', gtk.STOCK_GO_UP, _('Register initial stock...')),
             ("LoanNew", None, _("Loan...")),
             ("LoanClose", None, _("Close loan...")),
@@ -140,6 +141,9 @@ class StockApp(SearchableAppWindow):
         self.ProductStockHistory.props.is_important = True
 
     def create_ui(self):
+        if api.sysparam(self.conn).SMART_LIST_LOADING:
+            self.search.search.enable_lazy_search()
+
         self.popup = self.uimanager.get_widget('/StockSelection')
         self.app.launcher.add_new_items([self.NewReceiving, self.NewTransfer,
                                          self.NewStockDecrease, self.LoanNew])
@@ -232,8 +236,8 @@ class StockApp(SearchableAppWindow):
                              data_type=str, visible=False),
                 SearchColumn('location', title=_("Location"), data_type=str,
                              width=100, visible=False),
-                SearchColumn('stock', title=_('Quantity'),
-                             data_type=decimal.Decimal, width=100),
+                Column('stock', title=_('Quantity'),
+                       data_type=decimal.Decimal, width=100),
                 SearchColumn('unit', title=_("Unit"), data_type=str,
                              width=40, visible=False),
                 Column('has_image', title=_('Picture'),
@@ -380,7 +384,10 @@ class StockApp(SearchableAppWindow):
         if self.check_open_inventory():
             return
         branch = self.branch_filter.get_state().value
-        self.run_dialog(InitialStockDialog, self.conn, branch)
+        trans = api.new_transaction()
+        retval = self.run_dialog(InitialStockDialog, trans, branch)
+        api.finish_transaction(trans, retval)
+        trans.close()
         self.search.refresh()
 
     def on_StockPictureViewer__activate(self, button):
