@@ -53,7 +53,8 @@ from stoqlib.gui.editors.tilleditor import CashInEditor, CashOutEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.personsearch import ClientSearch
-from stoqlib.gui.search.salesearch import SaleSearch, SoldItemsByBranchSearch
+from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
+                                           SoldItemsByBranchSearch)
 from stoqlib.gui.search.tillsearch import TillFiscalOperationsSearch
 from stoqlib.gui.slaves.saleslave import return_sale
 from stoqlib.reporting.sale import SalesReport
@@ -130,7 +131,7 @@ class TillApp(SearchableAppWindow):
         self.Details.props.is_important = True
 
     def create_ui(self):
-        self.popup = self.uimanager.get_widget('/SaleSelection')
+        self.popup = self.uimanager.get_widget('/TillSelection')
 
         self.current_branch = api.get_current_branch(self.conn)
         # Groups
@@ -185,7 +186,8 @@ class TillApp(SearchableAppWindow):
                         columns=['status'])
 
     def get_columns(self):
-        return [SearchColumn('id', title=_('#'), width=60,
+        return [SearchColumn('identifier', title=_('#'), width=60,
+                             long_title=_('Order number'),
                              data_type=int, format='%05d', sorted=True),
                 Column('status_name', title=_(u'Status'), data_type=str,
                         visible=False),
@@ -214,7 +216,7 @@ class TillApp(SearchableAppWindow):
         # 2) Are in the status QUOTE or ORDERED.
         # 3) For the order statuses, the date should be the same as today
 
-        new = AND(Sale.q.branchID == self.current_branch.id,
+        new = AND(Sale.q.branch_id == self.current_branch.id,
                  OR(Sale.q.status == Sale.STATUS_QUOTE,
                     Sale.q.status == Sale.STATUS_ORDERED,
                     const.DATE(Sale.q.open_date) == date.today()))
@@ -313,7 +315,7 @@ class TillApp(SearchableAppWindow):
                                "Until it is opened, it's not possible to "
                                "confirm the sale. Do you want to try again?"),
                              gtk.RESPONSE_YES, _("Try again"), _("Cancel coupon")):
-                    break
+                    return None
 
         return coupon
 
@@ -507,7 +509,7 @@ class TillApp(SearchableAppWindow):
         if self.check_open_inventory():
             return
 
-        self._run_search_dialog(SaleSearch)
+        self._run_search_dialog(SaleWithToolbarSearch)
         self.refresh()
 
     def on_SearchSoldItemsByBranch__activate(self, button):
