@@ -34,10 +34,12 @@ import sys
 
 _ = gettext.gettext
 
+# When changing something here, remember to update
+# the README and the debian control files
 DATEUTIL_REQUIRED = (1, 4, 1)
 GTK_REQUIRED = (2, 20, 0)
 GUDEV_REQUIRED = (147, )
-KIWI_REQUIRED = (1, 9, 35)
+KIWI_REQUIRED = (1, 9, 36)
 MAKO_REQUIRED = (0, 2, 5)
 PIL_REQUIRED = (1, 1, 5)
 PYCAIRO_REQUIRED = (1, 8, 2)
@@ -49,7 +51,8 @@ PYGTKWEBKIT_REQUIRED = (1, 1, 7)
 PYOBJC_REQUIRED = (2, 3)
 PYSERIAL_REQUIRED = (2, 1)
 REPORTLAB_REQUIRED = (2, 4)
-STOQDRIVERS_REQUIRED = (0, 9, 17)
+STORM_REQUIRED = (0, 19)
+STOQDRIVERS_REQUIRED = (0, 9, 18)
 TWISTED_CORE_REQUIRED = (10, 0)
 TWISTED_WEB_REQUIRED = (10, 0)
 XLWT_REQUIRED = (0, 7, 2)
@@ -83,9 +86,10 @@ class DependencyChecker(object):
         self._check_twisted_web(TWISTED_WEB_REQUIRED)
         self._check_xlwt(XLWT_REQUIRED)
 
-        # Postgres
+        # Database
         self._check_psql(PSQL_REQUIRED)
         self._check_psycopg(PSYCOPG_REQUIRED)
+        self._check_storm(STORM_REQUIRED)
 
         # Printing
         # FIXME: might be interesting to allow to run Stoq with printing
@@ -180,6 +184,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Kiwi",
                           url='http://www.async.com.br/projects/kiwi/',
                           version=version)
+            return
 
         kiwi_version = kiwi.__version__.version
         if kiwi_version < version:
@@ -195,6 +200,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="pycairo",
                           url='http://www.cairographics.org/pycairo/',
                           version=version)
+            return
 
         if cairo.version_info < version:
             self._too_old(project="pycairo",
@@ -209,6 +215,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Pypoppler",
                           url='https://launchpad.net/poppler-python',
                           version=version)
+            return
 
         pypoppler_version = poppler.pypoppler_version
         if pypoppler_version < version:
@@ -267,6 +274,23 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                 found=psycopg2_version,
                 required=version)
 
+    def _check_storm(self, version):
+        try:
+            import storm
+        except ImportError:
+            self._missing(
+                project="storm -  an object-relational mapper",
+                url='https://storm.canonical.com',
+                version=version)
+            return
+
+        if storm.version_info < version:
+            self._too_old(
+                project="storm -  an object-relational mapper",
+                url='https://storm.canonical.com',
+                found=storm.version,
+                required=version)
+
     def _check_stoqdrivers(self, version):
         try:
             import stoqdrivers
@@ -274,6 +298,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Stoqdrivers",
                           url='http://www.stoq.com.br',
                           version=version)
+            return
 
         stoqdrivers_version = stoqdrivers.__version__
         if stoqdrivers_version < version:
@@ -290,6 +315,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project='Python Imaging Library (PIL)',
                           url='http://www.pythonware.com/products/pil/',
                           version=version)
+            return
 
         if map(int, PIL.Image.VERSION.split('.')) < list(version):
             self._too_old(project='Python Imaging Library (PIL)',
@@ -304,6 +330,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Reportlab",
                           url='http://www.reportlab.org/',
                           version=version)
+            return
 
         rl_version = map(int, reportlab.Version.split('.'))
         if rl_version < list(version):
@@ -319,6 +346,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Dateutil",
                           url='http://labix.org/python-dateutil/',
                           version=version)
+            return
 
         if (not hasattr(dateutil, "__version__") or
             map(int, dateutil.__version__.split('.')) < list(version)):
@@ -334,6 +362,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project="Mako",
                           url='http://www.makotemplates.org/',
                           version=version)
+            return
 
         if map(int, mako.__version__.split('.')) < list(version):
             self._too_old(project="Mako",
@@ -358,6 +387,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project='TwistedCore',
                           url='http://twistedmatrix.com/',
                           version=version)
+            return
 
         if map(int, twisted.version.base().split('.')) < list(version):
             self._too_old(project="TwistedCore",
@@ -372,6 +402,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project='TwistedWeb',
                           url='http://twistedmatrix.com/',
                           version=version)
+            return
 
         if map(int, twisted.web.version.base().split('.')) < list(version):
             self._too_old(project="TwistedWeb",
@@ -387,6 +418,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project='xlwt',
                           url='http://www.python-excel.org/',
                           version=version)
+            return
 
         if map(int, xlwt.__VERSION__.split('.')) < list(version):
             self._too_old(project="xlwt",
@@ -402,6 +434,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             self._missing(project='pyobjc',
                           url='http://pyobjc.sf.net/',
                           version=version)
+            return
 
         if map(int, objc.__version__.split('.')) < list(version):
             self._too_old(project="pyobjc",
