@@ -31,7 +31,7 @@ import optparse
 log = logging.getLogger('stoq.main')
 
 
-def main(args):
+def get_shell(args):
     log.info('parsing command line arguments: %s ' % (args, ))
     from stoq.lib.options import get_option_parser
     parser = get_option_parser()
@@ -52,10 +52,25 @@ def main(args):
                      dest="splashscreen",
                      default=True,
                      help='Disable the splash screen')
+    group.add_option('', '--version',
+                     action="store_true",
+                     dest="version",
+                     help='Show the application version')
     parser.add_option_group(group)
 
     options, args = parser.parse_args(args)
 
+    if options.version:
+        import stoq
+        raise SystemExit(stoq.version)
+
+    from stoq.gui.shell import Shell
+    return args, Shell(options)
+
+
+def main(args):
+    args, shell = get_shell(args)
+
     if len(args) < 2:
         appname = None
     else:
@@ -70,6 +85,4 @@ def main(args):
             raise SystemExit("'%s' is not an application. "
                              "Valid applications are: %s" % (appname, apps))
 
-    from stoq.gui.shell import Shell
-    shell = Shell(options)
     shell.main(appname)
