@@ -35,11 +35,11 @@ import glib
 from kiwi.component import get_utility
 from twisted.internet.defer import inlineCallbacks, returnValue
 
-from stoqlib.database.interfaces import IDatabaseSettings
 from stoqlib.database.runtime import (get_connection, new_transaction,
-                                      rollback_and_begin, finish_transaction)
+                                      finish_transaction)
 from stoqlib.database.runtime import (get_current_branch,
                                       get_current_station, get_current_user)
+from stoqlib.database.settings import db_settings
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.lib.interfaces import IStoqConfig
 from stoqlib.lib.parameters import sysparam, is_developer_mode
@@ -58,9 +58,6 @@ class StoqAPI(object):
     def finish_transaction(self, trans, model):
         return finish_transaction(trans, model)
 
-    def rollback_and_begin(self, trans):
-        rollback_and_begin(trans)
-
     def get_current_branch(self, conn):
         return get_current_branch(conn)
 
@@ -107,7 +104,7 @@ class StoqAPI(object):
 
     @property
     def db_settings(self):
-        return get_utility(IDatabaseSettings)
+        return db_settings
 
     @property
     def user_settings(self):
@@ -197,8 +194,9 @@ class StoqAPI(object):
         # This is fetching all persons to cache the objects and avoid extra
         # queries when constructing the combo strings.
         from stoqlib.domain.person import Person
-        people = list(Person.select((Person.q.id == resultset.sourceClass.q.personID),
-                                    connection=resultset._getConnection()))
+        people = list(Person.select((
+            Person.q.id == resultset.sourceClass.q.person_id),
+                                    connection=resultset._connection))
         people  # pyflakes
         return self.for_combo(resultset)
 
