@@ -29,17 +29,16 @@ import sets
 import socket
 
 from dateutil.parser import parse
-from kiwi.component import get_utility, provide_utility
+from kiwi.component import provide_utility
 from kiwi.log import Logger
 
 from stoqlib.database.admin import create_base_schema
-from stoqlib.database.database import dump_table
-from stoqlib.database.interfaces import (ICurrentBranchStation, ICurrentBranch,
-                                         IDatabaseSettings)
+from stoqlib.database.interfaces import ICurrentBranchStation, ICurrentBranch
 from stoqlib.database.orm import ORMObjectNotFound, const
 from stoqlib.database.runtime import (get_connection, new_transaction,
                                       get_current_branch)
 from stoqlib.database.policy import get_policy_by_name
+from stoqlib.database.settings import db_settings
 from stoqlib.database.tables import get_table_type_by_name
 from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
@@ -88,7 +87,6 @@ def get_tables(policy, pfilter=None):
     :param policy: a SynchronizationPolicy
     :param pfilter: a sequence of states to skip or None to fetch all
     :returns: a list of tables
-    :rtype: list of sqlobject tables
     """
     tables = []
     for table_name, table_policy in policy.tables:
@@ -142,10 +140,10 @@ class TableSerializer:
                 results.count(), table.sqlmeta.table))
 
             for so in results:
-                tec = TransactionEntry.get(so.te_createdID,
+                tec = TransactionEntry.get(so.te_created_id,
                                            connection=self._conn)
                 data += self._serialize_insert(tec)
-                tem = TransactionEntry.get(so.te_modifiedID,
+                tem = TransactionEntry.get(so.te_modified_id,
                                            connection=self._conn)
                 data += self._serialize_insert(tem)
                 data += self._serialize_insert(so)
@@ -162,7 +160,7 @@ class TableSerializer:
                 results.count(), table.sqlmeta.table))
 
             for so in results:
-                te = TransactionEntry.get(so.te_modifiedID,
+                te = TransactionEntry.get(so.te_modified_id,
                                           connection=self._conn)
                 data += self._serialize_update(te)
                 data += self._serialize_update(so)
@@ -247,16 +245,14 @@ class SynchronizationService(XMLRPCService):
         :returns: an integer representing the insert
         """
         log.info('service.sql_prepare()')
-        settings = get_utility(IDatabaseSettings)
-
         CMD = ("psql -n -h %(address)s -U %(username)s "
                "-p %(port)s %(dbname)s --variable ON_ERROR_STOP=")
 
         cmd = CMD % dict(
-            address=settings.address,
-            username=settings.username,
-            port=settings.port,
-            dbname=settings.dbname)
+            address=db_settings.address,
+            username=db_settings.username,
+            port=db_settings.port,
+            dbname=db_settings.dbname)
 
         noisy = False
         if noisy:
@@ -329,9 +325,9 @@ class SynchronizationService(XMLRPCService):
                 for so in branch.fetchTIDs(
                     table, timestamp, te_type, conn):
                     if te_type == TransactionEntry.CREATED:
-                        f = so.te_createdID
+                        f = so.te_created_id
                     elif te_type == TransactionEntry.MODIFIED:
-                        f = so.te_modifiedID
+                        f = so.te_modified_id
                     else:
                         raise AssertionError
                     te = TransactionEntry.get(f, connection=conn)
@@ -347,8 +343,8 @@ class SynchronizationService(XMLRPCService):
                              for column in so.sqlmeta.columnList]
                     objs.append((conn.sqlrepr(so.id),
                                  attrs,
-                                 conn.sqlrepr(so.te_createdID),
-                                 conn.sqlrepr(so.te_modifiedID),
+                                 conn.sqlrepr(so.te_created_id),
+                                 conn.sqlrepr(so.te_modified_id),
                                  conn.sqlrepr(te.te_time),
                                  conn.sqlrepr(te.user_id),
                                  conn.sqlrepr(te.station_id)))
@@ -383,7 +379,7 @@ class SynchronizationClient(object):
     def _dump_tables(self, tables):
         combined = ''
         for table in tables:
-            proc = dump_table(table.sqlmeta.table)
+            proc = db_settings.dump_table(table.sqlmeta.table)
             # This is kind of tricky, only send data when we reached CHUNKSIZE,
             # it saves resources since rpc calls can be expensive
             while True:
@@ -427,7 +423,7 @@ class SynchronizationClient(object):
 
     def _get_synchronization(self, trans, branch):
         return BranchSynchronization.selectOneBy(
-            branchID=branch.id, connection=trans)
+            branch_id=branch.id, connection=trans)
 
     def _update_synchronization(self, trans, station, timestamp, policy):
         sync = self._get_synchronization(trans, station.branch)
