@@ -80,7 +80,8 @@ _tables = [
      ('sale', ["SaleItem",
                "Delivery",
                "Sale"]),
-     ('renegotiation', ["RenegotiationData"]),
+     ('returnedsale', ["ReturnedSale",
+                       "ReturnedSaleItem"]),
      ('sellable', ["SellableUnit",
                    "SellableTaxConstant",
                    "SellableCategory",
@@ -101,6 +102,7 @@ _tables = [
      ('commission', ["CommissionSource", "Commission"]),
      ('transfer', ["TransferOrder", "TransferOrderItem"]),
      ('inventory', ["Inventory", "InventoryItem"]),
+     ('image', ["Image"]),
      ('production', ["ProductionOrder",
                      "ProductionItem",
                      "ProductionMaterial",
