@@ -152,6 +152,10 @@ def create_call(trans):
     return ExampleCreator.create(trans, 'Calls')
 
 
+def create_credit_check_history(trans):
+    return ExampleCreator.create(trans, 'CreditCheckHistory')
+
+
 def create_client_category(trans):
     return ExampleCreator.create(trans, 'ClientCategory')
 
@@ -183,6 +187,14 @@ class ExampleCreator(object):
     def clear(self):
         self._role = None
 
+    def clean_domain(self, domains):
+        # The database used for tests is the example one. So, when the tests
+        # start, there is already data that could cause unwanted behavior in
+        # a few tests, like GUI search ones.
+        for domain in domains:
+            for item in domain.select(connection=self.trans):
+                domain.delete(item.id, self.trans)
+
     def set_transaction(self, trans):
         self.trans = trans
 
@@ -190,6 +202,7 @@ class ExampleCreator(object):
         known_types = {
             'Account': self.create_account,
             'AccountTransaction': self.create_account_transaction,
+            'Address': self.create_address,
             'PaymentMethod': self.get_payment_method,
             'Sellable': self.create_sellable,
             'PaymentGroup': self.create_payment_group,
@@ -204,6 +217,7 @@ class ExampleCreator(object):
             'Company': self.create_company,
             'Branch': self.create_branch,
             'Employee': self.create_employee,
+            'Image': self.create_image,
             'Individual': self.create_individual,
             'Inventory': self.create_inventory,
             'InventoryItem': self.create_inventory_item,
@@ -224,24 +238,30 @@ class ExampleCreator(object):
             'Supplier': self.create_supplier,
             'Transporter': self.create_transporter,
             'LoginUser': self.create_user,
+            'MilitaryData': self.create_military_data,
             'Product': self.create_product,
+            'ProductSupplierInfo': self.create_product_supplier_info,
             'Storable': self.create_storable,
             'PurchaseOrder': self.create_purchase_order,
             'PurchaseItem': self.create_purchase_order_item,
             'ReceivingOrder': self.create_receiving_order,
             'ReceivingOrderItem': self.create_receiving_order_item,
-            'RenegotiationData': self.create_renegotiation_data,
+            'ReturnedSale': self.create_returned_sale,
             'Sale': self.create_sale,
             'SaleItem': self.create_sale_item,
             'SaleItemIcms': self.create_sale_item_icms,
             'SaleItemIpi': self.create_sale_item_ipi,
             'Sellable': self.create_sellable,
             'SellableCategory': self.create_sellable_category,
+            'SellableTaxConstant': self.create_sellable_tax_constant,
             'SellableUnit': self.create_sellable_unit,
             'Service': self.create_service,
             'StockDecrease': self.create_stock_decrease,
+            'StockDecreaseItem': self.create_stock_decrease_item,
             'Till': self.create_till,
             'UserProfile': self.create_user_profile,
+            'VoterData': self.create_voter_data,
+            'WorkPermitData': self.create_work_permit_data,
             'ProductionOrder': self.create_production_order,
             'ProductionItem': self.create_production_item,
             'ProductionMaterial': self.create_production_material,
@@ -254,9 +274,14 @@ class ExampleCreator(object):
             'PaymentCategory': self.create_payment_category,
             'FiscalDayHistory': self.create_fiscal_day_history,
             'Calls': self.create_call,
+            'CreditCheckHistory': self.create_credit_check_history,
             'BankAccount': self.create_bank_account,
             'QuoteGroup': self.create_quote_group,
             'Quotation': self.create_quotation,
+            'InvoicePrinter': self.create_invoice_printer,
+            'Delivery': self.create_delivery,
+            'Liaison': self.create_liaison,
+            'PaymentRenegotiation': self.create_payment_renegotiation,
             }
         if isinstance(model_type, basestring):
             model_name = model_type
@@ -265,31 +290,37 @@ class ExampleCreator(object):
         if model_name in known_types:
             return known_types[model_name]()
 
-    def create_person(self):
+    def create_person(self, name='John'):
         from stoqlib.domain.person import Person
-        return Person(name='John', connection=self.trans)
+        return Person(name=name, connection=self.trans)
 
-    def create_branch(self, name='Dummy'):
+    def create_branch(self, name='Dummy', phone_number='12345678',
+                      fax_number='87564321'):
         from stoqlib.domain.person import Branch, Company, Person
-        person = Person(name=name, connection=self.trans)
+        person = Person(name=name, phone_number=phone_number,
+                        fax_number=fax_number, connection=self.trans)
+        self.create_address(person=person)
         fancy_name = name + ' shop'
         Company(person=person, fancy_name=fancy_name,
                 connection=self.trans)
         return Branch(person=person, connection=self.trans)
 
-    def create_supplier(self):
+    def create_supplier(self, name='Supplier', fancy_name='Company Name'):
         from stoqlib.domain.person import Company, Person, Supplier
-        person = Person(name='Supplier', connection=self.trans)
-        Company(person=person, fancy_name='Company Name',
+        person = Person(name=name, connection=self.trans)
+        Company(person=person, fancy_name=fancy_name,
                 cnpj='90.117.749/7654-80',
                 connection=self.trans)
         return Supplier(person=person, connection=self.trans)
 
-    def create_employee_role(self):
+    def create_employee_role(self, name='Role'):
+        from stoqlib.domain.person import EmployeeRole
+        role = EmployeeRole.selectOneBy(name=name, connection=self.trans)
+        if not role:
+            role = EmployeeRole(name=name, connection=self.trans)
         if not self._role:
-            from stoqlib.domain.person import EmployeeRole
-            self._role = EmployeeRole(name='Role', connection=self.trans)
-        return self._role
+            self._role = role
+        return role
 
     def create_employee(self, name="SalesPerson"):
         from stoqlib.domain.person import Employee, Individual, Person
@@ -304,9 +335,9 @@ class ExampleCreator(object):
         employee = self.create_employee()
         return SalesPerson(person=employee.person, connection=self.trans)
 
-    def create_client(self):
+    def create_client(self, name='Client'):
         from stoqlib.domain.person import Client, Individual, Person
-        person = Person(name='Client', connection=self.trans)
+        person = Person(name=name, connection=self.trans)
         Individual(person=person, connection=self.trans)
         return Client(person=person, connection=self.trans)
 
@@ -315,31 +346,40 @@ class ExampleCreator(object):
         person = Person(name='individual', connection=self.trans)
         return Individual(person=person, connection=self.trans)
 
-    def create_user(self):
+    def create_user(self, username='username'):
         from stoqlib.domain.person import LoginUser
         individual = self.create_individual()
         profile = self.create_user_profile()
         return LoginUser(person=individual.person,
-                         username='username',
+                         username=username,
                          password='password',
                          profile=profile,
                          connection=self.trans)
 
-    def create_storable(self):
-        from stoqlib.domain.product import Product, Storable
-        sellable = self.create_sellable()
-        product = Product(sellable=sellable, connection=self.trans)
+    def create_storable(self, product=None):
+        from stoqlib.domain.product import Storable
+        if not product:
+            sellable = self.create_sellable()
+            product = sellable.product
         return Storable(product=product, connection=self.trans)
 
+    def create_product_supplier_info(self, supplier=None, product=None):
+        from stoqlib.domain.product import ProductSupplierInfo
+        product = product or self.create_product(create_supplier=False)
+        supplier = supplier or self.create_supplier()
+        ProductSupplierInfo(
+            connection=self.trans,
+            supplier=supplier,
+            product=product,
+            is_main_supplier=True,
+            )
+
     def create_product(self, price=None, create_supplier=True,
                        branch=None, stock=None):
-        from stoqlib.domain.product import ProductSupplierInfo, Storable
+        from stoqlib.domain.product import Storable
         sellable = self.create_sellable(price=price)
         if create_supplier:
-            ProductSupplierInfo(connection=self.trans,
-                                supplier=self.create_supplier(),
-                                product=sellable.product,
-                                is_main_supplier=True)
+            self.create_product_supplier_info(product=sellable.product)
         product = sellable.product
         if not branch:
             branch = get_current_branch(self.trans)
@@ -350,16 +390,16 @@ class ExampleCreator(object):
 
         return product
 
-    def create_product_component(self):
+    def create_product_component(self, product=None, component=None):
         from stoqlib.domain.product import ProductComponent
-        product = self.create_product()
-        component = self.create_product()
-        return ProductComponent(product=product,
-                                component=component,
+        return ProductComponent(product=product or self.create_product(),
+                                component=component or self.create_product(),
                                 connection=self.trans)
 
-    def create_sellable(self, price=None):
+    def create_sellable(self, price=None, product=True,
+                        description='Description'):
         from stoqlib.domain.product import Product
+        from stoqlib.domain.service import Service
         from stoqlib.domain.sellable import Sellable
         tax_constant = sysparam(self.trans).DEFAULT_PRODUCT_TAX_CONSTANT
         if price is None:
@@ -367,9 +407,12 @@ class ExampleCreator(object):
         sellable = Sellable(cost=125,
                             tax_constant=tax_constant,
                             price=price,
-                            description="Description",
+                            description=description,
                             connection=self.trans)
-        Product(sellable=sellable, connection=self.trans)
+        if product:
+            Product(sellable=sellable, connection=self.trans)
+        else:
+            Service(sellable=sellable, connection=self.trans)
         return sellable
 
     def create_sellable_unit(self, description=u'', allow_fraction=True):
@@ -378,12 +421,14 @@ class ExampleCreator(object):
                             description=description,
                             allow_fraction=allow_fraction)
 
-    def create_sellable_category(self):
+    def create_sellable_category(self, description=None, parent=None):
         from stoqlib.domain.sellable import SellableCategory
-        return SellableCategory(description="Category",
+        description = description or "Category"
+        return SellableCategory(description=description,
+                                category=parent,
                                 connection=self.trans)
 
-    def create_sale(self, id_=None):
+    def create_sale(self, id_=None, branch=None, client=None):
         from stoqlib.domain.sale import Sale
         from stoqlib.domain.till import Till
         till = Till.get_current(self.trans)
@@ -391,23 +436,31 @@ class ExampleCreator(object):
             till = self.create_till()
             till.open_till()
         salesperson = self.create_sales_person()
-        branch = self.create_branch()
         group = self.create_payment_group()
+        if client:
+            group.payer = client.person
         extra_args = dict()
         if id_:
             extra_args['id'] = id_
+            extra_args['identifier'] = id_
 
         return Sale(coupon_id=0,
                     open_date=const.NOW(),
-                    salesperson=salesperson, branch=branch,
+                    salesperson=salesperson,
+                    branch=branch or get_current_branch(self.trans),
                     cfop=sysparam(self.trans).DEFAULT_SALES_CFOP,
                     group=group,
+                    client=client,
                     connection=self.trans,
                     **extra_args)
 
-    def create_sale_item(self, sale=None):
+    def create_returned_sale(self):
+        sale = self.create_sale()
+        return sale.create_sale_return_adapter()
+
+    def create_sale_item(self, sale=None, product=True):
         from stoqlib.domain.sale import SaleItem
-        sellable = self.create_sellable()
+        sellable = self.create_sellable(product=product)
         return SaleItem(connection=self.trans,
                         quantity=1,
                         price=100,
@@ -426,46 +479,54 @@ class ExampleCreator(object):
         from stoqlib.domain.person import ClientCategory
         return ClientCategory(name=name, connection=self.trans)
 
-    def create_client_category_price(self):
+    def create_client_category_price(self, category=None, sellable=None,
+                                     price=None):
         from stoqlib.domain.sellable import ClientCategoryPrice
-        sellable = self.create_sellable(price=50)
-        return ClientCategoryPrice(sellable=sellable,
-                                   category=self.create_client_category(),
-                                   price=100,
+        return ClientCategoryPrice(sellable=sellable or self.create_sellable(price=50),
+                                   category=category or self.create_client_category(),
+                                   price=price or 100,
                                    connection=self.trans)
 
-    def create_stock_decrease(self):
+    def create_stock_decrease_item(self):
+        from stoqlib.domain.stockdecrease import StockDecreaseItem
+        return StockDecreaseItem(stock_decrease=self.create_stock_decrease(),
+                                 sellable=self.create_sellable(),
+                                 quantity=1,
+                                 connection=self.trans)
+
+    def create_stock_decrease(self, branch=None, user=None, reason=''):
         from stoqlib.domain.stockdecrease import StockDecrease
 
-        branch = self.create_branch()
-        user = self.create_user()
         employee = self.create_employee()
         cfop = self.create_cfop_data()
-
-        return StockDecrease(responsible=user,
+        return StockDecrease(responsible=user or get_current_user(self.trans),
                              removed_by=employee,
-                             branch=branch,
+                             branch=branch or get_current_branch(self.trans),
                              status=StockDecrease.STATUS_INITIAL,
                              cfop=cfop,
+                             reason=reason,
                              connection=self.trans)
 
     def create_city_location(self):
         from stoqlib.domain.address import CityLocation
-        return CityLocation(country='Groenlandia',
-                            city='Acapulco',
-                            state='Wisconsin',
-                            connection=self.trans)
+        return CityLocation.get_or_create(
+            self.trans,
+            country='United States',
+            city='Los Angeles',
+            state='Californa',
+            )
 
-    def create_address(self):
+    def create_address(self, person=None, city_location=None):
         from stoqlib.domain.address import Address
+        city_location = city_location or self.create_city_location()
         return Address(street='Mainstreet',
                        streetnumber=138,
                        district='Cidade Araci',
                        postal_code='12345-678',
                        complement='Compl',
                        is_main_address=True,
-                       person=None,
-                       city_location=self.create_city_location(),
+                       person=person,
+                       city_location=city_location,
                        connection=self.trans)
 
     def create_parameter_data(self):
@@ -487,38 +548,52 @@ class ExampleCreator(object):
         from stoqlib.domain.profile import UserProfile
         return UserProfile(connection=self.trans, name='assistant')
 
-    def create_purchase_order(self):
+    def create_profile_settings(self, user_profile=None, app='admin'):
+        from stoqlib.domain.profile import ProfileSettings
+        if not user_profile:
+            user_profile = self.create_user_profile()
+        return ProfileSettings(connection=self.trans, app_dir_name=app,
+                               has_permission=True,
+                               user_profile=user_profile)
+
+    def create_purchase_order(self, supplier=None, branch=None):
         from stoqlib.domain.purchase import PurchaseOrder
         group = self.create_payment_group()
-        return PurchaseOrder(supplier=self.create_supplier(),
-                              branch=self.create_branch(),
-                              group=group,
-                              responsible=get_current_user(self.trans),
-                              connection=self.trans)
+        return PurchaseOrder(supplier=supplier or self.create_supplier(),
+                             branch=branch or self.create_branch(),
+                             group=group,
+                             responsible=get_current_user(self.trans),
+                             connection=self.trans)
 
-    def create_quote_group(self):
+    def create_quote_group(self, branch=None):
         from stoqlib.domain.purchase import QuoteGroup
-        return QuoteGroup(connection=self.trans)
+        if not branch:
+            branch = get_current_branch(self.trans)
+        return QuoteGroup(connection=self.trans, branch=branch)
 
     def create_quotation(self):
         from stoqlib.domain.purchase import Quotation
-        quote_group = self.create_quote_group()
         purchase_order = self.create_purchase_order()
+        quote_group = self.create_quote_group(branch=purchase_order.branch)
         return Quotation(connection=self.trans,
                          group=quote_group,
-                         purchase=purchase_order)
+                         purchase=purchase_order,
+                         branch=purchase_order.branch)
+
+    def create_purchase_order_item(self, order=None):
+        if not order:
+            order = self.create_purchase_order()
 
-    def create_purchase_order_item(self):
         from stoqlib.domain.purchase import PurchaseItem
         return PurchaseItem(connection=self.trans,
                             quantity=8, quantity_received=0,
                             cost=125, base_cost=125,
                             sellable=self.create_sellable(),
-                            order=self.create_purchase_order())
+                            order=order)
 
     def create_production_order(self):
         from stoqlib.domain.production import ProductionOrder
-        return ProductionOrder(branch=self.create_branch(),
+        return ProductionOrder(branch=get_current_branch(self.trans),
                                responsible=self.create_employee(),
                                description='production',
                                connection=self.trans)
@@ -569,7 +644,7 @@ class ExampleCreator(object):
         return CfopData(connection=self.trans, code=u'123',
                         description=u'test')
 
-    def create_receiving_order(self, purchase_order=None):
+    def create_receiving_order(self, purchase_order=None, branch=None, user=None):
         from stoqlib.domain.receiving import ReceivingOrder
         if purchase_order is None:
             purchase_order = self.create_purchase_order()
@@ -578,9 +653,9 @@ class ExampleCreator(object):
         return ReceivingOrder(connection=self.trans,
                               invoice_number=222,
                               supplier=purchase_order.supplier,
-                              responsible=self.create_user(),
+                              responsible=user or get_current_user(self.trans),
                               purchase=purchase_order,
-                              branch=self.create_branch(),
+                              branch=branch or get_current_branch(self.trans),
                               cfop=cfop)
 
     def create_receiving_order_item(self, receiving_order=None, sellable=None,
@@ -631,29 +706,21 @@ class ExampleCreator(object):
                                              iss_value=10,
                                              invoice_number=201)
 
-    def create_service(self):
+    def create_service(self, description='Description', price=10):
         from stoqlib.domain.sellable import Sellable, SellableTaxConstant
         from stoqlib.domain.service import Service
         tax_constant = SellableTaxConstant.get_by_type(
             TaxType.SERVICE, self.trans)
         sellable = Sellable(tax_constant=tax_constant,
-                            price=10,
-                            description="Description",
+                            price=price,
+                            description=description,
                             connection=self.trans)
         service = Service(sellable=sellable, connection=self.trans)
         return service
 
-    def create_renegotiation_data(self):
-        from stoqlib.domain.renegotiation import RenegotiationData
-        person = self.create_person()
-        return RenegotiationData(connection=self.trans,
-                                 paid_total=10,
-                                 invoice_number=None,
-                                 responsible=person)
-
-    def create_transporter(self):
+    def create_transporter(self, name='John'):
         from stoqlib.domain.person import Company, Transporter
-        person = self.create_person()
+        person = self.create_person(name)
         Company(person=person, connection=self.trans)
         return Transporter(person=person,
                            connection=self.trans)
@@ -675,14 +742,16 @@ class ExampleCreator(object):
                               short_name='Velec',
                               open_contract_date=datetime.date(2006, 01, 01))
 
-    def create_payment(self, payment_type=None, date=None,
-                       value=None, method=None):
+    def create_payment(self, payment_type=None, date=None, value=None,
+                       method=None, branch=None, group=None):
         from stoqlib.domain.payment.payment import Payment
         if payment_type is None:
             payment_type = Payment.TYPE_OUT
         if not date:
             date = datetime.date.today()
-        return Payment(group=None,
+        return Payment(group=group or self.create_payment_group(),
+                       description='Test payment',
+                       branch=branch or get_current_branch(self.trans),
                        open_date=date,
                        due_date=date,
                        value=Decimal(10),
@@ -692,6 +761,22 @@ class ExampleCreator(object):
                        connection=self.trans,
                        payment_type=payment_type)
 
+    def create_card_payment(self, date=None, provider_id='AMEX'):
+        from stoqlib.domain.payment.method import CreditCardData
+        from stoqlib.domain.person import CreditProvider
+        if date is None:
+            date = datetime.datetime.today()
+
+        provider = CreditProvider.selectOneBy(provider_id=provider_id,
+                                              connection=self.trans)
+        payment = self.create_payment(date=date,
+                                      method=self.get_payment_method('card'))
+
+        CreditCardData(payment=payment, provider=provider,
+                       connection=self.trans)
+
+        return payment
+
     def create_payment_group(self):
         from stoqlib.domain.payment.group import PaymentGroup
         return PaymentGroup(connection=self.trans)
@@ -707,13 +792,13 @@ class ExampleCreator(object):
     def create_station(self):
         from stoqlib.domain.station import BranchStation
         return BranchStation(name="station",
-                             branch=None,
+                             branch=get_current_branch(self.trans),
                              connection=self.trans)
 
-    def create_transfer_order(self):
+    def create_transfer_order(self, source_branch=None, dest_branch=None):
         from stoqlib.domain.transfer import TransferOrder
-        source_branch = self.create_branch("Source")
-        dest_branch = self.create_branch("Dest")
+        source_branch = source_branch or self.create_branch("Source")
+        dest_branch = dest_branch or self.create_branch("Dest")
         source_resp = self.create_employee("Ipswich")
         dest_resp = self.create_employee("Bolton")
         return TransferOrder(source_branch=source_branch,
@@ -722,25 +807,27 @@ class ExampleCreator(object):
                              destination_responsible=dest_resp,
                              connection=self.trans)
 
-    def create_transfer_order_item(self, order=None, quantity=5):
+    def create_transfer_order_item(self, order=None, quantity=5, sellable=None):
         from stoqlib.domain.product import Product, Storable
         from stoqlib.domain.sellable import Sellable
         from stoqlib.domain.transfer import TransferOrderItem
         if not order:
             order = self.create_transfer_order()
-        sellable = self.create_sellable()
-        sellable.status = Sellable.STATUS_AVAILABLE
+        if not sellable:
+            sellable = self.create_sellable()
+            sellable.status = Sellable.STATUS_AVAILABLE
         product = Product.selectOneBy(sellable=sellable, connection=self.trans)
-        storable = Storable(product=product, connection=self.trans)
-        storable.increase_stock(quantity, order.source_branch)
+        if not product.storable:
+            storable = Storable(product=product, connection=self.trans)
+            storable.increase_stock(quantity, order.source_branch)
         return TransferOrderItem(sellable=sellable,
                                  transfer_order=order,
                                  quantity=quantity,
                                  connection=self.trans)
 
-    def create_inventory(self):
+    def create_inventory(self, branch=None):
         from stoqlib.domain.inventory import Inventory
-        branch = self.create_branch("Main")
+        branch = branch or self.create_branch("Main")
         return Inventory(branch=branch, connection=self.trans)
 
     def create_inventory_item(self, inventory=None, quantity=5):
@@ -758,23 +845,28 @@ class ExampleCreator(object):
                              inventory=inventory,
                              connection=self.trans)
 
-    def create_loan(self):
+    def create_loan(self, branch=None, client=None):
         from stoqlib.domain.loan import Loan
-        user = self.create_user()
+        user = get_current_user(self.trans)
         return Loan(responsible=user,
-                    branch=self.create_branch(),
+                    client=client,
+                    branch=branch or get_current_branch(self.trans),
                     connection=self.trans)
 
-    def create_loan_item(self):
+    def create_loan_item(self, loan=None, product=None, quantity=1):
         from stoqlib.domain.loan import LoanItem
         from stoqlib.domain.product import Storable
-        loan = self.create_loan()
-        sellable = self.create_sellable()
-        storable = Storable(product=sellable.product,
-                            connection=self.trans)
-        storable.increase_stock(10, loan.branch)
+        loan = loan or self.create_loan()
+        if not product:
+            sellable = self.create_sellable()
+            storable = Storable(product=sellable.product,
+                                connection=self.trans)
+            storable.increase_stock(10, loan.branch)
+        else:
+            sellable = product.sellable
+            storable = product.storable
         return LoanItem(loan=loan, sellable=sellable, price=10,
-                        quantity=1, connection=self.trans)
+                        quantity=quantity, connection=self.trans)
 
     def get_payment_method(self, name='money'):
         from stoqlib.domain.payment.method import PaymentMethod
@@ -797,25 +889,40 @@ class ExampleCreator(object):
         storable.increase_stock(100, get_current_branch(self.trans))
         return sellable
 
-    def add_payments(self, obj, method_type='money', date=None):
+    def add_payments(self, obj, method_type='money', installments=1,
+                     date=None):
         from stoqlib.domain.sale import Sale
         from stoqlib.domain.purchase import PurchaseOrder
+        assert installments > 0
+        if not date:
+            date = datetime.datetime.today()
+        elif isinstance(date, datetime.date):
+            date = datetime.datetime(date.year, date.month, date.day)
+
         method = self.get_payment_method(method_type)
+        due_dates = self.create_installment_dates(date, installments)
         if isinstance(obj, Sale):
-            total = obj.get_sale_subtotal()
-            payment = method.create_inpayment(obj.group, total)
+            total = obj.get_total_sale_amount()
+            payment = method.create_inpayments(obj.group, obj.branch, total,
+                                               due_dates=due_dates)
         elif isinstance(obj, PurchaseOrder):
-            total = obj.get_purchase_subtotal()
-            payment = method.create_outpayment(obj.group, total)
+            total = obj.get_purchase_total()
+            payment = method.create_outpayments(obj.group, obj.branch, total,
+                                                due_dates=due_dates)
         else:
             raise ValueError(obj)
 
-        if date:
-            payment.due_date = date
-            payment.open_date = date
+        for p in payment:
+            p.open_date = date
 
         return payment
 
+    def create_installment_dates(self, date, installments):
+        due_dates = []
+        for i in range(installments):
+            due_dates.append(date + datetime.timedelta(days=i))
+        return due_dates
+
     def create_account(self):
         from stoqlib.domain.account import Account
         return Account(description="Test Account",
@@ -862,15 +969,25 @@ class ExampleCreator(object):
                                 station=self.create_station(),
                                 connection=self.trans)
 
-    def create_call(self):
+    def create_call(self, person=None, attendant=None):
         from stoqlib.domain.person import Calls
         return Calls(date=datetime.date(2011, 1, 1),
                      message="Test call message",
-                     person=self.create_person(),
-                     attendant=self.create_user(),
+                     person=person or self.create_person(),
+                     attendant=attendant or self.create_user(),
                      description="Test call",
                      connection=self.trans)
 
+    def create_credit_check_history(self, user=None, client=None):
+        from stoqlib.domain.person import CreditCheckHistory
+        return CreditCheckHistory(check_date=datetime.date(2011, 1, 1),
+                                  identifier="identifier123",
+                                  status=CreditCheckHistory.STATUS_NOT_INCLUDED,
+                                  notes="random note",
+                                  user=user or self.create_user(),
+                                  client=client or self.create_client(),
+                                  connection=self.trans)
+
     def create_commission_source(self, category=None):
         from stoqlib.domain.commission import CommissionSource
         if not category:
@@ -882,3 +999,47 @@ class ExampleCreator(object):
                                 sellable=sellable,
                                 installments_value=1,
                                 connection=self.trans)
+
+    def create_invoice_printer(self):
+        from stoqlib.domain.invoice import InvoicePrinter
+        return InvoicePrinter(device_name='/dev/ttyS0',
+                              description='Invoice Printer',
+                              connection=self.trans)
+
+    def create_delivery(self):
+        from stoqlib.domain.sale import Delivery
+        return Delivery(connection=self.trans)
+
+    def create_liaison(self):
+        from stoqlib.domain.person import Liaison
+        return Liaison(connection=self.trans,
+                       person=self.create_person(),
+                       name='name',
+                       phone_number='12345678')
+
+    def create_work_permit_data(self):
+        from stoqlib.domain.person import WorkPermitData
+        return WorkPermitData(connection=self.trans)
+
+    def create_military_data(self):
+        from stoqlib.domain.person import MilitaryData
+        return MilitaryData(connection=self.trans)
+
+    def create_voter_data(self):
+        from stoqlib.domain.person import VoterData
+        return VoterData(connection=self.trans)
+
+    def create_image(self):
+        from stoqlib.domain.image import Image
+        return Image(
+            connection=self.trans,
+            description="Test image",
+            )
+
+    def create_payment_renegotiation(self, group=None):
+        from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
+        return PaymentRenegotiation(responsible=get_current_user(self.trans),
+                                    branch=get_current_branch(self.trans),
+                                    group=group or self.create_payment_group(),
+                                    client=self.create_client(),
+                                    connection=self.trans)
