@@ -33,7 +33,7 @@ from zope.interface import implements
 
 from stoqlib.database.orm import (UnicodeCol, DateTimeCol, ForeignKey, IntCol,
                                   BoolCol)
-from stoqlib.database.orm import LEFTJOINOn, INNERJOINOn, const
+from stoqlib.database.orm import LeftJoin, Join, const
 from stoqlib.database.orm import Viewable
 from stoqlib.database.orm import PriceCol
 from stoqlib.database.runtime import get_current_branch
@@ -63,7 +63,7 @@ class FiscalBookEntry(Domain):
      TYPE_SERVICE,
      TYPE_INVENTORY) = range(3)
 
-    date = DateTimeCol(default=datetime.datetime.now)
+    date = DateTimeCol(default_factory=datetime.datetime.now)
     is_reversal = BoolCol(default=False)
     invoice_number = IntCol()
     cfop = ForeignKey("CfopData")
@@ -145,13 +145,18 @@ class FiscalBookEntry(Domain):
             iss_value=value,
             )
 
-    def reverse_entry(self, invoice_number):
+    def reverse_entry(self, invoice_number,
+                      iss_value=None, icms_value=None, ipi_value=None):
         conn = self.get_connection()
+        icms_value = icms_value if icms_value is not None else self.icms_value
+        iss_value = iss_value if iss_value is not None else self.iss_value
+        ipi_value = ipi_value if ipi_value is not None else self.ipi_value
+
         return FiscalBookEntry(
             entry_type=self.entry_type,
-            iss_value=self.iss_value,
-            icms_value=self.icms_value,
-            ipi_value=self.ipi_value,
+            iss_value=iss_value,
+            icms_value=icms_value,
+            ipi_value=ipi_value,
             cfop=sysparam(conn).DEFAULT_RETURN_SALES_CFOP,
             branch=self.branch,
             invoice_number=invoice_number,
@@ -165,21 +170,21 @@ class _FiscalBookEntryView(Viewable):
 
     columns = dict(
         id=FiscalBookEntry.q.id,
-        date=FiscalBookEntry.q.date,
+        date=const.DATE(FiscalBookEntry.q.date),
         invoice_number=FiscalBookEntry.q.invoice_number,
-        cfop_id=FiscalBookEntry.q.cfopID,
-        branch_id=FiscalBookEntry.q.branchID,
-        drawee_id=FiscalBookEntry.q.draweeID,
-        payment_group_id=FiscalBookEntry.q.payment_groupID,
+        cfop_id=FiscalBookEntry.q.cfop_id,
+        branch_id=FiscalBookEntry.q.branch_id,
+        drawee_id=FiscalBookEntry.q.drawee_id,
+        payment_group_id=FiscalBookEntry.q.payment_group_id,
         cfop_code=CfopData.q.code,
         drawee_name=Person.q.name,
         )
 
     joins = [
-        LEFTJOINOn(None, Person,
-                   Person.q.id == FiscalBookEntry.q.draweeID),
-        INNERJOINOn(None, CfopData,
-                    CfopData.q.id == FiscalBookEntry.q.cfopID)
+        LeftJoin(Person,
+                   Person.q.id == FiscalBookEntry.q.drawee_id),
+        Join(CfopData,
+                    CfopData.q.id == FiscalBookEntry.q.cfop_id)
         ]
 
     @property
