@@ -36,13 +36,12 @@ from kiwi.argcheck import argcheck
 from kiwi.currency import currency
 from zope.interface import implements
 
-from stoqlib.database.orm import IntCol, ForeignKey
+from stoqlib.database.orm import ForeignKey
 from stoqlib.database.orm import SingleJoin
 from stoqlib.database.orm import AND, IN
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -51,21 +50,8 @@ _ = stoqlib_gettext
 class PaymentGroup(Domain):
     """A base class for payment group adapters. """
 
-    (STATUS_INITIAL,
-     STATUS_CONFIRMED,
-     STATUS_PAID,
-     STATUS_CANCELLED) = range(4)
-
-    statuses = {
-        STATUS_INITIAL: _(u"Preview"),
-        STATUS_CONFIRMED: _(u"Confirmed"),
-        STATUS_PAID: _(u"Closed"),
-        STATUS_CANCELLED: _(u"Cancelled"),
-        }
-
     implements(IContainer)
 
-    status = IntCol(default=STATUS_INITIAL)
     payer = ForeignKey('Person', default=None)
     recipient = ForeignKey('Person', default=None)
     # This is where this payment group was renegotiated, ie, this payments
@@ -114,89 +100,81 @@ class PaymentGroup(Domain):
         return self.payments.count()
 
     #
-    # Fiscal methods
+    # Private
     #
 
     def _get_paid_payments(self):
-        return Payment.select(AND(Payment.q.groupID == self.id,
+        return Payment.select(AND(Payment.q.group_id == self.id,
                                   IN(Payment.q.status,
                                      [Payment.STATUS_PAID,
                                       Payment.STATUS_REVIEWING,
                                       Payment.STATUS_CONFIRMED])),
                               connection=self.get_connection())
 
+    def _get_payments_sum(self, payments, attr):
+        in_payments_value = payments.filterBy(
+            payment_type=Payment.TYPE_IN).sum(attr) or 0
+        out_payments_value = payments.filterBy(
+            payment_type=Payment.TYPE_OUT).sum(attr) or 0
+
+        if self.sale or self._renegotiation:
+            return currency(in_payments_value - out_payments_value)
+        elif self.purchase:
+            return currency(out_payments_value - in_payments_value)
+
+        # FIXME: Is this right for payments not linked to a
+        #        sale/purchase/renegotiation?
+        return currency(payments.sum(attr) or 0)
+
     #
     # Public API
     #
 
-    def can_cancel(self):
-        """Everything can be called
-        :returns: True if the payment group can be cancelled, otherwise False
-        """
-        return self.status != PaymentGroup.STATUS_CANCELLED
-
-    def can_confirm(self):
-        """Newly created payment groups can be confirmed
-        :returns: True if the payment group can be confirmed, otherwise False
-        """
-        return self.status == PaymentGroup.STATUS_INITIAL
-
-    def can_pay(self):
-        """Confirmed payment groups can be paid
-        :returns: True if the payment group can be paid, otherwise False
-        """
-        return self.status == PaymentGroup.STATUS_CONFIRMED
-
     def confirm(self):
-        """Confirms the payment group
+        """Confirms all payments in this payment group
+
         Confirming the payment group means that the customer has
         confirmed the transactions. All individual payments are set to
         pending.
         """
-        assert self.can_confirm(), self.get_status_string()
-
         for payment in self.get_valid_payments():
+            if payment.is_pending() or payment.is_paid():
+                continue
             payment.set_pending()
 
-        self.status = PaymentGroup.STATUS_CONFIRMED
-
     def pay(self):
-        """Pay all payments in the payment group
+        """Pay all payments in this payment group
         """
-        assert self.can_pay(), self.get_status_string()
-
         for payment in self.get_valid_payments():
+            if payment.is_paid():
+                continue
             payment.pay()
 
-        self.status = PaymentGroup.STATUS_PAID
-
     def pay_money_payments(self):
-        """Pay all money payments in the payment group
+        """Pay all money payments in this payment group
         """
-        assert self.can_pay(), self.get_status_string()
-
         for payment in self.get_valid_payments():
-            if payment.is_money():
+            if payment.is_money() and not payment.is_paid():
                 payment.pay()
 
     def cancel(self):
-        """Cancel all payments in the payment group
+        """Cancel all pending payments in this payment group
         """
-        assert self.can_cancel(), self.get_status_string()
-
         for payment in self.get_pending_payments():
+            if payment.is_cancelled():
+                continue
             payment.cancel()
 
-        self.status = PaymentGroup.STATUS_CANCELLED
-
     def get_total_paid(self):
-        return currency(self._get_paid_payments().sum('value') or 0)
+        return self._get_payments_sum(self._get_paid_payments(),
+                                      Payment.q.value)
 
     def get_total_value(self):
         """Returns the sum of all payment values.
         :returns: the total payment value or zero.
         """
-        return currency(self.get_valid_payments().sum('value') or 0)
+        return self._get_payments_sum(self.get_valid_payments(),
+                                      Payment.q.value)
 
     def clear_unused(self):
         """Delete payments of preview status associated to the current
@@ -220,9 +198,9 @@ class PaymentGroup(Domain):
         if self.sale:
             return _(u'sale %s') % self.sale.get_order_number_str()
         elif self.purchase:
-            return _(u'order %s') % self.purchase.id
+            return _(u'order %s') % self.purchase.identifier
         elif self._renegotiation:
-            return _(u'renegotiation %s') % self._renegotiation.id
+            return _(u'renegotiation %s') % self._renegotiation.identifier
         # FIXME: Add a proper description
         else:
             return ''
@@ -243,49 +221,37 @@ class PaymentGroup(Domain):
             return self._renegotiation
         return None
 
-    def get_status_string(self):
-        if not self.status in PaymentGroup.statuses.keys():
-            raise DatabaseInconsistency("Invalid status, got %d"
-                                        % self.status)
-        return self.statuses[self.status]
-
     def get_total_discount(self):
         """Returns the sum of all payment discounts.
         :returns: the total payment discount or zero.
         """
-        discount = Payment.selectBy(
-            group=self, connection=self.get_connection()).sum('discount')
-
-        return currency(discount or 0)
+        return self._get_payments_sum(self.get_valid_payments(),
+                                      Payment.q.discount)
 
     def get_total_interest(self):
         """Returns the sum of all payment interests.
         :returns: the total payment interest or zero.
         """
-        interest = Payment.selectBy(
-            group=self, connection=self.get_connection()).sum('interest')
-
-        return currency(interest or 0)
+        return self._get_payments_sum(self.get_valid_payments(),
+                                      Payment.q.interest)
 
     def get_total_penalty(self):
         """Returns the sum of all payment penalties.
         :returns: the total payment penalty or zero.
         """
-        penalty = Payment.selectBy(
-            group=self, connection=self.get_connection()).sum('penalty')
-
-        return currency(penalty or 0)
+        return self._get_payments_sum(self.get_valid_payments(),
+                                      Payment.q.penalty)
 
     def get_valid_payments(self):
         """Returns all payments that are not cancelled.
         """
-        return Payment.select(AND(Payment.q.groupID == self.id,
+        return Payment.select(AND(Payment.q.group_id == self.id,
                                   Payment.q.status != Payment.STATUS_CANCELLED),
                               connection=self.get_connection())
 
     def get_payments_by_method_name(self, method_name):
         from stoqlib.domain.payment.method import PaymentMethod
-        return Payment.select(AND(Payment.q.groupID == self.id,
-                                  Payment.q.methodID == PaymentMethod.q.id,
+        return Payment.select(AND(Payment.q.group_id == self.id,
+                                  Payment.q.method_id == PaymentMethod.q.id,
                                   PaymentMethod.q.method_name == method_name),
                               connection=self.get_connection())
