@@ -61,7 +61,7 @@ class MoneyPaymentOperation(object):
         pass
 
     def create_transaction(self):
-        return False
+        return True
 
     def selectable(self, method):
         return True
@@ -276,6 +276,10 @@ class CardPaymentOperation(object):
     def require_person(self, payment_type):
         return False
 
+    #
+    #  Public API
+    #
+
     @argcheck(Payment)
     def get_card_data_by_payment(self, payment):
         """Get an existing CreditCardData instance from a payment object."""
@@ -436,6 +440,58 @@ class OnlinePaymentOperation(object):
     def print_(self, payment):
         pass
 
+    def require_person(self, payment_type):
+        return True
+
+
+class TradePaymentOperation(object):
+    implements(IPaymentOperation)
+
+    description = _('Trade')
+    max_installments = 1
+
+    #
+    # IPaymentOperation
+    #
+
+    def payment_create(self, payment):
+        pass
+
+    def payment_delete(self, payment):
+        pass
+
+    def create_transaction(self):
+        # FIXME: Is it right to not create a transaction for this?
+        return False
+
+    def selectable(self, method):
+        return False
+
+    def creatable(self, method, payment_type, separate):
+        return False
+
+    def can_cancel(self, payment):
+        return False
+
+    def can_change_due_date(self, payment):
+        return False
+
+    def can_pay(self, payment):
+        return False
+
+    def can_print(self, payment):
+        return False
+
+    def print_(self, payment):
+        pass
+
+    def get_constant(self, payment):
+        # FIXME: What constant should this get?
+        return PaymentMethodType.MONEY
+
+    def require_person(self, payment_type):
+        return False
+
 
 # The MultiplePaymentOperation is not a payment operation, but we need to
 # register it, so it could be activated or not. It will not create anything
@@ -492,6 +548,9 @@ class MultiplePaymentOperation(object):
     def get_constant(self, payment):
         return PaymentMethodType.MULTIPLE
 
+    def require_person(self, payment_type):
+        return False
+
 
 class InvalidPaymentOperation(object):
     """This operation will be used as a fallback for methods that wore removed
@@ -540,6 +599,9 @@ class InvalidPaymentOperation(object):
     def print_(self, payment):
         pass
 
+    def require_person(self, payment_type):
+        return False
+
 
 def get_payment_operation_manager():
     """Returns the payment operation manager"""
@@ -556,6 +618,7 @@ def get_payment_operation_manager():
             ('bill', BillPaymentOperation),
             ('card', CardPaymentOperation),
             ('store_credit', StoreCreditPaymentOperation),
+            ('trade', TradePaymentOperation),
             ('multiple', MultiplePaymentOperation),
             ('deposit', DepositPaymentOperation),
             ('online', OnlinePaymentOperation),
