@@ -25,27 +25,26 @@
 
 This module is centered around payments.
 
-The main payment class is :class:`Payment` which is a transfer of money, to/from
-a :class:`branch <stoqlib.domain.person.Branch>`.
+The main payment class is |payment| which is a transfer of money,
+to or from a |branch|.
 
-Certain changes to a payment is saved in :class:`PaymentChangeHistory` and
-:class:`PaymentFlowHistory`.
+Certain changes to a payment is saved in :class:`PaymentChangeHistory`
 """
 
 import datetime
-from decimal import Decimal
 
 from kiwi.currency import currency
 from kiwi.log import Logger
 
+from stoqlib.database.orm import AutoReload
 from stoqlib.database.orm import (IntCol, DateTimeCol, UnicodeCol, ForeignKey,
                                   PriceCol)
-from stoqlib.database.orm import (const, DESC, AND, OR, MultipleJoin,
-                                  SingleJoin)
+from stoqlib.database.orm import const, MultipleJoin, SingleJoin
+from stoqlib.domain.account import AccountTransaction
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
-from stoqlib.domain.account import AccountTransaction
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
+from stoqlib.lib.dateutils import create_date_interval
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -53,18 +52,15 @@ log = Logger('stoqlib.domain.payment.payment')
 
 
 class Payment(Domain):
-    """Payment, a transfer of money between a :class:`branch <stoqlib.domain.person.Branch>`
-    and :class:`client <stoqlib.domain.person.Client>` or a
-    :class:`supplier <stoqlib.domain.person.Supplier>`
+    """Payment, a transfer of money between a |branch| and |client| or a
+    |supplier|.
 
     Payments between:
 
-    * a client and a branch are :obj:`.TYPE_IN`, has a
-      :class:`sale <stoqlib.domain.sale.Sale>` associated.
-    * branch and a supplier are :obj:`.TYPE_OUT`, has a
-      :class:`purchase order <stoqlib.domain.purchase.PurchaseOrder>` associated.
+    * a client and a branch are :obj:`.TYPE_IN`, has a |sale| associated.
+    * branch and a supplier are :obj:`.TYPE_OUT`, has a |purchase| associated.
 
-    Payments are sometimes referred to as *installements*.
+    Payments are sometimes referred to as *installments*.
 
     Sales and purchase orders can be accessed via the
     :obj:`payment group <.group>`
@@ -105,13 +101,11 @@ class Payment(Domain):
     """
 
     #: incoming to the company, accounts receivable, payment from
-    #: a :class:`~stoqlib.domain.person.Client` to
-    #: a :class:`~stoqlib.domain.person.Branch`.
+    #: a |client| to a |branch|
     TYPE_IN = 0
 
     #: outgoing from the company, accounts payable, a payment from
-    #: a :class:`~stoqlib.domain.person.Branch` to
-    #: a :class:`~stoqlib.domain.person.Supplier`
+    #: |branch| to a |supplier|
     TYPE_OUT = 1
 
     #: payment group this payment belongs to hasn't been confirmed,
@@ -145,7 +139,12 @@ class Payment(Domain):
     #: type of payment :obj:`.TYPE_IN` or :obj:`.TYPE_OUT`
     payment_type = IntCol()
 
-    #: status, see :class:`Payment` for more information.
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
+
+    #: status, see |payment| for more information.
     status = IntCol(default=STATUS_PREVIEW)
 
     #: description payment, usually something like "1/3 Money for Sale 1234"
@@ -155,7 +154,7 @@ class Payment(Domain):
     #        inconsistencies
 
     #: when this payment was opened
-    open_date = DateTimeCol(default=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=datetime.datetime.now)
 
     #: when this payment is due
     due_date = DateTimeCol()
@@ -190,19 +189,23 @@ class Payment(Domain):
     #: number of the payment
     payment_number = UnicodeCol(default=None)
 
-    #: :class:`payment method <stoqlib.domain.payment.method.PaymentMethod>` for this
+    #: |branch| associated with this payment.
+    #: For a :obj:`.TYPE_IN` payment, this is the branch that will receive
+    #: the money. For a :obj:`.TYPE_IN` payment, this is the branch that
+    #: will make the payment
+    branch = ForeignKey('Branch', allow_none=False)
+
+    #: |paymentmethod| for this payment
     #: payment
     method = ForeignKey('PaymentMethod')
 
-    #: :class:`group <stoqlib.domain.payment.group.PaymentGroup>` for this
-    #: payment
+    #: |paymentgroup| for this payment
     group = ForeignKey('PaymentGroup')
 
-    #: :class:`till <stoqlib.domain.till.Till>` that this payment belongs to
+    #: |till| that this payment belongs to
     till = ForeignKey('Till')
 
-    #: :class:`category <stoqlib.domain.payment.category.PaymentCategory>` this
-    #: payment belongs to, can be None
+    #: |paymentmethod| this payment belongs to, can be None
     category = ForeignKey('PaymentCategory')
 
     #: list of :class:`comments <stoqlib.domain.payment.comments.PaymentComment>` for
@@ -238,6 +241,50 @@ class Payment(Domain):
 
         super(cls, Payment).delete(obj_id, connection)
 
+    @classmethod
+    def create_repeated(cls, trans, payment, repeat_type, start_date, end_date):
+        """Create a set of repeated payments.
+        Given a type of interval (*repeat_type*), a start date and an end_date,
+        this creates a list of payments for that interval.
+
+        Note, this will also update the description of the payment that's passed
+        in.
+        :param trans: a database transaction
+        :param payment: the payment to repeat
+        :param repeat_type: the kind of repetition (weekly, monthly etc)
+        :param start_date: the date to start this repetition
+        :param end_date: the date to end this repetition
+        :returns: a list of repeated payments
+        """
+        dates = create_date_interval(interval_type=repeat_type,
+                                     start_date=start_date,
+                                     end_date=end_date)
+        n_dates = dates.count()
+        if n_dates == 1:
+            raise AssertionError
+        description = payment.description
+        payment.description = '1/%d %s' % (n_dates, description)
+        payment.due_date = dates[0]
+
+        payments = []
+        for i, date in enumerate(dates[1:]):
+            p = Payment(open_date=payment.open_date,
+                        branch=payment.branch,
+                        payment_type=payment.payment_type,
+                        status=payment.status,
+                        description='%d/%d %s' % (i + 2, n_dates,
+                                                  description),
+                        value=payment.value,
+                        base_value=payment.base_value,
+                        due_date=date,
+                        method=payment.method,
+                        group=payment.group,
+                        till=payment.till,
+                        category=payment.category,
+                        connection=trans)
+            payments.append(p)
+        return payments
+
     #
     # Properties
     #
@@ -259,6 +306,13 @@ class Payment(Domain):
             if bank_account:
                 return bank_account.bank_number
 
+    @property
+    def installment_number(self):
+        payments = self.group.get_valid_payments().orderBy(Payment.q.id)
+        for i, payment in enumerate(payments):
+            if self == payment:
+                return i + 1
+
     def get_status_str(self):
         """The :obj:`.status` as a translated string"""
         if not self.status in self.statuses:
@@ -288,8 +342,6 @@ class Payment(Domain):
         self._check_status(self.STATUS_PREVIEW, 'set_pending')
         self.status = self.STATUS_PENDING
 
-        PaymentFlowHistory.add_payment(self.get_connection(), self)
-
     def set_not_paid(self, change_entry):
         """Set a :obj:`.STATUS_PAID` payment as :obj:`.STATUS_PENDING`.
         This requires clearing paid_date and paid_value
@@ -302,9 +354,6 @@ class Payment(Domain):
         change_entry.last_status = self.STATUS_PAID
         change_entry.new_status = self.STATUS_PENDING
 
-        PaymentFlowHistory.remove_paid_payment(self.get_connection(), self,
-                                               self.paid_date)
-
         self.status = self.STATUS_PENDING
         self.paid_date = None
         self.paid_value = None
@@ -321,8 +370,6 @@ class Payment(Domain):
         self.paid_date = paid_date or const.NOW()
         self.status = self.STATUS_PAID
 
-        PaymentFlowHistory.add_paid_payment(self.get_connection(), self)
-
         if (self.is_separate_payment() or
             self.method.operation.create_transaction()):
             AccountTransaction.create_from_payment(self, account)
@@ -350,12 +397,6 @@ class Payment(Domain):
             raise StoqlibError(_("Invalid status for cancel operation, "
                                  "got %s") % self.get_status_str())
 
-        if self.status == Payment.STATUS_PAID:
-            PaymentFlowHistory.remove_paid_payment(self.get_connection(),
-                                                   self)
-        else:
-            PaymentFlowHistory.remove_payment(self.get_connection(), self)
-
         old_status = self.status
         self.status = self.STATUS_CANCELLED
         self.cancel_date = const.NOW()
@@ -377,21 +418,13 @@ class Payment(Domain):
         if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
             raise StoqlibError(_("Invalid status for change_due_date operation, "
                                  "got %s") % self.get_status_str())
-        conn = self.get_connection()
-        PaymentFlowHistory.remove_payment(conn, self, self.due_date)
-        PaymentFlowHistory.add_payment(conn, self, new_due_date)
         self.due_date = new_due_date
 
     def update_value(self, new_value):
         """Update the payment value.
 
-        This will update the logging of the
-        :class:`payment flow history <PaymentFlowHistory>` as well.
         """
-        conn = self.get_connection()
-        PaymentFlowHistory.remove_payment(conn, self, self.due_date)
         self.value = new_value
-        PaymentFlowHistory.add_payment(conn, self, self.due_date)
 
     def get_payable_value(self):
         """Returns the calculated payment value with the daily penalty.
@@ -500,7 +533,7 @@ class Payment(Domain):
         return ""
 
     def get_payment_number_str(self):
-        return u'%05d' % self.id
+        return u'%05d' % self.identifier
 
     def is_inpayment(self):
         """Find out if a payment is :obj:`incoming <.TYPE_IN>`
@@ -557,14 +590,14 @@ class PaymentChangeHistory(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/payment_change_history.html>`__
     """
 
-    #: the changed :class:`payment <stoqlib.domain.payment.payment.Payment>`
+    #: the changed |payment|
     payment = ForeignKey('Payment')
 
     #: the reason of the change
     change_reason = UnicodeCol(default=None)
 
     #: when the changed happened
-    change_date = DateTimeCol(default=datetime.datetime.now)
+    change_date = DateTimeCol(default_factory=datetime.datetime.now)
 
     #: the due date that was set before the changed
     last_due_date = DateTimeCol(default=None)
@@ -577,273 +610,3 @@ class PaymentChangeHistory(Domain):
 
     #: status after change
     new_status = IntCol(default=None)
-
-
-class PaymentFlowHistory(Domain):
-    """The flow of payments during a day.
-
-    See also:
-    `schema <http://doc.stoq.com.br/schema/tables/payment_flow_history.html>`__
-    """
-
-    # FIXME: this class really needs a branch, it doesn't make sense
-    #        without one.
-
-    #: date this entry represent
-    history_date = DateTimeCol(default=datetime.datetime.now)
-
-    #: the amount scheduled to be received
-    to_receive = PriceCol(default=Decimal(0))
-
-    #: the amount received
-    received = PriceCol(default=Decimal(0))
-
-    #: the amount scheduled to be paid
-    to_pay = PriceCol(default=Decimal(0))
-
-    #: the amount paid
-    paid = PriceCol(default=Decimal(0))
-
-    #: the balance of the last day plus the amount to be received minus
-    #: the amount to be paid.
-    balance_expected = PriceCol(default=Decimal(0))
-
-    #: the balance of the last day plus the amount received minus the amount paid.
-    balance_real = PriceCol(default=Decimal(0))
-
-    #: number of payments to receive
-    to_receive_payments = IntCol(default=0)
-
-    #: number of payments received
-    received_payments = IntCol(default=0)
-
-    #: payments to pay
-    to_pay_payments = IntCol(default=0)
-
-    #: payments paid
-    paid_payments = IntCol(default=0)
-
-    #
-    # Public API
-    #
-
-    def get_last_day_real_balance(self):
-        """Returns the real balance value of the previous day or zero if
-        there's no previous day.
-        """
-        last_day = PaymentFlowHistory.get_last_day(self.get_connection(),
-                                                   self.history_date)
-        if last_day:
-            return last_day.balance_real
-        return Decimal(0)
-
-    def get_divergent_payments(self):
-        """Returns a :class:`Payment` sequence that meet to following requirements:
-
-        * The payment due date, paid date or cancel date is the current
-          PaymentFlowHistory date.
-        * The payment was paid/received with different values (eg with
-          discount or surcharges).
-        * The payment was scheduled to be paid/received in the current,
-          but it was not.
-        * The payment was not expected to be paid/received the current date.
-        """
-        date = self.history_date
-        query = AND(OR(const.DATE(Payment.q.due_date) == date,
-                       const.DATE(Payment.q.paid_date) == date,
-                       const.DATE(Payment.q.cancel_date) == date),
-                    OR(Payment.q.paid_value == None,
-                       Payment.q.value != Payment.q.paid_value,
-                       Payment.q.paid_date == None,
-                       const.DATE(Payment.q.due_date) != const.DATE(Payment.q.paid_date)))
-        return Payment.select(query, connection=self.get_connection())
-
-    #
-    # Private API
-    #
-
-    def _update_balance(self):
-        """Updates the balance_expected and balance_real values following this
-        rule:
-
-        * :obj:`.balance_expected`: last_day_balance + to_receive - to_pay
-        * :obj:`.balance_real`: last_day_balance + received - paid
-
-        """
-        last_day = self.get_last_day_real_balance()
-        old_balance_real = self.balance_real
-        self.balance_expected = last_day + self.to_receive - self.to_pay
-        self.balance_real = last_day + self.received - self.paid
-
-        # balance_real affects the future (last_day real balance)
-        if old_balance_real != self.balance_real:
-            next_day = PaymentFlowHistory.get_next_day(self.get_connection(),
-                                                       self.history_date)
-            if next_day is not None:
-                # this could take a long time update all tuples.
-                next_day._update_balance()
-
-    def _update_registers(self, payment, value, accomplished=True):
-        """Updates the :class:`PaymentFlowHistory` attributes according to the
-        :class:`payment <Payment>`, value and if the payment was accomplished or not.
-
-        :param payment: the payment that will be registered.
-        :param value: the value that will be used to update history
-          attributes.
-        :param accomplished: indicates if we should update the attributes that
-          holds information about the accomplished payments or attributes
-          related to payments that will be accomplished later.
-        """
-        if value > 0:
-            payment_qty = 1
-        else:
-            payment_qty = -1
-
-        if payment.is_outpayment():
-            if accomplished:
-                self.paid += value
-                self.paid_payments += payment_qty
-            else:
-                # XXX: Workaround for bug 4241 with PaymentFlowHistory that
-                # the values are not updated correcly.
-                to_pay = self.to_pay + value
-                if to_pay < 0:
-                    to_pay = 0
-                self.to_pay = to_pay
-                self.to_pay_payments += payment_qty
-        elif payment.is_inpayment():
-            if accomplished:
-                self.received += value
-                self.received_payments += payment_qty
-            else:
-                # XXX: Workaround for bug 4241 with PaymentFlowHistory that
-                # the values are not updated correcly.
-                to_receive = self.to_receive + value
-                if to_receive < 0:
-                    to_receive = 0
-                self.to_receive = to_receive
-                self.to_receive_payments += payment_qty
-        self._update_balance()
-
-    #
-    # Classmethods
-    #
-
-    @classmethod
-    def get_last_day(cls, conn, reference_date=None):
-        """Returns the :class:`PaymentFlowHistory` instance of the last day
-        registered or None if there is no registry. If reference_date was not
-        specified, the referente date will be the current date.
-
-        :param reference_date: the reference date to use when querying the
-                               last day.
-        :param conn: a database connection.
-        """
-        if reference_date is None:
-            reference_date = datetime.date.today()
-        results = PaymentFlowHistory.select(
-                            const.DATE(PaymentFlowHistory.q.history_date) < reference_date,
-                            orderBy=DESC(PaymentFlowHistory.q.history_date),
-                            connection=conn).limit(1)
-        if results:
-            return results[0]
-
-    @classmethod
-    def get_next_day(cls, conn, reference_date=None):
-        """Returns the :class:`PaymentFlowHistory` instance of the next day
-        registered or None if there is no registry. If reference_date was not
-        specified, the referente date will be the current date.
-
-        :param reference_date: the reference date to use when querying the
-          next day.
-        :param conn: a database connection.
-        """
-        if reference_date is None:
-            reference_date = datetime.date.today()
-        results = PaymentFlowHistory.select(
-                            const.DATE(PaymentFlowHistory.q.history_date) > reference_date,
-                            orderBy=PaymentFlowHistory.q.history_date,
-                            connection=conn).limit(1)
-        if results:
-            return results[0]
-
-    @classmethod
-    def get_or_create_flow_history(cls, conn, date):
-        """Returns a :class:`PaymentFlowHistory` instance.
-
-        :param conn: a database connection.
-        :param date: the date of the :class:`PaymentFlowHistory` we want to
-          retrieve or create.
-        """
-        if isinstance(date, datetime.datetime):
-            date = date.date()
-        day_history = PaymentFlowHistory.selectOneBy(history_date=date,
-                                                     connection=conn)
-        if day_history is not None:
-            return day_history
-        return cls(history_date=date, connection=conn)
-
-    @classmethod
-    def add_payment(cls, conn, payment, reference_date=None):
-        """Adds a payment in the :class:`PaymentFlowHistory` registry according to
-        the payment due date.
-
-        :param conn: a database connection.
-        :param payment: the payment to be added in the registry.
-        :param reference_date: the reference date to use when add the payment,
-          if not specified, the reference will be the payment due date.
-        """
-        if reference_date is None and payment.due_date:
-            reference_date = payment.due_date.date()
-        day_history = cls.get_or_create_flow_history(conn, reference_date)
-        day_history._update_registers(payment, payment.value,
-                                      accomplished=False)
-
-    @classmethod
-    def add_paid_payment(cls, conn, payment, reference_date=None):
-        """Adds a paid payment in the :class:`PaymentFlowHistory` registry. The paid
-        payment will be added in the current day registry.
-
-        :param conn: a database connection.
-        :param payment: the paid payment to be added in the registry.
-        :param reference_date: the reference date to use when add the paid
-          payment, if not specified, the reference will be the current date.
-        """
-        if reference_date is None:
-            reference_date = datetime.date.today()
-        day_history = cls.get_or_create_flow_history(conn, reference_date)
-        day_history._update_registers(payment, payment.value,
-                                      accomplished=True)
-
-    @classmethod
-    def remove_payment(cls, conn, payment, reference_date=None):
-        """Removes a payment in the :class:`PaymentFlowHistory` registry. The
-        payment will be deducted from registry according to its due date.
-
-        :param conn: a database connection.
-        :param payment: the payment to be removed in the registry.
-        :param reference_date: the reference date to use when remove the
-          payment, if not specified, the reference will be the payment due date.
-        """
-        if reference_date is None:
-            reference_date = payment.due_date.date()
-
-        day_history = cls.get_or_create_flow_history(conn, reference_date)
-        day_history._update_registers(payment, -payment.value,
-                                      accomplished=False)
-
-    @classmethod
-    def remove_paid_payment(cls, conn, payment, reference_date=None):
-        """Removes a paid payment in the :class:`PaymentFlowHistory` registry. The paid
-        payment will be removed in the current day registry.
-
-        :param conn: a database connection.
-        :param payment: the paid payment to be removed in the registry.
-        :param reference_date: the reference date to use when remove the paid
-          payment, if not specified, the reference will be the current date.
-        """
-        if reference_date is None:
-            reference_date = datetime.date.today()
-        day_history = cls.get_or_create_flow_history(conn, reference_date)
-        day_history._update_registers(payment, -payment.paid_value,
-                                      accomplished=True)
