@@ -23,11 +23,12 @@
 ##
 
 import datetime
+from dateutil.relativedelta import relativedelta
 
 from kiwi.datatypes import converter
 
 from stoqlib.database.orm import AND, OR, const
-from stoqlib.database.orm import Alias, LEFTJOINOn, INNERJOINOn
+from stoqlib.database.orm import Alias, LeftJoin, Join
 from stoqlib.database.orm import Viewable, Field
 from stoqlib.domain.account import BankAccount
 from stoqlib.domain.payment.category import PaymentCategory
@@ -41,6 +42,7 @@ from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
 from stoqlib.domain.person import Person, CreditProvider
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sale import Sale
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
 
@@ -49,7 +51,7 @@ _ = stoqlib_gettext
 
 class _CommentsSummary(Viewable):
     columns = dict(
-        id=PaymentComment.q.paymentID,
+        id=PaymentComment.q.payment_id,
         comments_number=const.COUNT(PaymentComment.q.id),
     )
 
@@ -60,6 +62,7 @@ class BasePaymentView(Viewable):
     columns = dict(
         # Payment
         id=Payment.q.id,
+        identifier=Payment.q.identifier,
         description=Payment.q.description,
         due_date=Payment.q.due_date,
         status=Payment.q.status,
@@ -67,10 +70,10 @@ class BasePaymentView(Viewable):
         value=Payment.q.value,
         paid_value=Payment.q.paid_value,
         payment_number=Payment.q.payment_number,
-        group_id=Payment.q.groupID,
+        group_id=Payment.q.group_id,
 
         # PaymentGroup
-        renegotiated_id=PaymentGroup.q.renegotiationID,
+        renegotiated_id=PaymentGroup.q.renegotiation_id,
 
         # PaymentMethod
         method_name=PaymentMethod.q.method_name,
@@ -95,41 +98,35 @@ class BasePaymentView(Viewable):
     PaymentGroup_Purchase = Alias(PaymentGroup, 'payment_group_purchase')
 
     _count_joins = [
-        LEFTJOINOn(None, PaymentGroup,
-                   PaymentGroup.q.id == Payment.q.groupID),
-        LEFTJOINOn(None, PaymentCategory,
-                   PaymentCategory.q.id == Payment.q.categoryID),
-        INNERJOINOn(None, PaymentMethod,
-                    Payment.q.methodID == PaymentMethod.q.id),
+        LeftJoin(PaymentGroup,
+                   PaymentGroup.q.id == Payment.q.group_id),
+        LeftJoin(PaymentCategory,
+                   PaymentCategory.q.id == Payment.q.category_id),
+        Join(PaymentMethod,
+                    Payment.q.method_id == PaymentMethod.q.id),
 
         # Purchase
-        LEFTJOINOn(None, PaymentGroup_Purchase,
-                   PaymentGroup_Purchase.q.id == Payment.q.groupID),
-        LEFTJOINOn(None, PurchaseOrder,
-                   PurchaseOrder.q.groupID == PaymentGroup_Purchase.q.id),
+        LeftJoin(PaymentGroup_Purchase,
+                   PaymentGroup_Purchase.q.id == Payment.q.group_id),
+        LeftJoin(PurchaseOrder,
+                   PurchaseOrder.q.group_id == PaymentGroup_Purchase.q.id),
 
         # Sale
-        LEFTJOINOn(None, PaymentGroup_Sale,
-                   PaymentGroup_Sale.q.id == Payment.q.groupID),
-        LEFTJOINOn(None, Sale,
-                   Sale.q.groupID == PaymentGroup_Sale.q.id),
+        LeftJoin(PaymentGroup_Sale,
+                   PaymentGroup_Sale.q.id == Payment.q.group_id),
+        LeftJoin(Sale,
+                   Sale.q.group_id == PaymentGroup_Sale.q.id),
     ]
 
     joins = _count_joins + [
-        LEFTJOINOn(None, CommentsSummary,
+        LeftJoin(CommentsSummary,
                    Field('_comments', 'id') == Payment.q.id),
         ]
 
     @classmethod
-    def post_search_callback(cls, conn, sresults):
-        # FIXME: Use storm api to create this query storm.expr.compile
-        from stoqlib.database.orm import Select
-        select = Select(['COUNT(*) as count',
-                         'SUM(value) as sum'],
-                        join=cls._count_joins,
-                        clause=sresults.clause,
-                        staticTables=sresults.tables)
-        return ('count', 'sum'), conn.sqlrepr(select)
+    def post_search_callback(cls, sresults):
+        select = sresults.get_select_expr(const.COUNT(1), const.SUM(cls.value))
+        return ('count', 'sum'), select
 
     def can_change_due_date(self):
         return self.status not in [Payment.STATUS_PAID,
@@ -176,7 +173,7 @@ class BasePaymentView(Viewable):
     @property
     def purchase(self):
         if self.purchase_id:
-            return PurchaseOrder.get(self.purchase_id)
+            return PurchaseOrder.get(self.purchase_id, self.get_connection())
 
     @property
     def operation(self):
@@ -187,7 +184,7 @@ class BasePaymentView(Viewable):
     @property
     def sale(self):
         if self.sale_id:
-            return Sale.get(self.sale_id)
+            return Sale.get(self.sale_id, self.get_connection())
 
     @classmethod
     def select_pending(cls, due_date=None, connection=None):
@@ -210,21 +207,21 @@ class InPaymentView(BasePaymentView):
     columns.update(dict(
         drawee=Person.q.name,
         person_id=Person.q.id,
-        renegotiated_id=PaymentGroup.q.renegotiationID,
+        renegotiated_id=PaymentGroup.q.renegotiation_id,
         renegotiation_id=PaymentRenegotiation.q.id,
         ))
 
     _count_joins = BasePaymentView._count_joins[:]
     _count_joins.append(
-        LEFTJOINOn(None, Person,
-                    PaymentGroup.q.payerID == Person.q.id))
+        LeftJoin(Person,
+                    PaymentGroup.q.payer_id == Person.q.id))
 
     joins = BasePaymentView.joins[:]
     joins.extend([
-        LEFTJOINOn(None, Person,
-                    PaymentGroup.q.payerID == Person.q.id),
-        LEFTJOINOn(None, PaymentRenegotiation,
-                   PaymentRenegotiation.q.groupID == PaymentGroup.q.id),
+        LeftJoin(Person,
+                    PaymentGroup.q.payer_id == Person.q.id),
+        LeftJoin(PaymentRenegotiation,
+                   PaymentRenegotiation.q.group_id == PaymentGroup.q.id),
     ])
 
     clause = (Payment.q.payment_type == Payment.TYPE_IN)
@@ -244,6 +241,27 @@ class InPaymentView(BasePaymentView):
     def get_parent(self):
         return self.sale or self.renegotiation
 
+    @classmethod
+    def has_late_payments(cls, conn, person):
+        """Checks if the provided person has unpaid payments that are overdue
+
+        :param person: A :class:`person <stoqlib.domain.person.Person>` to
+          check if has late payments
+        :returns: True if the person has overdue payments. False otherwise
+        """
+        tolerance = sysparam(conn).TOLERANCE_FOR_LATE_PAYMENTS
+
+        query = AND(cls.q.person_id == person.id,
+                    cls.q.status == Payment.STATUS_PENDING,
+                    cls.q.due_date < datetime.date.today() -
+                                     relativedelta(days=tolerance))
+
+        late_payments = cls.select(query, connection=conn)
+        if late_payments.any():
+            return True
+
+        return False
+
 
 class OutPaymentView(BasePaymentView):
     columns = BasePaymentView.columns.copy()
@@ -253,13 +271,13 @@ class OutPaymentView(BasePaymentView):
 
     _count_joins = BasePaymentView._count_joins[:]
     _count_joins.append(
-        LEFTJOINOn(None, Person,
-                   BasePaymentView.PaymentGroup_Sale.q.recipientID == Person.q.id))
+        LeftJoin(Person,
+                   BasePaymentView.PaymentGroup_Sale.q.recipient_id == Person.q.id))
 
     joins = BasePaymentView.joins[:]
     joins.extend([
-        LEFTJOINOn(None, Person,
-                   Person.q.id == BasePaymentView.PaymentGroup_Sale.q.recipientID),
+        LeftJoin(Person,
+                   Person.q.id == BasePaymentView.PaymentGroup_Sale.q.recipient_id),
     ])
 
     clause = (Payment.q.payment_type == Payment.TYPE_OUT)
@@ -272,6 +290,7 @@ class CardPaymentView(Viewable):
 
     columns = dict(
         id=Payment.q.id,
+        identifier=Payment.q.identifier,
         description=Payment.q.description,
         drawee_name=_DraweePerson.q.name,
         provider_name=_ProviderPerson.q.name,
@@ -285,22 +304,22 @@ class CardPaymentView(Viewable):
         fee_calc=CreditCardData.q.fee_value, )
 
     joins = [
-        INNERJOINOn(None, PaymentMethod,
-                    PaymentMethod.q.id == Payment.q.methodID),
-        INNERJOINOn(None, CreditCardData,
-                    CreditCardData.q.paymentID == Payment.q.id),
-        INNERJOINOn(None, CreditProvider,
-              CreditProvider.q.id == CreditCardData.q.providerID),
-        INNERJOINOn(None, _ProviderPerson,
-            _ProviderPerson.q.id == CreditProvider.q.personID),
-        LEFTJOINOn(None, PaymentGroup,
-                    PaymentGroup.q.id == Payment.q.groupID),
-        LEFTJOINOn(None, _DraweePerson,
-                    _DraweePerson.q.id == PaymentGroup.q.payerID),
-        LEFTJOINOn(None, Sale,
-                   Sale.q.groupID == PaymentGroup.q.id),
-        LEFTJOINOn(None, PaymentRenegotiation,
-                   PaymentRenegotiation.q.groupID == PaymentGroup.q.id),
+        Join(PaymentMethod,
+                    PaymentMethod.q.id == Payment.q.method_id),
+        Join(CreditCardData,
+                    CreditCardData.q.payment_id == Payment.q.id),
+        Join(CreditProvider,
+              CreditProvider.q.id == CreditCardData.q.provider_id),
+        Join(_ProviderPerson,
+            _ProviderPerson.q.id == CreditProvider.q.person_id),
+        LeftJoin(PaymentGroup,
+                    PaymentGroup.q.id == Payment.q.group_id),
+        LeftJoin(_DraweePerson,
+                    _DraweePerson.q.id == PaymentGroup.q.payer_id),
+        LeftJoin(Sale,
+                   Sale.q.group_id == PaymentGroup.q.id),
+        LeftJoin(PaymentRenegotiation,
+                   PaymentRenegotiation.q.group_id == PaymentGroup.q.id),
         ]
 
     def get_status_str(self):
@@ -319,7 +338,7 @@ class CardPaymentView(Viewable):
     @classmethod
     def select_by_provider(cls, query, provider, having=None, connection=None):
         if provider:
-            provider_query = CreditCardData.q.providerID == provider.id
+            provider_query = CreditCardData.q.provider_id == provider.id
             if query:
                 query = AND(query, provider_query)
             else:
@@ -332,6 +351,7 @@ class _BillandCheckPaymentView(Viewable):
     """A base view for check and bill payments."""
     columns = dict(
         id=Payment.q.id,
+        identifier=Payment.q.identifier,
         due_date=Payment.q.due_date,
         paid_date=Payment.q.paid_date,
         status=Payment.q.status,
@@ -344,11 +364,11 @@ class _BillandCheckPaymentView(Viewable):
     )
 
     joins = [
-        LEFTJOINOn(None, CheckData, Payment.q.id == CheckData.q.paymentID),
-        INNERJOINOn(None, PaymentMethod,
-                    Payment.q.methodID == PaymentMethod.q.id),
-        LEFTJOINOn(None, BankAccount,
-                   BankAccount.q.id == CheckData.q.bank_accountID),
+        LeftJoin(CheckData, Payment.q.id == CheckData.q.payment_id),
+        Join(PaymentMethod,
+                    Payment.q.method_id == PaymentMethod.q.id),
+        LeftJoin(BankAccount,
+                   BankAccount.q.id == CheckData.q.bank_account_id),
     ]
 
     clause = OR(PaymentMethod.q.method_name == 'bill',
@@ -400,13 +420,13 @@ class PaymentChangeHistoryView(Viewable):
     )
 
     joins = [
-        INNERJOINOn(None, Payment,
-                    Payment.q.id == PaymentChangeHistory.q.paymentID)
+        Join(Payment,
+                    Payment.q.id == PaymentChangeHistory.q.payment_id)
     ]
 
     @classmethod
     def select_by_group(cls, group, connection):
-        return PaymentChangeHistoryView.select((Payment.q.groupID == group.id),
+        return PaymentChangeHistoryView.select((Payment.q.group_id == group.id),
                                            connection=connection)
 
     @property
