@@ -28,9 +28,10 @@ from decimal import Decimal
 
 from zope.interface import implements
 
+from stoqlib.database.orm import AutoReload
 from stoqlib.database.orm import (UnicodeCol, ForeignKey, DateTimeCol, IntCol,
                                   QuantityCol, BoolCol, MultipleJoin)
-from stoqlib.database.orm import AND
+from stoqlib.database.orm import AND, Join, Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.product import ProductHistory
 from stoqlib.domain.interfaces import IContainer, IDescribable
@@ -47,7 +48,7 @@ class ProductionOrder(Domain):
                         have been added.
     :cvar ORDER_WAITING: The production order is waiting some conditions to
                          start the manufacturing process.
-    :cvar ORDER_PRODUCTION: The production order have already started.
+    :cvar ORDER_PRODUCING: The production order have already started.
     :cvar ORDER_CLOSED: The production have finished.
 
     :attribute status: the production order status
@@ -71,8 +72,12 @@ class ProductionOrder(Domain):
                 ORDER_QA: _(u'Quality Assurance'),
                 }
 
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
     status = IntCol(default=ORDER_OPENED)
-    open_date = DateTimeCol(default=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=datetime.datetime.now)
     expected_start_date = DateTimeCol(default=None)
     start_date = DateTimeCol(default=None)
     close_date = DateTimeCol(default=None)
@@ -197,7 +202,7 @@ class ProductionOrder(Domain):
         return ProductionOrder.statuses[self.status]
 
     def get_order_number(self):
-        return u'%04d' % self.id
+        return u'%04d' % self.identifier
 
     def get_branch_name(self):
         return self.branch.person.name
@@ -543,7 +548,7 @@ class ProductionProducedItem(Domain):
 
     @classmethod
     def is_valid_serial_range(cls, product, first, last, conn):
-        query = AND(cls.q.productID == product.id,
+        query = AND(cls.q.product_id == product.id,
                     cls.q.serial_number >= first,
                     cls.q.serial_number <= last)
         # There should be no results for the range to be valid
@@ -643,3 +648,21 @@ class ProductionItemQualityResult(Domain):
         self.test_passed = self.quality_test.result_value_passes(value)
         self.result_value = '%s' % (value, )
         self.produced_item.check_tests()
+
+
+class ProductionOrderProducingView(Viewable):
+    columns = dict(
+        id=ProductionOrder.q.id,
+        )
+
+    joins = [
+        Join(ProductionItem,
+               ProductionOrder.q.id == ProductionItem.q.order_id),
+        ]
+
+    clause = (ProductionOrder.q.status == ProductionOrder.ORDER_PRODUCING)
+
+    @classmethod
+    def is_product_being_produced(cls, product):
+        query = ProductionItem.q.product_id == product.id
+        return cls.select(query, connection=product.get_connection()).count() > 0
