@@ -30,8 +30,9 @@ from kiwi.argcheck import argcheck
 from kiwi.currency import currency
 from zope.interface import implements
 
+from stoqlib.database.orm import AutoReload
 from stoqlib.database.orm import ForeignKey, IntCol, DateTimeCol, UnicodeCol
-from stoqlib.database.orm import AND, INNERJOINOn, LEFTJOINOn, const
+from stoqlib.database.orm import AND, Join, LeftJoin, const
 from stoqlib.database.orm import Viewable, Alias, Field
 from stoqlib.database.orm import PriceCol, BoolCol, QuantityCol
 from stoqlib.database.runtime import get_current_user
@@ -57,19 +58,23 @@ _ = stoqlib_gettext
 
 class PurchaseItem(Domain):
     """This class stores information of the purchased items.
-
-    B{Importante attributes}
-        - I{base_cost}: the cost which helps the purchaser to define the
-                        main cost of a certain product.
     """
     quantity = QuantityCol(default=1)
     quantity_received = QuantityCol(default=0)
     quantity_sold = QuantityCol(default=0)
     quantity_returned = QuantityCol(default=0)
+
+    #: the cost which helps the purchaser to define the
+    #: main cost of a certain product.
     base_cost = PriceCol()
+
     cost = PriceCol()
     expected_receival_date = DateTimeCol(default=None)
+
+    #: the |sellable|
     sellable = ForeignKey('Sellable')
+
+    #: the |purchase|
     order = ForeignKey('PurchaseOrder')
 
     def _create(self, id, **kw):
@@ -123,13 +128,14 @@ class PurchaseItem(Domain):
     @classmethod
     def get_ordered_quantity(cls, conn, sellable):
         """Returns the quantity already ordered of a given sellable.
+
         :param conn: a database connection
         :param sellable: the sellable we want to know the quantity ordered.
         :returns: the quantity already ordered of a given sellable or zero if
-        no quantity have been ordered.
+          no quantity have been ordered.
         """
-        query = AND(PurchaseItem.q.sellableID == sellable.id,
-                    PurchaseOrder.q.id == PurchaseItem.q.orderID,
+        query = AND(PurchaseItem.q.sellable_id == sellable.id,
+                    PurchaseOrder.q.id == PurchaseItem.q.order_id,
                     PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED)
         ordered_items = PurchaseItem.select(query, connection=conn)
         return ordered_items.sum('quantity') or Decimal(0)
@@ -160,11 +166,16 @@ class PurchaseOrder(Domain, Adaptable):
     freight_types = {FREIGHT_FOB: _(u'FOB'),
                      FREIGHT_CIF: _(u'CIF')}
 
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
+
     status = IntCol(default=ORDER_QUOTING)
-    open_date = DateTimeCol(default=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=datetime.datetime.now)
     quote_deadline = DateTimeCol(default=None)
-    expected_receival_date = DateTimeCol(default=datetime.datetime.now)
-    expected_pay_date = DateTimeCol(default=datetime.datetime.now)
+    expected_receival_date = DateTimeCol(default_factory=datetime.datetime.now)
+    expected_pay_date = DateTimeCol(default_factory=datetime.datetime.now)
     receival_date = DateTimeCol(default=None)
     confirm_date = DateTimeCol(default=None)
     notes = UnicodeCol(default='')
@@ -180,9 +191,9 @@ class PurchaseOrder(Domain, Adaptable):
     responsible = ForeignKey('LoginUser')
     group = ForeignKey('PaymentGroup')
 
-    def __init__(self, *args, **kwargs):
+    def _init(self, *args, **kwargs):
         self.addFacet(IPaymentTransaction)
-        Domain.__init__(self, *args, **kwargs)
+        Domain._init(self, *args, **kwargs)
 
     #
     # IContainer Implementation
@@ -253,7 +264,7 @@ class PurchaseOrder(Domain, Adaptable):
 
     @property
     def order_number(self):
-        return self.id
+        return self.identifier
 
     @property
     def payments(self):
@@ -263,7 +274,7 @@ class PurchaseOrder(Domain, Adaptable):
         is, all payments on the payment group that were not cancelled.
         If you need to get the cancelled too, use self.group.payments.
 
-        :returns: a list of :class:`stoqlib.domain.payment.payment.Payment`
+        :returns: a list of |payment|
         """
         return self.group.get_valid_payments()
 
@@ -290,6 +301,7 @@ class PurchaseOrder(Domain, Adaptable):
 
     def can_cancel(self):
         """Find out if it's possible to cancel the order
+
         :returns: True if it's possible to cancel the order, otherwise False
         """
         # FIXME: Canceling partial orders disabled until we fix bug 3282
@@ -302,6 +314,7 @@ class PurchaseOrder(Domain, Adaptable):
 
     def can_close(self):
         """Find out if it's possible to close the order
+
         :returns: True if it's possible to close the order, otherwise False
         """
 
@@ -427,7 +440,8 @@ class PurchaseOrder(Domain, Adaptable):
         return self.responsible.get_description()
 
     def get_order_number_str(self):
-        return u'%05d' % self.id
+        # FIXME: Add branch acronim here
+        return u'%05d' % self.identifier
 
     def get_purchase_subtotal(self):
         """Get the subtotal of the purchase.
@@ -501,14 +515,20 @@ class PurchaseOrder(Domain, Adaptable):
 
 
 class Quotation(Domain):
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
+
     group = ForeignKey('QuoteGroup')
     purchase = ForeignKey('PurchaseOrder')
+    branch = ForeignKey('Branch')
 
     implements(IDescribable)
 
     def get_description(self):
         supplier = self.purchase.supplier.person.name
-        return "Group %04d - %s" % (self.group.id, supplier)
+        return "Group %04d - %s" % (self.group.identifier, supplier)
 
     #
     # Public API
@@ -533,6 +553,13 @@ class QuoteGroup(Domain):
 
     implements(IContainer, IDescribable)
 
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
+
+    branch = ForeignKey('Branch')
+
     #
     # IContainer
     #
@@ -556,14 +583,15 @@ class QuoteGroup(Domain):
     @argcheck(PurchaseOrder)
     def add_item(self, item):
         conn = self.get_connection()
-        return Quotation(purchase=item, group=self, connection=conn)
+        return Quotation(purchase=item, group=self, branch=self.branch,
+                         connection=conn)
 
     #
     # IDescribable
     #
 
     def get_description(self):
-        return _(u"quote number %04d" % self.id)
+        return _(u"quote number %04d" % self.identifier)
 
     #
     # Public API
@@ -600,8 +628,6 @@ class PurchaseOrderAdaptToPaymentTransaction(object):
             payment.pay()
 
     def cancel(self):
-        assert self.purchase.group.can_cancel()
-
         self._payback_paid_payments()
         self.purchase.group.cancel()
 
@@ -621,9 +647,9 @@ class PurchaseOrderAdaptToPaymentTransaction(object):
 
         money = PaymentMethod.get_by_name(self.purchase.get_connection(), 'money')
         payment = money.create_inpayment(
-            self.purchase.group, paid_value,
+            self.purchase.group, self.purchase.branch, paid_value,
             description=_('%s Money Returned for Purchase %d') % (
-            '1/1', self.purchase.id))
+            '1/1', self.purchase.identifier))
         payment.set_pending()
         payment.pay()
 
@@ -665,12 +691,12 @@ class PurchaseItemView(Viewable):
         )
 
     joins = [
-        INNERJOINOn(None, PurchaseOrder,
-                    PurchaseOrder.q.id == PurchaseItem.q.orderID),
-        INNERJOINOn(None, Sellable,
-                    Sellable.q.id == PurchaseItem.q.sellableID),
-        LEFTJOINOn(None, SellableUnit,
-                   SellableUnit.q.id == Sellable.q.unitID),
+        Join(PurchaseOrder,
+                    PurchaseOrder.q.id == PurchaseItem.q.order_id),
+        Join(Sellable,
+                    Sellable.q.id == PurchaseItem.q.sellable_id),
+        LeftJoin(SellableUnit,
+                   SellableUnit.q.id == Sellable.q.unit_id),
         ]
 
     def get_quantity_as_string(self):
@@ -684,11 +710,11 @@ class PurchaseItemView(Viewable):
     @classmethod
     def select_by_purchase(cls, purchase, connection):
         return PurchaseItemView.select(PurchaseOrder.q.id == purchase.id,
-                                       connection=connection)
+                                       connection=connection).orderBy(PurchaseItem.q.id)
 
     @property
     def purchase_item(self):
-        return PurchaseItem.get(self.id)
+        return PurchaseItem.get(self.id, self.get_connection())
 
 
 #
@@ -705,7 +731,7 @@ class _PurchaseItemSummary(Viewable):
     """
 
     columns = dict(
-        id=PurchaseItem.q.orderID,
+        id=PurchaseItem.q.order_id,
         ordered_quantity=const.SUM(PurchaseItem.q.quantity),
         received_quantity=const.SUM(PurchaseItem.q.quantity_received),
         subtotal=const.SUM(PurchaseItem.q.cost * PurchaseItem.q.quantity),
@@ -744,6 +770,7 @@ class PurchaseOrderView(Viewable):
 
     columns = dict(
         id=PurchaseOrder.q.id,
+        identifier=PurchaseOrder.q.identifier,
         status=PurchaseOrder.q.status,
         open_date=PurchaseOrder.q.open_date,
         quote_deadline=PurchaseOrder.q.quote_deadline,
@@ -769,35 +796,40 @@ class PurchaseOrderView(Viewable):
     )
 
     joins = [
-        INNERJOINOn(None, PurchaseItemSummary,
+        Join(PurchaseItemSummary,
                     Field('_purchase_item', 'id') == PurchaseOrder.q.id),
 
-        LEFTJOINOn(None, Supplier,
-                   PurchaseOrder.q.supplierID == Supplier.q.id),
-        LEFTJOINOn(None, Transporter,
-                   PurchaseOrder.q.transporterID == Transporter.q.id),
-        LEFTJOINOn(None, Branch,
-                   PurchaseOrder.q.branchID == Branch.q.id),
-        LEFTJOINOn(None, LoginUser,
-                   PurchaseOrder.q.responsibleID == LoginUser.q.id),
+        LeftJoin(Supplier,
+                   PurchaseOrder.q.supplier_id == Supplier.q.id),
+        LeftJoin(Transporter,
+                   PurchaseOrder.q.transporter_id == Transporter.q.id),
+        LeftJoin(Branch,
+                   PurchaseOrder.q.branch_id == Branch.q.id),
+        LeftJoin(LoginUser,
+                   PurchaseOrder.q.responsible_id == LoginUser.q.id),
 
-        LEFTJOINOn(None, Person_Supplier,
-                   Supplier.q.personID == Person_Supplier.q.id),
-        LEFTJOINOn(None, Person_Transporter,
-                   Transporter.q.personID == Person_Transporter.q.id),
-        LEFTJOINOn(None, Person_Branch,
-                   Branch.q.personID == Person_Branch.q.id),
-       LEFTJOINOn(None, Person_Responsible,
-                   LoginUser.q.personID == Person_Responsible.q.id),
+        LeftJoin(Person_Supplier,
+                   Supplier.q.person_id == Person_Supplier.q.id),
+        LeftJoin(Person_Transporter,
+                   Transporter.q.person_id == Person_Transporter.q.id),
+        LeftJoin(Person_Branch,
+                   Branch.q.person_id == Person_Branch.q.id),
+       LeftJoin(Person_Responsible,
+                   LoginUser.q.person_id == Person_Responsible.q.id),
     ]
 
+    @classmethod
+    def post_search_callback(cls, sresults):
+        select = sresults.get_select_expr(const.COUNT(1), const.SUM(cls.total))
+        return ('count', 'sum'), select
+
     #
     # Properties
     #
 
     @property
     def purchase(self):
-        return PurchaseOrder.get(self.id)
+        return PurchaseOrder.get(self.id, self.get_connection())
 
     #
     # Public API
