@@ -36,9 +36,10 @@ from stoqlib.database.orm import BoolCol, PriceCol, PercentCol
 from stoqlib.database.orm import DateTimeCol, UnicodeCol, IntCol, ForeignKey
 from stoqlib.database.orm import SingleJoin, MultipleJoin
 from stoqlib.database.orm import AND, IN, OR
-from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import CategoryCreateEvent, CategoryEditEvent
+from stoqlib.domain.interfaces import IDescribable
+from stoqlib.domain.image import Image
 from stoqlib.exceptions import (DatabaseInconsistency, SellableError,
                                 BarcodeDoesNotExists, TaxError)
 from stoqlib.lib.parameters import sysparam
@@ -47,6 +48,9 @@ from stoqlib.lib.validators import is_date_in_interval
 
 _ = stoqlib_gettext
 
+# pyflakes: Sellable.has_image requires that Image is imported at least once
+Image
+
 #
 # Base Domain Classes
 #
@@ -55,8 +59,6 @@ _ = stoqlib_gettext
 class SellableUnit(Domain):
     """ A class used to represent the sellable unit.
 
-    :cvar allow_fraction: If the unit allows to be represented in fractions.
-      e.g. We can have 1 car, 2 cars, but not 1/2 car.
     """
     implements(IDescribable)
 
@@ -82,6 +84,9 @@ class SellableUnit(Domain):
     #: a description (using ``CUSTOM_PM`` constant) or as an index (using UNIT_*).
     #: Also, this is directly related to the DeviceSettings editor.
     unit_index = IntCol(default=int(UnitType.CUSTOM))
+
+    #: If the unit allows to be represented in fractions.
+    #:  e.g. We can have 1 car, 2 cars, but not 1/2 car.
     allow_fraction = BoolCol(default=True)
 
     # IDescribable
@@ -115,7 +120,7 @@ class SellableTaxConstant(Domain):
         """Fetch the tax constant for tax_type
         :param tax_type: the tax constant to fetch
         :param conn: a database connection
-        :returns: a :class:`SellableTaxConstant` or None if none is found
+        :returns: a |sellabletaxconstant| or ``None`` if none is found
         """
         return SellableTaxConstant.selectOneBy(
             tax_type=int(tax_type),
@@ -144,7 +149,7 @@ class SellableCategory(Domain):
     #: belongs to this category.
     salesperson_commission = PercentCol(default=0)
 
-    #: base category of this category, None for base categories themselves
+    #: base category of this category, ``None`` for base categories themselves
     category = ForeignKey('SellableCategory', default=None)
     tax_constant = ForeignKey('SellableTaxConstant', default=None)
 
@@ -252,7 +257,7 @@ class SellableCategory(Domain):
         :param conn: a database connection
         :returns: categories
         """
-        return cls.select(cls.q.categoryID == None, connection=conn)
+        return cls.select(cls.q.category_id == None, connection=conn)
 
     #
     # Domain hooks
@@ -304,6 +309,20 @@ class ClientCategoryPrice(Domain):
         self.delete(self.id, self.get_connection())
 
 
+def _validate_code(sellable, attr, code):
+    if sellable.check_code_exists(code):
+        raise SellableError(
+            _("The sellable code %r already exists") % (code, ))
+    return code
+
+
+def _validate_barcode(sellable, attr, barcode):
+    if sellable.check_barcode_exists(barcode):
+        raise SellableError(
+            _("The sellable barcode %r already exists") % (barcode, ))
+    return barcode
+
+
 class Sellable(Domain):
     """ Sellable information of a certain item such a product
     or a service. Note that sellable is not actually a concrete item but
@@ -324,11 +343,11 @@ class Sellable(Domain):
                 STATUS_BLOCKED: _(u'Blocked')}
 
     #: an internal code identifying the sellable in Stoq
-    code = UnicodeCol(default='')
+    code = UnicodeCol(default='', validator=_validate_code)
 
     #: barcode, mostly for products, usually printed and attached to the
     #: package.
-    barcode = UnicodeCol(default='')
+    barcode = UnicodeCol(default='', validator=_validate_barcode)
 
     # This default status is used when a new sellable is created,
     # so it must be *always* UNAVAILABLE (that means no stock for it).
@@ -390,20 +409,6 @@ class Sellable(Domain):
 
         Domain._create(self, id, **kw)
 
-    #
-    # ORMObject setters
-    #
-
-    def _set_code(self, code):
-        if self.check_code_exists(code):
-            raise SellableError(_("The code %s already exists") % code)
-        self._SO_set_code(code)
-
-    def _set_barcode(self, barcode):
-        if self.check_barcode_exists(barcode):
-            raise SellableError(_("The barcode %s already exists") % barcode)
-        self._SO_set_barcode(barcode)
-
     #
     # Helper methods
     #
@@ -423,14 +428,15 @@ class Sellable(Domain):
 
     @property
     def product_storable(self):
-        """If this is a product and has stock, fetch the storable for this.
+        """If this is a |product| and has stock, fetch the |storable| for this.
         This is a shortcut to avoid having to do multiple queries and
-        check if product isn't none before fetching the storable.
-        :returns: The storable or None if there isn't one
+        check if |product| is set before fetching the |storable|.
+
+        :returns: The |storable| or ``None`` if there isn't one
         """
         from stoqlib.domain.product import Product, Storable
-        return Storable.selectOne(AND(Storable.q.productID == Product.q.id,
-                                      Product.q.sellableID == self.id),
+        return Storable.selectOne(AND(Storable.q.product_id == Product.q.id,
+                                      Product.q.sellable_id == self.id),
                                   connection=self.get_connection())
 
     @property
@@ -505,7 +511,7 @@ class Sellable(Domain):
     def is_closed(self):
         """Whether the sellable is closed or not.
 
-        :returns: True if closed, False otherwise.
+        :returns: ``True`` if closed, False otherwise.
         """
         return self.status == Sellable.STATUS_CLOSED
 
@@ -532,9 +538,10 @@ class Sellable(Domain):
     def can_remove(self):
         """Whether we can delete this sellable from the database.
 
-        `False` if the product/service was used in some cases below::
+        ``False`` if the product/service was used in some cases below::
+
           - Sold or received
-          - The product is in a purchase
+          - The |product| is in a |purchase|
         """
         from stoqlib.domain.sale import SaleItem
         if SaleItem.selectBy(connection=self.get_connection(),
@@ -561,9 +568,9 @@ class Sellable(Domain):
     def can_close(self):
         """Whether we can close this sellable.
 
-        :returns: True if the product has no stock left or the service
+        :returns: ``True`` if the product has no stock left or the service
             is not required by the system (i.e. Delivery service is
-            required). False otherwise.
+            required). ``False`` otherwise.
         """
         if self.service:
             return self.service.can_close()
@@ -573,7 +580,7 @@ class Sellable(Domain):
         return self.commission
 
     def get_short_description(self):
-        """Returns a short description of the current sale
+        """Returns a short description of the current sellable
 
         :returns: description
         :rtype: string
@@ -605,10 +612,10 @@ class Sellable(Domain):
         return category and category.description or u""
 
     def get_tax_constant(self):
-        """Returns the tax constant for this sellable.
+        """Returns the |sellabletaxconstant| for this sellable.
         If it's unset, return the constant from the category, if any
 
-        :returns: the tax constant or None if unset
+        :returns: the |sellabletaxconstant| or None if unset
         """
         if self.tax_constant:
             return self.tax_constant
@@ -634,10 +641,10 @@ class Sellable(Domain):
         return info
 
     def get_price_for_category(self, category):
-        """Given the :class:`ClientCategory`, returns the price for that category
+        """Given the |clientcategory|, returns the price for that category
         or the default sellable price.
 
-        :param category: a :class:`ClientCategory`
+        :param category: a |clientcategory|
         :returns: The value that should be used as a price for this sellable.
         """
         info = self.get_category_price_info(category)
@@ -646,13 +653,13 @@ class Sellable(Domain):
         return self.price
 
     def check_code_exists(self, code):
-        """Returns True if we already have a sellable with the given code
+        """Returns ``True`` if we already have a sellable with the given code
         in the database.
         """
         return self.check_unique_value_exists('code', code)
 
     def check_barcode_exists(self, barcode):
-        """Returns True if we already have a sellable with the given barcode
+        """Returns ``True`` if we already have a sellable with the given barcode
         in the database.
         """
         return self.check_unique_value_exists('barcode', barcode)
@@ -686,7 +693,7 @@ class Sellable(Domain):
         If the new quantity is fractioned, check on this sellable unit if it
         allows fractioned quantities. If not, this new quantity cannot be used.
 
-        :returns: True if new quantity is Ok, False otherwise.
+        :returns: ``True`` if new quantity is Ok, ``False`` otherwise.
         """
         if self.unit and not self.unit.allow_fraction:
             return not bool(new_quantity % 1)
@@ -695,7 +702,7 @@ class Sellable(Domain):
 
     def is_valid_price(self, newprice, category=None):
         """Returns True if the new price respects the maximum discount
-        configured for the sellable, otherwise returns False.
+        configured for the sellable, otherwise returns ``False``.
 
         :param newprice: The new price that we are trying to sell this
           sellable for.
@@ -735,8 +742,8 @@ class Sellable(Domain):
     #
 
     def remove(self):
-        """Remove this sellable from the database (including the product or
-        service).
+        """Remove this sellable from the database (including the |product| or
+        |service|).
         """
         assert self.can_remove()
 
@@ -768,9 +775,9 @@ class Sellable(Domain):
 
     @classmethod
     def get_available_sellables(cls, conn):
-        """Returns sellable objects which can be added in a sale. By
+        """Returns sellable objects which can be added in a |sale|. By
         default a delivery sellable can not be added manually by users
-        since a separated dialog is responsible for that.
+        since a separate dialog is responsible for that.
         """
         query = cls.get_available_sellables_query(conn)
         return cls.select(query, connection=conn)
@@ -782,20 +789,20 @@ class Sellable(Domain):
         from stoqlib.domain.product import Product, ProductSupplierInfo
         query = AND(OR(cls.get_available_sellables_query(conn),
                        cls.q.status == cls.STATUS_UNAVAILABLE),
-                    cls.q.id == Product.q.sellableID,
+                    cls.q.id == Product.q.sellable_id,
                     Product.q.consignment == consigned)
         if storable:
-            from stoqlib.domain.product import Product, Storable
+            from stoqlib.domain.product import Storable
             query = AND(query,
-                        Sellable.q.id == Product.q.sellableID,
-                        Storable.q.productID == Product.q.id)
+                        Sellable.q.id == Product.q.sellable_id,
+                        Storable.q.product_id == Product.q.id)
 
         # FIXME: Inserting ProductSupplierInfo in this query breaks storm
         if supplier:
             query = AND(query,
-                        Sellable.q.id == Product.q.sellableID,
-                        Product.q.id == ProductSupplierInfo.q.productID,
-                        ProductSupplierInfo.q.supplierID == supplier.id)
+                        Sellable.q.id == Product.q.sellable_id,
+                        Product.q.id == ProductSupplierInfo.q.product_id,
+                        ProductSupplierInfo.q.supplier_id == supplier.id)
 
         return query
 
@@ -807,9 +814,10 @@ class Sellable(Domain):
         available sellables plus the sold ones.
 
         :param conn: a database connection
-        :param storable: if True, only return Storables
-        :param supplier: a supplier or None, if set limit the returned
-          object to this supplier
+        :param storable: if `True`, only return sellables that also are
+          |storable|
+        :param supplier: a |supplier| or ``None``, if set limit the returned
+          object to this |supplier|
         """
         query = cls.get_unblocked_sellables_query(conn, storable, supplier,
                                                   consigned)
@@ -817,9 +825,9 @@ class Sellable(Domain):
 
     @classmethod
     def get_unavailable_sellables(cls, conn):
-        """Returns sellable objects which can be added in a sale. By
-        default a delivery sellable can not be added manually by users
-        since a separated dialog is responsible for that.
+        """Returns sellable objects which can be added in a |sale|. By
+        default a |delivery| sellable can not be added manually by users
+        since a separate dialog is responsible for that.
         """
         return cls.selectBy(status=cls.STATUS_UNAVAILABLE, connection=conn)
 
