@@ -26,7 +26,7 @@
 from zope.interface import implements
 
 from stoqlib.database.orm import ForeignKey
-from stoqlib.database.orm import INNERJOINOn, LEFTJOINOn
+from stoqlib.database.orm import Join, LeftJoin
 from stoqlib.database.orm import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ServiceCreateEvent, ServiceEditEvent,
@@ -50,7 +50,7 @@ class Service(Domain):
 
     implements(IDescribable)
 
-    #: The :class:`sellable <stoqlib.domain.sellable.Sellable>`
+    #: The |sellable| for this service
     sellable = ForeignKey('Sellable')
 
     def remove(self):
@@ -141,13 +141,13 @@ class ServiceView(Viewable):
         )
 
     joins = [
-        INNERJOINOn(None, Service,
-                    Service.q.sellableID == Sellable.q.id),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
+        Join(Service,
+                    Service.q.sellable_id == Sellable.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
         # Category
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
 
         ]
 
