@@ -44,8 +44,7 @@ class SystemTable(ORMObject):
         """Checks if Stoqlib database is properly installed
         :param conn: a database connection
         """
-        table_name = cls.sqlmeta.table
-        if not conn.tableExists(table_name):
+        if not conn.tableExists('system_table'):
             return False
 
         return bool(cls.select(connection=conn))
@@ -56,17 +55,12 @@ class TransactionEntry(ORMObject):
     A TransactionEntry keeps track of state associated with a database
     transaction. It's main use case is to know information about the system when
     a domain object is created or modified.
-
-    :cvar te_time:
-    :cvar type: if it represents a creation or modification
-    :cvar user_id:
-    :cvar station_id:
     """
 
     (CREATED,
      MODIFIED) = range(2)
 
-    te_time = DateTimeCol(notNone=True)
+    te_time = DateTimeCol(allow_none=False)
 
     # This is used by base classes in Stoq, ORMObject does not allow
     # us to use circular dependencies so instead we define them
@@ -74,6 +68,8 @@ class TransactionEntry(ORMObject):
 
     user_id = IntCol(default=None) # ForeignKey('LoginUser')
     station_id = IntCol(default=None) # ForeignKey('BranchStation')
+
+    #: if it represents a creation or modification
     type = IntCol()
 
     @property
