@@ -40,7 +40,6 @@ from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.exceptions import ModelDataError
 from stoqlib.lib import test
 from stoqlib.lib.diffutils import diff_files
-from stoqlib.lib.pluginmanager import get_plugin_manager
 
 # This test should be inside plugins/nfe, but it's not reachable there
 sys.path.append(os.path.join(os.path.dirname(stoqlib.__file__), '..',
@@ -49,19 +48,9 @@ from nfegenerator import NFeGenerator, NFeIdentification
 
 
 class TestNfeGenerator(DomainTest):
-
-    def setUp(self):
-        DomainTest.setUp(self)
-
-        manager = get_plugin_manager()
-        if not manager.is_installed('nfe'):
-            # STOQLIB_TEST_QUICK won't let dropdb on testdb run. Just a
-            # precaution to avoid trying to install it again
-            manager.install_plugin('nfe')
-
     def test_generated_files(self):
         due_date = datetime.datetime(2011, 10, 24)
-        sale = self._create_sale(1666, 1234, 4321, due_date)
+        sale = self._create_sale(1666, due_date=due_date)
         generator = NFeGenerator(sale, self.trans)
 
         # If we generate random cnf, the test will always fail
@@ -71,6 +60,8 @@ class TestNfeGenerator(DomainTest):
         _get_today_date = NFeGenerator._get_today_date
         NFeGenerator._get_today_date = lambda s: due_date
 
+        generator.sale_id = 1234
+        generator.payment_ids = [4321]
         generator.generate()
         NFeIdentification._get_random_cnf = _get_random_cnf
         NFeGenerator._get_today_date = _get_today_date
@@ -79,10 +70,10 @@ class TestNfeGenerator(DomainTest):
         expected = os.path.join(basedir, "nfe-expected.txt")
         output = os.path.join(basedir, "nfe-output.txt")
         if not os.path.isfile(expected):
-            with open(expected, 'w') as fp:
+            with open(expected, 'wb') as fp:
                 fp.write(strip_accents(generator._as_txt()))
             return
-        with open(output, 'w') as fp:
+        with open(output, 'wb') as fp:
             fp.write(strip_accents(generator._as_txt()))
 
         # Diff and compare
@@ -92,15 +83,17 @@ class TestNfeGenerator(DomainTest):
         self.failIf(diff, '%s\n%s' % ("Files differ, output:", diff))
 
     def test_invalid_cnpj(self):
-        sale = self._create_sale(2666, 2345, 5432)
+        sale = self._create_sale(2666)
         company = sale.branch.person.company
         company.cnpj = '123.321.678/4567-90'
 
         generator = NFeGenerator(sale, self.trans)
+        generator.sale_id = 2345
+        generator.payment_ids = [5432]
         self.assertRaises(ModelDataError, generator.generate)
 
-    def _create_sale(self, invoice_number, sale_id, payment_id, due_date=None):
-        sale = self.create_sale(sale_id)
+    def _create_sale(self, invoice_number, due_date=None):
+        sale = self.create_sale()
         sale.invoice_number = invoice_number
         sale.branch = get_current_branch(self.trans)
 
@@ -129,12 +122,10 @@ class TestNfeGenerator(DomainTest):
         sale.order()
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
-        payment = method.create_inpayment(sale.group,
-                                           sale.get_sale_subtotal(),
-                                           due_date=due_date)
+        method.create_inpayment(sale.group, sale.branch,
+                                sale.get_sale_subtotal(),
+                                due_date=due_date)
         sale.confirm()
-        # Workaround to avoid differences on nfe because of id
-        payment.id = payment_id
 
         return sale
 
