@@ -29,13 +29,15 @@ from kiwi.currency import currency
 
 from stoqlib.domain.payment.comment import PaymentComment
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.payment.payment import Payment, PaymentFlowHistory
+from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.lib.dateutils import INTERVALTYPE_MONTH
 
 
 class TestPayment(DomainTest):
     def test_new(self):
         payment = Payment(value=currency(10), due_date=datetime.datetime.now(),
+                          branch=self.create_branch(),
                           method=None,
                           group=None,
                           till=None,
@@ -50,6 +52,7 @@ class TestPayment(DomainTest):
     def testGetPenalty(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           open_date=datetime.datetime.now(),
                           method=method,
@@ -89,6 +92,7 @@ class TestPayment(DomainTest):
     def testGetInterest(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -126,6 +130,7 @@ class TestPayment(DomainTest):
     def testIsPaid(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -142,6 +147,7 @@ class TestPayment(DomainTest):
     def testIsCancelled(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -160,6 +166,7 @@ class TestPayment(DomainTest):
     def testGetPaidDateString(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -176,6 +183,7 @@ class TestPayment(DomainTest):
     def testGetOpenDateString(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -189,6 +197,7 @@ class TestPayment(DomainTest):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         open_date = due_date = self._get_relative_day(-4)
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=due_date,
                           open_date=open_date,
                           method=method,
@@ -205,6 +214,7 @@ class TestPayment(DomainTest):
     def testCancel(self):
         method = PaymentMethod.get_by_name(self.trans, 'check')
         payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
                           method=method,
                           group=None,
@@ -217,198 +227,24 @@ class TestPayment(DomainTest):
         payment.cancel()
         self.assertEqual(payment.status, Payment.STATUS_CANCELLED)
 
+    def testCreateRepeatedMonth(self):
+        p = self.create_payment()
+        p.description = 'Rent'
+        p.category = self.create_payment_category()
+        payments = Payment.create_repeated(self.trans, p,
+                                           INTERVALTYPE_MONTH,
+                                           datetime.date(2012, 1, 1),
+                                           datetime.date(2012, 12, 31))
+        self.assertEquals(len(payments), 11)
+        self.assertEquals(p.due_date, datetime.datetime(2012, 1, 1))
+        self.assertEquals(p.description, '1/12 Rent')
 
-class TestPaymentFlowHistory(DomainTest):
+        self.assertEquals(payments[0].due_date, datetime.datetime(2012, 2, 1))
+        self.assertEquals(payments[1].due_date, datetime.datetime(2012, 3, 1))
+        self.assertEquals(payments[10].due_date, datetime.datetime(2012, 12, 1))
 
-    def testGetOrCreateFlowHistory(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(self.trans,
-                                                                today)
-        history2 = PaymentFlowHistory.get_or_create_flow_history(self.trans,
-                                                                 today)
-        self.failIf(history is not history2)
-
-    def testGetLastDay(self):
-        today = datetime.datetime.today()
-        yesterday = today + datetime.timedelta(days=-1)
-        tomorrow = today + datetime.timedelta(days=+1)
-
-        today_history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        yesterday_history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, yesterday)
-        PaymentFlowHistory.get_or_create_flow_history(self.trans, tomorrow)
-
-        self.failUnless(PaymentFlowHistory.get_last_day(self.trans, today) is
-                        yesterday_history)
-        self.failUnless(PaymentFlowHistory.get_last_day(self.trans) is
-                        yesterday_history)
-        self.failUnless(PaymentFlowHistory.get_last_day(self.trans, tomorrow) is
-                        today_history)
-
-    def testGetLastDayRealBalance(self):
-        today = datetime.datetime.today()
-        yesterday = today + datetime.timedelta(days=-1)
-        tomorrow = today + datetime.timedelta(days=+1)
-
-        today_history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        yesterday_history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, yesterday)
-        tomorrow_history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, tomorrow)
-
-        self.assertEqual(today_history.get_last_day_real_balance(),
-                         yesterday_history.balance_real)
-        self.assertEqual(tomorrow_history.get_last_day_real_balance(),
-                         today_history.balance_real)
-        # FIXME: this is 436, why?
-        #self.assertEqual(yesterday_history.get_last_day_real_balance(),
-        #                 Decimal(0))
-
-    def testGetDivergentPayments(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        self.failIf(history.get_divergent_payments())
-
-        payment = self.create_payment(Payment.TYPE_IN)
-        payment.value = Decimal(100)
-        payment.due_date = today
-        payment.set_pending()
-
-        # not received
-        self.failUnless(payment in history.get_divergent_payments())
-        payment.pay()
-        # For some reason, the test fails if we do not set paid_date.
-        payment.paid_date = today
-        self.failIf(payment in history.get_divergent_payments())
-
-        payment2 = self.create_payment(Payment.TYPE_OUT)
-        payment2.value = Decimal(10)
-        payment2.due_date = today
-        payment2.set_pending()
-
-        # not paid
-        self.failUnless(payment2 in history.get_divergent_payments())
-        payment2.pay()
-        payment2.paid_date = today
-        self.failIf(payment2 in history.get_divergent_payments())
-        # should be empty now
-        self.failIf(history.get_divergent_payments())
-
-        payment3 = self.create_payment(Payment.TYPE_IN)
-        payment3.value = Decimal(30)
-        payment3.due_date = today
-        payment3.set_pending()
-        payment3.interest = Decimal(1)
-        payment3.pay()
-        payment3.paid_date = today
-        # paid value is different
-        self.failUnless(payment3 in history.get_divergent_payments())
-
-        payment4 = self.create_payment(Payment.TYPE_OUT)
-        payment4.value = Decimal(40)
-        payment4.due_date = today + datetime.timedelta(days=-1)
-        payment4.set_pending()
-        payment4.pay()
-        payment4.paid_date = today
-        # not expected to be received today
-        self.failUnless(payment4 in history.get_divergent_payments())
-
-    def testAddPayment(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        old_to_receive = history.to_receive
-
-        payment = self.create_payment(Payment.TYPE_IN)
-        payment.value = Decimal(100)
-        payment.due_date = today
-        payment.set_pending()
-
-        self.assertEqual(old_to_receive + Decimal(100), history.to_receive)
-
-        old_to_pay = history.to_pay
-        payment2 = self.create_payment(Payment.TYPE_OUT)
-        payment2.value = Decimal(10)
-        payment2.due_date = today
-        payment2.set_pending()
-        self.assertEqual(old_to_pay + Decimal(10), history.to_pay)
-
-    def testRemovePayment(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        old_to_receive = history.to_receive
-
-        payment = self.create_payment(Payment.TYPE_IN)
-        payment.value = Decimal(100)
-        payment.due_date = today
-        payment.set_pending()
-
-        self.assertEqual(old_to_receive + Decimal(100), history.to_receive)
-        payment.cancel()
-        self.assertEqual(old_to_receive, history.to_receive)
-
-        old_to_pay = history.to_pay
-        payment2 = self.create_payment(Payment.TYPE_OUT)
-        payment2.value = Decimal(10)
-        payment2.due_date = today
-        payment2.set_pending()
-
-        self.assertEqual(old_to_pay + Decimal(10), history.to_pay)
-        payment2.cancel()
-        self.assertEqual(old_to_pay, history.to_pay)
-
-    def testAddPaidPayment(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        old_received = history.received
-
-        payment = self.create_payment(Payment.TYPE_IN)
-        payment.value = Decimal(100)
-        payment.due_date = today
-        payment.set_pending()
-        payment.pay()
-
-        self.assertEqual(old_received + Decimal(100), history.received)
-
-        old_paid = history.paid
-        payment2 = self.create_payment(Payment.TYPE_OUT)
-        payment2.value = Decimal(10)
-        payment2.due_date = today
-        payment2.set_pending()
-        payment2.pay()
-        self.assertEqual(old_paid + Decimal(10), history.paid)
-
-    def testRemovePaidPayment(self):
-        today = datetime.datetime.today()
-        history = PaymentFlowHistory.get_or_create_flow_history(
-            self.trans, today)
-        old_received = history.received
-
-        payment = self.create_payment(Payment.TYPE_IN)
-        payment.value = Decimal(100)
-        payment.due_date = today
-        payment.set_pending()
-        payment.pay()
-
-        self.assertEqual(old_received + Decimal(100), history.received)
-        payment.cancel()
-        self.assertEqual(old_received, history.received)
-
-        old_paid = history.paid
-        payment2 = self.create_payment(Payment.TYPE_OUT)
-        payment2.value = Decimal(10)
-        payment2.due_date = today
-        payment2.set_pending()
-        payment2.pay()
-
-        self.assertEqual(old_paid + Decimal(10), history.paid)
-        payment2.cancel()
-        self.assertEqual(old_paid, history.paid)
+        self.assertEquals(payments[0].description, '2/12 Rent')
+        self.assertEquals(payments[10].description, '12/12 Rent')
 
 
 class TestPaymentComment(DomainTest):
