@@ -24,6 +24,9 @@
 """ Test case for stoq/domain/person.py module.  """
 
 import datetime
+from dateutil.relativedelta import relativedelta
+from decimal import Decimal
+from storm.store import AutoReload
 
 from kiwi.currency import currency
 
@@ -32,7 +35,10 @@ from stoqlib.domain.person import Calls, Liaison
 from stoqlib.domain.address import Address, CityLocation
 from stoqlib.domain.exampledata import ExampleCreator
 from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.person import (Branch, Client, ClientCategory, Company,
+from stoqlib.domain.payment.method import PaymentMethod
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.person import (Branch, Client, ClientCategory,
+                                   ClientSalaryHistory, Company,
                                    CreditProvider, Employee, EmployeeRole,
                                    EmployeeRoleHistory, Individual,
                                    LoginUser, Person, SalesPerson, Supplier,
@@ -41,6 +47,9 @@ from stoqlib.domain.product import Product
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sellable import ClientCategoryPrice
 from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.enums import LatePaymentPolicy
+from stoqlib.exceptions import SellError
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
 
@@ -107,10 +116,16 @@ class TestPerson(DomainTest):
         self.assertEquals(person.get_address_string(), _(u'%s %s, %s') % (
             address.street, address.streetnumber, address.district))
 
+    def testGetMobileNumberNumber(self):
+        person = self.create_person()
+        person.mobile_number = '0321-12345'
+        self.assertEquals(person.mobile_number, '032112345')
+
     def testGetPhoneNumberNumber(self):
         person = self.create_person()
         person.phone_number = '0321-12345'
         self.assertEquals(person.get_phone_number_number(), 32112345)
+        self.assertEquals(person.phone_number, '032112345')
 
         person.phone_number = None
         self.assertEquals(person.get_phone_number_number(), 0)
@@ -118,6 +133,7 @@ class TestPerson(DomainTest):
     def testGetFaxNumberNumber(self):
         person = self.create_person()
         person.fax_number = '0321-12345'
+        self.assertEquals(person.fax_number, '032112345')
         self.assertEquals(person.get_fax_number_number(), 32112345)
 
         person.fax_number = None
@@ -244,10 +260,14 @@ class TestClient(_PersonFacetTest, DomainTest):
         self.assertEquals(categories.count(), 0)
 
         category = self.create_client_category('Category')
+        categories = ClientCategory.selectBy(name='Category',
+                                             connection=self.trans)
         self.assertEquals(categories.count(), 1)
 
         self.assertTrue(category.can_remove())
         category.remove()
+        categories = ClientCategory.selectBy(name='Category',
+                                             connection=self.trans)
         self.assertEquals(categories.count(), 0)
 
         sellable = self.create_sellable(price=50)
@@ -258,6 +278,170 @@ class TestClient(_PersonFacetTest, DomainTest):
                             connection=self.trans)
         self.assertFalse(category.can_remove())
 
+    def test_can_purchase_allow_all(self):
+        #: This parameter always allows the client to purchase, no matter if he
+        #: has late payments
+        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
+                                str(int(LatePaymentPolicy.ALLOW_SALES)))
+
+        client = self.create_client()
+        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
+        check_method = PaymentMethod.get_by_name(self.trans, 'check')
+        money_method = PaymentMethod.get_by_name(self.trans, 'money')
+        store_credit_method = PaymentMethod.get_by_name(self.trans,
+                                                        'store_credit')
+        today = datetime.date.today()
+
+        # client can pay if he doesn't have any payments
+        client.credit_limit = Decimal("1000")
+        self.assertTrue(client.can_purchase(money_method, currency("200")))
+
+        # client can pay if he has payments that are not overdue
+        payment = self.create_payment(Payment.TYPE_IN, today, method=bill_method)
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        self.assertTrue(client.can_purchase(check_method, currency("200")))
+
+        # client can pay even if he does have overdue payments
+        payment = self.create_payment(Payment.TYPE_IN,
+                            today - relativedelta(days=1), method=check_method)
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        self.assertTrue(client.can_purchase(store_credit_method, currency("200")))
+
+        # But he cannot pay if its above the credit limit
+        self.assertRaises(SellError, client.can_purchase, store_credit_method, currency("1001"))
+
+    def test_can_purchase_disallow_store_credit(self):
+        #: This parameter disallows the client to purchase with store credit
+        #: when he has late payments
+        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
+                                str(int(LatePaymentPolicy.DISALLOW_STORE_CREDIT)))
+
+        client = self.create_client()
+        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
+        check_method = PaymentMethod.get_by_name(self.trans, 'check')
+        money_method = PaymentMethod.get_by_name(self.trans, 'money')
+        store_credit_method = PaymentMethod.get_by_name(self.trans,
+                                                        'store_credit')
+        today = datetime.date.today()
+
+        # client can pay if he doesn't have any payments
+        self.assertTrue(client.can_purchase(money_method, currency("0")))
+
+        # client can pay if he has payments that are not overdue
+        payment = self.create_payment(Payment.TYPE_IN, today, method=bill_method)
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        self.assertTrue(client.can_purchase(money_method, currency("0")))
+
+        # for a client with overdue payments
+        payment = self.create_payment(Payment.TYPE_IN,
+                                      today - relativedelta(days=1),
+                                      method=money_method)
+        payment.status = Payment.STATUS_PENDING
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        # client can pay if payment method is not store credit
+        self.assertTrue(client.can_purchase(check_method, currency("0")))
+        self.assertTrue(client.can_purchase(money_method, currency("0")))
+        # client can not pay if payment method is store credit
+        self.assertRaises(SellError, client.can_purchase, store_credit_method, currency("0"))
+
+    def test_can_purchase_disallow_all(self):
+        #: This parameter disallows the client to purchase with store credit
+        #: when he has late payments
+        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
+                                str(int(LatePaymentPolicy.DISALLOW_SALES)))
+
+        client = self.create_client()
+        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
+        check_method = PaymentMethod.get_by_name(self.trans, 'check')
+        money_method = PaymentMethod.get_by_name(self.trans, 'money')
+        store_credit_method = PaymentMethod.get_by_name(self.trans,
+                                                        'store_credit')
+        today = datetime.date.today()
+
+        # client can pay if he doesn't have any payments
+        self.assertTrue(client.can_purchase(money_method, currency("0")))
+
+        # client can pay if he has overdue payments
+        payment = self.create_payment(Payment.TYPE_IN, today, method=bill_method)
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        self.assertTrue(client.can_purchase(check_method, currency("0")))
+
+        # client can not pay if he has overdue payments
+        payment = self.create_payment(Payment.TYPE_IN,
+                                      today - relativedelta(days=1),
+                                      method=bill_method)
+        payment.group = self.create_payment_group()
+        payment.group.payer = client.person
+        payment.status = Payment.STATUS_PENDING
+        self.assertRaises(SellError, client.can_purchase, store_credit_method,
+                                     currency("0"))
+        self.assertRaises(SellError, client.can_purchase, check_method,
+                                     currency("0"))
+        self.assertRaises(SellError, client.can_purchase, money_method,
+                                     currency("0"))
+
+    def test_can_purchase_total_amount(self):
+        method = PaymentMethod.get_by_name(self.trans, 'store_credit')
+
+        # client can not buy if he does not have enough store credit
+        client = self.create_client()
+        client.credit_limit = currency('0')
+        self.assertRaises(SellError, client.can_purchase, method, currency('1'))
+
+        # client can buy if he has enough store credit
+        client.credit_limit = currency('1000')
+        self.assertTrue(client.can_purchase(method, currency('200')))
+        self.assertRaises(SellError, client.can_purchase, method, currency('1001'))
+
+    def test_update_credit_limit(self):
+        client = self.create_client()
+        client.salary = 100
+
+        # just setting paramater to a value that won't interfere in
+        # the tests
+        sysparam(self.trans).update_parameter(
+            "CREDIT_LIMIT_SALARY_PERCENT",
+            "5")
+
+        # testing if updates
+        Client.update_credit_limit(10, self.trans)
+        client.credit_limit = AutoReload
+        self.assertEquals(client.credit_limit, 10)
+
+        # testing if it does not update
+        client.credit_limit = 200
+        Client.update_credit_limit(0, self.trans)
+        self.assertEquals(client.credit_limit, 200)
+
+    def test_set_salary(self):
+        sysparam(self.trans).update_parameter(
+            "CREDIT_LIMIT_SALARY_PERCENT",
+            "10")
+
+        client = self.create_client()
+
+        self.assertEquals(client.salary, 0)
+        self.assertEquals(client.credit_limit, 0)
+
+        client.salary = 100
+
+        self.assertEquals(client.salary, 100)
+        self.assertEquals(client.credit_limit, 10)
+
+        sysparam(self.trans).update_parameter(
+            "CREDIT_LIMIT_SALARY_PERCENT",
+            "0")
+        client.credit_limit = 100
+        client.salary = 200
+
+        self.assertEquals(client.salary, 200)
+        self.assertEquals(client.credit_limit, 100)
+
 
 class TestSupplier(_PersonFacetTest, DomainTest):
     facet = Supplier
@@ -269,7 +453,7 @@ class TestSupplier(_PersonFacetTest, DomainTest):
 
     def testGetAllSuppliers(self):
         query = AND(Person.q.name == "test",
-                    Supplier.q.personID == Person.q.id)
+                    Supplier.q.person_id == Person.q.id)
 
         suppliers = Person.select(query, connection=self.trans)
         self.assertEqual(suppliers.count(), 0)
@@ -370,6 +554,17 @@ class TestBranch(_PersonFacetTest, DomainTest):
                         manager=manager, is_active=True)
         assert branch.get_active_branches(self.trans).count() == count + 1
 
+    def test_is_from_same_company(self):
+        branch1 = self.create_branch()
+        branch1.person.company.cnpj = '111.222.333/0001-11'
+
+        branch2 = self.create_branch()
+        branch2.person.company.cnpj = '555.666.777/0001-11'
+        self.assertFalse(branch1.is_from_same_company(branch2))
+
+        branch2.person.company.cnpj = '111.222.333/0002-22'
+        self.assertTrue(branch1.is_from_same_company(branch2))
+
 
 class TestCreditProvider(_PersonFacetTest, DomainTest):
     facet = CreditProvider
@@ -411,3 +606,17 @@ class TransporterTest(_PersonFacetTest, DomainTest):
         transporter = self.create_transporter()
         one_more = transporter.get_active_transporters(self.trans).count()
         self.assertEqual(count + 1, one_more)
+
+
+class TestClientSalaryHistory(DomainTest):
+    def testAdd(self):
+        client = self.create_client()
+        user = self.create_user()
+
+        client.salary = 20
+        ClientSalaryHistory.add(self.trans, 10, client, user)
+        salary_histories = ClientSalaryHistory.select(connection=self.trans)
+        last_salary_history = salary_histories[-1]
+
+        self.assertEquals(last_salary_history.client, client)
+        self.assertEquals(last_salary_history.new_salary, 20)
