@@ -26,21 +26,37 @@ import datetime
 from decimal import Decimal
 
 from kiwi.currency import currency
+from nose.exc import SkipTest
 
 from stoqlib.api import api
+from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.commission import CommissionSource, Commission
-from stoqlib.domain.fiscal import CfopData, FiscalBookEntry
-from stoqlib.domain.payment.group import PaymentGroup
+from stoqlib.domain.fiscal import FiscalBookEntry
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.sale import Sale
-from stoqlib.domain.till import Till, TillEntry
+from stoqlib.domain.sale import Sale, SalePaymentMethodView
+from stoqlib.domain.till import TillEntry
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.parameters import sysparam
 
 
 class TestSale(DomainTest):
 
+    def testSalePaymentsOrdered(self):
+        sale = self.create_sale()
+        self.add_payments(sale, method_type='check', installments=10)
+        initial_date = datetime.datetime(2012, 10, 15)
+        for i, p in enumerate(sale.payments):
+            p.open_date = initial_date - datetime.timedelta(i)
+
+        prev_p = None
+        for p in sale.payments:
+            if prev_p is None:
+                prev_p = p
+                continue
+            self.assertGreater(p.open_date, prev_p.open_date)
+            prev_p = p
+
     def testGetPercentageValue(self):
         sale = self.create_sale()
         sellable = self.create_sellable()
@@ -214,26 +230,76 @@ class TestSale(DomainTest):
         self.assertEqual(sale.status, Sale.STATUS_PAID)
         self.assertEqual(sale.close_date.date(), datetime.date.today())
 
-    def testReturn(self):
-        sale = self.create_sale()
-        self.add_product(sale)
+    def testTotalReturn(self):
+        sale = self.create_sale(branch=get_current_branch(self.trans))
+        sellable = self.add_product(sale)
+        storable = sellable.product_storable
+        balance_before_confirm = storable.get_balance_for_branch(sale.branch)
+
         sale.order()
         self.add_payments(sale)
         sale.confirm()
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm - 1)
+        balance_before_return = storable.get_balance_for_branch(sale.branch)
 
         self.failUnless(sale.can_return())
-        sale.return_(sale.create_sale_return_adapter())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
+
         self.failIf(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
         self.assertEqual(sale.return_date.date(), datetime.date.today())
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_return + 1)
+        # Since this is a total return, balance should be
+        # as it wasn't ever confirmed
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm)
 
-        # FIXME: branch mess:
-        # - increase_stock in cancel() uses sale.branch
-        # - decrease_stock in confirm() uses get_current_branch()
-        #balance_after_sale = storable.get_balance_for_branch(sale.branch)
-        #self.assertEqual(balance_before_sale, balance_after_sale)
+    def testPartialReturn(self):
+        sale = self.create_sale(branch=get_current_branch(self.trans))
+        sellable = self.add_product(sale, quantity=5)
+        storable = sellable.product_storable
+        balance_before_confirm = storable.get_balance_for_branch(sale.branch)
 
-    def testReturnPaid(self):
+        sale.order()
+        self.add_payments(sale)
+        sale.confirm()
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm - 5)
+        balance_before_return = storable.get_balance_for_branch(sale.branch)
+
+        self.failUnless(sale.can_return())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.returned_items[0].quantity = 2
+        returned_sale.return_()
+        self.failUnless(sale.can_return())
+        self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
+        # 2 of 5 returned
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_return + 2)
+        # Since we return 2, it's like we sold 3 instead of 5
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm - 3)
+
+        returned_sale = sale.create_sale_return_adapter()
+        # Since we already returned 2 above, this should be created with 3
+        self.assertEqual(returned_sale.returned_items[0].quantity, 3)
+        # Now this is the final return and will be considered as a total return
+        returned_sale.return_()
+        self.failIf(sale.can_return())
+        self.assertEqual(sale.status, Sale.STATUS_RETURNED)
+        self.assertEqual(sale.return_date.date(), datetime.date.today())
+        # All 5 returned (2 before plus 3 above)
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_return + 5)
+        # Since everything was returned, balance should be
+        # as it wasn't ever confirmed
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm)
+
+    def testTotalReturnPaid(self):
         sale = self.create_sale()
         self.failIf(sale.can_return())
 
@@ -248,96 +314,83 @@ class TestSale(DomainTest):
         sale.set_paid()
         self.failUnless(sale.can_return())
 
-        sale.return_(sale.create_sale_return_adapter())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
         self.failIf(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
         self.assertEqual(sale.return_date.date(), datetime.date.today())
 
-        till = Till.get_current(self.trans)
-        self.assertEqual(sale.group.status, PaymentGroup.STATUS_CANCELLED)
         paid_payment = sale.payments[0]
-        payment = Payment.selectOneBy(group=sale.group, till=till,
-                                      payment_type=Payment.TYPE_OUT,
-                                      connection=self.trans)
-        self.failUnless(payment)
+        payment = sale.payments[1]
         self.assertEqual(payment.value, paid_payment.value)
-        self.assertEqual(payment.status, Payment.STATUS_PAID)
+        self.assertEqual(payment.status, Payment.STATUS_PENDING)
         self.assertEqual(payment.method.method_name, 'money')
 
-        cfop = CfopData.selectOneBy(code='5.202', connection=self.trans)
-        book_entry = FiscalBookEntry.selectOneBy(
-            entry_type=FiscalBookEntry.TYPE_PRODUCT,
+        fbe = FiscalBookEntry.selectOneBy(
             payment_group=sale.group,
-            cfop=cfop,
+            is_reversal=False,
             connection=self.trans)
-        self.failUnless(book_entry)
-        self.assertEqual(book_entry.icms_value,
-                         Decimal("0.18") * paid_payment.value)
+        rfbe = FiscalBookEntry.selectOneBy(
+            payment_group=sale.group,
+            is_reversal=True,
+            connection=self.trans)
+        # The fiscal entries should be totally reversed
+        self.assertEqual(fbe.icms_value - rfbe.icms_value, 0)
+        self.assertEqual(fbe.iss_value - rfbe.iss_value, 0)
+        self.assertEqual(fbe.ipi_value - rfbe.ipi_value, 0)
 
-    def testReturnPaidWithPenalty(self):
+    def testPartialReturnPaid(self):
         sale = self.create_sale()
         self.failIf(sale.can_return())
 
-        self.add_product(sale, price=300)
+        self.add_product(sale, quantity=2)
         sale.order()
         self.failIf(sale.can_return())
 
-        till = Till.get_current(self.trans)
-        balance_initial = till.get_balance()
-
         self.add_payments(sale)
         sale.confirm()
         self.failUnless(sale.can_return())
 
-        balance_before_return = till.get_balance()
-        self.failIf(balance_before_return <= balance_initial)
-
         sale.set_paid()
         self.failUnless(sale.can_return())
 
-        renegotiation = sale.create_sale_return_adapter()
-        renegotiation.penalty_value = currency(50)
-        sale.return_(renegotiation)
-        self.failIf(sale.can_return())
-        self.assertEqual(sale.status, Sale.STATUS_RETURNED)
-        self.assertEqual(sale.return_date.date(), datetime.date.today())
-        self.assertEqual(sale.group.status, PaymentGroup.STATUS_CANCELLED)
+        payment = sale.payments[0]
+        self.assertEqual(payment.value, 20)
 
-        paid_payment = Payment.selectOneBy(
-            group=sale.group,
-            till=till,
-            payment_type=Payment.TYPE_IN,
-            connection=self.trans)
-        self.failUnless(paid_payment)
-        self.failUnless(paid_payment.is_inpayment())
-        self.assertEqual(paid_payment.status, Payment.STATUS_PAID)
-        self.assertEqual(paid_payment.method.method_name, 'money')
-        return_payment = Payment.selectOneBy(
-            group=sale.group,
-            till=till,
-            payment_type=Payment.TYPE_OUT,
-            connection=self.trans)
-        self.failUnless(return_payment)
-        self.failUnless(return_payment.is_outpayment())
-        self.assertEqual(return_payment.status, Payment.STATUS_PAID)
-        self.assertEqual(return_payment.method.method_name, 'money')
-        out_payment_plus_penalty = return_payment.value + renegotiation.penalty_value
-        self.assertEqual(out_payment_plus_penalty, paid_payment.value)
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.returned_items[0].quantity = 1
+        returned_sale.return_()
+        self.assertTrue(sale.can_return())
+        self.assertEqual(sale.status, Sale.STATUS_PAID)
 
-        cfop = CfopData.selectOneBy(code='5.202', connection=self.trans)
-        book_entry = FiscalBookEntry.selectOneBy(
-            entry_type=FiscalBookEntry.TYPE_PRODUCT,
+        paid_payment = sale.payments[0]
+        returned_payment = sale.payments[1]
+        self.assertTrue(returned_payment.payment_type, Payment.TYPE_OUT)
+        # Since a half of the products were returned, half of the paid
+        # value should be reverted to the client
+        self.assertEqual(returned_payment.value, paid_payment.value / 2)
+        self.assertEqual(returned_payment.status, Payment.STATUS_PENDING)
+        self.assertEqual(returned_payment.method.method_name, 'money')
+
+        fbe = FiscalBookEntry.selectOneBy(
             payment_group=sale.group,
-            cfop=cfop,
+            is_reversal=False,
             connection=self.trans)
-        self.failUnless(book_entry)
-        self.assertEqual(book_entry.icms_value,
-                         Decimal("0.18") * paid_payment.value)
+        rfbe = FiscalBookEntry.selectOneBy(
+            payment_group=sale.group,
+            is_reversal=True,
+            connection=self.trans)
+        # Since a half of the products were returned, half of the
+        # taxes should be reverted. That is,
+        # actual_value - reverted_value = actual_value / 2
+        self.assertEqual(fbe.icms_value - rfbe.icms_value,
+                         fbe.icms_value / 2)
+        self.assertEqual(fbe.iss_value - rfbe.iss_value,
+                         fbe.iss_value / 2)
+        self.assertEqual(fbe.ipi_value - rfbe.ipi_value,
+                         fbe.ipi_value / 2)
 
-        balance_final = till.get_balance()
-        self.failIf(balance_initial >= balance_final)
-
-    def testReturnNotPaid(self):
+    def testTotalReturnNotPaid(self):
         sale = self.create_sale()
         self.failIf(sale.can_return())
 
@@ -345,33 +398,56 @@ class TestSale(DomainTest):
         sale.order()
         self.failIf(sale.can_return())
 
-        till = Till.get_current(self.trans)
-        balance_initial = till.get_balance()
-
         method = PaymentMethod.get_by_name(self.trans, 'check')
-        payment = method.create_inpayment(sale.group, Decimal(300))
+        payment = method.create_inpayment(sale.group, sale.branch, Decimal(300))
         sale.confirm()
         self.failUnless(sale.can_return())
 
-        balance_before_return = till.get_balance()
-        self.failIf(balance_before_return <= balance_initial)
-
-        sale.return_(sale.create_sale_return_adapter())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
         self.failIf(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
         self.assertEqual(sale.return_date.date(), datetime.date.today())
 
-        self.assertEqual(sale.group.status, PaymentGroup.STATUS_CANCELLED)
         returned_amount = 0
         for payment in sale.payments:
             if payment.is_outpayment():
                 returned_amount += payment.value
         self.assertEqual(returned_amount, currency(0))
 
-        balance_final = till.get_balance()
-        self.assertEqual(balance_before_return, balance_final)
+    def testPartialReturnNotPaid(self):
+        sale = self.create_sale()
+        self.failIf(sale.can_return())
 
-    def testReturnNotEntirelyPaid(self):
+        self.add_product(sale, quantity=2, price=300)
+        sale.order()
+        self.failIf(sale.can_return())
+
+        method = PaymentMethod.get_by_name(self.trans, 'check')
+        payment = method.create_inpayment(sale.group, sale.branch, Decimal(600))
+        sale.confirm()
+        self.failUnless(sale.can_return())
+
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.returned_items[0].quantity = 1
+
+        # Mimic what is done on sale return wizard that is to cancel
+        # the existing payment and create another one with the new
+        # total (in this case, 300)
+        method.create_inpayment(sale.group, sale.branch, Decimal(300))
+        payment.cancel()
+
+        returned_sale.return_()
+        self.failUnless(sale.can_return())
+        self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
+
+        returned_amount = 0
+        for payment in sale.payments:
+            if payment.is_outpayment():
+                returned_amount += payment.value
+        self.assertEqual(returned_amount, currency(0))
+
+    def testTotalReturnNotEntirelyPaid(self):
         sale = self.create_sale()
         self.failIf(sale.can_return())
 
@@ -379,14 +455,11 @@ class TestSale(DomainTest):
         sale.order()
         self.failIf(sale.can_return())
 
-        till = Till.get_current(self.trans)
-        balance_initial = till.get_balance()
-
         # Add 3 check payments of 100 each
         method = PaymentMethod.get_by_name(self.trans, 'check')
-        payment1 = method.create_inpayment(sale.group, Decimal(100))
-        method.create_inpayment(sale.group, Decimal(100))
-        method.create_inpayment(sale.group, Decimal(100))
+        payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(100))
+        method.create_inpayment(sale.group, sale.branch, Decimal(100))
+        method.create_inpayment(sale.group, sale.branch, Decimal(100))
         sale.confirm()
 
         # Pay the first payment.
@@ -394,105 +467,97 @@ class TestSale(DomainTest):
         payment.pay()
         self.failUnless(sale.can_return())
 
-        balance_before_return = till.get_balance()
-        self.failIf(balance_before_return <= balance_initial)
-
         self.failUnless(sale.can_return())
-        sale.return_(sale.create_sale_return_adapter())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
         self.failIf(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
         self.assertEqual(sale.return_date.date(), datetime.date.today())
 
-        self.assertEqual(sale.group.status, PaymentGroup.STATUS_CANCELLED)
         returned_amount = 0
         for payment in sale.payments:
+            if payment.is_inpayment():
+                # At this point, inpayments should be either paid or cancelled
+                self.assertFalse(payment.is_pending())
+                self.assertTrue(payment.is_paid() or payment.is_cancelled())
             if payment.is_outpayment():
                 returned_amount += payment.value
         self.assertEqual(payment.value, returned_amount)
 
-        # Till balance after return.
-        balance_after_return = balance_before_return - returned_amount
-
-        balance_final = till.get_balance()
-        self.assertEqual(balance_after_return, balance_final)
-
-    def testReturnNotEntirelyPaidWithPenalty(self):
+    def testPartialReturnNotEntirelyPaid(self):
         sale = self.create_sale()
         self.failIf(sale.can_return())
 
-        # Add product of costing 300 to the sale
         self.add_product(sale, price=300)
         sale.order()
         self.failIf(sale.can_return())
 
-        # We start out with an empty till
-        till = Till.get_current(self.trans)
-        balance_initial = till.get_balance()
-        self.assertEqual(balance_initial, 0)
-
         # Add 3 check payments of 100 each
         method = PaymentMethod.get_by_name(self.trans, 'check')
-        payment1 = method.create_inpayment(sale.group, Decimal(100))
-        method.create_inpayment(sale.group, Decimal(100))
-        method.create_inpayment(sale.group, Decimal(100))
+        payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(100))
+        method.create_inpayment(sale.group, sale.branch, Decimal(100))
+        method.create_inpayment(sale.group, sale.branch, Decimal(100))
         sale.confirm()
 
-        # We should have three payments in the sale
-        self.assertEqual(sale.payments.count(), 3)
-
-        # Pay the first payment
+        # Pay the first payment.
         payment = payment1
         payment.pay()
         self.failUnless(sale.can_return())
 
-        # Make sure we received the money in the current till
-        balance_before_return = till.get_balance()
-        self.assertEqual(balance_before_return, 300)
         self.failUnless(sale.can_return())
-
-        # Return the product, with a 50 penality
-        penalty = 50
-        renegotiation = sale.create_sale_return_adapter()
-        renegotiation.penalty_value = penalty
-        sale.return_(renegotiation)
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
         self.failIf(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
         self.assertEqual(sale.return_date.date(), datetime.date.today())
-        self.assertEqual(sale.group.status, PaymentGroup.STATUS_CANCELLED)
 
-        # Till balance after return.
-        total_returned = renegotiation.paid_total - penalty
-        balance_after_return = balance_before_return - total_returned
-        self.failIf(balance_after_return >= balance_before_return)
+        returned_amount = 0
+        for payment in sale.payments:
+            if payment.is_inpayment():
+                # At this point, inpayments should be either paid or cancelled
+                self.assertTrue(payment.is_paid() or payment.is_cancelled())
+            if payment.is_outpayment():
+                returned_amount += payment.value
+        self.assertEqual(payment.value, returned_amount)
 
-        # Penality is still 50
-        self.assertEqual(renegotiation.penalty_value, penalty)
+    def testTrade(self):
+        sale = self.create_sale(branch=get_current_branch(self.trans))
+        self.failIf(sale.can_return())
 
-        # We know have four payments in the group, the outpayment as well
-        self.assertEqual(sale.group.payments.count(), 4)
+        sellable = self.add_product(sale)
+        storable = sellable.product_storable
+        balance_before_confirm = storable.get_balance_for_branch(sale.branch)
+        sale.order()
+        self.failIf(sale.can_return())
 
-        p1, p2, p3, p4 = sale.group.payments.orderBy('id')
-        # First three payments are incoming, one each of 50
-        self.failUnless(p1.is_inpayment())
-        self.failIf(p1.is_outpayment())
-        self.assertEquals(p1.value, 100)
+        self.add_payments(sale)
+        sale.confirm()
+        self.failUnless(sale.can_return())
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm - 1)
+        balance_before_trade = storable.get_balance_for_branch(sale.branch)
 
-        self.failUnless(p2.is_inpayment())
-        self.failIf(p2.is_outpayment())
-        self.assertEquals(p2.value, 100)
+        sale.set_paid()
+        self.failUnless(sale.can_return())
 
-        self.failUnless(p3.is_inpayment())
-        self.failIf(p3.is_outpayment())
-        self.assertEquals(p3.value, 100)
+        returned_sale = sale.create_sale_return_adapter()
+        self.assertRaises(AssertionError, returned_sale.trade)
+        new_sale = self.create_sale()
+        returned_sale.new_sale = new_sale
+        returned_sale.trade()
 
-        # Last payment is outgoing and should be the same amount as the penalty
-        self.failIf(p4.is_inpayment())
-        self.failUnless(p4.is_outpayment())
-        self.assertEquals(p4.value, penalty)
-
-        # Paid payments: return money in the till, except the penality.
-        # To Pay payments: not return money, the value must remain in the till.
-        self.assertEqual(till.get_balance(), balance_after_return)
+        group = returned_sale.group
+        payment = group.payments[0]
+        self.assertTrue(payment.is_paid())
+        self.assertEqual(group, new_sale.group)
+        self.assertEqual(group.payments.count(), 1)
+        self.assertEqual(payment.value, returned_sale.returned_total)
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_trade + 1)
+        # Since this is a total return, balance should be
+        # as it wasn't ever confirmed
+        self.assertEqual(storable.get_balance_for_branch(sale.branch),
+                         balance_before_confirm)
 
     def testCanEdit(self):
         sale = self.create_sale()
@@ -715,7 +780,10 @@ class TestSale(DomainTest):
         self.assertEquals(commissions.count(), 1)
         self.assertEquals(commissions[0].value, Decimal('56.00'))
 
-    def testCommissionAmountWhenSaleReturn(self):
+    def testCommissionAmountWhenSaleReturnsCompletly(self):
+        raise SkipTest("See stoqlib.domain.returned_sale.ReturnedSale.return_ "
+                       "and bug 5215.")
+
         sale = self.create_sale()
         sellable = self.add_product(sale, price=200)
         CommissionSource(sellable=sellable,
@@ -729,7 +797,8 @@ class TestSale(DomainTest):
         self.failIf(Commission.selectBy(sale=sale,
                                         connection=self.trans))
         sale.confirm()
-        sale.return_(sale.create_sale_return_adapter())
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.return_()
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
 
         commissions = Commission.selectBy(sale=sale,
@@ -739,6 +808,40 @@ class TestSale(DomainTest):
         self.assertEqual(commissions.count(), 2)
         self.failIf(commissions[-1].value >= 0)
 
+    def testCommissionAmountWhenSaleReturnsPartially(self):
+        raise SkipTest("See stoqlib.domain.returnedsale.ReturnedSale.return_ "
+                       "and bug 5215.")
+
+        sale = self.create_sale()
+        sellable = self.add_product(sale, quantity=2, price=200)
+        CommissionSource(sellable=sellable,
+                         direct_value=10,
+                         installments_value=5,
+                         connection=self.trans)
+        sale.order()
+        # payment method: money
+        # installments number: 1
+        self.add_payments(sale)
+        self.failIf(Commission.selectBy(sale=sale,
+                                        connection=self.trans))
+        sale.confirm()
+        commission_value_before_return = Commission.selectBy(
+            connection=self.trans, sale=sale).sum(Commission.value)
+
+        returned_sale = sale.create_sale_return_adapter()
+        returned_sale.returned_items[0].quantity = 1
+        returned_sale.return_()
+        self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
+
+        commissions = Commission.selectBy(sale=sale,
+                                          connection=self.trans)
+        # Since we returned half of the products, commission should
+        # be reverted by half too
+        self.assertEqual(commissions.sum(Commission.value),
+                         commission_value_before_return / 2)
+        self.assertEqual(commissions.count(), 2)
+        self.failIf(commissions[-1].value >= 0)
+
     def testGetClientRole(self):
         sale = self.create_sale()
         client_role = sale.get_client_role()
@@ -781,7 +884,7 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        payment = self.add_payments(sale, method_type='check')
+        payment = self.add_payments(sale, method_type='check')[0]
 
         account = self.create_account()
         payment.method.destination_account = account
@@ -804,19 +907,19 @@ class TestSale(DomainTest):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
-        payment = self.add_payments(sale, method_type='money')
+        payment = self.add_payments(sale, method_type='money')[0]
         account = self.create_account()
         payment.method.destination_account = account
         self.failIf(account.transactions)
         sale.confirm()
-        self.failIf(account.transactions)
+        self.failUnless(account.transactions)
 
     def testPayments(self):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
 
-        check_payment = self.add_payments(sale, method_type='check')
+        check_payment = self.add_payments(sale, method_type='check')[0]
         self.assertEqual(sale.payments.count(), 1)
         self.assertTrue(check_payment in sale.payments)
         self.assertEqual(sale.group.payments.count(), 1)
@@ -829,7 +932,7 @@ class TestSale(DomainTest):
         self.assertEqual(sale.group.payments.count(), 1)
         self.assertTrue(check_payment in sale.group.payments)
 
-        money_payment = self.add_payments(sale, method_type='money')
+        money_payment = self.add_payments(sale, method_type='money')[0]
         self.assertEqual(sale.payments.count(), 1)
         self.assertTrue(money_payment in sale.payments)
         self.assertEqual(sale.group.payments.count(), 2)
@@ -859,3 +962,72 @@ class TestSaleItem(DomainTest):
         service = self.create_service()
         sale_item = sale.add_sellable(service.sellable, quantity=2)
         self.failIf(sale_item.is_service() is False)
+
+
+class TestSalePaymentMethodView(DomainTest):
+    def test_with_one_payment_method_sales(self):
+        # Let's create two sales: one with money and another with bill.
+        sale_money = self.create_sale()
+        self.add_product(sale_money)
+        self.add_payments(sale_money, method_type='money')
+
+        sale_bill = self.create_sale()
+        self.add_product(sale_bill)
+        self.add_payments(sale_bill, method_type='bill')
+
+        # If we search for sales that have money payment...
+        method = PaymentMethod.get_by_name(self.trans, 'money')
+        res = SalePaymentMethodView.select_by_payment_method(
+                                                connection=self.trans,
+                                                method=method)
+        # Initial database already has a money payment
+        self.assertEquals(res.count(), 2)
+        # Only the first sale should be in the results.
+        self.assertTrue(sale_money in [r.sale for r in res])
+        self.assertFalse(sale_bill in [r.sale for r in res])
+
+        # We don't have any sale with deposit payment method.
+        method = PaymentMethod.get_by_name(self.trans, 'deposit')
+        res = SalePaymentMethodView.select_by_payment_method(
+                                                connection=self.trans,
+                                                method=method)
+        self.assertEquals(res.count(), 0)
+
+    def test_with_two_payment_method_sales(self):
+        # Create sale with two payments with different methods: money and bill.
+        sale_two_methods = self.create_sale()
+        self.add_product(sale_two_methods)
+        self.add_payments(sale_two_methods, method_type='money')
+        self.add_payments(sale_two_methods, method_type='bill')
+
+        # The sale should appear when searching for money payments...
+        method = PaymentMethod.get_by_name(self.trans, 'money')
+        res = SalePaymentMethodView.select_by_payment_method(
+                                                connection=self.trans,
+                                                method=method)
+        # Initial database already has a money payment
+        self.assertEquals(res.count(), 2)
+        self.assertTrue(sale_two_methods in [r.sale for r in res])
+
+        # And bill payments...
+        method = PaymentMethod.get_by_name(self.trans, 'bill')
+        res = SalePaymentMethodView.select_by_payment_method(
+                                                connection=self.trans,
+                                                method=method)
+        # Initial database already has a bill payment
+        self.assertEquals(res.count(), 2)
+        self.assertTrue(sale_two_methods in [r.sale for r in res])
+
+    def test_with_two_installments_sales(self):
+        # A sale that has two installments of the same method should appear only
+        # once in the results.
+        sale_two_inst = self.create_sale()
+        self.add_product(sale_two_inst)
+        self.add_payments(sale_two_inst, method_type='deposit', installments=2)
+
+        method = PaymentMethod.get_by_name(self.trans, 'deposit')
+        res = SalePaymentMethodView.select_by_payment_method(
+                                                connection=self.trans,
+                                                method=method)
+        self.assertEquals(res.count(), 1)
+        self.assertTrue(sale_two_inst in [r.sale for r in res])
