@@ -26,12 +26,13 @@ from decimal import Decimal
 
 from kiwi.currency import currency
 
+from stoqlib.exceptions import SellableError
+from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.product import Storable
 from stoqlib.domain.sellable import (Sellable,
                                      SellableCategory, ClientCategoryPrice)
 from stoqlib.domain.sale import Sale
-from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.views import (ProductFullStockView,
                                   ProductFullWithClosedStockView,
                                   ProductClosedStockView)
@@ -186,6 +187,30 @@ class TestSellable(DomainTest):
         self.failUnless(sellable.markup == 0,
                         "Expected markup %r, got %r" % (0, sellable.markup))
 
+    def test_get_unblocked_sellables(self):
+        # Sellable and query without supplier
+        sellable = self.create_sellable()
+        available = Sellable.get_unblocked_sellables(self.trans)
+        self.assertTrue(sellable in list(available))
+
+        # Sellable without supplier, but querying with one
+        supplier = self.create_supplier()
+        available = Sellable.get_unblocked_sellables(self.trans,
+                                                     supplier=supplier)
+        self.assertFalse(sellable in list(available))
+
+        # Relate the two
+        from stoqlib.domain.product import ProductSupplierInfo
+        ProductSupplierInfo(connection=self.trans,
+                            supplier=supplier,
+                            product=sellable.product,
+                            is_main_supplier=True)
+
+        # Now the sellable should appear in the results
+        available = Sellable.get_unblocked_sellables(self.trans,
+                                                     supplier=supplier)
+        self.assertTrue(sellable in list(available))
+
     def testIsValidQuantity(self):
         sellable = self.create_sellable()
         unit = self.create_sellable_unit()
@@ -293,6 +318,12 @@ class TestSellable(DomainTest):
         # ProductFullStockView and ProductFullWithClosedStock View,
         # but not on ProductClosedStockView.
         sellable = self.create_sellable()
+        results_not_closed = ProductFullStockView.select(connection=self.trans)
+        results_with_closed = ProductFullWithClosedStockView.select(
+                                                         connection=self.trans)
+        results_only_closed = ProductClosedStockView.select(
+                                                         connection=self.trans)
+
         self.assertEqual(len(list(results_not_closed)), count_not_closed + 1L)
         self.assertEqual(len(list(results_with_closed)), count_with_closed + 1L)
         self.assertEqual(len(list(results_only_closed)), count_only_closed)
@@ -307,6 +338,11 @@ class TestSellable(DomainTest):
         # ProductClosedStockViewand ProductFullWithClosedStock View,
         # but not on ProductFullStockView.
         sellable.close()
+        results_not_closed = ProductFullStockView.select(connection=self.trans)
+        results_with_closed = ProductFullWithClosedStockView.select(
+                                                         connection=self.trans)
+        results_only_closed = ProductClosedStockView.select(
+                                                         connection=self.trans)
         self.assertEquals(sellable.status, Sellable.STATUS_CLOSED)
         self.assertTrue(sellable.is_closed())
         self.assertEqual(len(list(results_not_closed)), count_not_closed)
@@ -416,3 +452,17 @@ class TestSellable(DomainTest):
         category_price.remove()
         total = ClientCategoryPrice.selectBy(connection=self.trans).count()
         self.assertEquals(total, 0)
+
+    def test_code(self):
+        sellable = self.create_sellable(price=100)
+        sellable.code = 'code'
+        self.assertEquals(sellable.code, 'code')
+        sellable2 = self.create_sellable(price=100)
+        self.assertRaises(SellableError, setattr, sellable2, 'code', 'code')
+
+    def test_barcode(self):
+        sellable = self.create_sellable(price=100)
+        sellable.barcode = 'barcode'
+        self.assertEquals(sellable.barcode, 'barcode')
+        sellable2 = self.create_sellable(price=100)
+        self.assertRaises(SellableError, setattr, sellable2, 'barcode', 'barcode')
