@@ -32,6 +32,7 @@ from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.views import AccountView
 from stoqlib.domain.views import ProductComponentView
 from stoqlib.domain.views import ProductFullStockView
+from stoqlib.domain.views import ProductFullStockItemView
 from stoqlib.domain.views import QuotationView
 from stoqlib.domain.views import SellableCategoryView
 from stoqlib.domain.views import SellableFullStockView
@@ -190,6 +191,44 @@ class TestProductFullStockView(DomainTest):
             None, connection=self.trans)
         self.assertEquals(results[0].price, 10)
 
+    def test_with_unblocked_sellables_query(self):
+        # This is used in the purchase wizard and breaks storm
+        from stoqlib.domain.product import ProductSupplierInfo
+        from stoqlib.domain.sellable import Sellable
+
+        p1 = self.create_product()
+        supplier = self.create_supplier()
+
+        # Product should appear when querying without a supplier
+        query = Sellable.get_unblocked_sellables_query(self.trans)
+        results = ProductFullStockView.select(query, connection=self.trans)
+        self.assertTrue(p1.id in [p.product_id for p in results])
+
+        # But should not appear when querying with a supplier
+        query = Sellable.get_unblocked_sellables_query(self.trans,
+                                                       supplier=supplier)
+        results = ProductFullStockView.select(query, connection=self.trans)
+        self.assertFalse(p1.id in [p.id for p in results])
+
+        # Now relate the two
+        ProductSupplierInfo(connection=self.trans,
+                            supplier=supplier,
+                            product=p1,
+                            is_main_supplier=True)
+
+        # And it should appear now
+        query = Sellable.get_unblocked_sellables_query(self.trans,
+                                                       supplier=supplier)
+        results = ProductFullStockView.select(query, connection=self.trans)
+        self.assertTrue(p1.id in [s.product_id for s in results])
+
+        # But should not appear for a different supplier
+        other_supplier = self.create_supplier()
+        query = Sellable.get_unblocked_sellables_query(self.trans,
+                                                       supplier=other_supplier)
+        results = ProductFullStockView.select(query, connection=self.trans)
+        self.assertFalse(p1.id in [s.product_id for s in results])
+
 
 class TestProductComponentView(DomainTest):
     def testSellable(self):
@@ -323,8 +362,8 @@ class TestSellableCategoryView(DomainTest):
 
 class TestQuotationView(DomainTest):
     def testGroupQuotationPurchase(self):
-        quote = QuoteGroup(connection=self.trans)
         order = self.create_purchase_order()
+        quote = QuoteGroup(connection=self.trans, branch=order.branch)
         order.status = PurchaseOrder.ORDER_QUOTING
         quote.add_item(order)
 
@@ -473,3 +512,24 @@ class TestAccountView(DomainTest):
                                      connection=self.trans)
         self.failUnless(list(results))
         self.assertEquals(repr(results[0]), '<AccountView Test Account>')
+
+
+class TestProductFullStockItemView(DomainTest):
+
+    def testSelect(self):
+        from stoqlib.domain.product import Product
+        product = Product.select(connection=self.trans)[0]
+
+        order = self.create_purchase_order()
+        order.add_item(product.sellable, 1)
+        order.status = PurchaseOrder.ORDER_CONFIRMED
+
+        order2 = self.create_purchase_order()
+        order2.add_item(product.sellable, 4)
+        order2.status = PurchaseOrder.ORDER_CONFIRMED
+
+        # This viewable should return only one item for each existing product,
+        # event if there is more than one purchase order for the product.
+        results = ProductFullStockItemView.select(connection=self.trans)
+        ids = [r.id for r in results]
+        self.assertEquals(ids.count(product.sellable.id), 1)
