@@ -27,7 +27,8 @@ import datetime
 from kiwi.argcheck import argcheck
 from zope.interface import implements
 
-from stoqlib.database.orm import QuantityCol, const, INNERJOINOn, LEFTJOINOn
+from stoqlib.database.orm import AutoReload
+from stoqlib.database.orm import QuantityCol, const, Join, LeftJoin
 from stoqlib.database.orm import ForeignKey, IntCol, Viewable, Alias
 from stoqlib.database.orm import DateTimeCol
 from stoqlib.domain.base import Domain
@@ -36,7 +37,6 @@ from stoqlib.domain.person import Person, Branch
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.lib.translation import stoqlib_gettext
 
-
 _ = stoqlib_gettext
 
 
@@ -45,10 +45,10 @@ class TransferOrderItem(Domain):
 
     """
 
-    #: The :class:`sellable <stoqlib.domain.sellable.Sellable>` to transfer
+    #: The |sellable| to transfer
     sellable = ForeignKey('Sellable')
 
-    #: The :class:`transfer order <TransferOrder>` this item belongs to
+    #: The |transfer| this item belongs to
     transfer_order = ForeignKey('TransferOrder')
 
     #: The quantity to transfer
@@ -76,22 +76,27 @@ class TransferOrder(Domain):
 
     status = IntCol(default=STATUS_PENDING)
 
+    #: A numeric identifier for this object. This value should be used instead of
+    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: the user, in dialogs, lists, reports and such.
+    identifier = IntCol(default=AutoReload)
+
     #: The date the order was created
-    open_date = DateTimeCol(default=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=datetime.datetime.now)
 
     #: The date the order was received
-    receival_date = DateTimeCol(default=datetime.datetime.now)
+    receival_date = DateTimeCol(default_factory=datetime.datetime.now)
 
-    #: The branch sending the stock
+    #: The |branch| sending the stock
     source_branch = ForeignKey('Branch')
 
-    #: The branch receiving the stock
+    #: The |branch| receiving the stock
     destination_branch = ForeignKey('Branch')
 
-    #: Employee responsible for the transfer at source branch
+    #: The |employee| responsible for the |transfer| at source |branch|
     source_responsible = ForeignKey('Employee')
 
-    #: Employee responsible for the transfer at destination branch
+    #: The |employee| responsible for the |transfer| at destination |branch|
     destination_responsible = ForeignKey('Employee')
 
     #
@@ -124,7 +129,7 @@ class TransferOrder(Domain):
 
     @argcheck(TransferOrderItem)
     def send_item(self, transfer_item):
-        """Sends a product of this order to it's destination branch"""
+        """Sends a |product| of this order to it's destination |branch|"""
         assert self.can_close()
 
         storable = transfer_item.sellable.product_storable
@@ -150,28 +155,27 @@ class TransferOrder(Domain):
         self.status = TransferOrder.STATUS_CLOSED
 
     def get_source_branch_name(self):
-        """Returns the source branch name"""
+        """Returns the source |branch| name"""
         return self.source_branch.person.name
 
     def get_destination_branch_name(self):
-        """Returns the destination branch name"""
+        """Returns the destination |branch| name"""
         return self.destination_branch.person.name
 
     def get_source_responsible_name(self):
-        """Returns the name of the employee responsible for the transfer
-           at source branch
+        """Returns the name of the |employee| responsible for the transfer
+           at source |branch|
         """
         return self.source_responsible.person.name
 
     def get_destination_responsible_name(self):
-        """Returns the name of the employee responsible for the transfer
-           at destination branch
+        """Returns the name of the |employee| responsible for the transfer
+           at destination |branch|
         """
         return self.destination_responsible.person.name
 
     def get_total_items_transfer(self):
-        """Retuns the transfer items quantity or zero if there is no
-           item in transfer
+        """Retuns the |transferitems| quantity
         """
         return sum([item.quantity for item in self.get_items()], 0)
 
@@ -182,30 +186,31 @@ class TransferOrderView(Viewable):
 
     columns = dict(
         id=TransferOrder.q.id,
+        identifier=TransferOrder.q.identifier,
         open_date=TransferOrder.q.open_date,
         receival_date=TransferOrder.q.receival_date,
-        source_branch_id=TransferOrder.q.source_branchID,
-        destination_branch_id=TransferOrder.q.destination_branchID,
+        source_branch_id=TransferOrder.q.source_branch_id,
+        destination_branch_id=TransferOrder.q.destination_branch_id,
         source_branch_name=Person.q.name,
         destination_branch_name=PersonDest.q.name,
         total_itens=const.SUM(TransferOrderItem.q.quantity),
     )
 
     joins = [
-        INNERJOINOn(None, TransferOrderItem,
-                    TransferOrder.q.id == TransferOrderItem.q.transfer_orderID),
+        Join(TransferOrderItem,
+                    TransferOrder.q.id == TransferOrderItem.q.transfer_order_id),
         # Source
-        LEFTJOINOn(None, Branch,
-                   TransferOrder.q.source_branchID == Branch.q.id),
-        LEFTJOINOn(None, Person,
-                   Branch.q.personID == Person.q.id),
+        LeftJoin(Branch,
+                   TransferOrder.q.source_branch_id == Branch.q.id),
+        LeftJoin(Person,
+                   Branch.q.person_id == Person.q.id),
         # Destination
-        LEFTJOINOn(None, BranchDest,
-                   TransferOrder.q.destination_branchID == BranchDest.q.id),
-        LEFTJOINOn(None, PersonDest,
-                   BranchDest.q.personID == PersonDest.q.id),
+        LeftJoin(BranchDest,
+                   TransferOrder.q.destination_branch_id == BranchDest.q.id),
+        LeftJoin(PersonDest,
+                   BranchDest.q.person_id == PersonDest.q.id),
     ]
 
     @property
     def transfer_order(self):
-        return TransferOrder.get(self.id)
+        return TransferOrder.get(self.id, self.get_connection())
