@@ -24,14 +24,16 @@
 
 import datetime
 
-from stoqlib.database.orm import const, AND, INNERJOINOn, LEFTJOINOn, OR
+from stoqlib.database.orm import const, AND, Join, LeftJoin, OR
 from stoqlib.database.orm import Viewable, Field, Alias
 from stoqlib.domain.account import Account, AccountTransaction
+from stoqlib.domain.address import Address
 from stoqlib.domain.commission import CommissionSource
 from stoqlib.domain.loan import Loan, LoanItem
 from stoqlib.domain.person import (Person, Supplier,
                                    LoginUser, Branch,
-                                   Client, Employee)
+                                   Client, Employee,
+                                   Transporter)
 from stoqlib.domain.product import (Product,
                                     ProductStockItem,
                                     ProductHistory,
@@ -42,7 +44,7 @@ from stoqlib.domain.production import ProductionOrder, ProductionItem
 from stoqlib.domain.purchase import (Quotation, QuoteGroup, PurchaseOrder,
                                      PurchaseItem)
 from stoqlib.domain.receiving import ReceivingOrderItem, ReceivingOrder
-from stoqlib.domain.sale import SaleItem, Sale
+from stoqlib.domain.sale import SaleItem, Sale, Delivery
 from stoqlib.domain.sellable import (Sellable, SellableUnit,
                                      SellableCategory,
                                      SellableTaxConstant)
@@ -75,7 +77,7 @@ class ProductFullStockView(Viewable):
         status=Sellable.q.status,
         cost=Sellable.q.cost,
         description=Sellable.q.description,
-        image_id=Sellable.q.imageID,
+        image_id=Sellable.q.image_id,
         base_price=Sellable.q.base_price,
         on_sale_price=Sellable.q.on_sale_price,
         on_sale_start_date=Sellable.q.on_sale_start_date,
@@ -94,35 +96,41 @@ class ProductFullStockView(Viewable):
 
     joins = [
         # Tax Constant
-        LEFTJOINOn(None, SellableTaxConstant,
-                   SellableTaxConstant.q.id == Sellable.q.tax_constantID),
+        LeftJoin(SellableTaxConstant,
+                   SellableTaxConstant.q.id == Sellable.q.tax_constant_id),
         # Category
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
         # SellableUnit
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
         # Product
-        INNERJOINOn(None, Product,
-                    Product.q.sellableID == Sellable.q.id),
+        Join(Product,
+                    Product.q.sellable_id == Sellable.q.id),
         # Product Stock Item
-        LEFTJOINOn(None, Storable,
-                   Storable.q.productID == Product.q.id),
-        LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID == Storable.q.id),
+        LeftJoin(Storable,
+                   Storable.q.product_id == Product.q.id),
+        LeftJoin(ProductStockItem,
+                   ProductStockItem.q.storable_id == Storable.q.id),
         # Manufacturer
-        LEFTJOINOn(None, ProductManufacturer,
-                   Product.q.manufacturerID == ProductManufacturer.q.id),
+        LeftJoin(ProductManufacturer,
+                   Product.q.manufacturer_id == ProductManufacturer.q.id),
         ]
 
     clause = Sellable.q.status != Sellable.STATUS_CLOSED
 
+    @classmethod
+    def post_search_callback(cls, sresults):
+        select = sresults.get_select_expr(const.COUNT(const.DISTINCT(Sellable.q.id)),
+                                  const.COALESCE(const.SUM(ProductStockItem.q.quantity), 0))
+        return ('count', 'sum'), select
+
     @classmethod
     def select_by_branch(cls, query, branch, having=None, connection=None):
         if branch:
             # Also show products that were never purchased.
-            branch_query = OR(ProductStockItem.q.branchID == branch.id,
-                              ProductStockItem.q.branchID == None)
+            branch_query = OR(ProductStockItem.q.branch_id == branch.id,
+                              ProductStockItem.q.branch_id == None)
             if query:
                 query = AND(query, branch_query)
             else:
@@ -198,8 +206,8 @@ class ProductComponentView(ProductFullStockView):
 
     joins = ProductFullStockView.joins[:]
     joins.extend([
-        INNERJOINOn(None, ProductComponent,
-                    ProductComponent.q.productID == Product.q.id),
+        Join(ProductComponent,
+                    ProductComponent.q.product_id == Product.q.id),
         ])
 
 
@@ -232,16 +240,18 @@ class ProductWithStockView(ProductFullStockView):
 
 
 class _PurchaseItemTotal(Viewable):
+    # This subselect should query only from PurchaseItem, otherwise, more one
+    # product may appear more than once in the results (if there are purchase
+    # orders for it)
     columns = dict(
-        id=PurchaseItem.q.sellableID,
-        purchase_id=PurchaseOrder.q.id,
+        id=PurchaseItem.q.sellable_id,
         to_receive=const.SUM(PurchaseItem.q.quantity -
                              PurchaseItem.q.quantity_received)
     )
 
     joins = [
-        LEFTJOINOn(None, PurchaseOrder,
-                   PurchaseOrder.q.id == PurchaseItem.q.orderID)]
+        LeftJoin(PurchaseOrder,
+                 PurchaseOrder.q.id == PurchaseItem.q.order_id)]
 
     clause = PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED
 
@@ -263,7 +273,7 @@ class ProductFullStockItemView(ProductFullStockView):
                     Storable.q.minimum_quantity)))
 
     joins = ProductFullStockView.joins[:]
-    joins.append(LEFTJOINOn(None, _purchase_total,
+    joins.append(LeftJoin(_purchase_total,
                             Field('_purchase_total', 'id') == Sellable.q.id))
 
 
@@ -282,10 +292,10 @@ class ProductQuantityView(Viewable):
      """
 
     columns = dict(
-        id=ProductHistory.q.sellableID,
+        id=ProductHistory.q.sellable_id,
         code=Sellable.q.code,
         description=Sellable.q.description,
-        branch=ProductHistory.q.branchID,
+        branch=ProductHistory.q.branch_id,
         sold_date=ProductHistory.q.sold_date,
         received_date=ProductHistory.q.received_date,
         production_date=ProductHistory.q.production_date,
@@ -303,8 +313,8 @@ class ProductQuantityView(Viewable):
                       'decreased_date']
 
     joins = [
-        INNERJOINOn(None, Sellable,
-                    ProductHistory.q.sellableID == Sellable.q.id),
+        Join(Sellable,
+                    ProductHistory.q.sellable_id == Sellable.q.id),
     ]
 
 
@@ -346,30 +356,30 @@ class SellableFullStockView(Viewable):
 
     joins = [
         # Sellable unit
-        LEFTJOINOn(None, SellableUnit,
-                   SellableUnit.q.id == Sellable.q.unitID),
+        LeftJoin(SellableUnit,
+                   SellableUnit.q.id == Sellable.q.unit_id),
         # Category
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
         # Product
-        LEFTJOINOn(None, Product,
-                   Product.q.sellableID == Sellable.q.id),
+        LeftJoin(Product,
+                   Product.q.sellable_id == Sellable.q.id),
         # Product Stock Item
-        LEFTJOINOn(None, Storable,
-                   Storable.q.productID == Product.q.id),
-        LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID == Storable.q.id),
+        LeftJoin(Storable,
+                   Storable.q.product_id == Product.q.id),
+        LeftJoin(ProductStockItem,
+                   ProductStockItem.q.storable_id == Storable.q.id),
         # Manufacturer
-        LEFTJOINOn(None, ProductManufacturer,
-                   Product.q.manufacturerID == ProductManufacturer.q.id),
+        LeftJoin(ProductManufacturer,
+                   Product.q.manufacturer_id == ProductManufacturer.q.id),
         ]
 
     @classmethod
     def select_by_branch(cls, query, branch, having=None, connection=None):
         if branch:
             # We need the OR part to be able to list services
-            branch_query = OR(ProductStockItem.q.branchID == branch.id,
-                              ProductStockItem.q.branchID == None)
+            branch_query = OR(ProductStockItem.q.branch_id == branch.id,
+                              ProductStockItem.q.branch_id == None)
             if query:
                 query = AND(query, branch_query)
             else:
@@ -403,15 +413,15 @@ class SellableCategoryView(Viewable):
         id=SellableCategory.q.id,
         commission=CommissionSource.q.direct_value,
         installments_commission=CommissionSource.q.installments_value,
-        parent_id=SellableCategory.q.categoryID,
+        parent_id=SellableCategory.q.category_id,
         description=SellableCategory.q.description,
         suggested_markup=SellableCategory.q.suggested_markup,
     )
 
     joins = [
         # commission source
-        LEFTJOINOn(None, CommissionSource,
-                   CommissionSource.q.categoryID ==
+        LeftJoin(CommissionSource,
+                   CommissionSource.q.category_id ==
                    SellableCategory.q.id),
        ]
 
@@ -477,23 +487,24 @@ class QuotationView(Viewable):
     """
     columns = dict(
         id=Quotation.q.id,
-        purchase_id=Quotation.q.purchaseID,
-        group_id=Quotation.q.groupID,
-        group_code=Quotation.q.groupID,
+        purchase_id=Quotation.q.purchase_id,
+        group_id=Quotation.q.group_id,
+        identifier=Quotation.q.identifier,
+        group_identifier=QuoteGroup.q.identifier,
         open_date=PurchaseOrder.q.open_date,
         deadline=PurchaseOrder.q.quote_deadline,
         supplier_name=Person.q.name,
     )
 
     joins = [
-        INNERJOINOn(None, QuoteGroup,
-                    QuoteGroup.q.id == Quotation.q.groupID),
-        LEFTJOINOn(None, PurchaseOrder,
-                   PurchaseOrder.q.id == Quotation.q.purchaseID),
-        LEFTJOINOn(None, Supplier,
-                   Supplier.q.id == PurchaseOrder.q.supplierID),
-        LEFTJOINOn(None, Person, Person.q.id ==
-                   Supplier.q.personID),
+        Join(QuoteGroup,
+                    QuoteGroup.q.id == Quotation.q.group_id),
+        LeftJoin(PurchaseOrder,
+                   PurchaseOrder.q.id == Quotation.q.purchase_id),
+        LeftJoin(Supplier,
+                   Supplier.q.id == PurchaseOrder.q.supplier_id),
+        LeftJoin(Person, Person.q.id ==
+                   Supplier.q.person_id),
     ]
 
     @property
@@ -524,12 +535,12 @@ class SoldItemView(Viewable):
     )
 
     joins = [
-        LEFTJOINOn(None, SaleItem,
-                   Sellable.q.id == SaleItem.q.sellableID),
-        LEFTJOINOn(None, Sale,
-                   SaleItem.q.saleID == Sale.q.id),
-        LEFTJOINOn(None, SellableCategory,
-                   Sellable.q.categoryID == SellableCategory.q.id),
+        LeftJoin(SaleItem,
+                   Sellable.q.id == SaleItem.q.sellable_id),
+        LeftJoin(Sale,
+                   SaleItem.q.sale_id == Sale.q.id),
+        LeftJoin(SellableCategory,
+                   Sellable.q.category_id == SellableCategory.q.id),
     ]
 
     clause = OR(Sale.q.status == Sale.STATUS_CONFIRMED,
@@ -540,7 +551,7 @@ class SoldItemView(Viewable):
     def select_by_branch_date(cls, query, branch, date,
                               having=None, connection=None):
         if branch:
-            branch_query = Sale.q.branchID == branch.id
+            branch_query = Sale.q.branch_id == branch.id
             if query:
                 query = AND(query, branch_query)
             else:
@@ -572,24 +583,26 @@ class StockDecreaseItemsView(Viewable):
     """
     columns = dict(
         id=StockDecreaseItem.q.id,
+        quantity=StockDecreaseItem.q.quantity,
+        sellable=StockDecreaseItem.q.sellable_id,
+        decrease_id=StockDecrease.q.id,
+        decrease_identifier=StockDecrease.q.identifier,
         date=StockDecrease.q.confirm_date,
         removed_by_name=Person.q.name,
-        quantity=StockDecreaseItem.q.quantity,
-        sellable=StockDecreaseItem.q.sellableID,
         unit_description=SellableUnit.q.description,
     )
 
     joins = [
-        INNERJOINOn(None, StockDecrease,
-                    StockDecreaseItem.q.stock_decreaseID == StockDecrease.q.id),
-        LEFTJOINOn(None, Sellable,
-                   StockDecreaseItem.q.sellableID == Sellable.q.id),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
-        INNERJOINOn(None, Employee,
-                   StockDecrease.q.removed_byID == Employee.q.id),
-        INNERJOINOn(None, Person,
-                   Employee.q.personID == Person.q.id),
+        Join(StockDecrease,
+                    StockDecreaseItem.q.stock_decrease_id == StockDecrease.q.id),
+        LeftJoin(Sellable,
+                   StockDecreaseItem.q.sellable_id == Sellable.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
+        Join(Employee,
+                   StockDecrease.q.removed_by_id == Employee.q.id),
+        Join(Person,
+                   Employee.q.person_id == Person.q.id),
     ]
 
 
@@ -603,10 +616,10 @@ class SoldItemsByBranchView(SoldItemView):
     ))
 
     joins = SoldItemView.joins[:]
-    joins.append(LEFTJOINOn(None, Branch,
-                            Branch.q.id == Sale.q.branchID))
-    joins.append(LEFTJOINOn(None, Person,
-                            Branch.q.personID == Person.q.id))
+    joins.append(LeftJoin(Branch,
+                            Branch.q.id == Sale.q.branch_id))
+    joins.append(LeftJoin(Person,
+                            Branch.q.person_id == Person.q.id))
 
     clause = OR(SoldItemView.clause,
                 Sale.q.status == Sale.STATUS_RENEGOTIATED)
@@ -631,31 +644,32 @@ class PurchasedItemAndStockView(Viewable):
     columns = dict(
         id=PurchaseItem.q.id,
         product_id=Product.q.id,
+        code=Sellable.q.code,
         description=Sellable.q.description,
         purchased=PurchaseItem.q.quantity,
         received=PurchaseItem.q.quantity_received,
         stocked=const.SUM(ProductStockItem.q.quantity),
         expected_receival_date=PurchaseItem.q.expected_receival_date,
-        order_id=PurchaseOrder.q.id,
+        order_identifier=PurchaseOrder.q.identifier,
         purchased_date=PurchaseOrder.q.open_date,
-        branch=PurchaseOrder.q.branchID,
+        branch=PurchaseOrder.q.branch_id,
     )
 
     joins = [
-        LEFTJOINOn(None, PurchaseOrder,
-                   PurchaseItem.q.orderID == PurchaseOrder.q.id),
-        LEFTJOINOn(None, Sellable,
-                    Sellable.q.id == PurchaseItem.q.sellableID),
-        LEFTJOINOn(None, Product,
-                   Product.q.sellableID == PurchaseItem.q.sellableID),
-        LEFTJOINOn(None, Storable,
-                   Storable.q.productID == Product.q.id),
-        LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID == Storable.q.id),
+        LeftJoin(PurchaseOrder,
+                   PurchaseItem.q.order_id == PurchaseOrder.q.id),
+        LeftJoin(Sellable,
+                    Sellable.q.id == PurchaseItem.q.sellable_id),
+        LeftJoin(Product,
+                   Product.q.sellable_id == PurchaseItem.q.sellable_id),
+        LeftJoin(Storable,
+                   Storable.q.product_id == Product.q.id),
+        LeftJoin(ProductStockItem,
+                   ProductStockItem.q.storable_id == Storable.q.id),
     ]
 
     clause = AND(PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED,
-                 PurchaseOrder.q.branchID == ProductStockItem.q.branchID,
+                 PurchaseOrder.q.branch_id == ProductStockItem.q.branch_id,
                  PurchaseItem.q.quantity > PurchaseItem.q.quantity_received, )
 
     @property
@@ -670,7 +684,7 @@ class ConsignedItemAndStockView(PurchasedItemAndStockView):
         returned=PurchaseItem.q.quantity_returned,
     ))
     clause = AND(PurchaseOrder.q.consigned == True,
-                 PurchaseOrder.q.branchID == ProductStockItem.q.branchID)
+                 PurchaseOrder.q.branch_id == ProductStockItem.q.branch_id)
 
 
 class PurchaseReceivingView(Viewable):
@@ -680,7 +694,7 @@ class PurchaseReceivingView(Viewable):
     :cvar receival_date: the date when the receiving order was closed
     :cvar invoice_number: the number of the order that was received
     :cvar invoice_total: the total value of the received order
-    :cvar purchase_id: the id of the received order
+    :cvar purchase_identifier: the identifier of the received order
     :cvar branch_id: the id branch where the order was received
     :cvar purchase_responsible_name: the one who have confirmed the purchase
     :cvar responsible_name: the one who has received the order
@@ -696,28 +710,28 @@ class PurchaseReceivingView(Viewable):
         receival_date=ReceivingOrder.q.receival_date,
         invoice_number=ReceivingOrder.q.invoice_number,
         invoice_total=ReceivingOrder.q.invoice_total,
-        purchase_id=PurchaseOrder.q.id,
-        branch_id=ReceivingOrder.q.branchID,
+        purchase_identifier=PurchaseOrder.q.identifier,
+        branch_id=ReceivingOrder.q.branch_id,
         purchase_responsible_name=_PurchaseResponsible.q.name,
         responsible_name=_Responsible.q.name,
         supplier_name=_Supplier.q.name,
         )
 
     joins = [
-        LEFTJOINOn(None, PurchaseOrder,
-                   ReceivingOrder.q.purchaseID == PurchaseOrder.q.id),
-        LEFTJOINOn(None, _PurchaseUser,
-                   PurchaseOrder.q.responsibleID == _PurchaseUser.q.id),
-        LEFTJOINOn(None, _PurchaseResponsible,
-                   _PurchaseUser.q.personID == _PurchaseResponsible.q.id),
-        LEFTJOINOn(None, Supplier,
-                   ReceivingOrder.q.supplierID == Supplier.q.id),
-        LEFTJOINOn(None, _Supplier,
-                   Supplier.q.personID == _Supplier.q.id),
-        LEFTJOINOn(None, LoginUser,
-                   ReceivingOrder.q.responsibleID == LoginUser.q.id),
-        LEFTJOINOn(None, _Responsible,
-                   LoginUser.q.personID == _Responsible.q.id),
+        LeftJoin(PurchaseOrder,
+                   ReceivingOrder.q.purchase_id == PurchaseOrder.q.id),
+        LeftJoin(_PurchaseUser,
+                   PurchaseOrder.q.responsible_id == _PurchaseUser.q.id),
+        LeftJoin(_PurchaseResponsible,
+                   _PurchaseUser.q.person_id == _PurchaseResponsible.q.id),
+        LeftJoin(Supplier,
+                   ReceivingOrder.q.supplier_id == Supplier.q.id),
+        LeftJoin(_Supplier,
+                   Supplier.q.person_id == _Supplier.q.id),
+        LeftJoin(LoginUser,
+                   ReceivingOrder.q.responsible_id == LoginUser.q.id),
+        LeftJoin(_Responsible,
+                   LoginUser.q.person_id == _Responsible.q.id),
     ]
 
 
@@ -732,7 +746,8 @@ class SaleItemsView(Viewable):
         sellable_id=Sellable.q.id,
         code=Sellable.q.code,
         description=Sellable.q.description,
-        sale_id=SaleItem.q.saleID,
+        sale_id=SaleItem.q.sale_id,
+        sale_identifier=Sale.q.identifier,
         sale_date=Sale.q.open_date,
         client_name=Person.q.name,
         quantity=SaleItem.q.quantity,
@@ -740,16 +755,16 @@ class SaleItemsView(Viewable):
     )
 
     joins = [
-        LEFTJOINOn(None, Sellable,
-                    Sellable.q.id == SaleItem.q.sellableID),
-        LEFTJOINOn(None, Sale,
-                   SaleItem.q.saleID == Sale.q.id),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
-        LEFTJOINOn(None, Client,
-                   Sale.q.clientID == Client.q.id),
-        LEFTJOINOn(None, Person,
-                   Client.q.personID == Person.q.id),
+        LeftJoin(Sellable,
+                    Sellable.q.id == SaleItem.q.sellable_id),
+        LeftJoin(Sale,
+                   SaleItem.q.sale_id == Sale.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
+        LeftJoin(Client,
+                   Sale.q.client_id == Client.q.id),
+        LeftJoin(Person,
+                   Client.q.person_id == Person.q.id),
     ]
 
     clause = OR(Sale.q.status == Sale.STATUS_CONFIRMED,
@@ -764,8 +779,8 @@ class ReceivingItemView(Viewable):
     already received and the information related to that process.
 
     :cvar id: the id of the receiving item
-    :cvar order_id: the id of the receiving order
-    :cvar purchase_id: the id of the purchase order
+    :cvar order_identifier: the identifier of the receiving order
+    :cvar purchase_identifier: the identifier of the purchase order
     :cvar purchase_item_id: the id of the purchase item
     :cvar sellable_id: the id of the sellable related to the received item
     :cvar invoice_number: the invoice number of the receiving order
@@ -777,10 +792,10 @@ class ReceivingItemView(Viewable):
     """
     columns = dict(
         id=ReceivingOrderItem.q.id,
-        order_id=ReceivingOrder.q.id,
-        purchase_id=ReceivingOrder.q.purchaseID,
-        purchase_item_id=ReceivingOrderItem.q.purchase_itemID,
-        sellable_id=ReceivingOrderItem.q.sellableID,
+        order_identifier=ReceivingOrder.q.identifier,
+        purchase_identifier=PurchaseOrder.q.identifier,
+        purchase_item_id=ReceivingOrderItem.q.purchase_item_id,
+        sellable_id=ReceivingOrderItem.q.sellable_id,
         invoice_number=ReceivingOrder.q.invoice_number,
         receival_date=ReceivingOrder.q.receival_date,
         quantity=ReceivingOrderItem.q.quantity,
@@ -790,22 +805,24 @@ class ReceivingItemView(Viewable):
     )
 
     joins = [
-        LEFTJOINOn(None, ReceivingOrder,
-                   ReceivingOrderItem.q.receiving_orderID == ReceivingOrder.q.id),
-        LEFTJOINOn(None, Sellable,
-                   ReceivingOrderItem.q.sellableID == Sellable.q.id),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
-        LEFTJOINOn(None, Supplier,
-                   ReceivingOrder.q.supplierID == Supplier.q.id),
-        LEFTJOINOn(None, Person,
-                   Supplier.q.personID == Person.q.id),
+        LeftJoin(ReceivingOrder,
+                   ReceivingOrderItem.q.receiving_order_id == ReceivingOrder.q.id),
+        LeftJoin(PurchaseOrder,
+                   ReceivingOrder.q.purchase_id == PurchaseOrder.q.id),
+        LeftJoin(Sellable,
+                   ReceivingOrderItem.q.sellable_id == Sellable.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
+        LeftJoin(Supplier,
+                   ReceivingOrder.q.supplier_id == Supplier.q.id),
+        LeftJoin(Person,
+                   Supplier.q.person_id == Person.q.id),
     ]
 
 
 class ProductionItemView(Viewable):
     columns = dict(id=ProductionItem.q.id,
-                   order_id=ProductionOrder.q.id,
+                   order_identifier=ProductionOrder.q.identifier,
                    order_status=ProductionOrder.q.status,
                    quantity=ProductionItem.q.quantity,
                    produced=ProductionItem.q.produced,
@@ -815,16 +832,16 @@ class ProductionItemView(Viewable):
                    description=Sellable.q.description, )
 
     joins = [
-        LEFTJOINOn(None, ProductionOrder,
-                   ProductionItem.q.orderID == ProductionOrder.q.id),
-        LEFTJOINOn(None, Product,
-                   ProductionItem.q.productID == Product.q.id),
-        LEFTJOINOn(None, Sellable,
-                    Sellable.q.id == Product.q.sellableID),
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
+        LeftJoin(ProductionOrder,
+                   ProductionItem.q.order_id == ProductionOrder.q.id),
+        LeftJoin(Product,
+                   ProductionItem.q.product_id == Product.q.id),
+        LeftJoin(Sellable,
+                    Sellable.q.id == Product.q.sellable_id),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
     ]
 
     @property
@@ -837,33 +854,36 @@ class LoanView(Viewable):
     PersonResponsible = Alias(Person, 'person_responsible')
     PersonClient = Alias(Person, 'person_client')
 
-    columns = dict(id=Loan.q.id,
-                    status=Loan.q.status,
-                    open_date=Loan.q.open_date,
-                    close_date=Loan.q.close_date,
-                    expire_date=Loan.q.expire_date,
+    columns = dict(
+        id=Loan.q.id,
+        identifier=Loan.q.identifier,
+        status=Loan.q.status,
+        open_date=Loan.q.open_date,
+        close_date=Loan.q.close_date,
+        expire_date=Loan.q.expire_date,
 
-                    removed_by=Loan.q.removed_by,
-                    branch_name=PersonBranch.q.name,
-                    responsible_name=PersonResponsible.q.name,
-                    client_name=PersonClient.q.name,
-                    loaned=const.SUM(LoanItem.q.quantity),
-                    total=const.SUM(LoanItem.q.quantity * LoanItem.q.price), )
+        removed_by=Loan.q.removed_by,
+        branch_name=PersonBranch.q.name,
+        responsible_name=PersonResponsible.q.name,
+        client_name=PersonClient.q.name,
+        loaned=const.SUM(LoanItem.q.quantity),
+        total=const.SUM(LoanItem.q.quantity * LoanItem.q.price),
+    )
     joins = [
-        INNERJOINOn(None, LoanItem, Loan.q.id == LoanItem.q.loanID),
-        LEFTJOINOn(None, Branch,
-                   Loan.q.branchID == Branch.q.id),
-        LEFTJOINOn(None, LoginUser,
-                   Loan.q.responsibleID == LoginUser.q.id),
-        LEFTJOINOn(None, Client,
-                   Loan.q.clientID == Client.q.id),
+        Join(LoanItem, Loan.q.id == LoanItem.q.loan_id),
+        LeftJoin(Branch,
+                   Loan.q.branch_id == Branch.q.id),
+        LeftJoin(LoginUser,
+                   Loan.q.responsible_id == LoginUser.q.id),
+        LeftJoin(Client,
+                   Loan.q.client_id == Client.q.id),
 
-        LEFTJOINOn(None, PersonBranch,
-                   Branch.q.personID == PersonBranch.q.id),
-        LEFTJOINOn(None, PersonResponsible,
-                   LoginUser.q.personID == PersonResponsible.q.id),
-        LEFTJOINOn(None, PersonClient,
-                   Client.q.personID == PersonClient.q.id),
+        LeftJoin(PersonBranch,
+                   Branch.q.person_id == PersonBranch.q.id),
+        LeftJoin(PersonResponsible,
+                   LoginUser.q.person_id == PersonResponsible.q.id),
+        LeftJoin(PersonClient,
+                   Client.q.person_id == PersonClient.q.id),
     ]
 
     @property
@@ -872,30 +892,32 @@ class LoanView(Viewable):
 
 
 class LoanItemView(Viewable):
-    columns = dict(id=LoanItem.q.id,
-                   loan_id=Loan.q.id,
-                   loan_status=Loan.q.status,
-                   opened=Loan.q.open_date,
-                   closed=Loan.q.close_date,
-                   quantity=LoanItem.q.quantity,
-                   sale_quantity=LoanItem.q.sale_quantity,
-                   return_quantity=LoanItem.q.return_quantity,
-                   price=LoanItem.q.price,
-                   total=LoanItem.q.quantity * LoanItem.q.price,
-                   sellable_id=Sellable.q.id,
-                   code=Sellable.q.code,
-                   category_description=SellableCategory.q.description,
-                   unit_description=SellableUnit.q.description,
-                   description=Sellable.q.description, )
+    columns = dict(
+        id=LoanItem.q.id,
+        loan_identifier=Loan.q.identifier,
+        loan_status=Loan.q.status,
+        opened=Loan.q.open_date,
+        closed=Loan.q.close_date,
+        quantity=LoanItem.q.quantity,
+        sale_quantity=LoanItem.q.sale_quantity,
+        return_quantity=LoanItem.q.return_quantity,
+        price=LoanItem.q.price,
+        total=LoanItem.q.quantity * LoanItem.q.price,
+        sellable_id=Sellable.q.id,
+        code=Sellable.q.code,
+        category_description=SellableCategory.q.description,
+        unit_description=SellableUnit.q.description,
+        description=Sellable.q.description,
+    )
 
     joins = [
-        LEFTJOINOn(None, Loan, LoanItem.q.loanID == Loan.q.id),
-        LEFTJOINOn(None, Sellable,
-                   LoanItem.q.sellableID == Sellable.q.id),
-        LEFTJOINOn(None, SellableUnit,
-                   Sellable.q.unitID == SellableUnit.q.id),
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
+        LeftJoin(Loan, LoanItem.q.loan_id == Loan.q.id),
+        LeftJoin(Sellable,
+                   LoanItem.q.sellable_id == Sellable.q.id),
+        LeftJoin(SellableUnit,
+                   Sellable.q.unit_id == SellableUnit.q.id),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
     ]
 
 
@@ -903,21 +925,21 @@ class AccountView(Viewable):
 
     class _SourceSum(Viewable):
         columns = dict(
-            id=AccountTransaction.q.source_accountID,
+            id=AccountTransaction.q.source_account_id,
             value=const.SUM(AccountTransaction.q.value),
             )
 
     class _DestSum(Viewable):
         columns = dict(
-            id=AccountTransaction.q.accountID,
+            id=AccountTransaction.q.account_id,
             value=const.SUM(AccountTransaction.q.value),
             )
 
     columns = dict(
         id=Account.q.id,
-        parentID=Account.q.parentID,
+        parent_id=Account.q.parent_id,
         account_type=Account.q.account_type,
-        dest_accountID=Account.q.parentID,
+        dest_account_id=Account.q.parent_id,
         description=Account.q.description,
         code=Account.q.code,
         source_value=Field('source_sum', 'value'),
@@ -925,9 +947,9 @@ class AccountView(Viewable):
         )
 
     joins = [
-        LEFTJOINOn(None, Alias(_SourceSum, 'source_sum'),
+        LeftJoin(Alias(_SourceSum, 'source_sum'),
                    Field('source_sum', 'id') == Account.q.id),
-        LEFTJOINOn(None, Alias(_DestSum, 'dest_sum'),
+        LeftJoin(Alias(_DestSum, 'dest_sum'),
                    Field('dest_sum', 'id') == Account.q.id),
         ]
 
@@ -939,13 +961,13 @@ class AccountView(Viewable):
     @property
     def parent_account(self):
         """Get the parent account for this view"""
-        return Account.get(self.parentID, connection=self.get_connection())
+        return Account.get(self.parent_id, connection=self.get_connection())
 
     def matches(self, account_id):
         """Returns true if the account_id matches this account or its parent"""
         if self.id == account_id:
             return True
-        if self.parentID and self.parentID == account_id:
+        if self.parent_id and self.parent_id == account_id:
             return True
         return False
 
@@ -963,3 +985,60 @@ class AccountView(Viewable):
 
     def __repr__(self):
         return '<AccountView %s>' % (self.description, )
+
+
+class DeliveryView(Viewable):
+    PersonTransporter = Alias(Person, 'person_transporter')
+    PersonClient = Alias(Person, 'person_client')
+
+    columns = dict(
+        # Delivery
+        id=Delivery.q.id,
+        status=Delivery.q.status,
+        tracking_code=Delivery.q.tracking_code,
+        open_date=Delivery.q.open_date,
+        deliver_date=Delivery.q.deliver_date,
+        receive_date=Delivery.q.receive_date,
+
+        # Transporter
+        transporter_name=PersonTransporter.q.name,
+
+        # Client
+        client_name=PersonClient.q.name,
+
+        # Sale
+        sale_identifier=Sale.q.identifier,
+
+        # Address
+        address_id=Delivery.q.address_id,
+    )
+
+    joins = [
+        LeftJoin(Transporter,
+                 Transporter.q.id == Delivery.q.transporter_id),
+        LeftJoin(PersonTransporter,
+                 PersonTransporter.q.id == Transporter.q.person_id),
+        LeftJoin(SaleItem,
+                 SaleItem.q.id == Delivery.q.service_item_id),
+        LeftJoin(Sale,
+                 Sale.q.id == SaleItem.q.sale_id),
+        LeftJoin(Client,
+                 Client.q.id == Sale.q.client_id),
+        LeftJoin(PersonClient,
+                 PersonClient.q.id == Client.q.person_id),
+        #LeftJoin(Address,
+        #         Address.q.person_id == Client.q.person_id),
+        ]
+
+    @property
+    def status_str(self):
+        return Delivery.statuses[self.status]
+
+    @property
+    def delivery(self):
+        return Delivery.get(self.id, connection=self.get_connection())
+
+    @property
+    def address_str(self):
+        return Address.get(self.address_id,
+               connection=self.get_connection()).get_description()
