@@ -204,7 +204,7 @@ class ModelListDialog(BasicDialog):
             raise TypeError(
                 "%s needs to set it's list_slave_class attribute" % (
                 self.__class__.__name__, ))
-        self.list_slave = self.list_slave_class(self)
+        self.list_slave = self.list_slave_class(self, conn=conn)
 
         BasicDialog.__init__(self, title=self.title, size=self.size)
 
@@ -496,7 +496,10 @@ class SimpleListDialog(BasicDialog):
             return []
         return [selection]
 
-    # BasicDialog 'confirm' method override
+    #
+    #  BasicDialog
+    #
+
     def confirm(self):
-        self.retval = self.get_selection()
-        return True
+        super(SimpleListDialog, self).confirm()
+        self.retval = self.retval and self.get_selection()
