@@ -42,9 +42,11 @@ from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.lib.decorators import public
 from stoqlib.lib.defaults import get_weekday_start
 from stoqlib.lib.osutils import get_application_dir
 from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -74,11 +76,10 @@ class _SearchDialogDetailsSlave(GladeSlaveDelegate):
 
 class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
     def __init__(self, columns, tree=False, restore_name=None):
-        self._columns = columns
         self._restore_name = restore_name
         self._settings_key = 'search-columns-%s' % (
             api.get_current_user(api.get_connection()).username, )
-        self.restore_columns()
+        self._columns = self.restore_columns(columns)
 
         SearchSlaveDelegate.__init__(self, self._columns, tree=tree)
         self.search.connect("search-completed",
@@ -93,31 +94,71 @@ class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
             return
 
         d = {}
-        for col in self._columns:
-            d[col.title] = (col.treeview_column.get_visible(),
-                            col.treeview_column.get_width())
+        treeview = self.search.results.get_treeview()
+        for position, col in enumerate(treeview.get_columns()):
+            # Can happen if there's an empty space on columns' header.
+            # Normally on searchs that doesn't have an expand column.
+            if not hasattr(col, 'attribute'):
+                continue
+            d[col.attribute] = (
+                col.get_visible(),
+                col.get_width(),
+                col.get_sort_indicator(),
+                int(col.get_sort_order()),  # enums are not serializable
+                position,
+                )
 
         columns = api.user_settings.get(self._settings_key, {})
         columns[self._restore_name] = d
 
-    def restore_columns(self):
+    def restore_columns(self, cols):
         if not self._restore_name:
-            return
+            return cols
+
         columns = api.user_settings.get(self._settings_key, {})
         if columns:
             saved = columns.get(self._restore_name, {})
         else:
             saved = self._migrate_from_pickle()
 
-        for col in self._columns:
-            # Expanded columns should not have a width set.
-            if col.expand:
+        cols_dict = {}
+        for original_pos, col in enumerate(cols):
+            attr = col.attribute
+            props = saved.get(attr)
+            # This will happen for two reasons: a) the column is referenced by
+            # another one (only the column that references is saved) and
+            # b) Its a brand new column (not saved in the preferences)
+            if not props:
+                cols_dict[attr] = (col, original_pos)
                 continue
-            props = saved.get(col.title)
-            if props:
-                col.visible = props[0]
+
+            col.visible = props[0]
+            # Expanded columns should not have a width set
+            if not col.expand:
                 col.width = props[1]
 
+            # We didn't store sorted and order before
+            if len(props) <= 2:
+                continue
+
+            col.sorted = props[2]
+            col.order = props[3]
+
+            pos = props[4]
+            # If col references another column, the referenced column
+            # should appear before this col
+            if col.column:
+                referenced_col = cols_dict[col.column][0]
+                cols_dict[col.column] = (referenced_col, pos)
+                cols_dict[attr] = (col, pos + 1)
+                if col.sorted:
+                    referenced_col.sorted, col.sorted = True, False
+            else:
+                cols_dict[attr] = (col, pos)
+
+        cols.sort(key=lambda col: cols_dict[col.attribute][1])
+        return cols
+
     def set_message(self, message):
         self.search.results.set_message(message)
 
@@ -168,6 +209,7 @@ class SearchDialogPrintSlave(GladeSlaveDelegate):
 #
 
 
+@public(since="1.5.0")
 class SearchDialog(BasicDialog):
     """  Base class for *all* the search dialogs, responsible for the list
     construction and "Filter" and "Clear" buttons management.
@@ -230,7 +272,7 @@ class SearchDialog(BasicDialog):
                              title=title or self.title,
                              size=self.size)
 
-        self.executer = ORMObjectQueryExecuter(api.get_connection())
+        self.executer = ORMObjectQueryExecuter(conn)
         # FIXME: Remove this limit, but we need to migrate all existing
         #        searches to use lazy lists first. That in turn require
         #        us to rewrite the queries in such a way that count(*)
@@ -436,6 +478,22 @@ class SearchDialog(BasicDialog):
 
         return branch_filter
 
+    def create_payment_filter(self, label=None):
+        from stoqlib.domain.payment.method import PaymentMethod
+        methods = PaymentMethod.get_active_methods(self.conn)
+        items = [(_('Any'), None)]
+        for method in methods:
+            if method.method_name == 'multiple':
+                continue
+            items.append((method.description, method))
+
+        if not label:
+            label = _('Method:')
+        payment_filter = ComboSearchFilter(label, items)
+        payment_filter.select(None)
+
+        return payment_filter
+
     def create_provider_filter(self, label=None):
         from stoqlib.domain.person import CreditProvider
         providers = CreditProvider.get_active_providers(self.conn)
@@ -581,6 +639,7 @@ class SearchEditor(SearchDialog):
         """
 
         self.interface = interface
+        self._read_only = False
         self._message_bar = None
 
         SearchDialog.__init__(self, conn, table, search_table,
@@ -614,6 +673,7 @@ class SearchEditor(SearchDialog):
 
         self.set_edit_button_sensitive(False)
         self.results.connect('selection-changed', self._on_selection_changed)
+        self._check_permissions()
 
     def _setup_slaves(self):
         self._toolbar = SearchEditorToolBar()
@@ -621,6 +681,25 @@ class SearchEditor(SearchDialog):
         self._toolbar.connect("add", self._on_toolbar__new)
         self.attach_slave('extra_holder', self._toolbar)
 
+    def _check_permissions(self):
+        if not self.editor_class:
+            return
+
+        pm = PermissionManager.get_permission_manager()
+        key = self.editor_class.model_type.__name__
+        if not pm.can_create(key):
+            self.hide_new_button()
+
+        if not pm.can_edit(key):
+            if pm.can_see_details(key):
+                # Replace edit button with a details button. self._read_only
+                # will activate visual_mode for the editor
+                self._read_only = True
+                self._toolbar.edit_button_label.set_text(_('Details'))
+                self._toolbar.edit_button_image.set_from_stock('gtk-info', gtk.ICON_SIZE_BUTTON)
+            else:
+                self.hide_edit_button()
+
     # Public API
 
     @argcheck(bool)
@@ -628,6 +707,14 @@ class SearchEditor(SearchDialog):
         """Control sensitivity of button edit"""
         self._toolbar.edit_button.set_sensitive(value)
 
+    def set_edit_button_label(self, label, stock=None):
+        """Edits label and icon of the edit button
+        """
+        self._toolbar.edit_button_label.set_label(label)
+        if stock:
+            self._toolbar.edit_button_image.set_from_stock(stock,
+                                                           gtk.ICON_SIZE_BUTTON)
+
     def update_widgets(self, *args):
         self._toolbar.edit_button.set_sensitive(len(self.results))
 
@@ -672,7 +759,7 @@ class SearchEditor(SearchDialog):
     def run_editor(self, obj):
         trans = api.new_transaction()
         retval = self.run_dialog(self.editor_class, self, trans,
-                                 trans.get(obj))
+                                 trans.get(obj), visual_mode=self._read_only)
         if api.finish_transaction(trans, retval):
             # If the return value is an ORMObject, fetch it from
             # the right connection
