@@ -78,7 +78,6 @@ class WizardStep:
 class PluggableWizard(GladeDelegate):
     """ Wizard controller and view class """
     gladefile = 'PluggableWizard'
-    retval = None
 
     def __init__(self, title, first_step, size=None, edit_mode=False):
         """
@@ -250,6 +249,9 @@ class PluggableWizard(GladeDelegate):
 
         self._change_step(self._current.next_step())
 
+    def get_current_step(self):
+        return self._current
+
 
 class BaseWizardStep(WizardStep, GladeSlaveDelegate):
     """A wizard step base class definition"""
@@ -278,6 +280,7 @@ class BaseWizard(PluggableWizard, RunnableView):
     """A wizard base class definition"""
     title = None
     size = ()
+    help_section = None
 
     def __init__(self, conn, first_step, model=None, title=None,
                  size=None, edit_mode=False):
@@ -294,17 +297,19 @@ class BaseWizard(PluggableWizard, RunnableView):
         PluggableWizard.__init__(self, title=title, first_step=first_step,
                                  size=size, edit_mode=edit_mode)
         self.enable_window_controls()
+        if self.help_section:
+            self.set_help_section(self.help_section)
 
     def set_help_section(self, section):
         def on_help__clicked(button):
             show_section(section)
 
         self.buttonbox.set_layout(gtk.BUTTONBOX_END)
-        button = gtk.Button(stock=gtk.STOCK_HELP)
-        button.connect('clicked', on_help__clicked)
-        self.buttonbox.add(button)
-        self.buttonbox.set_child_secondary(button, True)
-        button.show()
+        self.help_button = gtk.Button(stock=gtk.STOCK_HELP)
+        self.help_button.connect('clicked', on_help__clicked)
+        self.buttonbox.add(self.help_button)
+        self.buttonbox.set_child_secondary(self.help_button, True)
+        self.help_button.show()
 
     def cancel(self):
         logger.info('Canceling wizard: %s' % self.__class__.__name__)
