@@ -31,6 +31,7 @@ from kiwi.ui.objectlist import ObjectList
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
+from stoqlib.database.runtime import get_connection
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.stockicons import STOQ_PLUGIN
 from stoqlib.lib.parameters import is_developer_mode
@@ -122,6 +123,10 @@ class PluginManagerDialog(BasicDialog):
 
     def _enable_plugin(self, plugin_model):
         plugin_name = plugin_model.name
+        # This should not really be necessary, but there may be deadlocks when
+        # activating the plugin. See bug 5272
+        conn = get_connection()
+        conn.commit()
         self._manager.install_plugin(plugin_name)
         self._manager.activate_plugin(plugin_name)
 
@@ -134,10 +139,9 @@ class PluginManagerDialog(BasicDialog):
                 "Please note that, once activated you will not "
                 "be able to disable it.")
         response = yesno(msg, gtk.RESPONSE_NO,
-                         _("Not now"), _("Activate plugin"))
+                         _("Activate plugin"), _("Not now"))
+
         if response:
-            self.retval = False
-        else:
             self._enable_plugin(self.klist.get_selected())
             self.close()
 
@@ -149,6 +153,6 @@ class PluginManagerDialog(BasicDialog):
         self._update_widgets()
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     ec = api.prepare_test()
     run_dialog(PluginManagerDialog, None, ec.trans)
