@@ -42,7 +42,7 @@ _ = stoqlib_gettext
 class _TemporaryQuoteGroup(object):
 
     def _create_purchase_order(self, trans, supplier, items):
-        order = PurchaseOrder(supplier=supplier,
+        order = PurchaseOrder(supplier=trans.get(supplier),
                               branch=api.get_current_branch(trans),
                               status=PurchaseOrder.ORDER_QUOTING,
                               expected_receival_date=None,
@@ -51,7 +51,7 @@ class _TemporaryQuoteGroup(object):
                               connection=trans)
 
         for sellable, quantity in items:
-            order.add_item(sellable, quantity)
+            order.add_item(trans.get(sellable), quantity)
 
         return order
 
@@ -82,7 +82,8 @@ class _TemporaryQuoteGroup(object):
                 supplier = supplier_info.supplier
                 quote_data.setdefault(supplier, []).append((sellable, quantity))
 
-        group = QuoteGroup(connection=trans)
+        group = QuoteGroup(connection=trans,
+                           branch=api.get_current_branch(trans))
 
         # For each supplier that offer a material we need, we create a quote
         # with all the materials he offers and add it to the group.
@@ -133,7 +134,7 @@ class ProductionQuoteDialog(BaseEditor):
     def _get_columns(self):
         return [Column('selected', title=" ", width=50,
                         data_type=bool, editable=True),
-                Column('obj.id', title=_(u"Order"), data_type=int,
+                Column('obj.identifier', title=_(u"Order"), data_type=int,
                         format="%04d"),
                 Column('obj.description', title=_(u"Description"),
                         data_type=str, sorted=True),
@@ -173,7 +174,7 @@ class ProductionQuoteDialog(BaseEditor):
         trans.close()
         info(_(u'The quote group was succesfully created and it is available '
                 'in the Purchase application.'))
-        return True
+        self.retval = group
 
     #
     # Kiwi Callback
