@@ -199,7 +199,7 @@ class PurchaseDetailsDialog(BaseEditor):
                        data_type=currency, width=100)]
 
     def _get_payments_columns(self):
-        return [Column('id', "#", data_type=int, width=50,
+        return [Column('identifier', "#", data_type=int, width=50,
                        format='%04d', justify=gtk.JUSTIFY_RIGHT),
                 Column('description', _("Description"), data_type=str,
                        width=150, expand=True,
