@@ -25,6 +25,7 @@
 """ Classes for sale details """
 
 import datetime
+import decimal
 
 import pango
 import gtk
@@ -32,11 +33,12 @@ from kiwi.currency import currency
 from kiwi.ui.widgets.list import Column, ColoredColumn
 
 from stoqlib.domain.person import Client
-from stoqlib.domain.sale import SaleView, Sale
+from stoqlib.domain.returnedsale import ReturnedSale
+from stoqlib.domain.sale import SaleView, Sale, ReturnedSaleItemsView
 from stoqlib.domain.payment.views import PaymentChangeHistoryView
-from stoqlib.domain.renegotiation import RenegotiationData
 from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.defaults import payment_value_colorize
+from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.base.dialogs import run_dialog
@@ -57,13 +59,14 @@ class _TemporaryOutPayment(object):
 
     def __init__(self, payment):
         self.id = payment.id
+        self.identifier = payment.identifier
         self.description = payment.description
         self.method.description = payment.method.description
         self.method.method_name = payment.method.method_name
         self.due_date = payment.due_date
         self.paid_date = payment.paid_date
         self.status_str = payment.get_status_str()
-        self.base_value = -payment.base_value
+        self.value = -payment.base_value
         self.paid_value = -(payment.paid_value or 0)
 
 
@@ -78,6 +81,7 @@ class SaleDetailsDialog(BaseEditor):
                      'salesperson_lbl',
                      'open_date_lbl',
                      'total_lbl',
+                     'return_total_lbl',
                      'order_number',
                      'subtotal_lbl',
                      'surcharge_lbl',
@@ -100,6 +104,7 @@ class SaleDetailsDialog(BaseEditor):
 
     def _setup_columns(self):
         self.items_list.set_columns(self._get_items_columns())
+        self.returned_items_list.set_columns(self._get_returned_items_columns())
         self.payments_list.set_columns(self._get_payments_columns())
         self.payments_info_list.set_columns(self._get_payments_info_columns())
 
@@ -117,8 +122,7 @@ class SaleDetailsDialog(BaseEditor):
 
         self.sale_order = Sale.get(self.model.id, connection=self.conn)
 
-        if (self.sale_order.status == Sale.STATUS_RETURNED or
-            self.sale_order.status == Sale.STATUS_RENEGOTIATED):
+        if self.sale_order.status == Sale.STATUS_RENEGOTIATED:
             self.status_details_button.show()
         else:
             self.status_details_button.hide()
@@ -126,8 +130,55 @@ class SaleDetailsDialog(BaseEditor):
         sale_items = self.sale_order.get_items()
         self.items_list.add_list(sale_items)
 
+        notes = []
+        details = self.sale_order.get_details_str()
+        if details:
+            notes.append(details)
+
+        returned_sale = ReturnedSale.selectOneBy(connection=self.conn,
+                                                 new_sale=self.model.id)
+        if returned_sale:
+            if returned_sale.sale:
+                traded_sale = returned_sale.sale.get_order_number_str()
+            else:
+                traded_sale = _("Unknown")
+            trade_notes = [
+                '====== %s ======' % _("Items traded for this sale"),
+                _("Date: %s") % returned_sale.return_date.strftime('%x'),
+                _("Traded sale: %s") % traded_sale,
+                _("Invoice number: %s") % returned_sale.invoice_number,
+                _("Reason: %s") % returned_sale.reason,
+                ]
+            notes.append('\n'.join(trade_notes))
+
+        returned_items = list(ReturnedSaleItemsView.select_by_sale(self.sale_order,
+                                                                   self.conn))
+        if returned_items:
+            self.returned_items_list.add_list(returned_items)
+            seen_set = set()
+            for item in returned_items:
+                if item.invoice_number in seen_set:
+                    continue
+
+                return_notes = ['====== %s ======' % (
+                                _("Itens returned on %s") % (
+                                  item.return_date.strftime('%x')))]
+                if item.new_sale:
+                    return_notes.append(_("Traded for sale: %s") % (
+                                        item.new_sale.get_order_number_str()))
+                return_notes.extend([
+                    _("Invoice number: %s") % item.invoice_number,
+                    _("Reason: %s") % item.reason,
+                    ])
+
+                notes.append('\n'.join(return_notes))
+                seen_set.add(item.invoice_number)
+        else:
+            page_no = self.details_notebook.page_num(self.returned_items_vbox)
+            self.details_notebook.remove_page(page_no)
+
         buffer = gtk.TextBuffer()
-        buffer.set_text(self.sale_order.get_details_str())
+        buffer.set_text('\n\n'.join(notes))
         self.notes.set_buffer(buffer)
 
         self.payments_list.add_list(self._get_payments(self.sale_order))
@@ -142,7 +193,7 @@ class SaleDetailsDialog(BaseEditor):
                                     for p in self.payments_list]))
 
     def _get_payments_columns(self):
-        return [Column('id', "#", data_type=int, width=50,
+        return [Column('identifier', "#", data_type=int, width=50,
                        format='%04d', justify=gtk.JUSTIFY_RIGHT),
                 Column('method.description', _("Type"),
                        data_type=str, width=60),
@@ -189,6 +240,22 @@ class SaleDetailsDialog(BaseEditor):
                 Column('reason', _(u"Reason"),
                         data_type=str, expand=True,
                         ellipsize=pango.ELLIPSIZE_END)]
+
+    def _get_returned_items_columns(self):
+        return [
+            Column('return_date', _("Date"), data_type=datetime.date,
+                   sorted=True),
+            Column('invoice_number', _("Invoice #"), data_type=int),
+            Column('code', _("Code"), data_type=str,
+                   visible=False),
+            Column('description', _("Description"), data_type=str,
+                   expand=True),
+            Column('quantity', _("Quantity"), data_type=decimal.Decimal,
+                   format_func=format_quantity),
+            Column('price', _("Sale price"), data_type=currency),
+            Column('total', _("Total"), data_type=currency),
+            ]
+
     #
     # BaseEditor hooks
     #
@@ -235,34 +302,7 @@ class SaleDetailsDialog(BaseEditor):
         run_dialog(ClientDetailsDialog, self, self.conn, client)
 
     def on_status_details_button__clicked(self, button):
-        if self.sale_order.status == Sale.STATUS_RETURNED:
-            run_dialog(SaleReturnDetailsDialog, self, self.conn,
-                       self.sale_order)
-        elif self.sale_order.status == Sale.STATUS_RENEGOTIATED:
+        if self.sale_order.status == Sale.STATUS_RENEGOTIATED:
             # XXX: Rename to renegotiated
             run_dialog(RenegotiationDetailsDialog, self, self.conn,
                        self.sale_order.group.renegotiation)
-
-
-class SaleReturnDetailsDialog(BaseEditor):
-    gladefile = "HolderTemplate"
-    model_type = Sale
-    title = _(u"Sale Cancellation Details")
-    size = (650, 350)
-    hide_footer = True
-
-    def setup_slaves(self):
-        from stoqlib.gui.slaves.saleslave import SaleReturnSlave
-        if self.model.status != Sale.STATUS_RETURNED:
-            raise StoqlibError("Invalid status for sale order, it should be "
-                               "cancelled")
-
-        renegotiation = RenegotiationData.selectOneBy(sale=self.model,
-                                                      connection=self.conn)
-        if renegotiation is None:
-            raise StoqlibError("Returned sales must have the renegotiation "
-                               "information.")
-
-        self.slave = SaleReturnSlave(self.conn, self.model, renegotiation,
-                                     visual_mode=True)
-        self.attach_slave("place_holder", self.slave)
