@@ -32,7 +32,7 @@ from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
 
 from stoqlib.api import api
-from stoqlib.database.orm import LEFTJOINOn
+from stoqlib.database.orm import LeftJoin
 from stoqlib.domain.sellable import (Sellable, ClientCategoryPrice,
                                      SellableCategory)
 from stoqlib.domain.person import ClientCategory
@@ -49,8 +49,8 @@ from stoqlib.database.orm import Viewable
 class CategoryPriceView(Viewable):
     columns = dict(
         id=ClientCategoryPrice.q.id,
-        sellable_id=ClientCategoryPrice.q.sellableID,
-        category_id=ClientCategoryPrice.q.categoryID,
+        sellable_id=ClientCategoryPrice.q.sellable_id,
+        category_id=ClientCategoryPrice.q.category_id,
         price=ClientCategoryPrice.q.price,
         max_discount=ClientCategoryPrice.q.max_discount,
     )
@@ -71,8 +71,8 @@ class SellableView(Viewable):
 
     joins = [
         # Category
-        LEFTJOINOn(None, SellableCategory,
-                   SellableCategory.q.id == Sellable.q.categoryID),
+        LeftJoin(SellableCategory,
+                   SellableCategory.q.id == Sellable.q.category_id),
     ]
 
     def __init__(self, *args, **kargs):
@@ -91,11 +91,11 @@ class SellableView(Viewable):
 
     def save_changes(self):
         for cat, value in self._new_prices.items():
-            info = ClientCategoryPrice.selectOneBy(sellableID=self.id,
+            info = ClientCategoryPrice.selectOneBy(sellable_id=self.id,
                                                 category=cat,
                                                 connection=self.get_connection())
             if not info:
-                info = ClientCategoryPrice(sellableID=self.id,
+                info = ClientCategoryPrice(sellable_id=self.id,
                                            category=cat,
                                            max_discount=self.max_discount,
                                            price=value,
@@ -120,7 +120,7 @@ class SellablePriceDialog(BaseEditor):
     def _setup_widgets(self):
         self.category.prefill(api.for_combo(self.categories))
 
-        prices = CategoryPriceView.select(connection=self.conn)
+        prices = CategoryPriceView.select(connection=self.conn).orderBy(ClientCategoryPrice.q.id)
         category_prices = {}
         for p in prices:
             c = category_prices.setdefault(p.sellable_id, {})
@@ -128,7 +128,7 @@ class SellablePriceDialog(BaseEditor):
 
         marker('SellableView')
         sellables = SellableView.select(connection=self.conn)
-        self._sellables = sellables
+        self._sellables = sellables.orderBy(Sellable.q.code)
 
         marker('add_items')
         for s in sellables:
@@ -177,7 +177,6 @@ class SellablePriceDialog(BaseEditor):
         # Call clear on objectlist before destruction. Workaround for a bug
         # when destructing the dialog taking to long
         self.slave.listcontainer.list.clear()
-        return False
 
     def on_confirm(self):
         marker('Saving prices')
@@ -201,7 +200,6 @@ class SellablePriceDialog(BaseEditor):
         d.stop()
         marker('Done saving prices')
         self.slave.listcontainer.list.clear()
-        return True
 
     #
     #   Callbacks
