@@ -59,7 +59,7 @@ class TillHistoryDialog(SearchDialog):
     #
 
     def get_columns(self, *args):
-        return [Column('id', _('Number'), data_type=int, width=100,
+        return [Column('identifier', _('Number'), data_type=int, width=100,
                         format='%03d', sorted=True),
                 Column('date', _('Date'),
                        data_type=datetime.date, width=110),
@@ -73,9 +73,9 @@ class TillHistoryDialog(SearchDialog):
     def create_filters(self):
         self.set_text_field_columns(['description'])
 
-        date_filter = DateSearchFilter(_('Date:'))
-        date_filter.select(Today)
-        self.add_filter(date_filter, columns=['date'])
+        self.date_filter = DateSearchFilter(_('Date:'))
+        self.date_filter.select(Today)
+        self.add_filter(self.date_filter, columns=['date'])
         # add summary label
         value_format = '<b>%s</b>'
         total_label = '<b>%s</b>' % api.escape(_(u'Total:'))
