@@ -87,7 +87,8 @@ class AccountEditor(BaseEditor):
         self.bank_model = _TemporaryBankAccount()
         BaseEditor.__init__(self, conn, model)
 
-        self.main_dialog.action_area.add(self._test_button)
+        self.main_dialog.action_area.pack_start(
+            self._test_button, expand=False, fill=False)
         self.main_dialog.action_area.set_child_secondary(
             self._test_button, True)
         self._test_button.show()
@@ -153,8 +154,6 @@ class AccountEditor(BaseEditor):
         self.model.account_type = self.account_type.get_selected()
         self._save_bank()
 
-        return self.model
-
     def refresh_ok(self, value):
         BaseEditor.refresh_ok(self, value)
 
@@ -195,7 +194,7 @@ class AccountEditor(BaseEditor):
     def _add_widget(self, label, widget, options=False):
         n_rows = self.table.props.n_rows
         l = gtk.Label()
-        l.set_markup(api.escape(label))
+        l.set_markup(label)
         l.props.xalign = 1.0
         self.table.resize(n_rows + 1, 2)
         self.table.attach(
@@ -222,7 +221,7 @@ class AccountEditor(BaseEditor):
         self.bank_number = ProxyEntry()
         self.bank_number.props.data_type = int
         self.bank_number.set_sensitive(False)
-        bank_number_lbl = self._add_widget(_("Number:"),
+        bank_number_lbl = self._add_widget(api.escape(_("Number:")),
                                            self.bank_number, options=True)
 
         self.bank_branch = ProxyEntry()
@@ -231,8 +230,8 @@ class AccountEditor(BaseEditor):
         self.bank_branch.props.data_type = 'str'
         self.bank_branch.props.mandatory = True
         self.bank_branch.model_attribute = "bank_branch"
-        bank_branch_lbl = self._add_widget(_("Agency:"),
-                                             self.bank_branch, options=True)
+        bank_branch_lbl = self._add_widget(api.escape(_("Agency:")),
+                                           self.bank_branch, options=True)
         if bank_number is not None:
             bank_branch_lbl.show()
             self.bank_branch.show()
@@ -242,7 +241,8 @@ class AccountEditor(BaseEditor):
         self.bank_account = ProxyEntry()
         self.bank_account.connect('validate', self._on_bank_account__validate,
                                   bank_info)
-        self._add_widget(_("Account:"), self.bank_account, options=True)
+        self._add_widget(api.escape(_("Account:")),
+                         self.bank_account, options=True)
         self.bank_account.model_attribute = "bank_account"
         self.bank_account.props.data_type = 'str'
         if bank_number is not None:
@@ -267,7 +267,7 @@ class AccountEditor(BaseEditor):
                 entry.props.data_type = 'str'
                 entry.connect('validate', self._on_bank_option__validate,
                               bank_info, option)
-                self._add_widget("<i>%s</i>:" % (option.capitalize(), ),
+                self._add_widget("<i>%s</i>:" % (api.escape(option.capitalize()), ),
                                  entry, options=True)
                 entry.show()
                 self._option_fields[option] = entry
@@ -308,7 +308,7 @@ class AccountEditor(BaseEditor):
 
         self.code.set_sensitive(False)
         self.bank_type = ProxyComboBox()
-        self._add_widget(_("Bank:"), self.bank_type)
+        self._add_widget(api.escape(_("Bank:")), self.bank_type)
         self.bank_type.connect('content-changed',
                                self._on_bank_type__content_changed)
         self.bank_type.show()
@@ -419,12 +419,12 @@ class AccountEditor(BaseEditor):
         self._print_test_bill()
 
 
-def test():
+def test():  # pragma nocover
     creator = api.prepare_test()
     retval = run_dialog(AccountEditor, None, creator.trans, None,
                         parent_account=None, visual_mode=True)
     api.finish_transaction(creator.trans, retval)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
