@@ -25,6 +25,7 @@
 """Dialog for listing client categories"""
 
 from kiwi.datatypes import ValidationError
+from kiwi.ui.forms import PercentageField
 from kiwi.ui.forms import TextField
 
 from stoqlib.api import api
@@ -39,10 +40,12 @@ _ = stoqlib_gettext
 class ClientCategoryEditor(BaseEditor):
     model_name = _('Client Category')
     model_type = ClientCategory
-    confirm_widgets = ['name']
+    confirm_widgets = ['name',
+                       'max_discount']
 
     fields = dict(
         name=TextField(_('Name'), proxy=True),
+        max_discount=PercentageField(_('Max Discount'), proxy=True),
         )
 
     def create_model(self, trans):
@@ -63,7 +66,7 @@ class ClientCategoryEditor(BaseEditor):
             return ValidationError(
                 _("The client category '%s' already exists.") % new_name)
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     ec = api.prepare_test()
     model = ec.create_client_category()
     run_dialog(ClientCategoryEditor,
