@@ -45,7 +45,7 @@ class ContactEditor(BaseEditor):
         phone_number=TextField(_('Phone Number'), mandatory=True, proxy=True),
         )
 
-    def __init__(self, conn, model, person):
+    def __init__(self, conn, model=None, person=None):
         self.person = person
         BaseEditor.__init__(self, conn, model)
         self.set_description(self.model.name)
@@ -58,7 +58,7 @@ class ContactEditor(BaseEditor):
         return Liaison(person=self.person, connection=conn)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     ec = api.prepare_test()
     client = ec.create_client()
     run_dialog(ContactEditor, parent=None, conn=ec.trans, model=None,
