@@ -187,8 +187,6 @@ class CreateDeliveryEditor(BaseEditor):
         for sale_item in self.sale_items:
             sale_item.estimated_fix_date = self.estimated_fix_date.read()
 
-        return self.model
-
 
 class DeliveryEditor(BaseEditor):
     """An editor for :class:`stoqlib.domain.sale.Delivery`"""
@@ -274,8 +272,8 @@ class DeliveryEditor(BaseEditor):
 
     def _get_delivery_items_columns(self):
         return [
-            Column('sellable', title=_('Products to deliver'), data_type=str,
-                   expand=True, format_func=lambda s: s.get_description()),
+            Column('sellable.description', title=_('Products to deliver'),
+                   data_type=str, expand=True, sorted=True),
             Column('quantity', title=_('Quantity'), data_type=decimal.Decimal,
                    format_func=format_quantity),
             ]
@@ -286,8 +284,9 @@ class DeliveryEditor(BaseEditor):
 
     def on_was_delivered_check__toggled(self, button):
         active = button.get_active()
-        # When delivered, don't let user change transporter
+        # When delivered, don't let user change transporter or address
         self.transporter.set_sensitive(not active)
+        self.address.set_sensitive(not active)
         for widget in (self.deliver_date, self.tracking_code):
             widget.set_sensitive(active)
 
@@ -306,11 +305,8 @@ class DeliveryEditor(BaseEditor):
     def on_was_received_check__toggled(self, button):
         active = button.get_active()
         self.receive_date.set_sensitive(active)
-        for widget in (self.change_address_button,
-                       # If it was received, don't let the user unmark
-                       # was_delivered_check
-                       self.was_delivered_check):
-            widget.set_sensitive(not active)
+        # If it was received, don't let the user unmark was_delivered_check
+        self.was_delivered_check.set_sensitive(not active)
 
         if not self.was_delivered_check.get_active():
             self.was_delivered_check.set_active(True)
