@@ -47,7 +47,7 @@ class CfopEditor(BaseEditor):
         description=TextField(_('Description'), mandatory=True, proxy=True),
         )
 
-    def __init__(self, conn, model, visual_mode=False):
+    def __init__(self, conn, model=None, visual_mode=False):
         BaseEditor.__init__(self, conn, model, visual_mode)
         self.set_description(self.model.code)
 
@@ -86,14 +86,14 @@ class FiscalBookEntryEditor(BaseEditor):
     #
 
     def get_title(self, model):
-        return _("Edit Fiscal Book Entry #%d") % model.id
+        return _("Edit Fiscal Book Entry #%d") % model.invoice_number
 
     def setup_proxies(self):
         self._setup_widgets()
         self.add_proxy(self.model,
                        FiscalBookEntryEditor.proxy_widgets)
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     ec = api.prepare_test()
     cfop = ec.create_cfop_data()
     run_dialog(CfopEditor, parent=None, conn=ec.trans, model=cfop)
