@@ -35,11 +35,9 @@ from stoqlib.database.runtime import get_current_station
 from stoqlib.domain.invoice import InvoiceLayout, InvoiceField, InvoicePrinter
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.station import BranchStation
-from stoqlib.gui.base.lists import ModelListDialog, ModelListSlave
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.fieldgrid import FieldGrid
-from stoqlib.lib.invoice import (get_invoice_fields, SaleInvoice,
-                                 print_sale_invoice, validate_invoice_number)
+from stoqlib.lib.invoice import get_invoice_fields, SaleInvoice
 from stoqlib.lib.message import info
 from stoqlib.lib.translation import stoqlib_gettext as _
 
@@ -214,28 +212,6 @@ class InvoiceLayoutEditor(BaseEditor):
                 print repr(line.tostring())
 
 
-class InvoiceLayoutListSlave(ModelListSlave):
-    model_type = InvoiceLayout
-    editor_class = InvoiceLayoutEditor
-    columns = [
-        Column('description', _('Description'), data_type=str,
-               expand=True, sorted=True),
-        Column('size', _('Size'), data_type=str, width=90,
-               format_func=lambda (w, h): '%dx%d' % (w, h)),
-    ]
-
-    def delete_model(self, model, trans):
-        for field in model.fields:
-            InvoiceField.delete(field.id, trans)
-        ModelListDialog.delete_model(self, model, trans)
-
-
-class InvoiceLayoutDialog(ModelListDialog):
-    list_slave_class = InvoiceLayoutListSlave
-    size = (500, 300)
-    title = _("Invoice Layouts")
-
-
 class InvoicePrinterEditor(BaseEditor):
     model_name = _(u'Invoice Printers')
     model_type = InvoicePrinter
@@ -269,58 +245,3 @@ class InvoicePrinterEditor(BaseEditor):
     def on_confirm(self):
         # Bug!
         self.model.layout = self.layout.get_selected()
-        return self.model
-
-
-class InvoicePrinterDialog(ModelListDialog):
-
-    # ModelListDialog
-    model_type = InvoicePrinter
-    editor_class = InvoicePrinterEditor
-    list_slave_class = InvoiceLayoutListSlave
-
-    size = (700, 300)
-    title = _("Invoice Printers")
-
-    # ListDialog
-    columns = [
-        Column('description', _('Description'), data_type=str,
-               expand=True, sorted=True),
-        Column('device_name', _('Device name'), data_type=str, width=150),
-        Column('station.name', _('Station'), data_type=str, width=80),
-        Column('layout.description', _('Layout'), data_type=str, width=120),
-    ]
-
-
-class SaleInvoicePrinterDialog(BaseEditor):
-    model_type = Sale
-    model_name = _(u'Sale Invoice')
-    gladefile = 'SaleInvoicePrinterDialog'
-    proxy_widgets = ('invoice_number', )
-    title = _(u'Sale Invoice Dialog')
-    size = (250, 100)
-
-    def __init__(self, conn, model, printer):
-        self._printer = printer
-        BaseEditor.__init__(self, conn, model)
-        self._setup_widgets()
-
-    def _setup_widgets(self):
-        self.main_dialog.ok_button.set_label(gtk.STOCK_PRINT)
-
-        if self.model.invoice_number is not None:
-            self.invoice_number.set_sensitive(False)
-        else:
-            last_invoice_number = Sale.get_last_invoice_number(self.conn) or 0
-            self.invoice_number.update(last_invoice_number + 1)
-
-    def setup_proxies(self):
-        self.add_proxy(self.model, SaleInvoicePrinterDialog.proxy_widgets)
-
-    def on_confirm(self):
-        invoice = SaleInvoice(self.model, self._printer.layout)
-        print_sale_invoice(invoice, self._printer)
-        return self.model
-
-    def on_invoice_number__validate(self, widget, value):
-        return validate_invoice_number(value, self.conn)
