@@ -58,12 +58,14 @@ class SystemParameterEditor(BaseEditor):
         # param itself can accept None.
         self._block_none_value = True
         self.sensitive = True
-        if model.field_name in ['DEMO_MODE']:
+        if model.field_name in ['DEMO_MODE', 'LOCAL_BRANCH',
+                                'SYNCHRONIZED_MODE']:
             self.sensitive = False
 
         self._parameter_details = get_parameter_details(model.field_name)
         BaseEditor.__init__(self, conn, model)
         self._setup_widgets()
+
     #
     # Helper methods
     #
@@ -259,10 +261,15 @@ class SystemParameterEditor(BaseEditor):
                             "type: %r" % (self.model.field_name,
                                           field_type))
 
-    def on_confirm(self):
+    def validate_confirm(self):
         if self._block_none_value and self.model.field_value is None:
             return False
-        return self.model
+
+        change_callback = self.constant.get_change_callback()
+        if change_callback:
+            change_callback(self.model.field_value, self.conn)
+
+        return True
 
     #
     # Callbacks
