@@ -147,11 +147,11 @@ class PaymentCategoryEditor(BaseEditor):
                 _(u"The payment category '%s' already exists.") % new_name)
 
 
-def test():
+def test():  # pragma nocover
     creator = api.prepare_test()
     retval = run_dialog(PaymentCategoryEditor, None, creator.trans, None)
     api.finish_transaction(creator.trans, retval)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
