@@ -28,13 +28,9 @@
 import datetime
 import operator
 
-from dateutil.relativedelta import relativedelta
-import gtk
-import pango
 from kiwi import ValueUnset
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
-from kiwi.ui.widgets.list import Column
 from kiwi.ui.forms import ChoiceField, DateField, PriceField, TextField
 
 from stoqlib.api import api
@@ -42,29 +38,27 @@ from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.payment.views import PaymentChangeHistoryView
-from stoqlib.domain.person import Client, Supplier
+from stoqlib.domain.person import Client, Supplier, Branch
 from stoqlib.domain.sale import SaleView
+from stoqlib.exceptions import SellError
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.paymentdetails import LonelyPaymentDetailsDialog
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.renegotiationdetails import RenegotiationDetailsDialog
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.fields import PaymentCategoryField, PersonField
-from stoqlib.lib.defaults import (INTERVALTYPE_WEEK,
-                                  INTERVALTYPE_MONTH)
+from stoqlib.lib.dateutils import get_interval_type_items
 from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
 _ = stoqlib_gettext
-INTERVALTYPE_ONCE = -1
-INTERVALTYPE_BIWEEKLY = 10
-INTERVALTYPE_QUARTERLY = 11
+_ONCE = -1
 
 
-class PaymentEditor(BaseEditor):
-    title = _("Payment")
+class _PaymentEditor(BaseEditor):
     confirm_widgets = ['due_date']
     model_type = Payment
+    model_name = _('payment')
 
     # Override in subclass
     person_type = None
@@ -73,6 +67,8 @@ class PaymentEditor(BaseEditor):
     # FIXME: Person should really be a proxy_widget attribute,
     # but it breaks when displaying an existing payment
     fields = dict(
+        branch=PersonField(_('Branch'), proxy=True, person_type=Branch,
+                           can_add=False, can_edit=False),
         method=ChoiceField(_('Method')),
         description=TextField(_('Description'), proxy=True, mandatory=True),
         person=PersonField(proxy=True),
@@ -106,9 +102,11 @@ class PaymentEditor(BaseEditor):
     def create_model(self, trans):
         group = PaymentGroup(connection=trans)
         money = PaymentMethod.get_by_name(trans, 'money')
+        branch = api.get_current_branch(trans)
         # Set status to PENDING now, to avoid calling set_pending on
         # on_confirm for payments that shoud not have its status changed.
         return Payment(open_date=datetime.date.today(),
+                       branch=branch,
                        status=Payment.STATUS_PENDING,
                        description='',
                        value=currency(0),
@@ -123,16 +121,14 @@ class PaymentEditor(BaseEditor):
 
     def setup_proxies(self):
         self._fill_method_combo()
-        self.repeat.prefill([
-            (_('Once'), INTERVALTYPE_ONCE),
-            (_('Weekly'), INTERVALTYPE_WEEK),
-            (_('Biweekly'), INTERVALTYPE_BIWEEKLY),
-            (_('Monthly'), INTERVALTYPE_MONTH),
-            (_('Quarterly'), INTERVALTYPE_QUARTERLY)])
-        self.add_proxy(self.model, PaymentEditor.proxy_widgets)
+        repeat_types = get_interval_type_items(with_multiples=True,
+                                               adverb=True)
+        repeat_types.insert(0, (_('Once'), _ONCE))
+        self.repeat.prefill(repeat_types)
+        self.add_proxy(self.model, _PaymentEditor.proxy_widgets)
 
     def validate_confirm(self):
-        if (self.repeat.get_selected() != INTERVALTYPE_ONCE and
+        if (self.repeat.get_selected() != _ONCE and
             not self._validate_date()):
             return False
         # FIXME: the kiwi view should export it's state and it should
@@ -150,15 +146,17 @@ class PaymentEditor(BaseEditor):
             person != ""):
             setattr(self.model.group,
                     self.person_attribute,
-                    person.person)
-        self.model.category = self.category.get_selected()
+                    self.conn.get(person.person))
+        self.model.category = self.conn.get(self.category.get_selected())
         method = self.method.get_selected()
         if method is not None:
             self.model.method = method
 
-        if self.repeat.get_selected() != INTERVALTYPE_ONCE:
-            self._create_repeated_payments()
-        return self.model
+        if self.repeat.get_selected() != _ONCE:
+            Payment.create_repeated(self.conn, self.model,
+                                    self.repeat.get_selected(),
+                                    self.model.due_date.date(),
+                                    self.end_date.get_date())
 
     # Private
 
@@ -193,7 +191,7 @@ class PaymentEditor(BaseEditor):
         self.end_date.set_sensitive(False)
         if self.edit_mode:
             for field_name in ['value', 'due_date', 'person',
-                               'repeat', 'end_date']:
+                               'repeat', 'end_date', 'branch']:
                 field = self.fields[field_name]
                 field.can_add = False
                 field.can_edit = False
@@ -208,7 +206,8 @@ class PaymentEditor(BaseEditor):
     def _show_order_dialog(self):
         group = self.model.group
         if group.sale:
-            sale_view = SaleView.select(SaleView.q.id == group.sale.id)[0]
+            sale_view = SaleView.get(group.sale.id,
+                                     connection=self.conn)
             run_dialog(SaleDetailsDialog, self, self.conn, sale_view)
         elif group.purchase:
             run_dialog(PurchaseDetailsDialog, self, self.conn, group.purchase)
@@ -225,7 +224,7 @@ class PaymentEditor(BaseEditor):
         due_date = self.due_date.get_date()
         if end_date and due_date:
             if end_date < due_date:
-                self.end_date.set_invalid(_("End date must be before start date"))
+                self.end_date.set_invalid(_("End date cannot be before start date"))
             else:
                 self.end_date.set_valid()
                 self.refresh_ok(self.is_valid)
@@ -245,57 +244,6 @@ class PaymentEditor(BaseEditor):
         else:
             self.person.set_property('mandatory', False)
 
-    def _create_repeated_payments(self):
-        # FIXME: Move most of this to stoqlib.domain.payment
-        start_date = self.model.due_date.date()
-        end_date = self.end_date.get_date()
-        repeat_type = self.repeat.get_selected()
-        if repeat_type == INTERVALTYPE_WEEK:
-            delta = relativedelta(weeks=1)
-        elif repeat_type == INTERVALTYPE_BIWEEKLY:
-            delta = relativedelta(weeks=2)
-        elif repeat_type == INTERVALTYPE_MONTH:
-            # Check if we're on the last day of month and make
-            # sure the payment will always be the last day of the
-            # month.
-            next_date = start_date + relativedelta(days=1)
-            if start_date.month != next_date.month:
-                # This really means: last day of month, it'll never
-                # cross month boundaries even if there are less than
-                # 31 days.
-                delta = relativedelta(months=1, day=31)
-            else:
-                delta = relativedelta(months=1, day=start_date.day)
-        elif repeat_type == INTERVALTYPE_QUARTERLY:
-            delta = relativedelta(months=3)
-        else:
-            raise AssertionError(repeat_type)
-
-        next_date = start_date + delta
-        dates = []
-        while next_date <= end_date:
-            dates.append(next_date)
-            next_date = next_date + delta
-        if not dates:
-            return
-        n_dates = len(dates) + 1
-        description = self.model.description
-        self.model.description = '1/%d %s' % (n_dates, description)
-        for i, date in enumerate(dates):
-            Payment(open_date=self.model.open_date,
-                    payment_type=self.model.payment_type,
-                    status=self.model.status,
-                    description='%d/%d %s' % (i + 2, n_dates,
-                                              description),
-                    value=self.model.value,
-                    base_value=self.model.base_value,
-                    due_date=date,
-                    method=self.model.method,
-                    group=self.model.group,
-                    till=self.model.till,
-                    category=self.model.category,
-                    connection=self.conn)
-
     #
     # Kiwi Callbacks
     #
@@ -305,7 +253,16 @@ class PaymentEditor(BaseEditor):
             return ValidationError(_("The value must be greater than zero."))
 
     def on_repeat__content_changed(self, repeat):
-        self.end_date.set_sensitive(repeat.get_selected() != INTERVALTYPE_ONCE)
+        if repeat.get_selected() == _ONCE:
+            self.end_date.set_sensitive(False)
+
+            # FIXME: need this check so tests won't crash
+            if hasattr(self, 'main_dialog'):
+                self.refresh_ok(True)
+
+            return
+
+        self.end_date.set_sensitive(True)
         self._validate_date()
 
     def on_due_date__content_changed(self, due_date):
@@ -321,7 +278,7 @@ class PaymentEditor(BaseEditor):
         self._validate_person()
 
 
-class InPaymentEditor(PaymentEditor):
+class InPaymentEditor(_PaymentEditor):
     payment_type = Payment.TYPE_IN
     person_attribute = 'payer'
     person_type = Client
@@ -329,8 +286,28 @@ class InPaymentEditor(PaymentEditor):
     help_section = 'account-receivable'
     category_type = PaymentCategory.TYPE_RECEIVABLE
 
+    def on_person__validate(self, widget, value):
+        if not value:
+            return
 
-class OutPaymentEditor(PaymentEditor):
+        # FIXME: If the object was created in the current dialog, its
+        # transaction will be already closed, so se need to fetch it again from
+        # the current connection
+        value = self.conn.get(value)
+        try:
+            #FIXME: model is not being updated correctly
+            value.can_purchase(self.method.read(), self.value.read())
+        except SellError as e:
+            return ValidationError(e)
+
+    def on_method__changed(self, method):
+        self.person.validate(force=True)
+
+    def on_value__changed(self, value):
+        self.person.validate(force=True)
+
+
+class OutPaymentEditor(_PaymentEditor):
     payment_type = Payment.TYPE_OUT
     person_attribute = 'recipient'
     person_type = Supplier
@@ -339,79 +316,6 @@ class OutPaymentEditor(PaymentEditor):
     category_type = PaymentCategory.TYPE_PAYABLE
 
 
-class LonelyPaymentDetailsDialog(BaseEditor):
-    gladefile = 'LonelyPaymentDetailsDialog'
-    size = (550, 350)
-    model_type = Payment
-    proxy_widgets = ['value',
-                     'interest',
-                     'paid_value',
-                     'penalty',
-                     'description',
-                     'discount',
-                     'due_date',
-                     'paid_date',
-                     'status']
-
-    def __init__(self, conn, payment):
-        BaseEditor.__init__(self, conn, payment)
-        self._setup_widgets()
-
-    def _setup_widgets(self):
-        self.payment_info_list.set_columns(self._get_columns())
-        changes = PaymentChangeHistoryView.select_by_group(self.model.group,
-                                                           connection=self.conn)
-        self.payment_info_list.add_list(changes)
-
-        # workaround to improve the dialog looking
-        if self.model.paid_value:
-            penalty = self._get_penalty()
-            self.penalty.update(penalty)
-            self.interest.update(self.model.interest)
-        else:
-            self.paid_value.update(currency(0))
-
-    def _get_penalty(self):
-        penalty = (self.model.paid_value -
-          (self.model.value - self.model.discount + self.model.interest))
-
-        return currency(penalty)
-
-    def _get_columns(self):
-        return [Column('change_date', _("When"),
-                        data_type=datetime.date, sorted=True, ),
-                Column('description', _("Payment"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END),
-                Column('changed_field', _("Changed"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('from_value', _("From"),
-                    data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('to_value', _("To"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('reason', _("Reason"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END)]
-
-    #
-    # BaseEditor
-    #
-
-    def setup_proxies(self):
-        self._proxy = self.add_proxy(
-            self.model, LonelyPaymentDetailsDialog.proxy_widgets)
-
-    def get_title(self, model):
-        if model is None:
-            return
-
-        if model.is_inpayment():
-            return _('Receiving Details')
-
-        if model.is_outpayment():
-            return _('Payment Details')
-
-
 def get_dialog_for_payment(payment):
     if payment is None:
         raise TypeError(payment)
@@ -425,11 +329,11 @@ def get_dialog_for_payment(payment):
     raise TypeError(payment)
 
 
-def test():
+def test():  # pragma nocover
     creator = api.prepare_test()
     retval = run_dialog(InPaymentEditor, None, creator.trans, None)
     api.finish_transaction(creator.trans, retval)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
