@@ -42,6 +42,7 @@ from stoqlib.gui.slaves.employeeslave import (EmployeeDetailsSlave,
                                       EmployeeRoleSlave,
                                       EmployeeRoleHistorySlave)
 from stoqlib.gui.slaves.userslave import UserDetailsSlave, UserStatusSlave
+from stoqlib.gui.slaves.userbranchaccessslave import UserBranchAccessSlave
 from stoqlib.gui.slaves.supplierslave import SupplierDetailsSlave
 from stoqlib.gui.slaves.transporterslave import TransporterDataSlave
 from stoqlib.gui.slaves.branchslave import BranchDetailsSlave
@@ -87,11 +88,6 @@ class UserEditor(BasePersonRoleEditor):
     help_section = 'user'
     ui_form_name = 'user'
 
-    def __init__(self, conn, model=None, role_type=None, person=None,
-                 visual_mode=False):
-        BasePersonRoleEditor.__init__(self, conn, model, role_type, person,
-                                      visual_mode=visual_mode)
-
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
         return person.login_user or LoginUser(person=person,
@@ -100,36 +96,41 @@ class UserEditor(BasePersonRoleEditor):
 
     def setup_slaves(self):
         BasePersonRoleEditor.setup_slaves(self)
+
         user_status = UserStatusSlave(self.conn, self.model,
-                            visual_mode=self.visual_mode)
+                                      visual_mode=self.visual_mode)
         self.main_slave.attach_person_slave(user_status)
+
         passwd_fields = not self.edit_mode
         self.user_details = UserDetailsSlave(self.conn, self.model,
-            show_password_fields=passwd_fields,
-            visual_mode=self.visual_mode)
+                                             show_password_fields=passwd_fields,
+                                             visual_mode=self.visual_mode)
         tab_text = _('User Details')
         self.main_slave._person_slave.attach_custom_slave(self.user_details,
                                                           tab_text)
+
         tab_child = self.main_slave._person_slave.custom_tab
         notebook = self.main_slave._person_slave.person_notebook
         notebook.reorder_child(tab_child, position=self.USER_TAB_POSITION)
         notebook.set_current_page(self.USER_TAB_POSITION)
 
+        tab_text = _('Branch Access')
+        self.user_branches = UserBranchAccessSlave(self.conn, self.model)
+        # XXX: workaround border being to large
+        self.user_branches.vbox1.set_border_width(0)
+        self.main_slave._person_slave.attach_extra_slave(self.user_branches,
+                                                         tab_text)
+
     def validate_confirm(self):
-        return self.user_details.validate_confirm()
-
-    def on_confirm(self):
-        self.main_slave.on_confirm()
-        self.user_details.on_confirm()
-        return self.model
+        return (self.user_details.validate_confirm() and
+                self.user_branches.validate_confirm())
 
 
-class CreditProviderEditor(BasePersonRoleEditor):
-    model_name = _('Credit Provider')
-    title = _('New Credit Provider')
+class CardProviderEditor(BasePersonRoleEditor):
+    model_name = _('Card Provider')
+    title = _('New Card Provider')
     model_type = CreditProvider
     gladefile = 'BaseTemplate'
-    provtype = None
 
     #
     # BaseEditor hooks
@@ -139,12 +140,10 @@ class CreditProviderEditor(BasePersonRoleEditor):
         person = BasePersonRoleEditor.create_model(self, conn)
         if person.credit_provider:
             return person.credi_provider
-        if self.provtype is None:
-            raise ValueError('subclasses of CreditProviderEditor must '
-                             'define a provtype attribute')
+
         return CreditProvider(person=person,
                               short_name='',
-                              provider_type=self.provtype,
+                              provider_type=CreditProvider.PROVIDER_CARD,
                               open_contract_date=datetime.datetime.today(),
                               connection=conn)
 
@@ -157,12 +156,6 @@ class CreditProviderEditor(BasePersonRoleEditor):
         slave.attach_slave('person_status_holder', self.details_slave)
 
 
-class CardProviderEditor(CreditProviderEditor):
-    model_name = _('Card Provider')
-    title = _('New Card Provider')
-    provtype = CreditProvider.PROVIDER_CARD
-
-
 class EmployeeEditor(BasePersonRoleEditor):
     model_name = _('Employee')
     title = _('New Employee')
@@ -171,6 +164,19 @@ class EmployeeEditor(BasePersonRoleEditor):
 
     ui_form_name = 'employee'
 
+    def __init__(self, conn, model=None, person=None, role_type=None,
+                 visual_mode=False, parent=None):
+        self.visual_mode = visual_mode
+
+        # Do not allow users of one branch edit employee from a different
+        # branch
+        if (model and model.branch and
+            not model.branch == api.get_current_branch(conn)):
+            self.visual_mode = True
+
+        BasePersonRoleEditor.__init__(self, conn, model, role_type=role_type,
+                                      visual_mode=self.visual_mode,
+                                      parent=parent)
     #
     # BaseEditor hooks
     #
@@ -214,11 +220,6 @@ class EmployeeEditor(BasePersonRoleEditor):
         slave._person_slave.attach_extra_slave(history_slave,
                                                history_tab_label)
 
-    def on_confirm(self):
-        self.individual_slave.on_confirm()
-        self.role_slave.on_confirm()
-        return self.model
-
 
 class EmployeeRoleEditor(BaseEditor):
     model_type = EmployeeRole
@@ -229,7 +230,7 @@ class EmployeeRoleEditor(BaseEditor):
         name=TextField(_('Name'), proxy=True, mandatory=True),
         )
 
-    def __init__(self, conn, model, visual_mode=False):
+    def __init__(self, conn, model=None, visual_mode=False):
         BaseEditor.__init__(self, conn, model, visual_mode=visual_mode)
         self.set_description(self.model.name)
 
@@ -341,19 +342,19 @@ class BranchEditor(BasePersonRoleEditor):
         self.main_slave.attach_person_slave(self.status_slave)
 
 
-def test_client():
+def test_client():  # pragma nocover
     from stoqlib.gui.wizards.personwizard import run_person_role_dialog
     creator = api.prepare_test()
     retval = run_person_role_dialog(ClientEditor, None, creator.trans, None)
     api.finish_transaction(creator.trans, retval)
 
 
-def test_employee_role():
+def test_employee_role():  # pragma nocover
     creator = api.prepare_test()
     role = creator.create_employee_role()
     run_dialog(EmployeeRoleEditor, parent=None, conn=creator.trans,
                model=role)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test_employee_role()
