@@ -26,32 +26,27 @@
 import sys
 
 import gtk
-from kiwi.currency import currency
+
 from kiwi.datatypes import ValidationError
-from kiwi.ui.forms import PriceField, TextField
-from kiwi.ui.objectlist import Column
+from kiwi.ui.forms import PercentageField, TextField
 from stoqdrivers.enum import TaxType, UnitType
 
 from stoqlib.api import api
 from stoqlib.database.exceptions import IntegrityError
 from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.person import ClientCategory
 from stoqlib.domain.sellable import (SellableCategory, Sellable,
                                      SellableUnit,
                                      SellableTaxConstant,
                                      ClientCategoryPrice)
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.lists import ModelListDialog, ModelListSlave
 from stoqlib.gui.databaseform import DatabaseForm
-from stoqlib.gui.editors.baseeditor import (BaseEditor,
-                                            BaseRelationshipEditorSlave)
+from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
 from stoqlib.gui.slaves.commissionslave import CommissionSlave
-from stoqlib.gui.slaves.sellableslave import OnSaleInfoSlave
-from stoqlib.lib.message import info, yesno, warning
+from stoqlib.lib.formatters import get_price_format_str
+from stoqlib.lib.message import yesno, warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.formatters import get_price_format_str, get_formatted_cost
 
 _ = stoqlib_gettext
 
@@ -61,6 +56,7 @@ _DEMO_BAR_CODES = ['2368694135945', '6234564656756', '6985413595971',
                    '1598756984265', '1598756984265', '']
 _DEMO_PRODUCT_LIMIT = 30
 
+
 #
 # Editors
 #
@@ -72,7 +68,7 @@ class SellableTaxConstantEditor(BaseEditor):
 
     fields = dict(
         description=TextField(_('Name'), proxy=True, mandatory=True),
-        tax_value=PriceField(_('Value'), proxy=True, mandatory=True),
+        tax_value=PercentageField(_('Value'), proxy=True, mandatory=True),
         )
 
     #
@@ -86,39 +82,6 @@ class SellableTaxConstantEditor(BaseEditor):
                                    connection=conn)
 
 
-class SellableTaxConstantsListSlave(ModelListSlave):
-    model_type = SellableTaxConstant
-    editor_class = SellableTaxConstantEditor
-    columns = [
-        Column('description', _('Description'), data_type=str, expand=True),
-        Column('value', _('Tax rate'), data_type=str, width=150),
-    ]
-
-    def selection_changed(self, constant):
-        if constant is None:
-            return
-        is_custom = constant.tax_type == TaxType.CUSTOM
-        self.listcontainer.remove_button.set_sensitive(is_custom)
-        self.listcontainer.edit_button.set_sensitive(is_custom)
-
-    def delete_model(self, model, trans):
-        sellables = Sellable.selectBy(tax_constant=model, connection=trans)
-        quantity = sellables.count()
-        if quantity > 0:
-            msg = _(u"You can't remove this tax, since %d products or "
-                    "services are taxed with '%s'.") % (
-                    quantity, model.get_description())
-            info(msg)
-        else:
-            SellableTaxConstant.delete(model.id, connection=trans)
-
-
-class SellableTaxConstantsDialog(ModelListDialog):
-    list_slave_class = SellableTaxConstantsListSlave
-    size = (500, 300)
-    title = _("Taxes")
-
-
 class BasePriceEditor(BaseEditor):
     gladefile = 'SellablePriceEditor'
     proxy_widgets = ('cost', 'markup', 'max_discount', 'price')
@@ -168,6 +131,7 @@ class SellablePriceEditor(BasePriceEditor):
     model_type = Sellable
 
     def setup_slaves(self):
+        from stoqlib.gui.slaves.sellableslave import OnSaleInfoSlave
         slave = OnSaleInfoSlave(self.conn, self.model)
         self.attach_slave('on_sale_holder', slave)
 
@@ -178,11 +142,6 @@ class SellablePriceEditor(BasePriceEditor):
             label = _('Calculate Commission From: %s') % desc
             commission_slave.change_label(label)
 
-    def on_confirm(self):
-        slave = self.get_slave('on_commission_data_holder')
-        slave.on_confirm()
-        return self.model
-
 
 class CategoryPriceEditor(BasePriceEditor):
     model_name = _(u'Category Price')
@@ -196,58 +155,6 @@ class CategoryPriceEditor(BasePriceEditor):
         BasePriceEditor.setup_proxies(self)
 
 
-#
-# Slaves
-#
-
-class CategoryPriceSlave(BaseRelationshipEditorSlave):
-    """A slave for changing the suppliers for a product.
-    """
-    target_name = _(u'Category')
-    editor = CategoryPriceEditor
-    model_type = ClientCategoryPrice
-
-    def __init__(self, conn, sellable, visual_mode=False):
-        self._sellable = sellable
-        BaseRelationshipEditorSlave.__init__(self, conn, visual_mode=visual_mode)
-
-    def get_targets(self):
-        cats = ClientCategory.select(connection=self.conn).orderBy('name')
-        return [(c.get_description(), c) for c in cats]
-
-    def get_relations(self):
-        return self._sellable.get_category_prices()
-
-    def _format_markup(self, obj):
-        return '%0.2f%%' % obj
-
-    def get_columns(self):
-        return [Column('category_name', title=_(u'Category'),
-                       data_type=str, expand=True, sorted=True),
-                Column('price', title=_(u'Price'), data_type=currency,
-                       format_func=get_formatted_cost, width=150),
-                Column('markup', title=_(u'Markup'), data_type=str,
-                       width=100, format_func=self._format_markup),
-                        ]
-
-    def create_model(self):
-        sellable = self._sellable
-        category = self.target_combo.get_selected_data()
-
-        if sellable.get_category_price_info(category):
-            product_desc = sellable.get_description()
-            info(_(u'%s already have a price for category %s') % (product_desc,
-                                                      category.get_description()))
-            return
-
-        model = ClientCategoryPrice(sellable=sellable,
-                                    category=category,
-                                    price=sellable.price,
-                                    max_discount=sellable.max_discount,
-                                    connection=self.conn)
-        return model
-
-
 #
 # Editors
 #
@@ -278,6 +185,7 @@ class SellableEditor(BaseEditor):
     proxy_widgets = (sellable_tax_widgets + sellable_widgets)
 
     def __init__(self, conn, model=None, visual_mode=False):
+        from stoqlib.gui.slaves.sellableslave import CategoryPriceSlave
         is_new = not model
         self._sellable = None
         self._demo_mode = sysparam(conn).DEMO_MODE
@@ -403,9 +311,12 @@ class SellableEditor(BaseEditor):
 
     def edit_sale_price(self):
         sellable = self.model.sellable
+        self.conn.savepoint('before_run_editor_sellable_price')
         result = run_dialog(SellablePriceEditor, self, self.conn, sellable)
         if result:
             self.sellable_proxy.update('price')
+        else:
+            self.conn.rollback_to_savepoint('before_run_editor_sellable_price')
 
     def setup_widgets(self):
         raise NotImplementedError
@@ -440,6 +351,10 @@ class SellableEditor(BaseEditor):
     # BaseEditor hooks
     #
 
+    def update_visual_mode(self):
+        self.add_category.set_sensitive(False)
+        self.sale_price_button.set_sensitive(False)
+
     def setup_sellable_combos(self):
         self._fill_categories()
         self.edit_category.set_sensitive(False)
@@ -478,11 +393,14 @@ class SellableEditor(BaseEditor):
         self.update_requires_weighing_label()
 
     def _run_category_editor(self, category=None):
-        # Editing this in a new transaction is causing a deadlock
+        self.conn.savepoint('before_run_editor_sellable_category')
         model = run_dialog(SellableCategoryEditor, self, self.conn, category)
         if model:
             self._fill_categories()
             self.category_combo.select(model)
+        else:
+            self.conn.rollback_to_savepoint('before_run_editor_sellable_category')
+
     #
     # Kiwi handlers
     #
@@ -500,9 +418,8 @@ class SellableEditor(BaseEditor):
             warning(_("It was not possible to remove '%s'")
                       % sellable_description, str(details))
             return
-        # We don't call self.confirm since it will call validate_confirm
-        self.cancel()
-        self.retval = True
+
+        self.confirm()
 
     def _on_close_sellable_button__clicked(self, button,
                                            parent_button_label=None):
@@ -573,7 +490,7 @@ class SellableEditor(BaseEditor):
             return ValidationError(_("Cost cannot be zero or negative"))
 
 
-def test_sellable_tax_constant():
+def test_sellable_tax_constant():  # pragma nocover
     ec = api.prepare_test()
     tax_constant = api.sysparam(ec.trans).DEFAULT_PRODUCT_TAX_CONSTANT
     run_dialog(SellableTaxConstantEditor,
@@ -581,5 +498,5 @@ def test_sellable_tax_constant():
     print tax_constant
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test_sellable_tax_constant()
