@@ -42,7 +42,8 @@ from stoqlib.domain.events import (TillOpenEvent, TillCloseEvent,
 from stoqlib.domain.person import Employee
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError, TillError
-from stoqlib.gui.editors.baseeditor import BaseEditor, BaseEditorSlave
+from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.gui.slaves.tillslave import RemoveCashSlave, BaseCashSlave
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.message import warning
@@ -127,12 +128,21 @@ class TillOpeningEditor(BaseEditor):
 
     def on_confirm(self):
         till = self.model.till
+        # Using api.get_connection instead of self.conn
+        # or it will return self.model.till
+        last_opened = Till.get_last_opened(api.get_connection())
+        if (last_opened and
+            last_opened.opening_date.date() == till.opening_date.date()):
+            warning(_("A till was opened earlier this day."))
+            self.retval = False
+            return
 
         try:
             TillOpenEvent.emit(till=till)
         except (TillError, DeviceError), e:
             warning(str(e))
-            return None
+            self.retval = False
+            return
 
         value = self.proxy.model.value
         if value:
@@ -143,7 +153,6 @@ class TillOpeningEditor(BaseEditor):
             _create_transaction(self.conn, till_entry)
             # The callsite is responsible for interacting with
             # the fiscal printer
-        return self.model
 
     #
     # Kiwi callbacks
@@ -250,14 +259,19 @@ class TillClosingEditor(BaseEditor):
         self.proxy = self.add_proxy(self.model,
                                     TillClosingEditor.proxy_widgets)
 
+    def validate_confirm(self):
+        till = self.model.till
+        removed = abs(self.model.value)
+        if removed and removed > till.get_balance():
+            warning(_("The amount that you want to remove is "
+                      "greater than the current balance."))
+            return False
+        return True
+
     def on_confirm(self):
         till = self.model.till
         removed = abs(self.model.value)
         if removed:
-            if removed > till.get_balance():
-                raise ValueError("The amount that you want to remove is "
-                                 "greater than the current balance.")
-
             assert self._close_ecf
             # We need to do this inside a new transaction, because if the
             # till closing fails further on, this still needs to be recorded
@@ -318,46 +332,6 @@ class TillClosingEditor(BaseEditor):
         self.proxy.update('balance')
 
 
-class BaseCashSlave(BaseEditorSlave):
-    """A slave representing two fields, which is used by Cash editors:
-
-    Date:        YYYY-MM-DD
-    Cash Amount: [        ]
-    """
-
-    model_type = Settable
-    gladefile = 'BaseCashSlave'
-    proxy_widgets = ('value', 'balance')
-
-    #
-    # BaseEditorSlave
-    #
-
-    def setup_proxies(self):
-        self.proxy = self.add_proxy(self.model, BaseCashSlave.proxy_widgets)
-        self.date.set_text(str(datetime.date.today()))
-        self.proxy.update('value', currency(0))
-
-    #
-    # Kiwi handlers
-    #
-
-    def on_value__validate(self, widget, value):
-        zero = currency(0)
-        if value <= zero:
-            return ValidationError(_("Value cannot be zero or less than zero"))
-
-
-class RemoveCashSlave(BaseCashSlave):
-
-    def on_value__validate(self, widget, value):
-        if value <= currency(0):
-            return ValidationError(_("Value cannot be zero or less than zero"))
-        if value > self.model.balance:
-            return ValidationError(
-                _("Value cannot be more than the total Till balance"))
-
-
 class CashAdvanceEditor(BaseEditor):
     """An editor which extends BaseCashSlave to include.
     It extends BaseCashSlave to include an employee combobox
@@ -400,29 +374,22 @@ class CashAdvanceEditor(BaseEditor):
         self.attach_slave("base_cash_holder", self.cash_slave)
         self._setup_widgets()
 
-    def validate_confirm(self):
-        return self.cash_slave.validate_confirm()
-
     def on_confirm(self):
-        valid = self.cash_slave.on_confirm()
-        if valid:
-            till = self.model.till
-            value = abs(self.model.value)
-            assert till
-            try:
-                TillRemoveCashEvent.emit(till=till, value=value)
-            except (TillError, DeviceError, DriverError), e:
-                warning(str(e))
-                return None
-            till_entry = till.add_debit_entry(
-                value, (_(u'Cash advance paid to employee: %s') % (
-                self._get_employee_name(), )))
+        till = self.model.till
+        value = abs(self.model.value)
+        assert till
+        try:
+            TillRemoveCashEvent.emit(till=till, value=value)
+        except (TillError, DeviceError, DriverError), e:
+            warning(str(e))
+            self.retval = False
+            return
+        till_entry = till.add_debit_entry(
+            value, (_(u'Cash advance paid to employee: %s') % (
+            self._get_employee_name(), )))
 
-            TillAddTillEntryEvent.emit(till_entry, self.conn)
-            _create_transaction(self.conn, till_entry)
-            return self.model
-
-        return valid
+        TillAddTillEntryEvent.emit(till_entry, self.conn)
+        _create_transaction(self.conn, till_entry)
 
     #
     # Callbacks
@@ -466,29 +433,22 @@ class CashOutEditor(BaseEditor):
                                       self._on_cash_slave__value_changed)
         self.attach_slave("base_cash_holder", self.cash_slave)
 
-    def validate_confirm(self):
-        return self.cash_slave.validate_confirm()
-
     def on_confirm(self):
-        valid = self.cash_slave.on_confirm()
-        if valid:
-            value = abs(self.model.value)
-            till = self.model.till
-            assert till
-            try:
-                TillRemoveCashEvent.emit(till=till, value=value)
-            except (TillError, DeviceError, DriverError), e:
-                warning(str(e))
-                return None
+        value = abs(self.model.value)
+        till = self.model.till
+        assert till
+        try:
+            TillRemoveCashEvent.emit(till=till, value=value)
+        except (TillError, DeviceError, DriverError), e:
+            warning(str(e))
+            self.retval = False
+            return
 
-            till_entry = till.add_debit_entry(
-                value, (_(u'Cash out: %s') % (self.reason.get_text(), )))
+        till_entry = till.add_debit_entry(
+            value, (_(u'Cash out: %s') % (self.reason.get_text(), )))
 
-            TillAddTillEntryEvent.emit(till_entry, self.conn)
-            _create_transaction(self.conn, till_entry)
-            return till_entry
-
-        return valid
+        TillAddTillEntryEvent.emit(till_entry, self.conn)
+        _create_transaction(self.conn, till_entry)
 
     def _on_cash_slave__value_changed(self, entry):
         self.cash_slave.model.value = -abs(self.cash_slave.model.value)
@@ -525,27 +485,20 @@ class CashInEditor(BaseEditor):
         self.cash_slave = BaseCashSlave(self.conn, self.model)
         self.attach_slave("base_cash_holder", self.cash_slave)
 
-    def validate_confirm(self):
-        return self.cash_slave.validate_confirm()
-
     def on_confirm(self):
-        valid = self.cash_slave.on_confirm()
-        if valid:
-            till = self.model.till
-            assert till
-            try:
-                TillAddCashEvent.emit(till=till,
-                                      value=self.model.value)
-            except (TillError, DeviceError, DriverError), e:
-                warning(str(e))
-                return None
+        till = self.model.till
+        assert till
+        try:
+            TillAddCashEvent.emit(till=till,
+                                  value=self.model.value)
+        except (TillError, DeviceError, DriverError), e:
+            warning(str(e))
+            self.retval = False
+            return
 
-            till_entry = till.add_credit_entry(
-                self.model.value,
-                (_(u'Cash in: %s') % (self.reason.get_text(), )))
+        till_entry = till.add_credit_entry(
+            self.model.value,
+            (_(u'Cash in: %s') % (self.reason.get_text(), )))
 
-            TillAddTillEntryEvent.emit(till_entry, self.conn)
-            _create_transaction(self.conn, till_entry)
-            return till_entry
-
-        return valid
+        TillAddTillEntryEvent.emit(till_entry, self.conn)
+        _create_transaction(self.conn, till_entry)
