@@ -172,6 +172,8 @@ _bindings = [
      _("Search for paid bills")),
 
     # Pos application
+    ('app.pos.new_trade', '<Primary>t',
+     _("Start a new trade")),
     ('app.pos.till_open', '<Primary>F6',
      _("Open the till")),
     ('app.pos.till_close', '<Primary>F7',
@@ -304,6 +306,10 @@ _bindings = [
     # Sales application
     ('app.sales.search_sold_items_by_branch', '<Primary><Alt>a',
      _("Search for sold items by branch")),
+    ('app.sales.search_sales_by_payment', '',
+     _("Search for sales by payment method")),
+    ('app.sales.search_salesperson_sales', '',
+     _("Search for the total sales made by a salesperson")),
     ('app.sales.search_products', '<Primary><Alt>p',
      _("Search for products")),
     ('app.sales.search_services', '<Primary><Alt>s',
@@ -330,10 +336,14 @@ _bindings = [
      _("Show details for the selected sale")),
     ('app.sales.search_client_calls', '',
      _("Search for client calls")),
+    ('app.sales.search_credit_check_history', '',
+     _("Search for client credit check history")),
     # books search books: <Primary><Alt>B
     # books search publishers: <Primary><Alt>P
 
     # Stock application
+    ('app.stock.stock_decrease', '<Primary>m',
+     _("Create a stock decrease")),
     ('app.stock.new_receiving', '<Primary>r',
      _("Create a new receiving")),
     ('app.stock.transfer_product', '<Primary>t',
