@@ -64,9 +64,7 @@ class LoanItemSearch(SearchDialog):
                         position=SearchFilterPosition.TOP)
 
     def get_columns(self):
-        return [SearchColumn('id', title=_(u'#'), data_type=int,
-                             format='%03d'),
-                SearchColumn('loan_id', title=_(u'Loan'), data_type=int,
+        return [SearchColumn('loan_identifier', title=_(u'Loan'), data_type=int,
                              format='%03d', sorted=True),
                 SearchColumn('opened', title=_(u'Open date'),
                              data_type=datetime.date, visible=False),
@@ -130,11 +128,11 @@ class LoanSearch(SearchDialog):
         self.set_searchbar_labels(_('matching:'))
 
         # Date
-        date_filter = DateSearchFilter(_('Date:'))
-        self.add_filter(date_filter, columns=['expire_date', 'open_date'])
+        self.date_filter = DateSearchFilter(_('Date:'))
+        self.add_filter(self.date_filter, columns=['expire_date', 'open_date'])
 
     def get_columns(self):
-        return [Column('id', _('#'), data_type=int, width=50),
+        return [Column('identifier', _('#'), data_type=int, width=50),
                 Column('open_date', _('Open date'),
                        data_type=datetime.date, sorted=True, width=100),
                 Column('expire_date', _('Expire date'),
