@@ -28,6 +28,7 @@ from kiwi.ui.objectlist import Column
 from zope.interface import providedBy
 
 from stoqlib.api import api
+from stoqlib.database.orm import AND
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.parameter import ParameterData
@@ -54,7 +55,14 @@ class ParameterSearch(BaseEditor):
 
     def _setup_widgets(self):
         self.results.set_columns(self._get_columns())
-        self._parameters = ParameterData.select(connection=self.conn)
+        clause = AND(
+            # Do not allow this parameter to be used by general users for now
+            ParameterData.q.field_name != "ALLOW_TRADE_NOT_REGISTERED_SALES",
+            # FIXME: This isn't doing anything for now. Not showing
+            # on the search as it could confuse the users.
+            ParameterData.q.field_name != "RETURN_MONEY_ON_SALES",
+            )
+        self._parameters = ParameterData.select(clause, connection=self.conn)
         self._reset_results()
         self.edit_button.set_sensitive(False)
 
@@ -76,8 +84,7 @@ class ParameterSearch(BaseEditor):
         """Given a ParameterData object, returns a string representation of
         its current value.
         """
-        constant = sysparam(self.conn).get_parameter_constant(
-                                                        obj.field_name)
+        constant = sysparam(self.conn).get_parameter_constant(obj.field_name)
         data = getattr(sysparam(self.conn), obj.field_name)
         if isinstance(data, Domain):
             if not (IDescribable in providedBy(data)):
@@ -108,16 +115,15 @@ class ParameterSearch(BaseEditor):
 
     def _filter_results(self, text):
         query = text.lower()
+        self._reset_results()
+
         if not query:
-            self._reset_results()
+            # Nothing to look for
+            return
 
         for param in self._parameters:
-            if (query in param.get_group().lower() or
-                query in param.get_short_description().lower()):
-                if param not in self.results:
-                    self.results.append(param)
-            else:
-                if param in self.results:
+            if (query not in param.get_group().lower() and
+                query not in param.get_short_description().lower()):
                     self.results.remove(param)
 
     #
@@ -137,4 +143,5 @@ class ParameterSearch(BaseEditor):
         self._filter_results(widget.get_text())
 
     def on_show_all_button__clicked(self, widget):
+        self.entry.update('')
         self._reset_results()
