@@ -93,7 +93,7 @@ class EmployeeSearch(BasePersonSearch):
 
     def _get_role_values(self):
         items = [(role.name, role.name) for role in
-                 EmployeeRole.select()]
+                 EmployeeRole.select(connection=self.conn)]
         items.insert(0, (_('Any'), None))
         return items
 
@@ -108,7 +108,7 @@ class EmployeeSearch(BasePersonSearch):
         self.add_filter(status_filter, SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('name', _('Name'), str, expand=True),
+        return [SearchColumn('name', _('Name'), str, expand=True, sorted=True),
                 SearchColumn('role', _('Role'), str, width=225,
                              valid_values=self._get_role_values()),
                 SearchColumn('registry_number', _('Registry Number'), str),
@@ -187,7 +187,7 @@ class AbstractCreditProviderSearch(BasePersonSearch):
                              format_func=format_phone_number, width=130),
                 SearchColumn('short_name', _('Short Name'), str,
                              width=150),
-                SearchColumn('is_active', _('Active'), data_type=bool,
+                Column('is_active', _('Active'), data_type=bool,
                              editable=True),
                 SearchColumn('credit_fee', _('Credit Fee'), data_type=Decimal,
                              width=90, visible=False),
@@ -299,7 +299,7 @@ class TransporterSearch(BasePersonSearch):
                              data_type=str, sorted=True, expand=True),
                 SearchColumn('phone_number', _('Phone Number'), str,
                              format_func=format_phone_number, width=180),
-                SearchColumn('freight_percentage', _('Freight (%)'), float,
+                SearchColumn('freight_percentage', _('Freight (%)'), Decimal,
                              width=150)]
 
     def get_editor_model(self, model):
@@ -342,7 +342,7 @@ class BranchSearch(BasePersonSearch):
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['name', 'phone_number'])
+        self.set_text_field_columns(['name', 'acronym', 'phone_number'])
         statuses = [(value, key)
                     for key, value in Branch.statuses.items()]
         statuses.insert(0, (_('Any'), None))
@@ -354,7 +354,9 @@ class BranchSearch(BasePersonSearch):
         self.search.add_filter(status_filter, SearchFilterPosition.TOP)
 
     def get_columns(self):
-        return [SearchColumn('name', _('Name'), str, expand=True),
+        return [SearchColumn('name', _('Name'), str, expand=True, sorted=True),
+                SearchColumn('acronym', _('Acronym'), data_type=str,
+                             visible=False),
                 SearchColumn('phone_number', _('Phone Number'), str,
                              width=150),
                 SearchColumn('manager_name', _('Manager'), str,
