@@ -35,7 +35,7 @@ from kiwi.ui.objectlist import Column, ColoredColumn, SearchColumn
 from stoqlib.api import api
 from stoqlib.database.orm import AND
 from stoqlib.domain.person import Branch
-from stoqlib.domain.product import Product
+from stoqlib.domain.product import Product, ProductHistory
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import (ProductQuantityView,
                                   ProductFullStockItemView, SoldItemView,
@@ -148,6 +148,7 @@ class ProductSearch(SearchEditor):
         status_filter.select(None)
         self.add_filter(status_filter, columns=['status'],
                         position=SearchFilterPosition.TOP)
+        self.status_filter = status_filter
 
     #
     # SearchEditor Hooks
@@ -243,16 +244,19 @@ class ProductSearchQuantity(SearchDialog):
         # Date
         date_filter = DateSearchFilter(_('Date:'))
         date_filter.select(Today)
-        self.add_filter(date_filter, columns=['sold_date', 'received_date',
-                                              'production_date',
-                                              'decreased_date'])
+        columns = [ProductHistory.q.sold_date,
+                   ProductHistory.q.received_date,
+                   ProductHistory.q.production_date,
+                   ProductHistory.q.decreased_date]
+        self.add_filter(date_filter, columns=columns)
+        self.date_filter = date_filter
 
         # Branch
-        branch_filter = self.create_branch_filter(_('In branch:'))
-        self.add_filter(branch_filter, columns=['branch'],
+        self.branch_filter = self.create_branch_filter(_('In branch:'))
+        self.add_filter(self.branch_filter, columns=['branch'],
                         position=SearchFilterPosition.TOP)
         # remove 'Any' option from branch_filter
-        branch_filter.combo.remove_text(0)
+        self.branch_filter.combo.remove_text(0)
 
     #
     # SearchEditor Hooks
@@ -354,6 +358,9 @@ class ProductsSoldSearch(SearchDialog):
 class ProductStockSearch(SearchEditor):
     title = _('Product Stock Search')
     size = (800, 450)
+    # FIXME: This search needs another viewable, since ProductFullStockView
+    # cannot filter the branch of the purchase, when counting the number of
+    # purchased orders by branch
     table = search_table = ProductFullStockItemView
     editor_class = ProductStockEditor
     has_new_button = False
@@ -368,7 +375,7 @@ class ProductStockSearch(SearchEditor):
         difference_label = gtk.Label()
         difference_label.set_markup(
             "<small><b>%s</b></small>"
-            % api.escape(_(u"The DIFFERENCE column is equal "
+            % api.escape(_(u"The DIFFERENCE column is equal to "
                            "IN STOCK minus MINIMUM columns")))
         difference_label.show()
         self.search.search.pack_end(difference_label, False, False, 6)
