@@ -28,7 +28,7 @@ from decimal import Decimal
 
 import gtk
 from kiwi.currency import currency
-from kiwi.ui.objectlist import SearchColumn
+from kiwi.ui.objectlist import SearchColumn, Column
 
 from stoqlib.api import api
 from stoqlib.database.orm import AND
@@ -54,7 +54,7 @@ class SellableSearch(SearchEditor):
     searchbar_result_strings = (_('sale item'), _('sale items'))
 
     def __init__(self, conn, hide_footer=False, hide_toolbar=True,
-                 selection_mode=gtk.SELECTION_MULTIPLE, search_str=None,
+                 selection_mode=gtk.SELECTION_BROWSE, search_str=None,
                  sale_items=None, quantity=None, double_click_confirm=False,
                  info_message=None):
         """
@@ -146,8 +146,8 @@ class SellableSearch(SearchEditor):
                              data_type=str, visible=False),
                 SearchColumn('model', title=_('Model'),
                              data_type=str, visible=False),
-                SearchColumn('price', title=_('Price'), data_type=currency,
-                              justify=gtk.JUSTIFY_RIGHT, width=120),
+                Column('price', title=_('Price'), data_type=currency,
+                       justify=gtk.JUSTIFY_RIGHT, width=120),
                 SearchColumn('category_description', title=_('Category'),
                              data_type=str, visible=False),
                 AccessorColumn('stock', title=_(u'Stock'),
@@ -194,14 +194,12 @@ class SellableSearch(SearchEditor):
         # If we select a quantity which is not an integer, filter out
         # sellables without a unit set
         if self.quantity is not None and (self.quantity % 1) != 0:
-            queries.append(Sellable.q.unitID != None)
+            queries.append(Sellable.q.unit_id != None)
         branch = api.get_current_branch(conn)
         query = AND(*queries)
         return SellableFullStockView.select_by_branch(query, branch,
                                                       connection=conn)
 
     def _get_available_stock(self, sellable_view):
-        if sellable_view.stock is None:
-            return None
         return sellable_view.stock - self.current_sale_stock.get(
             sellable_view.id, 0)
