@@ -33,7 +33,7 @@ from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import SearchColumn
 
 from stoqlib.api import api
-from stoqlib.database.orm import INNERJOINOn, Viewable
+from stoqlib.database.orm import Join, Viewable
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.person import Branch
 from stoqlib.domain.payment.group import PaymentGroup
@@ -59,6 +59,7 @@ class TillFiscalOperationsView(Viewable):
 
     columns = dict(
         id=Payment.q.id,
+        identifier=Payment.q.identifier,
         date=Payment.q.open_date,
         description=Payment.q.description,
         value=Payment.q.value,
@@ -69,18 +70,18 @@ class TillFiscalOperationsView(Viewable):
         )
 
     joins = [
-        INNERJOINOn(None, Till,
-                    Till.q.id == Payment.q.tillID),
-        INNERJOINOn(None, BranchStation,
-                    BranchStation.q.id == Till.q.stationID),
-        INNERJOINOn(None, Branch,
-                    Branch.q.id == BranchStation.q.branchID),
-        INNERJOINOn(None, PaymentGroup,
-                    PaymentGroup.q.id == Payment.q.groupID),
-        INNERJOINOn(None, Sale,
-                    Sale.q.groupID == PaymentGroup.q.id),
-        INNERJOINOn(None, CfopData,
-                    CfopData.q.id == Sale.q.cfopID),
+        Join(Till,
+                    Till.q.id == Payment.q.till_id),
+        Join(BranchStation,
+                    BranchStation.q.id == Till.q.station_id),
+        Join(Branch,
+                    Branch.q.id == BranchStation.q.branch_id),
+        Join(PaymentGroup,
+                    PaymentGroup.q.id == Payment.q.group_id),
+        Join(Sale,
+                    Sale.q.group_id == PaymentGroup.q.id),
+        Join(CfopData,
+                    CfopData.q.id == Sale.q.cfop_id),
         ]
 
 
@@ -111,7 +112,7 @@ class TillFiscalOperationsSearch(SearchDialog):
                         columns=['status'])
 
     def get_columns(self, *args):
-        return [SearchColumn('id', title=_('#'), width=60,
+        return [SearchColumn('identifier', title=_('#'), width=60,
                              justify=gtk.JUSTIFY_RIGHT, format="%05d",
                              data_type=int, sorted=True),
                 SearchColumn('date', title=_('Date'), width=100,
