@@ -135,6 +135,9 @@ class _SaleConfirmationModel(_ConfirmationModel):
     def get_order_number(self):
         return self._sale.id
 
+    def get_identifier(self):
+        return self._sale.identifier
+
     def get_person_name(self):
         if self._sale.client:
             return self._sale.client.person.name
@@ -158,6 +161,9 @@ class _PurchaseConfirmationModel(_ConfirmationModel):
     def get_order_number(self):
         return self._purchase.id
 
+    def get_identifier(self):
+        return self._purchase.identifier
+
     def get_person_name(self):
         if self._purchase.supplier:
             return self._purchase.supplier.person.name
@@ -172,6 +178,9 @@ class _LonelyConfirmationModel(_ConfirmationModel):
     def get_order_number(self):
         return -1
 
+    def get_identifier(self):
+        return -1
+
     def get_person_name(self):
         return u"None"
 
@@ -206,7 +215,7 @@ class _InstallmentConfirmationSlave(BaseEditor):
     model_type = _ConfirmationModel
     size = (640, 420)
     title = _("Confirm payment")
-    proxy_widgets = ('order_number',
+    proxy_widgets = ('identifier',
                      'installment_value',
                      'interest',
                      'penalty',
@@ -243,7 +252,7 @@ class _InstallmentConfirmationSlave(BaseEditor):
     # Private
 
     def _get_columns(self):
-        return [Column('id', data_type=int, visible=False,
+        return [Column('identifier', _('#'), data_type=int, visible=False,
                        sorted=True),
                 Column('description', _("Description"), data_type=str),
                 Column('due_date', _("Due"), data_type=datetime.date),
@@ -319,7 +328,6 @@ class _InstallmentConfirmationSlave(BaseEditor):
             payment.pay(pay_date, payment.paid_value,
                         account=self.account.get_selected())
         self.model.confirm()
-        return True
 
     #
     # Callbacks
@@ -383,7 +391,7 @@ class SaleInstallmentConfirmationSlave(_InstallmentConfirmationSlave):
         _InstallmentConfirmationSlave._setup_widgets(self)
         self.order_label.hide()
         self.person_label.hide()
-        self.order_number.hide()
+        self.identifier.hide()
         self.person_name.hide()
         self.details_button.hide()
 
@@ -419,7 +427,7 @@ class PurchaseInstallmentConfirmationSlave(_InstallmentConfirmationSlave):
         if isinstance(self.model, _LonelyConfirmationModel):
             self.order_label.hide()
             self.person_label.hide()
-            self.order_number.hide()
+            self.identifier.hide()
             self.person_name.hide()
             self.details_button.hide()
 
