@@ -40,8 +40,9 @@ class SelectPaymentMethodSlave(GladeSlaveDelegate):
 
     def __init__(self, connection=None,
                  payment_type=None,
-                 methods=[],
+                 methods=None,
                  default_method=None):
+        methods = methods or []
         self._widgets = {}
         self._methods = {}
         self._selected_method = None
@@ -109,6 +110,10 @@ class SelectPaymentMethodSlave(GladeSlaveDelegate):
     def get_selected_method(self):
         return self._selected_method
 
+    def select_method(self, method_name):
+        widget = self._widgets[method_name]
+        widget.set_active(True)
+
     def method_set_sensitive(self, method_name, sensitive):
         if method_name in self._widgets:
             widget = self._widgets[method_name]
