@@ -47,17 +47,20 @@ from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
 from stoqlib.domain.person import CreditProvider
 from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.domain.returnedsale import ReturnedSale
 from stoqlib.domain.sale import Sale
 from stoqlib.drivers.cheque import get_current_cheque_printer_settings
 from stoqlib.enums import CreatePaymentStatus
+from stoqlib.exceptions import SellError
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave, BaseEditor
 from stoqlib.gui.interfaces import IDomainSlaveMapper
-from stoqlib.lib.defaults import (interval_types, INTERVALTYPE_MONTH,
-                                  DECIMAL_PRECISION)
+from stoqlib.lib.dateutils import (INTERVALTYPE_MONTH,
+                                   get_interval_type_items,
+                                   create_date_interval)
+from stoqlib.lib.defaults import DECIMAL_PRECISION
 from stoqlib.lib.message import info, warning
-from stoqlib.lib.payment import (generate_payments_values,
-                                          generate_payments_due_dates)
+from stoqlib.lib.payment import generate_payments_values
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -97,6 +100,9 @@ class _TemporaryPaymentData(object):
         self.payment_number = payment_number
         self.bank_account = bank_account
 
+    def __repr__(self):
+        return '<_TemporaryPaymentData>'
+
 
 class _TemporaryBankData(object):
     def __init__(self, bank_number=None, bank_branch=None, bank_account=None):
@@ -201,9 +207,10 @@ class PaymentListSlave(GladeSlaveDelegate):
     gladefile = 'PaymentListSlave'
     gsignal('payment-edited')
 
-    def __init__(self, payment_type, group, method, total_value,
+    def __init__(self, payment_type, group, branch, method, total_value,
                  editor_class, parent):
         self.parent = parent
+        self.branch = branch
         self.payment_type = payment_type
         self.group = group
         self.total_value = total_value
@@ -295,7 +302,7 @@ class PaymentListSlave(GladeSlaveDelegate):
         """Add a payment to the list"""
         payment = _TemporaryPaymentData(description,
                                         value,
-                                        due_date,
+                                        due_date.date(),
                                         payment_number,
                                         bank_account)
         self.payment_list.append(payment)
@@ -303,13 +310,14 @@ class PaymentListSlave(GladeSlaveDelegate):
         if refresh:
             self.update_view()
 
-    def add_payments(self, installments_number, first_due_date,
+    def add_payments(self, installments_number, start_date,
                      interval, interval_type):
         values = generate_payments_values(self.total_value,
                                           installments_number)
-        due_dates = generate_payments_due_dates(installments_number,
-                                                first_due_date, interval,
-                                                interval_type)
+        due_dates = create_date_interval(interval_type=interval_type,
+                                         interval=interval,
+                                         count=installments_number,
+                                         start_date=start_date)
         bank_account = None
 
         self.clear_payments()
@@ -339,6 +347,7 @@ class PaymentListSlave(GladeSlaveDelegate):
                                          p.due_date.day)
             payment = self.method.create_payment(payment_type=self.payment_type,
                                                  payment_group=self.group,
+                                                 branch=self.branch,
                                                  value=p.value,
                                                  due_date=due_date,
                                                  description=p.description,
@@ -452,6 +461,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
     def _setup_payment_list(self):
         self.payment_list = PaymentListSlave(self.payment_type,
                                              self.payment_group,
+                                             self.order.branch,
                                              self.method,
                                              self.total_value,
                                              self.data_editor_class,
@@ -473,9 +483,8 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         self.intervals.set_range(1, 99)
         self.intervals.set_sensitive(has_installments)
 
-        items = [(label, constant)
-                 for constant, label in interval_types.items()]
-        self.interval_type_combo.prefill(items)
+        interval_types = get_interval_type_items(plural=True)
+        self.interval_type_combo.prefill(interval_types)
         self.interval_type_combo.select_item_by_data(INTERVALTYPE_MONTH)
         self.interval_type_combo.set_sensitive(has_installments)
 
@@ -486,6 +495,8 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         """Returns the order total amount """
         if isinstance(self.order, Sale):
             return self.order.get_total_sale_amount()
+        elif isinstance(self.order, ReturnedSale):
+            return self.model.sale_total
         elif isinstance(self.order, PurchaseOrder):
             return self.order.get_purchase_total()
         elif isinstance(self.order, PaymentRenegotiation):
@@ -494,14 +505,13 @@ class BasePaymentMethodSlave(BaseEditorSlave):
             raise TypeError
 
     def _get_payment_type(self):
-        if isinstance(self.order, Sale):
+        if isinstance(self.order, (Sale, PaymentRenegotiation, ReturnedSale)):
             return Payment.TYPE_IN
         elif isinstance(self.order, PurchaseOrder):
             return Payment.TYPE_OUT
-        elif isinstance(self.order, PaymentRenegotiation):
-            return Payment.TYPE_IN
         else:
-            raise TypeError
+            raise TypeError("Could not guess payment type for %r" %
+                    (self.order, ))
 
     def _create_payments(self):
         """Insert the payment_list's payments in the base."""
@@ -660,10 +670,10 @@ class CardMethodSlave(BaseEditorSlave):
     def __init__(self, wizard, parent, conn, order, payment_method,
                  outstanding_value=currency(0), first_duedate=None,
                  installments_number=None):
-        self.model = order
+        self.order = order
         self.wizard = wizard
         self.method = payment_method
-        self._payment_group = self.model.group
+        self._payment_group = self.order.group
         self.total_value = (outstanding_value or
                             self._get_total_amount())
         self._selected_type = CreditCardData.TYPE_CREDIT
@@ -711,10 +721,12 @@ class CardMethodSlave(BaseEditorSlave):
     # Private
 
     def _get_total_amount(self):
-        if isinstance(self.model, Sale):
-            return self.model.get_total_sale_amount()
-        elif isinstance(self.model, PaymentRenegotiation):
-            return self.model.total
+        if isinstance(self.order, Sale):
+            return self.order.get_total_sale_amount()
+        elif isinstance(self.order, ReturnedSale):
+            return self.model.sale_total
+        elif isinstance(self.order, PaymentRenegotiation):
+            return self.order.total
         else:
             raise TypeError
 
@@ -763,8 +775,8 @@ class CardMethodSlave(BaseEditorSlave):
         else:
             minimum = 1
 
-        self.installments_number.set_range(minimum, maximum)
         self.installments_number.set_sensitive(maximum != 1)
+        self.installments_number.set_range(minimum, maximum)
 
     def _setup_payments(self):
         provider = self.model.provider
@@ -779,9 +791,11 @@ class CardMethodSlave(BaseEditorSlave):
 
         if isinstance(self._order, PurchaseOrder):
             payments = self.method.create_outpayments(self._payment_group,
-                                                     self.total_value, due_dates)
+                                                      self.order.branch,
+                                                      self.total_value, due_dates)
         else:
             payments = self.method.create_inpayments(self._payment_group,
+                                                     self.order.branch,
                                                      self.total_value, due_dates)
 
         operation = self.method.operation
@@ -789,7 +803,7 @@ class CardMethodSlave(BaseEditorSlave):
             data = operation.get_card_data_by_payment(payment)
             data.card_type = payment_type
             data.provider = provider
-            data.fee = provider.get_fee_for_payment(provider, data)
+            data.fee = provider.get_fee_for_payment(data)
             data.fee_value = data.fee * payment.value / 100
 
     #
@@ -840,7 +854,7 @@ class _MultipleMethodEditor(BaseEditor):
         #FIXME: We need to control how many payments could be created, since
         #       we are ignoring the payments created previously.
         payments = order.group.get_valid_payments().filter(
-                                        Payment.q.methodID == self._method.id)
+                                        Payment.q.method_id == self._method.id)
         max_installments = self._method.max_installments - payments.count()
         self.slave.installments_number.set_range(1, max_installments)
 
@@ -851,7 +865,6 @@ class _MultipleMethodEditor(BaseEditor):
 
     def on_cancel(self):
         self.conn.rollback_to_savepoint('before_payment_creation')
-        return False
 
 
 class MultipleMethodSlave(BaseEditorSlave):
@@ -860,11 +873,14 @@ class MultipleMethodSlave(BaseEditorSlave):
     model_type = object
 
     def __init__(self, wizard, parent, conn, order, payment_method,
-                 outstanding_value=currency(0), finish_on_total=True):
+                 outstanding_value=currency(0), finish_on_total=True,
+                 allow_remove_paid=True):
         """
         :param finish_on_total: finalize the payment when the total value is
                                 reached.
         """
+        self._has_modified_payments = False
+        self._allow_remove_paid = allow_remove_paid
         self.finish_on_total = finish_on_total
         # We need a temporary object to hold the value that will be read from
         # the user. We will set a proxy with this temporary object to help
@@ -880,6 +896,9 @@ class MultipleMethodSlave(BaseEditorSlave):
         self._total_value = self._outstanding_value
         self._setup_widgets()
 
+        self.register_validate_function(self._refresh_next)
+        self.force_validation()
+
     def setup_proxies(self):
         self._proxy = self.add_proxy(self._holder, ['base_value'])
 
@@ -887,13 +906,10 @@ class MultipleMethodSlave(BaseEditorSlave):
     # inheriting BasePaymentMethodSlave.
 
     def update_view(self):
-        # The user can only confirm the payments if there is no value left.
-        can_confirm = self.can_confirm()
-
-        self._wizard.refresh_next(can_confirm)
+        self.force_validation()
         # If this is a sale wizard, we cannot go back after payments have
         # started being created.
-        if len(self.payments) > 0:
+        if self._has_modified_payments:
             self._wizard.disable_back()
 
     def finish(self):
@@ -908,6 +924,8 @@ class MultipleMethodSlave(BaseEditorSlave):
     def _get_total_amount(self):
         if isinstance(self.model, Sale):
             return self.model.get_total_sale_amount()
+        elif isinstance(self.model, ReturnedSale):
+            return self.model.sale_total
         elif isinstance(self.model, PaymentRenegotiation):
             return self.model.total
         elif isinstance(self.model, PurchaseOrder):
@@ -921,7 +939,7 @@ class MultipleMethodSlave(BaseEditorSlave):
 
     def _setup_widgets(self):
         self.remove_button.hide()
-        if isinstance(self.model, (PaymentRenegotiation, Sale)):
+        if isinstance(self.model, (PaymentRenegotiation, Sale, ReturnedSale)):
             payment_type = Payment.TYPE_IN
         elif isinstance(self.model, PurchaseOrder):
             payment_type = Payment.TYPE_OUT
@@ -953,12 +971,12 @@ class MultipleMethodSlave(BaseEditorSlave):
         total value is already reached), and enables or disables the value
         entry and add button.
         """
-        self.base_value.set_sensitive(not self.can_confirm())
-        self.add_button.set_sensitive(not self.can_confirm())
+        can_add = self._outstanding_value != 0
+        for widget in [self.base_value, self.add_button]:
+            widget.set_sensitive(can_add)
 
     def _update_values(self):
-        payments = self.model.group.get_valid_payments()
-        total_payments = payments.sum('base_value') or Decimal(0)
+        total_payments = self.model.group.get_total_value()
         self._outstanding_value = self._total_value - total_payments
         self.toggle_new_payments()
 
@@ -973,23 +991,31 @@ class MultipleMethodSlave(BaseEditorSlave):
         self.base_value.grab_focus()
 
     def _update_missing_or_change_value(self):
+        # The total value may be less than total received.
+        value = self._get_missing_change_value(with_new_payment=True)
+        self.missing_value.update(abs(value))
+
+        if value > 0:
+            self.missing_change.set_text(_('Missing:'))
+        elif value < 0 and isinstance(self.model, ReturnedSale):
+            self.missing_change.set_text(_('Overpaid:'))
+        elif value < 0:
+            self.missing_change.set_text(_('Change:'))
+        else:
+            self.missing_change.set_text(_('Difference:'))
+
+    def _get_missing_change_value(self, with_new_payment=False):
         received = self.received_value.read()
         if received == ValueUnset:
             received = currency(0)
 
-        new_payment = self.base_value.read()
-        if new_payment == ValueUnset:
-            new_payment = currency(0)
+        if with_new_payment:
+            new_payment = self.base_value.read()
+            if new_payment == ValueUnset:
+                new_payment = currency(0)
+            received += new_payment
 
-        total_received = received + new_payment
-
-        # The total value may be less than total received.
-        value = self._total_value - total_received
-        self.missing_value.update(abs(value))
-        if value > 0:
-            self.missing_change.set_text(_(u'Missing:'))
-        else:
-            self.missing_change.set_text(_(u'Change:'))
+        return self._total_value - received
 
     def _get_columns(self):
         return [Column('description', title=_(u'Description'), data_type=str,
@@ -1014,6 +1040,13 @@ class MultipleMethodSlave(BaseEditorSlave):
                   payment_method.method_name == 'store_credit'):
                 return
 
+        if self.model.group.payer and payment_method.method_name == 'store_credit':
+            try:
+                self.model.client.can_purchase(payment_method,
+                                    self.model.client.remaining_store_credit)
+            except SellError:
+                return
+
         children = self.methods_box.get_children()
         if children:
             group = children[0]
@@ -1035,20 +1068,26 @@ class MultipleMethodSlave(BaseEditorSlave):
 
         payments = self.model.group.get_valid_payments()
         payment_count = payments.filter(
-            Payment.q.methodID == self._method.id).count()
+            Payment.q.method_id == self._method.id).count()
         if payment_count >= self._method.max_installments:
             info(_(u'You can not add more payments using the %s '
                    'payment method.') % self._method.description)
             return False
 
-        if self._method.method_name == 'store_credit':
-            client = self.model.client
-            credit = client.remaining_store_credit
-            total = self._holder.value
+        # If we are creaing out payments (PurchaseOrder) or the Sale does not
+        # have a client, assume all options available are creatable.
+        if isinstance(self.model, PurchaseOrder) or not self.model.client:
+            return True
 
-            if credit < total:
-                info(_(u"Client %s does not have enought credit left.") % \
-                     client.person.name)
+        method_values = {self._method: self._holder.value}
+        for i, payment in enumerate(self.model.group.payments.orderBy('id')):
+            method_values.setdefault(payment.method, 0)
+            method_values[payment.method] += payment.value
+        for method, value in method_values.items():
+            try:
+                self.model.client.can_purchase(method, value)
+            except SellError as e:
+                warning(str(e))
                 return False
 
         return True
@@ -1076,13 +1115,12 @@ class MultipleMethodSlave(BaseEditorSlave):
             if not self._method.method_name == 'money':
                 self._run_payment_editor()
 
+        self._has_modified_payments = True
+
         self._update_payment_list()
         # Exigência do TEF: Deve finalizar ao chegar no total da venda.
-        if self.finish_on_total and self._outstanding_value == 0:
+        if self.finish_on_total and self.can_confirm():
             self._wizard.finish()
-        # Keep update_view after force_validation, since it can disable
-        # next/finish even if validation is ok
-        self.force_validation()
         self.update_view()
 
     def _remove_payment(self, payment):
@@ -1090,6 +1128,8 @@ class MultipleMethodSlave(BaseEditorSlave):
             payment.group.remove_item(payment)
             Payment.delete(payment.id, connection=self.conn)
         elif payment.is_paid():
+            if not self._allow_remove_paid:
+                return
             entry = PaymentChangeHistory(payment=payment,
                              change_reason=_('Payment renegotiated'),
                              connection=self.conn)
@@ -1099,10 +1139,9 @@ class MultipleMethodSlave(BaseEditorSlave):
         else:
             payment.cancel()
 
+        self._has_modified_payments = True
+
         self._update_payment_list()
-        # Keep update_view after force_validation, since it can disable
-        # next/finish even if validation is ok
-        self.force_validation()
         self.update_view()
 
     def _setup_cash_payment(self):
@@ -1114,10 +1153,10 @@ class MultipleMethodSlave(BaseEditorSlave):
 
         if isinstance(self.model, PurchaseOrder):
             payment = self._method.create_outpayment(
-                self.model.group, payment_value)
+                self.model.group, self.model.branch, payment_value)
         else:
             payment = self._method.create_inpayment(
-                self.model.group, payment_value)
+                self.model.group, self.model.branch, payment_value)
         # We have to modify the payment, so the fiscal printer can calculate
         # and print the change.
         payment.base_value = self._holder.value
@@ -1130,13 +1169,18 @@ class MultipleMethodSlave(BaseEditorSlave):
         # rename the payments at runtime.
         self.payments.clear()
         payment_group = self.model.group
-        payments = payment_group.payments
-        npayments = payments.count()
+        payments = list(payment_group.payments.orderBy(Payment.q.id))
+        preview_payments = [p for p in payments if p.is_preview()]
+        len_preview_payments = len(preview_payments)
 
-        for i, payment in enumerate(payments.orderBy('id')):
-            description = payment.method.describe_payment(payment_group, i + 1,
-                                                          npayments)
-            payment.description = description
+        for payment in payments:
+            if payment.is_preview():
+                continue
+            self.payments.append(payment)
+
+        for i, payment in enumerate(preview_payments):
+            payment.description = payment.method.describe_payment(
+                payment_group, i + 1, len_preview_payments)
             self.payments.append(payment)
 
         self._update_values()
@@ -1151,6 +1195,9 @@ class MultipleMethodSlave(BaseEditorSlave):
                             self._holder.value)
         return retval
 
+    def _refresh_next(self, value):
+        self._wizard.refresh_next(value and self.can_confirm())
+
     #
     #   Public API
     #
@@ -1159,7 +1206,13 @@ class MultipleMethodSlave(BaseEditorSlave):
         self.remove_button.show()
 
     def can_confirm(self):
-        return self._outstanding_value == 0
+        if (isinstance(self.model, ReturnedSale) and
+            self._get_missing_change_value() != 0):
+            # ReturnedSale won't return change
+            return False
+
+        # The user can only confirm the payments if there is no value left.
+        return self.is_valid and self._outstanding_value == 0
 
     #
     # Callbacks
@@ -1177,14 +1230,34 @@ class MultipleMethodSlave(BaseEditorSlave):
         self._add_payment()
 
     def on_remove_button__clicked(self, button):
-        payments = self.payments.get_selected_rows()
-        for payment in payments:
-            if not payment.is_cancelled():
-                self._remove_payment(payment)
+        payment = self.payments.get_selected()
+        if not payment:
+            return
+        if payment.is_cancelled():
+            return
+
+        self._remove_payment(payment)
 
     def on_payments__selection_changed(self, objectlist, payment):
-        has_payments = len(objectlist) > 0
-        self.remove_button.set_sensitive(has_payments)
+        if not payment:
+            # Nothing selected
+            can_remove = False
+        elif not self._allow_remove_paid and payment.is_paid():
+            can_remove = False
+        elif (isinstance(self.model, PurchaseOrder) and
+              payment.payment_type == Payment.TYPE_IN):
+            # Do not allow to remove inpayments on orders, as only
+            # outpayments can be added
+            can_remove = False
+        elif (isinstance(self.model, (PaymentRenegotiation, Sale, ReturnedSale)) and
+              payment.payment_type == Payment.TYPE_OUT):
+            # Do not allow to remove outpayments on orders, as only
+            # inpayments can be added
+            can_remove = False
+        else:
+            can_remove = True
+
+        self.remove_button.set_sensitive(can_remove)
 
     def on_base_value__activate(self, entry):
         if self.add_button.get_sensitive():
@@ -1192,10 +1265,13 @@ class MultipleMethodSlave(BaseEditorSlave):
 
     def on_base_value__changed(self, entry):
         try:
-            entry.read()
+            value = entry.read()
         except ValidationError, e:
             self.add_button.set_sensitive(False)
             return e
+
+        self.add_button.set_sensitive(value and
+                                      value is not ValueUnset)
         self._update_missing_or_change_value()
 
     def on_base_value__validate(self, entry, value):
@@ -1214,9 +1290,13 @@ class MultipleMethodSlave(BaseEditorSlave):
         if not value and self._outstanding_value > 0:
             retval = ValidationError(_(u'You must provide a payment value.'))
 
+        if (self._method.method_name == 'store_credit' and
+                value > self.model.client.remaining_store_credit):
+            retval = ValidationError(_(u'Client does not have enough credit.'))
+
         self._holder.value = value
         self.toggle_new_payments()
-        if not self.can_confirm():
+        if self._outstanding_value != 0:
             self.add_button.set_sensitive(not bool(retval))
 
         return retval
