@@ -26,7 +26,7 @@
 
 import time
 
-import gobject
+import glib
 import gtk
 import pango
 import pangocairo
@@ -40,6 +40,9 @@ from stoqlib.lib.translation import stoqlib_gettext
 WIDTH = 400
 HEIGHT = 260
 BORDER = 8 # This includes shadow out border from GtkFrame
+_WINDOW_TIMEOUT = 100 # How often we should check if there are
+                      # other visible windows
+
 _ = stoqlib_gettext
 
 
@@ -47,6 +50,7 @@ class SplashScreen(gtk.Window):
 
     def __init__(self):
         gtk.Window.__init__(self)
+        self.set_name('SplashWindow')
         self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_SPLASHSCREEN)
         self.resize(WIDTH, HEIGHT)
         # Ubuntu has backported the 3.0 has-resize-grip property,
@@ -68,6 +72,16 @@ class SplashScreen(gtk.Window):
         pixbuf_data = environ.get_resource_string("stoq", "pixmaps", "splash.png")
         self._pixbuf = pixbuf_from_string(pixbuf_data)
 
+        gtk.timeout_add(_WINDOW_TIMEOUT, self._hide_splash_timeout)
+
+    def _hide_splash_timeout(self):
+        # Hide the splash screen as soon as there is another window
+        # created
+        if len(gtk.window_list_toplevels()) > 1:
+            self.destroy()
+            return False
+        return True
+
     def _get_label(self):
         info = get_utility(IAppInfo, None)
         if not info:
@@ -75,7 +89,7 @@ class SplashScreen(gtk.Window):
         version = info.get("version")
         if ' ' in version:
             ver, rev = version.split(' ')
-            version = '%s <b>%s</b>' % (ver, rev)
+            version = '%s <b>%s</b>' % (ver, glib.markup_escape_text(rev))
         return _("Version: %s") % (version, )
 
     def _draw_gi(self, cr):
@@ -131,10 +145,3 @@ def show_splash():
     global _splash
     _splash = SplashScreen()
     _splash.show()
-
-
-def hide_splash():
-    global _splash
-    if _splash:
-        gobject.idle_add(_splash.destroy)
-        _splash = None
