@@ -30,11 +30,12 @@ from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.slaves import NoteSlave
 from stoqlib.gui.databaseform import DatabaseForm
-from stoqlib.gui.editors.addresseditor import (AddressAdditionDialog,
-                                               AddressSlave)
+from stoqlib.gui.dialogs.addressdialog import AddressAdditionDialog
+from stoqlib.gui.dialogs.liaisondialog import LiaisonListDialog
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave, BaseEditor
 from stoqlib.gui.search.callsearch import CallsSearch
-from stoqlib.gui.slaves.liaisonslave import LiaisonListDialog
+from stoqlib.gui.search.creditcheckhistorysearch import CreditCheckHistorySearch
+from stoqlib.gui.slaves.addressslave import AddressSlave
 from stoqlib.gui.templates.companytemplate import CompanyEditorTemplate
 from stoqlib.gui.templates.individualtemplate import IndividualEditorTemplate
 from stoqlib.lib.message import warning
@@ -54,14 +55,15 @@ class _PersonEditorTemplate(BaseEditorSlave):
                      'mobile_number',
                      'email')
 
-    def __init__(self, conn, model, visual_mode, parent):
+    def __init__(self, conn, model, visual_mode, ui_form_name, parent):
         self._parent = parent
-        if self._parent.ui_form_name:
-            self.db_form = DatabaseForm(conn, self._parent.ui_form_name)
+        if ui_form_name:
+            self.db_form = DatabaseForm(conn, ui_form_name)
         else:
             self.db_form = None
-        super(self.__class__, self).__init__(conn, model,
-                                             visual_mode=visual_mode)
+
+        super(_PersonEditorTemplate, self).__init__(conn, model,
+                                                    visual_mode=visual_mode)
         self._check_new_person()
 
     def _check_new_person(self):
@@ -93,10 +95,8 @@ class _PersonEditorTemplate(BaseEditorSlave):
         self.attach_model_slave('note_holder', NoteSlave, self.model)
 
     def on_confirm(self):
-        self.address_slave.confirm()
         main_address = self.address_slave.model
         main_address.person = self.model
-        return self.model
 
     #
     # Public API
@@ -160,6 +160,10 @@ class _PersonEditorTemplate(BaseEditorSlave):
         run_dialog(CallsSearch, self._parent, self.conn,
                    person=self.model, reuse_transaction=self.is_new_person)
 
+    def on_credit_check_history_button__clicked(self, button):
+        run_dialog(CreditCheckHistorySearch, self._parent, self.conn,
+                   client=self.model.client, reuse_transaction=self.is_new_person)
+
     #
     # Private API
     #
@@ -194,6 +198,8 @@ class _PersonEditorTemplate(BaseEditorSlave):
         elif addresses > 2:
             self.address_button.set_label(_("%i More Addresses...")
                                             % (addresses - 1))
+        if not self.model.client:
+            self.credit_check_history_button.hide()
 
     def _setup_form_fields(self):
         if not self.db_form:
@@ -225,7 +231,7 @@ class BasePersonRoleEditor(BaseEditor):
     ui_form_name = None
 
     def __init__(self, conn, model=None, role_type=None, person=None,
-                 visual_mode=False):
+                 visual_mode=False, parent=None):
         """ Creates a new BasePersonRoleEditor object
 
         :param conn: a database connection
@@ -236,6 +242,7 @@ class BasePersonRoleEditor(BaseEditor):
         """
         if not (model or role_type is not None):
             raise ValueError('A role_type attribute is required')
+        self._parent = parent
         self.individual_slave = None
         self.company_slave = None
         self._person_slave = None
@@ -278,7 +285,8 @@ class BasePersonRoleEditor(BaseEditor):
         self._person_slave = _PersonEditorTemplate(self.conn,
                                                    self.model.person,
                                                    visual_mode=self.visual_mode,
-                                                   parent=self)
+                                                   ui_form_name=self.ui_form_name,
+                                                   parent=self._parent or self)
 
         if individual:
             slave = IndividualEditorTemplate(self.conn,
@@ -300,17 +308,9 @@ class BasePersonRoleEditor(BaseEditor):
         self.main_slave.attach_slave('main_holder', self._person_slave)
 
     def on_confirm(self):
-        if self.individual_slave and self.company_slave:
-            self.individual_slave.on_confirm()
-            self.company_slave.on_confirm(confirm_person=False)
-        elif self.individual_slave:
-            self.individual_slave.on_confirm()
-        else:
-            self.company_slave.on_confirm()
         if (isinstance(self.model, Supplier) and
             not sysparam(self.conn).SUGGESTED_SUPPLIER):
             sysparam(self.conn).SUGGESTED_SUPPLIER = self.model.id
-        return self.model
 
     #
     # Public API
