@@ -37,7 +37,7 @@ import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import SummaryLabel
-from kiwi.ui.objectlist import SearchColumn
+from kiwi.ui.objectlist import SearchColumn, Column
 from kiwi.python import Settable
 
 from stoqlib.api import api
@@ -53,6 +53,7 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.lists import AdditionListSlave
 from stoqlib.gui.base.wizards import WizardEditorStep
 from stoqlib.gui.editors.producteditor import ProductEditor
+from stoqlib.gui.events import WizardSellableItemStepEvent
 from stoqlib.lib.defaults import sort_sellable_code
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -126,8 +127,8 @@ class _SellableSearch(SearchEditor):
                                         data_type=Decimal, visible=False))
 
         if 'stock' in self._table.columns:
-            columns.append(SearchColumn('stock', title=_(u'In Stock'),
-                                        data_type=Decimal))
+            columns.append(Column('stock', title=_(u'In Stock'),
+                                  data_type=Decimal))
 
         return columns
 
@@ -141,14 +142,14 @@ class _SellableSearch(SearchEditor):
     def run_editor(self, obj=None):
         trans = api.new_transaction()
         product = self.run_dialog(self.editor_class, self, trans,
-                                 trans.get(obj))
+                                 trans.get(obj), visual_mode=self._read_only)
 
         # This means we are creating a new product. After that, add the
         # current supplier as the supplier for this product
         if (obj is None and product
             and not product.is_supplied_by(self._supplier)):
             ProductSupplierInfo(connection=trans,
-                                supplier=self._supplier,
+                                supplier=trans.get(self._supplier),
                                 product=product,
                                 base_cost=product.sellable.cost,
                                 is_main_supplier=True)
@@ -219,6 +220,7 @@ class SellableItemStep(WizardEditorStep):
     summary_label_column = 'total'
     sellable_view = ProductFullStockItemView
     sellable_editable = False
+    cost_editable = True
 
     def __init__(self, wizard, previous, conn, model):
         WizardEditorStep.__init__(self, conn, wizard, model, previous)
@@ -229,13 +231,24 @@ class SellableItemStep(WizardEditorStep):
         self._reset_sellable()
         self.cost.set_digits(sysparam(conn).COST_PRECISION_DIGITS)
         self.quantity.set_digits(3)
+        WizardSellableItemStepEvent.emit(self)
 
+    #
     # Public API
+    #
+
+    def hide_item_addition_toolbar(self):
+        self.item_table.hide()
 
     def hide_add_button(self):
         """Hides the add button
         """
-        self.slave.add_button.hide()
+        self.slave.hide_add_button()
+
+    def hide_del_button(self):
+        """Hides the del button
+        """
+        self.slave.hide_del_button()
 
     def hide_edit_button(self):
         """Hides the edit button
@@ -266,7 +279,13 @@ class SellableItemStep(WizardEditorStep):
         """
         return Sellable.get_unblocked_sellables_query(self.conn)
 
-    def get_order_item(self):
+    def get_order_item(self, sellable, value, quantity):
+        """Adds the sellable to the current model
+
+        This method is called when the user added the sellable in the wizard
+        step. Subclasses should implement this method to add the sellable to the
+        current model.
+        """
         raise NotImplementedError('This method must be defined on child')
 
     def get_saved_items(self):
@@ -326,7 +345,7 @@ class SellableItemStep(WizardEditorStep):
         self.add_sellable_button.set_sensitive(has_sellable)
         self.force_validation()
         self.quantity.set_sensitive(has_sellable)
-        self.cost.set_sensitive(has_sellable)
+        self.cost.set_sensitive(has_sellable and self.cost_editable)
 
     def validate(self, value):
         self.add_sellable_button.set_sensitive(value
@@ -429,9 +448,9 @@ class SellableItemStep(WizardEditorStep):
         self.quantity.grab_focus()
 
     def _get_sellable(self):
-        """This method always read the barcode and searches de datbase.
+        """This method always read the barcode and searches de database.
 
-        If you only need the currencly selected sellable, use
+        If you only need the current selected sellable, use
         self.proxy.model.sellable
         """
         barcode = self.barcode.get_text()
@@ -462,14 +481,21 @@ class SellableItemStep(WizardEditorStep):
         sellable = self.proxy.model.sellable
         assert sellable
 
-        self._update_list(sellable)
+        sellable = self.conn.get(sellable)
+
+        self.add_sellable(sellable)
         self.proxy.set_model(None)
         self.sellable_selected(None)
         self.barcode.grab_focus()
 
-    def _update_list(self, sellable):
+    def add_sellable(self, sellable):
+        """Add a sellable to the current step
+
+        This will call step.get_order_item to create the correct item for the
+        current model, and this created item will be returned.
+        """
         quantity = self.get_quantity()
-        cost = sellable.cost
+        cost = self.cost.read()
         item = self.get_order_item(sellable, cost, quantity)
         if item is None:
             return
@@ -481,6 +507,7 @@ class SellableItemStep(WizardEditorStep):
 
         self._update_total()
         self._reset_sellable()
+        return item
 
     def _reset_sellable(self):
         self.proxy.set_model(None)
