@@ -147,7 +147,7 @@ class ConsignmentItemSelectionStep(BaseWizardStep):
 
     def get_columns(self):
         return [
-            Column('order.id', title=_('Order'), width=60, data_type=int,
+            Column('order.identifier', title=_('Order'), width=60, data_type=int,
                    sorted=True),
             Column('sellable.code', title=_('Code'), width=70, data_type=str),
             Column('sellable.description', title=_('Description'),
@@ -260,6 +260,7 @@ class CloseConsignmentPaymentStep(BaseWizardStep):
 
 class ConsignmentWizard(PurchaseWizard):
     title = _("New Consignment")
+    help_section = None
 
     def __init__(self, conn, model=None):
         model = model or self._create_model(conn)
