@@ -51,6 +51,9 @@ from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.base.wizards import (WizardEditorStep, BaseWizard,
                                       BaseWizardStep)
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
+from stoqlib.gui.events import (NewLoanWizardFinishEvent,
+                                CloseLoanWizardFinishEvent,
+                                LoanItemSelectionStepEvent)
 from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.editors.personeditor import ClientEditor
 from stoqlib.gui.editors.loaneditor import LoanItemEditor
@@ -238,7 +241,7 @@ class LoanSelectionStep(BaseWizardStep):
         self.search.set_text_field_columns(['client_name'])
 
     def _get_columns(self):
-        return [SearchColumn('id', title=_('#'), sorted=True,
+        return [SearchColumn('identifier', title=_('#'), sorted=True,
                              data_type=int),
                 SearchColumn('responsible_name', title=_(u'Responsible'),
                              data_type=str, expand=True),
@@ -248,7 +251,7 @@ class LoanSelectionStep(BaseWizardStep):
                              data_type=datetime.date),
                 SearchColumn('expire_date', title=_(u'Expire'),
                              data_type=datetime.date),
-                SearchColumn('loaned', title=_(u'Loaned'),
+                Column('loaned', title=_(u'Loaned'),
                              data_type=Decimal),
         ]
 
@@ -264,7 +267,7 @@ class LoanSelectionStep(BaseWizardStep):
                                         restore_name=self.__class__.__name__)
         self.search.enable_advanced_search()
         self.attach_slave('place_holder', self.search)
-        self.executer = ORMObjectQueryExecuter()
+        self.executer = ORMObjectQueryExecuter(self.conn)
         self.search.set_query_executer(self.executer)
         self.executer.set_table(LoanView)
         self.executer.add_query_callback(self.get_extra_query)
@@ -306,6 +309,7 @@ class LoanItemSelectionStep(BaseWizardStep):
         BaseWizardStep.__init__(self, conn, wizard, previous)
         self._original_items = {}
         self._setup_widgets()
+        LoanItemSelectionStepEvent.emit(self)
 
     def _setup_widgets(self):
         self.loan_items.set_columns(self.get_columns())
@@ -331,7 +335,6 @@ class LoanItemSelectionStep(BaseWizardStep):
 
     def get_columns(self):
         return [
-            Column('id', title=_('#'), data_type=int, sorted=True),
             Column('sellable.code', title=_('Code'), width=70, data_type=str),
             Column('sellable.description', title=_('Description'),
                    data_type=str, expand=True, searchable=True),
@@ -382,12 +385,11 @@ class LoanItemSelectionStep(BaseWizardStep):
                 sale.add_sellable(item.sellable, quantity, item.price)
 
             sale.order()
+            self.wizard.created_sale = sale
             info(_("Close loan details..."),
                  _("A sale was created from loan items. You can confirm "
                    "that sale in the Till application later."))
 
-        self.wizard.finish()
-
     #
     # Kiwi Callbacks
     #
@@ -396,7 +398,8 @@ class LoanItemSelectionStep(BaseWizardStep):
         self.edit_button.set_sensitive(bool(item))
 
     def on_loan_items__row_activated(self, widget, item):
-        self._edit_item(item)
+        if self.edit_button.get_sensitive() and self.edit_button.get_visible():
+            self._edit_item(item)
 
     def on_edit_button__clicked(self, widget):
         item = self.loan_items.get_selected()
@@ -450,6 +453,7 @@ class NewLoanWizard(BaseWizard):
         self.model.sync_stock()
         self.retval = self.model
         self.close()
+        NewLoanWizardFinishEvent.emit(self.model)
         self._print_receipt(self.model)
 
 
@@ -459,6 +463,7 @@ class CloseLoanWizard(BaseWizard):
     help_section = 'loan'
 
     def __init__(self, conn):
+        self.created_sale = None
         first_step = LoanSelectionStep(self, conn)
         BaseWizard.__init__(self, conn, first_step, model=None,
                             title=self.title, edit_mode=False)
@@ -473,3 +478,4 @@ class CloseLoanWizard(BaseWizard):
             self.model.close()
         self.retval = self.model
         self.close()
+        CloseLoanWizardFinishEvent.emit(self.model, self.created_sale)
