@@ -118,7 +118,7 @@ class PurchaseFinishPaymentAdjustStep(WizardEditorStep):
             self.missing_label.set_label(_('Overpaid:'))
 
     def _get_columns(self):
-        return [Column('id', "#", data_type=int, width=50,
+        return [Column('identifier', "#", data_type=int, width=50,
                        format='%04d', justify=gtk.JUSTIFY_RIGHT),
                 Column('description', _("Description"), data_type=str,
                        width=150, expand=True,
@@ -219,14 +219,17 @@ class PurchaseFinishWizard(BaseWizard):
 
         for payment in payments:
             payment.set_pending()
+            yield payment
 
     def _create_return_payment(self):
         money = PaymentMethod.get_by_name(self.conn, 'money')
-        description = _('Return payment for order %s') % self.purchase.id
+        description = _('Money returned for order %s') % (
+                        self.purchase.get_order_number_str(), )
         value = currency(self.model.paid_value - self.model.received_value)
         today = datetime.date.today()
 
         payment = Payment(open_date=today,
+                          branch=self.purchase.branch,
                           description=description,
                           value=value,
                           base_value=value,
@@ -238,15 +241,20 @@ class PurchaseFinishWizard(BaseWizard):
                           connection=self.conn,
                           payment_type=Payment.TYPE_IN)
         payment.set_pending()
+        return payment
 
     def finish(self):
+        """  When finishing this wizard is necessary to check if the paid
+        value was less or more than the received value.
+        If the paid value was lesser than what was received is created
+        a new payment. Otherwise a return payment is created for the purchase.
+        """
         model = self.model
-        self.retval = model
 
         if model.paid_value < model.received_value:
-            self._confirm_new_payments()
+            self.retval = self._confirm_new_payments()
         else:
-            self._create_return_payment()
+            self.retval = self._create_return_payment()
         self.purchase.close()
 
         self.close()
