@@ -233,9 +233,19 @@ class PurchaseItemStep(SellableItemStep):
         self.wizard.refresh_next(can_purchase)
 
     def get_order_item(self, sellable, cost, quantity):
+        # Associate the product with the supplier if they are not yet. This
+        # happens when the user checked the option to show all products on the
+        # first step
+        supplier_info = self._get_supplier_info()
+        if not supplier_info:
+            supplier_info = ProductSupplierInfo(product=sellable.product,
+                                                supplier=self.model.supplier,
+                                                connection=self.conn)
+            supplier_info.base_cost = cost
+
         item = self.model.add_item(sellable, quantity)
         self._set_expected_receival_date(item)
-        item.cost = self.cost.read()
+        item.cost = cost
         return item
 
     def get_saved_items(self):
@@ -258,7 +268,7 @@ class PurchaseItemStep(SellableItemStep):
         return [
             Column('sellable.code', title=_('Code'), width=100, data_type=str),
             Column('sellable.description', title=_('Description'),
-                   data_type=str, width=250, searchable=True),
+                   data_type=str, width=250, searchable=True, expand=True),
             Column('sellable.category_description', title=_('Category'),
                    data_type=str, searchable=True, visible=False),
             Column('quantity', title=_('Quantity'), data_type=float, width=90,
@@ -283,7 +293,7 @@ class PurchaseItemStep(SellableItemStep):
 
     def next_step(self):
         if self.model.consigned:
-            return FinishPurchaseStep(self.wizard, self, self.conn, self.model)
+            return FinishPurchaseStep(self.conn, self.wizard, self.model, self)
         return PurchasePaymentStep(self.wizard, self, self.conn, self.model)
 
     #
@@ -394,8 +404,7 @@ class PurchasePaymentStep(WizardEditorStep):
         return self.slave.finish()
 
     def next_step(self):
-        return FinishPurchaseStep(self.wizard, self, self.conn,
-                                  self.order)
+        return FinishPurchaseStep(self.conn, self.wizard, self.order, self)
 
     def post_init(self):
         self.model.clear_unused()
@@ -423,13 +432,6 @@ class FinishPurchaseStep(WizardEditorStep):
                      'transporter',
                      'notes')
 
-    def __init__(self, wizard, previous, conn, model):
-        WizardEditorStep.__init__(self, conn, wizard, model, previous)
-
-        has_open_inventory = Inventory.has_open(self.conn,
-                                            api.get_current_branch(self.conn))
-        self.receive_now.set_sensitive(not bool(has_open_inventory))
-
     def _setup_transporter_entry(self):
         self.add_transporter.set_tooltip_text(_("Add a new transporter"))
         self.edit_transporter.set_tooltip_text(_("Edit the selected transporter"))
@@ -502,6 +504,12 @@ class FinishPurchaseStep(WizardEditorStep):
         self.force_validation()
 
     def setup_proxies(self):
+        # Avoid changing widget states in __init__, so that plugins have a
+        # chance to override the default settings
+        has_open_inventory = Inventory.has_open(self.conn,
+                                            api.get_current_branch(self.conn))
+        self.receive_now.set_sensitive(not bool(has_open_inventory))
+
         self._setup_transporter_entry()
         self.proxy = self.add_proxy(self.model, self.proxy_widgets)
 
@@ -549,7 +557,7 @@ class FinishPurchaseStep(WizardEditorStep):
 
 class PurchaseWizard(BaseWizard):
     size = (775, 400)
-    help_section = 'purchase'
+    help_section = 'purchase-new'
 
     def __init__(self, conn, model=None, edit_mode=False):
         title = self._get_title(model)
@@ -566,7 +574,6 @@ class PurchaseWizard(BaseWizard):
         first_step = StartPurchaseStep(self, conn, model)
         BaseWizard.__init__(self, conn, first_step, model, title=title,
                             edit_mode=edit_mode)
-        self.set_help_section("purchase-new")
 
     def _get_title(self, model=None):
         if not model:
@@ -599,11 +606,11 @@ class PurchaseWizard(BaseWizard):
         self.close()
 
 
-def test():
+def test():  # pragma nocover
     creator = api.prepare_test()
     retval = run_dialog(PurchaseWizard, None, creator.trans)
     api.finish_transaction(creator.trans, retval)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
