@@ -42,6 +42,7 @@ from stoqlib.gui.wizards.abstractwizard import SellableItemStep
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.sellableimage import SellableImageViewer
 from stoqlib.gui.editors.receivingeditor import ReceivingItemEditor
+from stoqlib.gui.events import ReceivingOrderWizardFinishEvent
 from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
 from stoqlib.domain.receiving import (ReceivingOrder, ReceivingOrderItem,
@@ -90,7 +91,7 @@ class PurchaseSelectionStep(BaseWizardStep):
         return PurchaseOrderView.q.status == PurchaseOrder.ORDER_CONFIRMED
 
     def _get_columns(self):
-        return [SearchColumn('id', title=_('Number'), sorted=True,
+        return [SearchColumn('identifier', title=_('Number'), sorted=True,
                              data_type=int, width=80),
                 SearchColumn('open_date', title=_('Date Started'),
                              data_type=datetime.date, width=100),
@@ -133,8 +134,8 @@ class PurchaseSelectionStep(BaseWizardStep):
         if not self.wizard.model:
             self.wizard.model = self.model = ReceivingOrder(
                 responsible=api.get_current_user(self.conn),
-                supplier=None, invoice_number=None,
-                branch=None, purchase=purchase,
+                supplier=purchase.supplier, invoice_number=None,
+                branch=purchase.branch, purchase=purchase,
                 connection=self.conn)
 
         # Remove all the items added previously, used if we hit back
@@ -267,11 +268,6 @@ class ReceivingOrderProductStep(SellableItemStep):
         self.register_validate_function(self._validate)
 
     def next_step(self):
-        # Remove the items that will not be received now.
-        for item in self.model.get_items():
-            if item.quantity == 0:
-                ReceivingOrderItem.delete(item.id, connection=self.conn)
-
         return ReceivingInvoiceStep(self.conn, self.wizard, self.model, self)
 
     def get_columns(self):
@@ -348,7 +344,7 @@ class ReceivingInvoiceStep(WizardEditorStep):
 class ReceivingOrderWizard(BaseWizard):
     title = _("Receiving Order")
     size = (750, 350)
-    help_section = 'purchase-new-receival'
+    #help_section = 'purchase-new-receival'
 
     def __init__(self, conn):
         self.model = None
@@ -364,6 +360,14 @@ class ReceivingOrderWizard(BaseWizard):
         assert self.model
         assert self.model.branch
 
+        # Remove the items that will not be received now.
+        for item in self.model.get_items():
+            if item.quantity > 0:
+                continue
+            ReceivingOrderItem.delete(item.id, connection=self.conn)
+
+        ReceivingOrderWizardFinishEvent.emit(self.model)
+
         self.retval = self.model
         self.model.confirm()
         self.close()
