@@ -189,10 +189,13 @@ class StartSaleQuoteStep(WizardEditorStep):
                    title=_("Additional Information"))
 
     def on_create_cfop__clicked(self, widget):
+        self.conn.savepoint('before_run_editor_cfop')
         cfop = run_dialog(CfopEditor, self.wizard, self.conn, None)
         if cfop:
             self.cfop.append_item(cfop.get_description(), cfop)
             self.cfop.select_item_by_data(cfop)
+        else:
+            self.conn.rollback_to_savepoint('before_run_editor_cfop')
 
 
 class SaleQuoteItemStep(SellableItemStep):
@@ -205,8 +208,8 @@ class SaleQuoteItemStep(SellableItemStep):
 
     def get_sellable_view_query(self):
         branch = api.get_current_branch(self.conn)
-        branch_query = OR(ProductStockItem.q.branchID == branch.id,
-                          ProductStockItem.q.branchID == None)
+        branch_query = OR(ProductStockItem.q.branch_id == branch.id,
+                          ProductStockItem.q.branch_id == None)
         return AND(branch_query,
                    Sellable.get_available_sellables_for_quote_query(self.conn))
 
@@ -253,7 +256,6 @@ class SaleQuoteItemStep(SellableItemStep):
             self.slave.clear_message()
 
     def get_order_item(self, sellable, price, quantity):
-        price = self.cost.read()
         retval = self._validate_sellable_price(price)
         if retval is None:
             item = self.model.add_sellable(sellable, quantity, price)
