@@ -42,7 +42,7 @@ from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
 from stoqlib.domain.sale import Sale
 from stoqlib.enums import CreatePaymentStatus
-from stoqlib.exceptions import StoqlibError
+from stoqlib.exceptions import SellError, StoqlibError
 from stoqlib.lib.message import warning, yesno, marker
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
@@ -128,36 +128,24 @@ class BaseMethodSelectionStep(object):
     and a cash_change_holder EventBox in the glade file
     """
 
-    def __init__(self, create_payment=True):
-        self._create_payment = create_payment
-
-        if not create_payment:
-            for widget in [
-                self.select_method_holder,
-                self.cash_change_holder,
-                self.subtotal_expander,
-                ]:
-                widget.hide()
-
     #
     #   Private API
     #
 
     def _update_next_step(self, method):
-        if not self._create_payment:
-            self.wizard.enable_finish()
-            return
-
         if method and method.method_name == 'money':
             self.wizard.enable_finish()
-            self.cash_change_slave.enable_cash_change()
+            if self.need_create_payment():
+                self.cash_change_slave.enable_cash_change()
+            else:
+                self.cash_change_slave.disable_cash_change()
         else:
             self.wizard.disable_finish()
             self.cash_change_slave.disable_cash_change()
 
     def _get_total_amount(self):
         if isinstance(self.model, Sale):
-            return self.model.get_total_sale_amount()
+            return self.model.get_total_to_pay()
         elif isinstance(self.model, PaymentRenegotiation):
             return self.model.total
         else:
@@ -167,18 +155,32 @@ class BaseMethodSelectionStep(object):
     #   Public API
     #
 
+    def need_create_payment(self):
+        # If the sale is already paid, we cannot let the user create more,
+        # or even edit the existing ones.
+        return self._get_total_amount() > 0
+
     def get_selected_method(self):
         return self.pm_slave.get_selected_method()
 
     def setup_cash_payment(self, total=None):
         money_method = PaymentMethod.get_by_name(self.conn, 'money')
         total = total or self._get_total_amount()
-        return money_method.create_inpayment(self.model.group, total)
+        return money_method.create_inpayment(self.model.group,
+                                             self.model.branch, total)
 
     #
     # WizardStep hooks
     #
 
+    def post_init(self):
+        if not self.need_create_payment():
+            for widget in [self.select_method_holder,
+                           self.subtotal_expander]:
+                widget.hide()
+
+        self._update_next_step(self.pm_slave.get_selected_method())
+
     def setup_slaves(self):
         marker('SelectPaymentMethodSlave')
         self.pm_slave = SelectPaymentMethodSlave(connection=self.conn,
@@ -193,7 +195,7 @@ class BaseMethodSelectionStep(object):
             'activate', lambda entry: self.wizard.go_to_next())
 
     def next_step(self):
-        if not self._create_payment:
+        if not self.need_create_payment():
             return
 
         selected_method = self.get_selected_method()
@@ -217,13 +219,9 @@ class BaseMethodSelectionStep(object):
             return None
         elif selected_method.method_name == 'store_credit':
             client = self.model.client
-            credit = client.remaining_store_credit
             total = self._get_total_amount()
 
-            if credit < total:
-                warning(_(u"Client %s does not have enought credit left.") % \
-                        client.person.name)
-                return self
+            assert client.can_purchase(selected_method, total)
 
             step_class = PaymentMethodStep
         elif selected_method.method_name == 'card':
@@ -241,7 +239,16 @@ class BaseMethodSelectionStep(object):
 
         # None means no one catched this event
         if retval is None or retval == CreatePaymentStatus.UNHANDLED:
-            return step_class(self.wizard, self, self.conn, self.model, selected_method)
+            # FIXME: We cannot send outstanding_value to multiple editor
+            # since if we have a trade going on, it will be calculated wrong
+            if selected_method.method_name == 'multiple':
+                outstanding_value = None
+            else:
+                outstanding_value = self._get_total_amount()
+
+            return step_class(self.wizard, self, self.conn, self.model,
+                              selected_method,
+                              outstanding_value=outstanding_value)
 
         # finish the wizard
         if retval == CreatePaymentStatus.SUCCESS:
@@ -268,6 +275,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
                      'subtotal_lbl',
                      'salesperson',
                      'client',
+                     'total_paid_lbl',
                      'transporter', )
 
     invoice_widgets = ('invoice_number', )
@@ -278,19 +286,11 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.invoice_model = invoice_model
 
         self.payment_group = payment_group
+
+        BaseMethodSelectionStep.__init__(self)
         marker("WizardEditorStep.__init__")
         WizardEditorStep.__init__(self, conn, wizard, model)
 
-        # If the sale already have payments and they match its total amount,
-        # we cannot let the user create more, or even edit the existing ones.
-        if (payment_group.payments.count() and
-            payment_group.get_total_value() == model.get_total_sale_amount()):
-            create_payment = False
-        else:
-            create_payment = True
-
-        marker("BaseMethodSelectionStep.__init__")
-        BaseMethodSelectionStep.__init__(self, create_payment)
         self.update_discount_and_surcharge()
 
     #
@@ -298,7 +298,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     #
 
     def _update_totals(self):
-        for field_name in ('total_sale_amount', 'sale_subtotal'):
+        for field_name in ['total_to_pay', 'total_paid', 'sale_subtotal']:
             self.proxy.update(field_name)
         self.cash_change_slave.update_total_sale_amount()
 
@@ -431,16 +431,23 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.invoice_model.original_invoice = new_invoice_number
         marker('Finished setting up widgets')
 
+    def _refresh_next(self, validation_value):
+        self.client.validate(force=True)
+        client_valid = self.client.is_valid()
+        self.wizard.refresh_next(validation_value and client_valid)
+
     #
     # WizardStep hooks
     #
 
     def post_init(self):
+        BaseMethodSelectionStep.post_init(self)
+
         marker('Entering post_init')
         self.toogle_client_details()
-        if self._create_payment:
+        if self.need_create_payment():
             self.wizard.payment_group.clear_unused()
-        self.register_validate_function(self.wizard.refresh_next)
+        self.register_validate_function(self._refresh_next)
         self._update_next_step(self.get_selected_method())
 
         if hasattr(self, 'cash_change_slave'):
@@ -497,6 +504,27 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     def on_client__changed(self, entry):
         self.toogle_client_details()
         self._update_widgets()
+        self.discount_slave.update_max_discount()
+
+    def on_payment_method_changed(self, slave, method_name):
+        self.client.validate(force=True)
+        self._update_next_step(method_name)
+
+    def on_client__validate(self, widget, client):
+        if not client:
+            return
+
+        # this is used to avoid some tests from crashing
+        if not hasattr(self, 'pm_slave'):
+            return
+
+        method = self.pm_slave.get_selected_method()
+        try:
+            client.can_purchase(method, self.model.get_total_sale_amount())
+            self.wizard.refresh_next(True)
+        except SellError as e:
+            self.wizard.refresh_next(False)
+            return ValidationError(e)
 
     def on_create_client__clicked(self, button):
         self._create_client()
@@ -514,16 +542,20 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
 
     def on_discount_slave_changed(self, slave):
         self._update_totals()
+        self.client.validate()
 
     def on_notes_button__clicked(self, *args):
         run_dialog(NoteEditor, self.wizard, self.conn, self.model, 'notes',
                    title=_("Additional Information"))
 
     def on_create_cfop__clicked(self, widget):
+        self.conn.savepoint('before_run_editor_cfop')
         cfop = run_dialog(CfopEditor, self.wizard, self.conn, None)
         if cfop:
             self.cfop.append_item(cfop.get_description(), cfop)
             self.cfop.select_item_by_data(cfop)
+        else:
+            self.conn.rollback_to_savepoint('before_run_editor_cfop')
 
     def on_invoice_number__validate(self, widget, value):
         if not 0 < value <= 999999999:
@@ -633,7 +665,7 @@ class ConfirmSaleWizard(BaseWizard):
             print_report(BillReport, bills)
 
 
-def test():
+def test():  # pragma nocover
     creator = api.prepare_test()
     sale_item = creator.create_sale_item()
     retval = run_dialog(ConfirmSaleWizard, None, creator.trans,
@@ -641,5 +673,5 @@ def test():
     api.finish_transaction(creator.trans, retval)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
