@@ -41,9 +41,10 @@ from stoqlib.domain.transfer import TransferOrder, TransferOrderItem
 from stoqlib.domain.views import ProductWithStockView
 from stoqlib.gui.base.columns import AccessorColumn
 from stoqlib.gui.base.wizards import (BaseWizard, BaseWizardStep)
+from stoqlib.gui.events import StockTransferWizardFinishEvent
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
-from stoqlib.lib.message import yesno
+from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 from stoqlib.reporting.transfer_receipt import TransferOrderReceipt
 
@@ -100,7 +101,7 @@ class StockTransferProductStep(SellableItemStep):
 
     def get_sellable_view_query(self):
         branch = api.get_current_branch(self.conn)
-        branch_query = ProductStockItem.q.branchID == branch.id
+        branch_query = ProductStockItem.q.branch_id == branch.id
         sellable_query = Sellable.get_unblocked_sellables_query(self.conn,
                                                                 storable=True)
         return AND(branch_query, sellable_query)
@@ -239,6 +240,15 @@ class StockTransferFinishStep(BaseWizardStep):
         self.transfer_order.source_branch = self.branch
         self.transfer_order.destination_branch = items[0][1]
 
+    def _validate_destination_branch(self):
+        other_branch = self.destination_branch.read()
+
+        if not self.branch.is_from_same_company(other_branch):
+            warning(_(u"Branches are not from the same CNPJ"))
+            return False
+
+        return True
+
     #
     # WizardStep hooks
     #
@@ -253,6 +263,12 @@ class StockTransferFinishStep(BaseWizardStep):
     def has_next_step(self):
         return False
 
+    def validate_step(self):
+        if not self._validate_destination_branch():
+            return False
+
+        return True
+
     #
     # Kiwi callbacks
     #
@@ -291,9 +307,7 @@ class StockTransferWizard(BaseWizard):
     def _receipt_dialog(self, order):
         msg = _('Would you like to print a receipt for this transfer?')
         if yesno(msg, gtk.RESPONSE_YES, _("Print receipt"), _("Don't print")):
-            items = TransferOrderItem.selectBy(transfer_order=order,
-                                               connection=self.conn)
-            print_report(TransferOrderReceipt, order, items)
+            print_report(TransferOrderReceipt, order)
         return
 
     def finish(self):
@@ -316,4 +330,5 @@ class StockTransferWizard(BaseWizard):
 
         self.retval = self.model
         self.close()
+        StockTransferWizardFinishEvent.emit(order)
         self._receipt_dialog(order)
