@@ -87,7 +87,7 @@ class SaleImporter(CSVImporter):
 
         sale.order()
         method = PaymentMethod.get_by_name(trans, data.payment_method)
-        method.create_inpayment(group, total_price,
+        method.create_inpayment(group, branch, total_price,
                                 self.parse_date(data.due_date))
         sale.confirm()
         #XXX: The payments are paid automatically when a sale is confirmed.
