@@ -29,7 +29,6 @@ import gettext
 import os
 
 from kiwi.component import provide_utility
-from stoqlib.database.interfaces import IDatabaseSettings
 from stoqlib.lib.interfaces import IStoqConfig
 from stoqlib.lib.osutils import get_application_dir
 from stoqlib.exceptions import (FilePermissionError,
@@ -189,11 +188,16 @@ class StoqConfig:
             username = self.get(database_section, 'dbusername') or username
             port = self.get(database_section, 'port') or port
 
-        # FIXME: This should be done elsewhere
-        from stoqlib.database.settings import DatabaseSettings
-        self._settings = DatabaseSettings(rdbms, address, port,
-                                dbname, username, password)
-        return self._settings
+        # FIXME: This and load_settings() needs to be simplified now when
+        #        we only have one global settings singleton
+        from stoqlib.database.settings import db_settings
+        db_settings.rdbms = rdbms or db_settings.rdbms
+        db_settings.address = address or db_settings.address
+        db_settings.port = port or db_settings.port
+        db_settings.dbname = dbname or db_settings.dbname
+        db_settings.username = username or db_settings.username
+        db_settings.password = password or db_settings.password
+        return db_settings
 
     def set_from_options(self, options):
         """
@@ -201,14 +205,19 @@ class StoqConfig:
         :param options: a optparse.Values instance
         """
 
+        from stoqlib.database.settings import db_settings
         if options.address:
             self.set('Database', 'address', options.address)
+            db_settings.address = options.address
         if options.port:
             self.set('Database', 'port', options.port)
+            db_settings.port = options.port
         if options.dbname:
             self.set('Database', 'dbname', options.dbname)
+            db_settings.dbname = options.dbname
         if options.username:
             self.set('Database', 'dbusername', options.username)
+            db_settings.username = options.username
         if options.password:
             self.store_password(options.password)
 
@@ -252,7 +261,6 @@ def register_config(config):
     _config = config
 
     try:
-        provide_utility(IDatabaseSettings, config.get_settings(), replace=True)
         provide_utility(IStoqConfig, config, replace=True)
     except NoConfigurationError:
         msg = _(u"Error: Stoq configuration is not avaiable. Check that the "
