@@ -47,6 +47,7 @@ class Console(object):
             self.ns[table.__name__] = table
 
         self.ns['conn'] = self.conn
+        self.ns['store'] = self.conn.store
         self.ns['trans'] = self.trans
         self.ns['sysparam'] = api.sysparam
         self.ns['api'] = api
@@ -57,8 +58,7 @@ class Console(object):
             self.ns['now'] = datetime.datetime.now
             self.ns['today'] = datetime.date.today
 
-            for name in ('sqlobject', 'sqlobject.sqlbuilder',
-                         'stoqlib.database.runtime',
+            for name in ('stoqlib.database.runtime',
                          'stoqlib.lib.interfaces',
                          'stoqlib.domain.interfaces'):
                 mod = __import__(name, {}, {}, ' ')
