@@ -26,12 +26,19 @@ import re
 from kiwi.currency import format_price
 
 from stoqlib.database.runtime import get_connection
+from stoqlib.l10n.l10n import get_l10n_field
+from stoqlib.lib.cardinals.cardinals import get_cardinal_function
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.defaults import DECIMAL_PRECISION, QUANTITY_PRECISION
 
 _ = stoqlib_gettext
 
 
+#
+#  Quantity/Percentage formatters
+#
+
+
 def format_quantity(quantity):
     if (quantity * 100 % 100) == 0:
         return '%.0f' % quantity
@@ -42,10 +49,22 @@ def get_formatted_percentage(value):
     return "%.*f %%" % (DECIMAL_PRECISION, value)
 
 
+#
+#  Price formatters
+#
+
+
 def get_price_format_str():
     return '%%.%sf' % DECIMAL_PRECISION
 
 
+def get_price_as_cardinal(value):
+    function = get_cardinal_function('to_words_as_money')
+    currency_names = get_l10n_field(get_connection(),
+                                    'currency_names')
+    return function(value, currency_names)
+
+
 def get_formatted_price(float_value, symbol=True, precision=DECIMAL_PRECISION):
     return format_price(float_value, symbol=symbol,
                         precision=precision)
@@ -58,6 +77,25 @@ def get_formatted_cost(float_value, symbol=True):
                                precision=precision)
 
 
+#
+#  Date formatters
+#
+
+
+def get_full_date(date):
+    """Return a date in it's full format taking l10n in consideration
+
+    For example, for Brazil, it will return something like:
+      01 de janeiro de 2012
+    In the generic case, it will return something like:
+      January 01, 2012
+
+    """
+    full_date_format = get_l10n_field(get_connection(),
+                                      "full_date_format")
+    return date.strftime(full_date_format)
+
+
 #
 #  Phone number formatters
 #
@@ -82,14 +120,14 @@ def format_phone_number(phone_number):
     elif digits == 9:
         return '(%s) %s-%s' % (phone[:2], phone[2:5], phone[5:9])
     elif digits == 10:
-        # 0[358]00 XXX-XXX
-        if phone[1] in '358':
+        # 0[3589]00 XXX-XXX
+        if phone[:4] in ['0300', '0500', '0800', '0900']:
             return '%s %s-%s' % (phone[:4], phone[4:7],
                                  phone[7:])
         return '(%s) %s-%s' % (phone[:2], phone[2:6], phone[6:10])
     elif digits == 11:
-        # 0[358]00 XXX-XXXX
-        if phone[1] in '358':
+        # 0[3589]00 XXX-XXX
+        if phone[:4] in ['0300', '0500', '0800', '0900']:
             return '%s %s-%s' % (phone[:4], phone[4:7],
                                  phone[7:])
         if phone[:1] == '0':
