@@ -36,6 +36,7 @@ from stoqdrivers.enum import TaxType
 from stoqlib.database.orm import ORMObjectNotFound
 from stoqlib.database.runtime import new_transaction, get_connection
 from stoqlib.domain.parameter import ParameterData
+from stoqlib.enums import LatePaymentPolicy
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.l10n.l10n import get_l10n_field
 from stoqlib.lib.barcode import BarcodeInfo
@@ -52,6 +53,17 @@ _ = stoqlib_gettext
 log = Logger('stoqlib.parameters')
 
 
+def _credit_limit_salary_changed(new_value, conn):
+    from stoqlib.domain.person import Client
+
+    old_value = sysparam(conn).CREDIT_LIMIT_SALARY_PERCENT
+    if new_value == old_value:
+        return
+
+    new_value = Decimal(new_value)
+    Client.update_credit_limit(new_value, conn)
+
+
 class DirectoryParameter(object):
     def __init__(self, path):
         self.path = path
@@ -60,7 +72,8 @@ class DirectoryParameter(object):
 class ParameterDetails(object):
     def __init__(self, key, group, short_desc, long_desc, type,
                  initial=None, options=None, combo_data=None, range=None,
-                 multiline=False, validator=None, onupgrade=None):
+                 multiline=False, validator=None, onupgrade=None,
+                 change_callback=None):
         self.key = key
         self.group = group
         self.short_desc = short_desc
@@ -75,6 +88,7 @@ class ParameterDetails(object):
         if onupgrade is None:
             onupgrade = initial
         self.onupgrade = onupgrade
+        self.change_callback = change_callback
 
     #
     #  Public API
@@ -89,6 +103,9 @@ class ParameterDetails(object):
     def get_parameter_validator(self):
         return self.validator or self._get_generic_parameter_validator()
 
+    def get_change_callback(self):
+        return self.change_callback
+
     #
     #  Staticmethods
     #
@@ -361,6 +378,15 @@ _details = [
           'the sales payment is paid.'),
         bool, initial=False),
 
+    ParameterDetails(
+        'ALLOW_TRADE_NOT_REGISTERED_SALES',
+        _("Sales"),
+        _("Allow trade not registered sales"),
+        _("If this is set to True, you will be able to trade products "
+          "from sales not registered on Stoq. Use this option only if "
+          "you need to trade itens sold on other stores."),
+        bool, initial=False),
+
     ParameterDetails(
         'DEFAULT_OPERATION_NATURE',
         _('Sales'),
@@ -393,6 +419,26 @@ _details = [
           'sale orders '),
         'fiscal.CfopData'),
 
+    ParameterDetails(
+        'TOLERANCE_FOR_LATE_PAYMENTS',
+        _('Sales'),
+        _('Tolerance for a payment to be considered as a late payment.'),
+        _('How many days Stoq should allow a client to not pay a late '
+          'payment without considering it late.'),
+        int, initial=0, range=(0, 365)),
+
+    ParameterDetails(
+        'LATE_PAYMENTS_POLICY',
+        _('Sales'),
+        _('Policy for customers with late payments.'),
+        _('How should Stoq behave when creating a new sale for a client with '
+          'late payments'),
+        int, initial=int(LatePaymentPolicy.ALLOW_SALES),
+        options={int(LatePaymentPolicy.ALLOW_SALES): _('Allow sales'),
+                 int(LatePaymentPolicy.DISALLOW_STORE_CREDIT):
+                    _('Allow sales except with store credit'),
+                 int(LatePaymentPolicy.DISALLOW_SALES): _('Disallow sales')}),
+
     ParameterDetails(
         'DEFAULT_RECEIVING_CFOP',
         _('Purchase'),
@@ -449,6 +495,17 @@ _details = [
         int, initial=16,
         validator=ParameterDetails.validate_area_code),
 
+    ParameterDetails(
+        'CREDIT_LIMIT_SALARY_PERCENT',
+        _('General'),
+        _("Client's credit limit automatic calculation"),
+        _("This is used to calculate the client's credit limit according"
+          "to the client's salary. If this percent is changed it will "
+          "automatically recalculate the credit limit for all clients."),
+        Decimal, initial=0, range=(0, 100),
+        validator=ParameterDetails.validate_percentage,
+        change_callback=_credit_limit_salary_changed),
+
     ParameterDetails(
         'DEFAULT_PRODUCT_TAX_CONSTANT',
         _('Sales'),
@@ -590,6 +647,24 @@ _details = [
           'disable this parameter.'),
         bool,
         initial=True),
+
+    ParameterDetails(
+        'LOCAL_BRANCH',
+        _('General'),
+        _('Current branch for this database'),
+        _('When operating with synchronized databases, this parameter will be '
+          'used to restrict the data that will be sent to this database.'),
+        'person.Branch'),
+
+    ParameterDetails(
+        'SYNCHRONIZED_MODE',
+        _('General'),
+        _('Synchronized mode operation'),
+        _('This parameter indicates if Stoq is operating with synchronized '
+          'databases. When using synchronized databases, some operations with '
+          'branches different than the current one will be restriced.'),
+        bool,
+        initial=False),
     ]
 
 
@@ -668,10 +743,11 @@ class ParameterAccess(ClassInittableObject):
         self._create_main_company()
         self._create_delivery_service()
         self._create_product_tax_constant()
+        self._create_current_branch()
 
     def _create_default_image(self):
-        key = "CUSTOM_LOGO_FOR_REPORTS"
         from stoqlib.domain.image import Image
+        key = "CUSTOM_LOGO_FOR_REPORTS"
         if self.get_parameter_by_field(key, Image):
             return
         self._set_schema(key, None)
@@ -684,8 +760,8 @@ class ParameterAccess(ClassInittableObject):
         self._set_schema(key, None)
 
     def _create_suggested_unit(self):
-        key = "SUGGESTED_UNIT"
         from stoqlib.domain.sellable import SellableUnit
+        key = "SUGGESTED_UNIT"
         if self.get_parameter_by_field(key, SellableUnit):
             return
         self._set_schema(key, None)
@@ -754,13 +830,21 @@ class ParameterAccess(ClassInittableObject):
         tax_constant = SellableTaxConstant.get_by_type(TaxType.NONE, self.conn)
         self._set_schema(key, tax_constant.id)
 
+    def _create_current_branch(self):
+        from stoqlib.domain.person import Branch
+        key = "LOCAL_BRANCH"
+        if self.get_parameter_by_field(key, Branch):
+            return
+
+        self._set_schema(key, None, is_editable=False)
+
     #
     # Public API
     #
 
     @argcheck(str, object)
     def update_parameter(self, parameter_name, value):
-        if parameter_name in ['DEMO_MODE']:
+        if parameter_name in ['DEMO_MODE', 'LOCAL_BRANCH', 'SYNCHRONIZED_MODE']:
             raise AssertionError
         param = get_parameter_by_field(parameter_name, self.conn)
         param.field_value = str(value)
@@ -779,7 +863,12 @@ class ParameterAccess(ClassInittableObject):
             # XXX: workaround to works with boolean types:
             data = param.field_value
             if value_type is bool:
-                data = int(data)
+                if data == 'True':
+                    data = True
+                elif data == 'False':
+                    data = False
+                else:
+                    data = bool(int(data))
             self._cache[param_name] = value_type(data)
             return
         table = value_type
