@@ -100,6 +100,9 @@ class UserSettings(object):
     def items(self):
         return self._root.items()
 
+    def reset(self):
+        self._root = {}
+
     def flush(self):
         data = json.dumps(self._root,
                           indent=2,
@@ -153,7 +156,11 @@ class UserSettings(object):
         log.info("Migrating settings from Stoq.conf")
 
         # Migrate from old configuration settings
-        config = get_utility(IStoqConfig)
+        try:
+            config = get_utility(IStoqConfig)
+        except NotImplementedError:
+            # For unittests, migrating jenkins from old to new settings
+            return
 
         self.set('hide-demo-warning',
                  config.get('UI', 'hide_demo_warning') == 'True')
@@ -189,7 +196,7 @@ def get_settings():
         _settings = UserSettings()
     return _settings
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     s = UserSettings()
     columns = s.get('list-columns', [])
     columns.append({})
