@@ -26,7 +26,7 @@ import datetime
 import os
 import tempfile
 
-from twisted.trial import unittest
+import unittest
 
 import stoqlib
 from stoqlib.api import api
@@ -87,7 +87,7 @@ class TestBank(DomainTest):
         self.add_product(sale)
         sale.order()
         self.payment = self.add_payments(sale, method_type='bill',
-                                         date=datetime.date(2011, 5, 30))
+                                         date=datetime.date(2011, 5, 30))[0]
         sale.client = self.create_client()
         address = self.create_address()
         address.person = sale.client.person
