@@ -79,7 +79,7 @@ class TestSintegraGenerator(DomainTest):
         sale.order()
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
-        method.create_inpayment(sale.group,
+        method.create_inpayment(sale.group, sale.branch,
                                 sale.get_sale_subtotal())
 
         sale.confirm()
