@@ -810,7 +810,7 @@ class BillReport(object):
             line = line.replace('$DATE', payment.due_date.strftime('%d/%m/%Y'))
             instructions.append(line)
 
-        instructions.append('\n' + _('Stoq Retail Managment') + ' - www.stoq.com.br')
+        instructions.append('\n' + _('Stoq Retail Management') + ' - www.stoq.com.br')
         return instructions
 
     def _get_demonstrativo(self):
@@ -868,8 +868,9 @@ class BillReport(object):
             data_vencimento=payment.due_date.date(),
             data_documento=payment.open_date.date(),
             data_processamento=self.today,
-            nosso_numero=str(payment.id),
-            numero_documento=str(payment.id),
+            # FIXME: Maybe we should add the branch id to this numbers
+            nosso_numero=str(payment.identifier),
+            numero_documento=str(payment.identifier),
             sacado=self._get_sacado(),
             cedente=self._get_cedente(),
             demonstrativo=self._get_demonstrativo(),
