@@ -254,7 +254,6 @@ class SalesPersonReport(SearchResultsReport):
                  *args, **kwargs):
         branch = get_current_branch(get_connection()).get_description()
         self.payments_list = payments_list
-
         if salesperson_name:
             singular = _("payment for {salesperson} on branch {branch}").format(
                          salesperson=salesperson_name, branch=branch)
@@ -274,7 +273,7 @@ class SalesPersonReport(SearchResultsReport):
         self._setup_sales_person_table()
 
     def _get_columns(self):
-        columns = [OTC(_("Sale"), lambda obj: obj.id, width=80)]
+        columns = [OTC(_("Sale"), lambda obj: obj.identifier, width=80)]
         if self._sales_person is None:
             columns.append(OTC(_("Name"), lambda obj: obj.salesperson_name,
                            expand=True, truncate=True))
