@@ -29,7 +29,7 @@ import os
 import tempfile
 import sys
 
-from twisted.trial.unittest import SkipTest
+from nose.exc import SkipTest
 
 from stoqlib.database.runtime import get_current_station
 from stoqlib.database.runtime import get_current_branch
@@ -45,7 +45,6 @@ from stoqlib.domain.service import ServiceView
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.till import Till, TillEntry
 from stoqlib.domain.views import ProductFullStockView
-from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.lib.parameters import sysparam
 from stoqlib.reporting import tests
 from stoqlib.reporting.payments_receipt import (InPaymentReceipt,
@@ -63,24 +62,8 @@ from stoqlib.reporting.till import TillHistoryReport
 from stoqlib.lib.diffutils import diff_pdf_htmls
 from stoqlib.lib.pdf import pdftohtml
 
-_search_restore_columns = StoqlibSearchSlaveDelegate.restore_columns
-
 
 class TestReport(DomainTest):
-
-    def setUp(self):
-        super(TestReport, self).setUp()
-
-        # Some tests in here use searchs to populate the report. Avoid
-        # restoring the cache, if any, or we will have inexplicable diff.
-        StoqlibSearchSlaveDelegate.restore_columns = lambda s: None
-
-    def tearDown(self):
-        super(TestReport, self).tearDown()
-
-        # Restore original restore_columns, to avoid breaking other tests
-        StoqlibSearchSlaveDelegate.restore_columns = _search_restore_columns
-
     def checkPDF(self, report_class, *args, **kwargs):
         frame = sys._getframe(1)
         basename = frame.f_code.co_name[4:]
@@ -163,7 +146,8 @@ class TestReport(DomainTest):
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
         group = self.create_payment_group()
-        payment = method.create_inpayment(group, Decimal(100))
+        branch = self.create_branch()
+        payment = method.create_inpayment(group, branch, Decimal(100))
         payment.description = "Test receivable account"
         payment.group.payer = payer.person
         payment.set_pending()
@@ -180,7 +164,8 @@ class TestReport(DomainTest):
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
         group = self.create_payment_group()
-        payment = method.create_outpayment(group, Decimal(100))
+        branch = self.create_branch()
+        payment = method.create_outpayment(group, branch, Decimal(100))
         payment.description = "Test payable account"
         payment.group.recipient = drawee.person
         payment.set_pending()
@@ -190,16 +175,6 @@ class TestReport(DomainTest):
 
         self.checkPDF(OutPaymentReceipt, payment, order=None, date=date)
 
-    def testTransferOrderReceipt(self):
-        raise SkipTest('Issues with pdftohtml version.')
-
-        from stoqlib.domain.transfer import TransferOrder, TransferOrderItem
-        from stoqlib.reporting.transfer_receipt import TransferOrderReceipt
-        orders = list(TransferOrder.select(connection=self.trans))
-        items = TransferOrderItem.selectBy(transfer_order=orders[0],
-                                           connection=self.trans)
-        self.checkPDF(TransferOrderReceipt, orders[0], items)
-
     def testProductReport(self):
         from stoqlib.gui.search.productsearch import ProductSearch
         search = ProductSearch(self.trans)
@@ -225,24 +200,30 @@ class TestReport(DomainTest):
         sellable = self.create_sellable()
         sale.add_sellable(sellable, price=100)
         method = PaymentMethod.get_by_name(self.trans, 'bill')
-        payment = method.create_inpayment(sale.group, Decimal(100))
-        TillEntry(value=25, id=20,
+        payment = method.create_inpayment(sale.group, sale.branch, Decimal(100))
+        TillEntry(value=25,
+                  identifier=20,
                   description="Cash In",
                   payment=None,
                   till=till,
+                  branch=till.station.branch,
                   date=datetime.date(2007, 1, 1),
                   connection=self.trans)
-        TillEntry(value=-5, id=21,
+        TillEntry(value=-5,
+                  identifier=21,
                   description="Cash Out",
                   payment=None,
                   till=till,
+                  branch=till.station.branch,
                   date=datetime.date(2007, 1, 1),
                   connection=self.trans)
 
-        TillEntry(value=100, id=22,
+        TillEntry(value=100,
+                  identifier=22,
                   description=sellable.get_description(),
                   payment=payment,
                   till=till,
+                  branch=till.station.branch,
                   date=datetime.date(2007, 1, 1),
                   connection=self.trans)
         till_entry = list(TillEntry.selectBy(connection=self.trans, till=till))
@@ -280,15 +261,18 @@ class TestReport(DomainTest):
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
         till = Till.get_last_opened(self.trans)
-        method.create_inpayment(sale.group,
+        method.create_inpayment(sale.group, sale.branch,
                                 sale.get_sale_subtotal(),
                                 till=till)
         sale.confirm()
         sale.set_paid()
 
         salesperson_name = salesperson.person.name
-        commissions = CommissionView.select(connection=self.trans)
-        self.checkPDF(SalesPersonReport, list(commissions), salesperson_name,
+        commissions = list(CommissionView.select(connection=self.trans))
+        commissions[0].identifier = 1
+        commissions[1].identifier = 139
+
+        self.checkPDF(SalesPersonReport, commissions, salesperson_name,
                       date=datetime.date(2007, 1, 1))
 
     def testSaleOrderReport(self):
